@@ -8,15 +8,15 @@
 
 #include <algorithm>
 #include <map>
+#include <memory>
 #include <unordered_map>
 #include <utility>
 
 #include "apps/saved_files_service_factory.h"
-#include "base/memory/ptr_util.h"
 #include "base/value_conversions.h"
-#include "chrome/browser/chrome_notification_types.h"
-#include "chrome/browser/profiles/profile.h"
+#include "content/public/browser/browser_context.h"
 #include "content/public/browser/notification_service.h"
+#include "extensions/browser/api/file_system/saved_file_entry.h"
 #include "extensions/browser/extension_host.h"
 #include "extensions/browser/extension_prefs.h"
 #include "extensions/browser/extension_system.h"
@@ -31,6 +31,7 @@ using extensions::APIPermission;
 using extensions::Extension;
 using extensions::ExtensionHost;
 using extensions::ExtensionPrefs;
+using extensions::SavedFileEntry;
 
 namespace {
 
@@ -61,14 +62,12 @@ void AddSavedFileEntry(ExtensionPrefs* prefs,
                        const SavedFileEntry& file_entry) {
   ExtensionPrefs::ScopedDictionaryUpdate update(
       prefs, extension_id, kFileEntries);
-  base::DictionaryValue* file_entries = update.Get();
-  if (!file_entries)
-    file_entries = update.Create();
+  auto file_entries = update.Create();
   DCHECK(!file_entries->GetDictionaryWithoutPathExpansion(file_entry.id, NULL));
 
   std::unique_ptr<base::DictionaryValue> file_entry_dict =
-      base::MakeUnique<base::DictionaryValue>();
-  file_entry_dict->Set(kFileEntryPath, CreateFilePathValue(file_entry.path));
+      std::make_unique<base::DictionaryValue>();
+  file_entry_dict->SetKey(kFileEntryPath, CreateFilePathValue(file_entry.path));
   file_entry_dict->SetBoolean(kFileEntryIsDirectory, file_entry.is_directory);
   file_entry_dict->SetInteger(kFileEntrySequenceNumber,
                               file_entry.sequence_number);
@@ -82,9 +81,9 @@ void UpdateSavedFileEntry(ExtensionPrefs* prefs,
                           const SavedFileEntry& file_entry) {
   ExtensionPrefs::ScopedDictionaryUpdate update(
       prefs, extension_id, kFileEntries);
-  base::DictionaryValue* file_entries = update.Get();
+  auto file_entries = update.Get();
   DCHECK(file_entries);
-  base::DictionaryValue* file_entry_dict = NULL;
+  std::unique_ptr<prefs::DictionaryValueUpdate> file_entry_dict;
   file_entries->GetDictionaryWithoutPathExpansion(file_entry.id,
                                                   &file_entry_dict);
   DCHECK(file_entry_dict);
@@ -98,16 +97,14 @@ void RemoveSavedFileEntry(ExtensionPrefs* prefs,
                           const std::string& file_entry_id) {
   ExtensionPrefs::ScopedDictionaryUpdate update(
       prefs, extension_id, kFileEntries);
-  base::DictionaryValue* file_entries = update.Get();
-  if (!file_entries)
-    file_entries = update.Create();
+  auto file_entries = update.Create();
   file_entries->RemoveWithoutPathExpansion(file_entry_id, NULL);
 }
 
 // Clears all SavedFileEntry for the app from ExtensionPrefs.
 void ClearSavedFileEntries(ExtensionPrefs* prefs,
                            const std::string& extension_id) {
-  prefs->UpdateExtensionPref(extension_id, kFileEntries, NULL);
+  prefs->UpdateExtensionPref(extension_id, kFileEntries, nullptr);
 }
 
 // Returns all SavedFileEntries for the app.
@@ -145,20 +142,9 @@ std::vector<SavedFileEntry> GetSavedFileEntries(
 
 }  // namespace
 
-SavedFileEntry::SavedFileEntry() : is_directory(false), sequence_number(0) {}
-
-SavedFileEntry::SavedFileEntry(const std::string& id,
-                               const base::FilePath& path,
-                               bool is_directory,
-                               int sequence_number)
-    : id(id),
-      path(path),
-      is_directory(is_directory),
-      sequence_number(sequence_number) {}
-
 class SavedFilesService::SavedFiles {
  public:
-  SavedFiles(Profile* profile, const std::string& extension_id);
+  SavedFiles(content::BrowserContext* context, const std::string& extension_id);
   ~SavedFiles();
 
   void RegisterFileEntry(const std::string& id,
@@ -177,7 +163,7 @@ class SavedFilesService::SavedFiles {
 
   void LoadSavedFileEntriesFromPreferences();
 
-  Profile* profile_;
+  content::BrowserContext* context_;
   const std::string extension_id_;
 
   // Contains all file entries that have been registered, keyed by ID.
@@ -193,41 +179,28 @@ class SavedFilesService::SavedFiles {
 };
 
 // static
-SavedFilesService* SavedFilesService::Get(Profile* profile) {
-  return SavedFilesServiceFactory::GetForProfile(profile);
+SavedFilesService* SavedFilesService::Get(content::BrowserContext* context) {
+  return SavedFilesServiceFactory::GetForBrowserContext(context);
 }
 
-SavedFilesService::SavedFilesService(Profile* profile) : profile_(profile) {
+SavedFilesService::SavedFilesService(content::BrowserContext* context)
+    : context_(context) {
   registrar_.Add(this,
                  extensions::NOTIFICATION_EXTENSION_HOST_DESTROYED,
                  content::NotificationService::AllSources());
-  registrar_.Add(this,
-                 chrome::NOTIFICATION_APP_TERMINATING,
-                 content::NotificationService::AllSources());
 }
 
-SavedFilesService::~SavedFilesService() {}
+SavedFilesService::~SavedFilesService() = default;
 
 void SavedFilesService::Observe(int type,
                                 const content::NotificationSource& source,
                                 const content::NotificationDetails& details) {
-  switch (type) {
-    case extensions::NOTIFICATION_EXTENSION_HOST_DESTROYED: {
-      ExtensionHost* host = content::Details<ExtensionHost>(details).ptr();
-      const Extension* extension = host->extension();
-      if (extension) {
-        ClearQueueIfNoRetainPermission(extension);
-        Clear(extension->id());
-      }
-      break;
-    }
-
-    case chrome::NOTIFICATION_APP_TERMINATING: {
-      // Stop listening to NOTIFICATION_EXTENSION_HOST_DESTROYED in particular
-      // as all extension hosts will be destroyed as a result of shutdown.
-      registrar_.RemoveAll();
-      break;
-    }
+  DCHECK_EQ(extensions::NOTIFICATION_EXTENSION_HOST_DESTROYED, type);
+  ExtensionHost* host = content::Details<ExtensionHost>(details).ptr();
+  const Extension* extension = host->extension();
+  if (extension) {
+    ClearQueueIfNoRetainPermission(extension);
+    Clear(extension->id());
   }
 }
 
@@ -248,7 +221,7 @@ std::vector<SavedFileEntry> SavedFilesService::GetAllFileEntries(
   SavedFiles* saved_files = Get(extension_id);
   if (saved_files)
     return saved_files->GetAllFileEntries();
-  return GetSavedFileEntries(ExtensionPrefs::Get(profile_), extension_id);
+  return GetSavedFileEntries(ExtensionPrefs::Get(context_), extension_id);
 }
 
 bool SavedFilesService::IsRegistered(const std::string& extension_id,
@@ -271,10 +244,16 @@ void SavedFilesService::ClearQueueIfNoRetainPermission(
 }
 
 void SavedFilesService::ClearQueue(const extensions::Extension* extension) {
-  ClearSavedFileEntries(ExtensionPrefs::Get(profile_), extension->id());
+  ClearSavedFileEntries(ExtensionPrefs::Get(context_), extension->id());
   Clear(extension->id());
 }
 
+void SavedFilesService::OnApplicationTerminating() {
+  // Stop listening to NOTIFICATION_EXTENSION_HOST_DESTROYED in particular
+  // as all extension hosts will be destroyed as a result of shutdown.
+  registrar_.RemoveAll();
+}
+
 SavedFilesService::SavedFiles* SavedFilesService::Get(
     const std::string& extension_id) const {
   auto it = extension_id_to_saved_files_.find(extension_id);
@@ -291,7 +270,7 @@ SavedFilesService::SavedFiles* SavedFilesService::GetOrInsert(
     return saved_files;
 
   std::unique_ptr<SavedFiles> scoped_saved_files(
-      new SavedFiles(profile_, extension_id));
+      new SavedFiles(context_, extension_id));
   saved_files = scoped_saved_files.get();
   extension_id_to_saved_files_.insert(
       std::make_pair(extension_id, std::move(scoped_saved_files)));
@@ -302,13 +281,13 @@ void SavedFilesService::Clear(const std::string& extension_id) {
   extension_id_to_saved_files_.erase(extension_id);
 }
 
-SavedFilesService::SavedFiles::SavedFiles(Profile* profile,
+SavedFilesService::SavedFiles::SavedFiles(content::BrowserContext* context,
                                           const std::string& extension_id)
-    : profile_(profile), extension_id_(extension_id) {
+    : context_(context), extension_id_(extension_id) {
   LoadSavedFileEntriesFromPreferences();
 }
 
-SavedFilesService::SavedFiles::~SavedFiles() {}
+SavedFilesService::SavedFiles::~SavedFiles() = default;
 
 void SavedFilesService::SavedFiles::RegisterFileEntry(
     const std::string& id,
@@ -319,7 +298,7 @@ void SavedFilesService::SavedFiles::RegisterFileEntry(
     return;
 
   registered_file_entries_[id] =
-      base::MakeUnique<SavedFileEntry>(id, file_path, is_directory, 0);
+      std::make_unique<SavedFileEntry>(id, file_path, is_directory, 0);
 }
 
 void SavedFilesService::SavedFiles::EnqueueFileEntry(const std::string& id) {
@@ -342,7 +321,7 @@ void SavedFilesService::SavedFiles::EnqueueFileEntry(const std::string& id) {
   }
   saved_file_lru_.insert(
       std::make_pair(file_entry->sequence_number, file_entry));
-  ExtensionPrefs* prefs = ExtensionPrefs::Get(profile_);
+  ExtensionPrefs* prefs = ExtensionPrefs::Get(context_);
   if (old_sequence_number) {
     saved_file_lru_.erase(old_sequence_number);
     UpdateSavedFileEntry(prefs, extension_id_, *file_entry);
@@ -397,7 +376,7 @@ void SavedFilesService::SavedFiles::MaybeCompactSequenceNumbers() {
     return;
 
   int sequence_number = 0;
-  ExtensionPrefs* prefs = ExtensionPrefs::Get(profile_);
+  ExtensionPrefs* prefs = ExtensionPrefs::Get(context_);
   for (std::map<int, SavedFileEntry*>::iterator it = saved_file_lru_.begin();
        it != saved_file_lru_.end();
        ++it) {
@@ -418,7 +397,7 @@ void SavedFilesService::SavedFiles::MaybeCompactSequenceNumbers() {
 }
 
 void SavedFilesService::SavedFiles::LoadSavedFileEntriesFromPreferences() {
-  ExtensionPrefs* prefs = ExtensionPrefs::Get(profile_);
+  ExtensionPrefs* prefs = ExtensionPrefs::Get(context_);
   std::vector<SavedFileEntry> saved_entries =
       GetSavedFileEntries(prefs, extension_id_);
   for (std::vector<SavedFileEntry>::iterator it = saved_entries.begin();
