@@ -145,6 +145,12 @@ class ASH_EXPORT AppListControllerImpl
     return home_launcher_gesture_handler_.get();
   }
 
+  // Called when a window starts/ends dragging. If we're in tablet mode and home
+  // launcher is enabled, we should hide the home launcher during dragging a
+  // window and reshow it when the drag ends.
+  void OnWindowDragStarted();
+  void OnWindowDragEnded();
+
   // app_list::AppListViewDelegate:
   app_list::AppListModel* GetModel() override;
   app_list::SearchModel* GetSearchModel() override;
@@ -164,6 +170,7 @@ class ASH_EXPORT AppListControllerImpl
                                            int event_flags) override;
   void ViewShown(int64_t display_id) override;
   void ViewClosing() override;
+  void ViewClosed() override;
   void GetWallpaperProminentColors(
       GetWallpaperProminentColorsCallback callback) override;
   void ActivateItem(const std::string& id, int event_flags) override;
@@ -174,6 +181,9 @@ class ASH_EXPORT AppListControllerImpl
                                int event_flags) override;
   void ShowWallpaperContextMenu(const gfx::Point& onscreen_location,
                                 ui::MenuSourceType source_type) override;
+  bool ProcessHomeLauncherGesture(ui::GestureEvent* event,
+                                  const gfx::Point& screen_location) override;
+  bool CanProcessEventsOnApplistViews() override;
   ws::WindowService* GetWindowService() override;
 
   void OnVisibilityChanged(bool visible);
@@ -186,7 +196,7 @@ class ASH_EXPORT AppListControllerImpl
   // ShellObserver:
   void OnOverviewModeStarting() override;
   void OnOverviewModeEnding() override;
-  void OnOverviewModeEndingAnimationComplete() override;
+  void OnOverviewModeEndingAnimationComplete(bool canceled) override;
 
   // TabletModeObserver:
   void OnTabletModeStarted() override;
@@ -232,6 +242,8 @@ class ASH_EXPORT AppListControllerImpl
   // Update the visibility of Assistant functionality.
   void UpdateAssistantVisibility();
 
+  int64_t GetDisplayIdToShowAppListOn();
+
   ws::WindowService* window_service_;
 
   base::string16 last_raw_query_;
@@ -262,10 +274,6 @@ class ASH_EXPORT AppListControllerImpl
   // Whether the home launcher feature is enabled.
   const bool is_home_launcher_enabled_;
 
-  // Whether the device is in overview mode. The home launcher (if enabled)
-  // should be hidden during overview mode.
-  bool in_overview_mode_ = false;
-
   // Each time overview mode is exited, set this variable based on whether
   // overview mode is sliding out, so the home launcher knows what to do when
   // overview mode exit animations are finished.
@@ -275,6 +283,9 @@ class ASH_EXPORT AppListControllerImpl
   // should be hidden during wallpaper preview.
   bool in_wallpaper_preview_ = false;
 
+  // Whether we're currently in a window dragging process.
+  bool in_window_dragging_ = false;
+
   mojo::Binding<mojom::VoiceInteractionObserver> voice_interaction_binding_;
 
   DISALLOW_COPY_AND_ASSIGN(AppListControllerImpl);
