@@ -33,6 +33,12 @@ void SearchResult::SetIcon(const gfx::ImageSkia& icon) {
     observer.OnMetadataChanged();
 }
 
+void SearchResult::SetChipIcon(const gfx::ImageSkia& chip_icon) {
+  metadata_->chip_icon = chip_icon;
+  for (auto& observer : observers_)
+    observer.OnMetadataChanged();
+}
+
 void SearchResult::set_title(const base::string16& title) {
   metadata_->title = title;
   for (auto& observer : observers_)
