@@ -4,24 +4,10 @@
 
 #include "ash/app_list/presenter/app_list_presenter_delegate.h"
 
+#include "ash/app_list/views/app_list_view.h"
 #include "base/time/time.h"
-#include "ui/app_list/views/app_list_view.h"
 
 namespace app_list {
-namespace {
-
-// The minimal margin (in pixels) around the app list when in centered mode.
-const int kMinimalCenteredAppListMargin = 10;
-
-}  // namespace
-
-base::TimeDelta AppListPresenterDelegate::animation_duration() {
-  // Duration for show/hide animation in milliseconds.
-  static constexpr base::TimeDelta kAnimationDurationMs =
-      base::TimeDelta::FromMilliseconds(200);
-
-  return kAnimationDurationMs;
-}
 
 base::TimeDelta AppListPresenterDelegate::GetAnimationDurationFullscreen(
     bool is_side_shelf,
@@ -48,9 +34,5 @@ base::TimeDelta AppListPresenterDelegate::GetAnimationDurationFullscreen(
                        : kAnimationDurationMs;
 }
 
-int AppListPresenterDelegate::GetMinimumBoundsHeightForAppList(
-    const app_list::AppListView* app_list) {
-  return app_list->bounds().height() + 2 * kMinimalCenteredAppListMargin;
-}
 
 }  // namespace app_list
