@@ -158,7 +158,7 @@ const TestParams kAppsGridViewTestParams[] = {
 
 const TestParams kAppsGridViewDragTestParams[] = {
     {false /* is_rtl_enabled */, false /* is_apps_grid_gap_enabled */,
-     false /* is_apps_grid_gap_enabled */},
+     false /* is_new_style_launcher_enabled */},
     {false, false, true},
     {true, false, false},
     {true, false, true},
@@ -170,7 +170,7 @@ const TestParams kAppsGridViewDragTestParams[] = {
 
 const TestParams kAppsGridGapTestParams[] = {
     {false /* is_rtl_enabled */, true /* is_apps_grid_gap_enabled */,
-     false /* is_apps_grid_gap_enabled */},
+     false /* is_new_style_launcher_enabled */},
     {false, true, true},
     {true, true, false},
     {true, true, true},
@@ -198,14 +198,17 @@ class AppsGridViewTest : public views::ViewsTestBase,
       is_new_style_launcher_enabled_ = GetParam().is_new_style_launcher_enabled;
     }
     if (is_apps_grid_gap_enabled_) {
-      enabled_features.emplace_back(features::kEnableAppsGridGapFeature);
+      enabled_features.emplace_back(
+          app_list_features::kEnableAppsGridGapFeature);
     } else {
-      disabled_features.emplace_back(features::kEnableAppsGridGapFeature);
+      disabled_features.emplace_back(
+          app_list_features::kEnableAppsGridGapFeature);
     }
     if (is_new_style_launcher_enabled_) {
-      enabled_features.emplace_back(features::kEnableNewStyleLauncher);
+      enabled_features.emplace_back(app_list_features::kEnableNewStyleLauncher);
     } else {
-      disabled_features.emplace_back(features::kEnableNewStyleLauncher);
+      disabled_features.emplace_back(
+          app_list_features::kEnableNewStyleLauncher);
     }
     scoped_feature_list_.InitWithFeatures(enabled_features, disabled_features);
     views::ViewsTestBase::SetUp();
@@ -1087,7 +1090,7 @@ class AppsGridGapTest : public AppsGridViewTest {
   // testing::Test overrides:
   void SetUp() override {
     scoped_feature_list_.InitWithFeatures(
-        {app_list::features::kEnableAppsGridGapFeature}, {});
+        {app_list_features::kEnableAppsGridGapFeature}, {});
     AppsGridViewTest::SetUp();
     apps_grid_view_->set_page_flip_delay_in_ms_for_testing(10);
     GetPaginationModel()->SetTransitionDurations(10, 10);
@@ -1320,8 +1323,8 @@ TEST_P(AppsGridGapTest, MoveLastItemToNewEmptyPage) {
   EXPECT_EQ(std::string("Item 0"), model_->GetModelContent());
 }
 
-TEST_P(AppsGridGapTest, MoveItemToPreviousFullPageNotAllowed) {
-  const int kApps = 1 + GetTilesPerPage(0);
+TEST_P(AppsGridGapTest, MoveItemToPreviousFullPage) {
+  const int kApps = 2 + GetTilesPerPage(0);
   model_->PopulateApps(kApps);
 
   // There are two pages and last item is on second page.
@@ -1331,56 +1334,78 @@ TEST_P(AppsGridGapTest, MoveItemToPreviousFullPageNotAllowed) {
   const views::ViewModelT<AppListItemView>* view_model =
       apps_grid_view_->view_model();
   EXPECT_EQ(kApps, view_model->view_size());
-  for (int i = 0; i < kApps - 1; ++i) {
-    EXPECT_EQ(view_model->view_at(i),
-              test_api_->GetViewAtVisualIndex(0 /* page */, i /* slot */));
-    EXPECT_EQ("Item " + std::to_string(i),
+  for (int i = 0; i < kApps; ++i) {
+    EXPECT_EQ(view_model->view_at(i), test_api_->GetViewAtVisualIndex(
+                                          i / GetTilesPerPage(0) /* page */,
+                                          i % GetTilesPerPage(0) /* slot */));
+    EXPECT_EQ("Item " + base::IntToString(i),
               view_model->view_at(i)->item()->id());
   }
-  EXPECT_EQ(view_model->view_at(kApps - 1),
-            test_api_->GetViewAtVisualIndex(1 /* page */, 0 /* slot */));
-  EXPECT_EQ("Item " + std::to_string(kApps - 1),
-            view_model->view_at(kApps - 1)->item()->id());
 
-  // There's no "page break" item between Item 19 and 20, although there are two
-  // pages. It will only be added after user operations.
-  EXPECT_EQ(std::string("Item 0,Item 1,Item 2,Item 3,Item 4,Item 5,Item 6,Item "
-                        "7,Item 8,Item 9,Item 10,Item 11,Item 12,Item 13,Item "
-                        "14,Item 15,Item 16,Item 17,Item 18,Item 19,Item 20"),
-            model_->GetModelContent());
+  // There's no "page break" item at the end of first page, although there are
+  // two pages. It will only be added after user operations.
+  std::string model_content = "Item 0";
+  for (int i = 1; i < kApps; ++i)
+    model_content.append(",Item " + base::IntToString(i));
+  EXPECT_EQ(model_content, model_->GetModelContent());
 
   // Drag the last item to the first item's left position in previous page.
-  gfx::Point from = test_api_->GetItemTileRectAtVisualIndex(1, 0).CenterPoint();
+  gfx::Point from = test_api_->GetItemTileRectAtVisualIndex(1, 1).CenterPoint();
   gfx::Rect tile_rect = test_api_->GetItemTileRectAtVisualIndex(0, 0);
   gfx::Point to_in_previous_page = tile_rect.CenterPoint();
   to_in_previous_page.set_x(tile_rect.x());
   GetPaginationModel()->SelectPage(1, false);
   SimulateDragToNeighborPage(false /* next_page */, from, to_in_previous_page);
 
-  // The dragging is not successfull, so nothing changes visually.
+  // The dragging is successful, the last item becomes the first item.
   EXPECT_EQ("0", page_flip_waiter_->selected_pages());
   EXPECT_EQ(0, GetPaginationModel()->selected_page());
   TestAppListItemViewIndice();
   EXPECT_EQ(kApps, view_model->view_size());
-  EXPECT_EQ(view_model->view_at(0),
-            test_api_->GetViewAtVisualIndex(0 /* page */, 0 /* slot */));
-  for (int i = 0; i < kApps - 1; ++i) {
-    EXPECT_EQ(view_model->view_at(i),
-              test_api_->GetViewAtVisualIndex(0 /* page */, i /* slot */));
-    EXPECT_EQ("Item " + std::to_string(i),
+  for (int i = 0; i < kApps; ++i) {
+    EXPECT_EQ(view_model->view_at(i), test_api_->GetViewAtVisualIndex(
+                                          i / GetTilesPerPage(0) /* page */,
+                                          i % GetTilesPerPage(0) /* slot */));
+    EXPECT_EQ("Item " + base::IntToString((i + kApps - 1) % kApps),
               view_model->view_at(i)->item()->id());
   }
-  EXPECT_EQ(view_model->view_at(kApps - 1),
-            test_api_->GetViewAtVisualIndex(1 /* page */, 0 /* slot */));
-  EXPECT_EQ("Item " + std::to_string(kApps - 1),
-            view_model->view_at(kApps - 1)->item()->id());
 
   // A "page break" item is added to split the pages.
-  EXPECT_EQ(std::string("Item 0,Item 1,Item 2,Item 3,Item 4,Item 5,Item 6,Item "
-                        "7,Item 8,Item 9,Item 10,Item 11,Item 12,Item 13,Item "
-                        "14,Item 15,Item 16,Item 17,Item 18,Item "
-                        "19,PageBreakItem,Item 20"),
-            model_->GetModelContent());
+  model_content = "Item " + base::IntToString(kApps - 1);
+  for (int i = 1; i < kApps; ++i) {
+    model_content.append(",Item " + base::IntToString(i - 1));
+    if (i == GetTilesPerPage(0) - 1)
+      model_content.append(",PageBreakItem");
+  }
+  EXPECT_EQ(model_content, model_->GetModelContent());
+
+  // Again drag the last item to the first item's left position in previous
+  // page.
+  GetPaginationModel()->SelectPage(1, false);
+  SimulateDragToNeighborPage(false /* next_page */, from, to_in_previous_page);
+
+  // The dragging is successful, the last item becomes the first item again.
+  EXPECT_EQ("0", page_flip_waiter_->selected_pages());
+  EXPECT_EQ(0, GetPaginationModel()->selected_page());
+  TestAppListItemViewIndice();
+  EXPECT_EQ(kApps, view_model->view_size());
+  for (int i = 0; i < kApps; ++i) {
+    EXPECT_EQ(view_model->view_at(i), test_api_->GetViewAtVisualIndex(
+                                          i / GetTilesPerPage(0) /* page */,
+                                          i % GetTilesPerPage(0) /* slot */));
+    EXPECT_EQ("Item " + base::IntToString((i + kApps - 2) % kApps),
+              view_model->view_at(i)->item()->id());
+  }
+
+  // A "page break" item still exists.
+  model_content = "Item " + base::IntToString(kApps - 2) + ",Item " +
+                  base::IntToString(kApps - 1);
+  for (int i = 2; i < kApps; ++i) {
+    model_content.append(",Item " + base::IntToString(i - 2));
+    if (i == GetTilesPerPage(0) - 1)
+      model_content.append(",PageBreakItem");
+  }
+  EXPECT_EQ(model_content, model_->GetModelContent());
 }
 
 }  // namespace test
