@@ -157,20 +157,11 @@ class APP_LIST_EXPORT ContentsView : public views::View,
   void TransitionChanged() override;
   void TransitionEnded() override;
 
-  // Returns the size of current display.
-  gfx::Size GetDisplaySize() const;
-
-  // Starts the fade out animation when the app list is closed.
-  void FadeOutOnClose(base::TimeDelta animation_duration);
-
-  // Starts the fade in animation when the app list is opened.
-  void FadeInOnOpen(base::TimeDelta animation_duration);
-
   // Returns selected view in active page.
   views::View* GetSelectedView() const;
 
-  // Updates the opacity of the items in this view during dragging.
-  void UpdateOpacity();
+  // Updates y position and opacity of the items in this view during dragging.
+  void UpdateYPositionAndOpacity();
 
  private:
   // Sets the active launcher page, accounting for whether the change is for
