@@ -38,7 +38,11 @@ void LogAppLaunch(int index_in_suggestion_chip_container) {
 
 SearchResultSuggestionChipView::SearchResultSuggestionChipView(
     AppListViewDelegate* view_delegate)
-    : view_delegate_(view_delegate), weak_ptr_factory_(this) {}
+    : view_delegate_(view_delegate), weak_ptr_factory_(this) {
+  suggestion_chip_view_ = new SuggestionChipView(
+      app_list::SuggestionChipView::Params(), /* listener */ this);
+  AddChildView(suggestion_chip_view_);
+}
 
 SearchResultSuggestionChipView::~SearchResultSuggestionChipView() {
   SetSearchResult(nullptr);
@@ -55,6 +59,7 @@ void SearchResultSuggestionChipView::SetSearchResult(SearchResult* item) {
   if (item_)
     item_->AddObserver(this);
 
+  SetVisible(!!item_);
   UpdateSuggestionChipView();
 }
 
@@ -105,20 +110,16 @@ void SearchResultSuggestionChipView::GetAccessibleNodeData(
 }
 
 void SearchResultSuggestionChipView::UpdateSuggestionChipView() {
-  if (!item_)
+  if (!item_) {
+    suggestion_chip_view_->SetIcon(gfx::ImageSkia());
+    suggestion_chip_view_->SetText(base::string16());
+    suggestion_chip_view_->SetAccessibleName(base::string16());
     return;
-
-  if (suggestion_chip_view_) {
-    suggestion_chip_view_->SetIcon(item_->icon());
-    suggestion_chip_view_->SetText(item_->title());
-  } else {
-    app_list::SuggestionChipView::Params params;
-    params.text = item_->title();
-    params.icon = item_->icon();
-    suggestion_chip_view_ = new SuggestionChipView(params, /* listener */ this);
-    AddChildView(suggestion_chip_view_);
   }
 
+  suggestion_chip_view_->SetIcon(item_->chip_icon());
+  suggestion_chip_view_->SetText(item_->title());
+
   base::string16 accessible_name = item_->title();
   if (item_->id() == app_list::kInternalAppIdContinueReading) {
     accessible_name = l10n_util::GetStringFUTF16(
