@@ -62,13 +62,16 @@ SearchResultView::SearchResultView(SearchResultListView* list_view,
     : list_view_(list_view),
       view_delegate_(view_delegate),
       icon_(new views::ImageView),
+      badge_icon_(new views::ImageView),
       actions_view_(new SearchResultActionsView(this)),
       progress_bar_(new views::ProgressBar),
       weak_ptr_factory_(this) {
   SetFocusBehavior(FocusBehavior::ALWAYS);
   icon_->set_can_process_events_within_subtree(false);
+  badge_icon_->set_can_process_events_within_subtree(false);
 
   AddChildView(icon_);
+  AddChildView(badge_icon_);
   AddChildView(actions_view_);
   AddChildView(progress_bar_);
   set_context_menu_controller(this);
@@ -205,6 +208,17 @@ void SearchResultView::Layout() {
   icon_bounds.Intersect(rect);
   icon_->SetBoundsRect(icon_bounds);
 
+  gfx::Rect badge_icon_bounds;
+
+  const int badge_icon_dimension =
+      AppListConfig::instance().search_list_badge_icon_dimension();
+  badge_icon_bounds = gfx::Rect(icon_bounds.right() - badge_icon_dimension / 2,
+                                icon_bounds.bottom() - badge_icon_dimension / 2,
+                                badge_icon_dimension, badge_icon_dimension);
+
+  badge_icon_bounds.Intersect(rect);
+  badge_icon_->SetBoundsRect(badge_icon_bounds);
+
   const int max_actions_width =
       (rect.right() - kActionButtonRightMargin - icon_bounds.right()) / 2;
   int actions_width =
@@ -338,6 +352,17 @@ void SearchResultView::OnMetadataChanged() {
     SetIconImage(icon, icon_,
                  AppListConfig::instance().search_list_icon_dimension());
 
+  // Updates |badge_icon_|.
+  const gfx::ImageSkia badge_icon(result_ ? result_->badge_icon()
+                                          : gfx::ImageSkia());
+  if (badge_icon.isNull()) {
+    badge_icon_->SetVisible(false);
+  } else {
+    SetIconImage(badge_icon, badge_icon_,
+                 AppListConfig::instance().search_list_badge_icon_dimension());
+    badge_icon_->SetVisible(true);
+  }
+
   // Updates |actions_view_|.
   actions_view_->SetActions(result_ ? result_->actions()
                                     : SearchResult::Actions());
