@@ -42,6 +42,15 @@ SuggestionChipContainerView::SuggestionChipContainerView(
           kChipSpacing));
   layout_manager->set_main_axis_alignment(
       views::BoxLayout::MainAxisAlignment::MAIN_AXIS_ALIGNMENT_CENTER);
+
+  for (size_t i = 0; i < static_cast<size_t>(kNumStartPageTiles); ++i) {
+    SearchResultSuggestionChipView* chip =
+        new SearchResultSuggestionChipView(view_delegate_);
+    chip->SetVisible(false);
+    chip->SetIndexInSuggestionChipContainer(i);
+    suggestion_chip_views_.emplace_back(chip);
+    AddChildView(chip);
+  }
 }
 
 SuggestionChipContainerView::~SuggestionChipContainerView() = default;
@@ -50,29 +59,20 @@ int SuggestionChipContainerView::DoUpdate() {
   if (IgnoreUpdateAndLayout())
     return num_results();
 
-  // Clear all current suggestion chips.
-  for (size_t i = 0; i < suggestion_chip_views_.size(); ++i)
-    delete suggestion_chip_views_[i];
-  suggestion_chip_views_.clear();
-
   std::vector<SearchResult*> display_results =
       SearchModel::FilterSearchResultsByDisplayType(
           results(), ash::SearchResultDisplayType::kRecommendation,
-          kNumStartPageTiles);
+          /*excludes=*/{}, kNumStartPageTiles);
 
-  // Create a suggestion chip for each search result, but wait until layout to
-  // add them as child views when we know this view's bounds.
-  for (size_t i = 0; i < display_results.size(); ++i) {
-    auto* result = display_results[i];
-    SearchResultSuggestionChipView* chip =
-        new SearchResultSuggestionChipView(view_delegate_);
-    chip->SetSearchResult(result);
-    chip->SetIndexInSuggestionChipContainer(i);
-    suggestion_chip_views_.emplace_back(chip);
+  // Update search results here, but wait until layout to add them as child
+  // views when we know this view's bounds.
+  for (size_t i = 0; i < static_cast<size_t>(kNumStartPageTiles); ++i) {
+    suggestion_chip_views_[i]->SetSearchResult(
+        i < display_results.size() ? display_results[i] : nullptr);
   }
 
   Layout();
-  return suggestion_chip_views_.size();
+  return std::min(kNumStartPageTiles, static_cast<int>(display_results.size()));
 }
 
 const char* SuggestionChipContainerView::GetClassName() const {
@@ -84,15 +84,19 @@ void SuggestionChipContainerView::Layout() {
     return;
 
   // Only show the chips that fit in this view's contents bounds.
-  RemoveAllChildViews(false /* delete_children */);
   int total_width = 0;
   const int max_width = GetContentsBounds().width();
   for (auto* chip : suggestion_chip_views_) {
-    const int chip_width = chip->GetPreferredSize().width();
-    if (chip_width + total_width > max_width)
+    if (!chip->result())
       break;
-    AddChildView(chip);
-    total_width += (total_width == 0 ? 0 : kChipSpacing) + chip_width;
+    const gfx::Size size = chip->CalculatePreferredSize();
+    if (size.width() + total_width > max_width) {
+      chip->SetVisible(false);
+    } else {
+      chip->SetVisible(true);
+      chip->SetSize(size);
+    }
+    total_width += (total_width == 0 ? 0 : kChipSpacing) + size.width();
   }
 
   views::View::Layout();
@@ -126,6 +130,12 @@ void SuggestionChipContainerView::DisableFocusForShowingActiveFolder(
     chip->suggestion_chip_view()->SetEnabled(!disabled);
 }
 
+void SuggestionChipContainerView::OnTabletModeChanged(bool started) {
+  // Enable/Disable chips' background blur based on tablet mode.
+  for (auto* chip : suggestion_chip_views_)
+    chip->suggestion_chip_view()->SetBackgroundBlurEnabled(started);
+}
+
 bool SuggestionChipContainerView::IgnoreUpdateAndLayout() const {
   // Ignore update and layout when this view is not shown.
   const ash::AppListState state = contents_view_->GetActiveState();
