@@ -5,6 +5,9 @@
 #ifndef ASH_ASSISTANT_ASSISTANT_UI_CONTROLLER_H_
 #define ASH_ASSISTANT_ASSISTANT_UI_CONTROLLER_H_
 
+#include <map>
+#include <string>
+
 #include "ash/ash_export.h"
 #include "ash/assistant/assistant_controller_observer.h"
 #include "ash/assistant/model/assistant_interaction_model_observer.h"
@@ -17,6 +20,11 @@
 #include "ash/highlighter/highlighter_controller.h"
 #include "base/macros.h"
 #include "base/timer/timer.h"
+#include "ui/display/display_observer.h"
+#include "ui/events/event_handler.h"
+#include "ui/gfx/geometry/rect.h"
+#include "ui/keyboard/keyboard_controller_observer.h"
+#include "ui/views/event_monitor.h"
 #include "ui/views/widget/widget_observer.h"
 
 namespace chromeos {
@@ -45,7 +53,10 @@ class ASH_EXPORT AssistantUiController
       public AssistantMiniViewDelegate,
       public CaptionBarDelegate,
       public DialogPlateObserver,
-      public HighlighterController::Observer {
+      public HighlighterController::Observer,
+      public keyboard::KeyboardControllerObserver,
+      public display::DisplayObserver,
+      public ui::EventHandler {
  public:
   explicit AssistantUiController(AssistantController* assistant_controller);
   ~AssistantUiController() override;
@@ -54,7 +65,7 @@ class ASH_EXPORT AssistantUiController
   void SetAssistant(chromeos::assistant::mojom::Assistant* assistant);
 
   // Returns the underlying model.
-  const AssistantUiModel* model() const { return &assistant_ui_model_; }
+  const AssistantUiModel* model() const { return &model_; }
 
   // Adds/removes the specified model |observer|.
   void AddModelObserver(AssistantUiModelObserver* observer);
@@ -92,13 +103,25 @@ class ASH_EXPORT AssistantUiController
   void OnDeepLinkReceived(
       assistant::util::DeepLinkType type,
       const std::map<std::string, std::string>& params) override;
-  void OnUrlOpened(const GURL& url) override;
+  void OnUrlOpened(const GURL& url, bool from_server) override;
 
   // AssistantUiModelObserver:
   void OnUiVisibilityChanged(AssistantVisibility new_visibility,
                              AssistantVisibility old_visibility,
                              AssistantSource source) override;
 
+  // keyboard::KeyboardControllerObserver:
+  void OnKeyboardWorkspaceOccludedBoundsChanged(
+      const gfx::Rect& new_bounds) override;
+
+  // display::DisplayObserver:
+  void OnDisplayMetricsChanged(const display::Display& display,
+                               uint32_t changed_metrics) override;
+
+  // ui::EventHandler:
+  void OnMouseEvent(ui::MouseEvent* event) override;
+  void OnTouchEvent(ui::TouchEvent* event) override;
+
   void ShowUi(AssistantSource source);
   void HideUi(AssistantSource source);
   void CloseUi(AssistantSource source);
@@ -107,20 +130,36 @@ class ASH_EXPORT AssistantUiController
   AssistantContainerView* GetViewForTest();
 
  private:
+  // Invoked on either a mouse or touch pressed event.
+  void OnPressedEvent(const ui::LocatedEvent& event);
+
   // Updates UI mode to |ui_mode| if specified. Otherwise UI mode is updated on
   // the basis of interaction/widget visibility state.
   void UpdateUiMode(base::Optional<AssistantUiMode> ui_mode = base::nullopt);
 
+  // Calculate and update the usable work area.
+  void UpdateUsableWorkArea(aura::Window* root_window);
+
+  // Construct |container_view_| and add keyboard/display observers.
+  void CreateContainerView();
+
+  // Reset |container_view_| and remove keyboard/display observers.
+  void ResetContainerView();
+
   AssistantController* const assistant_controller_;  // Owned by Shell.
 
   // Owned by AssistantController.
   chromeos::assistant::mojom::Assistant* assistant_ = nullptr;
 
-  AssistantUiModel assistant_ui_model_;
+  AssistantUiModel model_;
 
   AssistantContainerView* container_view_ =
       nullptr;  // Owned by view hierarchy.
 
+  std::unique_ptr<views::EventMonitor> event_monitor_;
+
+  gfx::Rect keyboard_workspace_occluded_bounds_;
+
   // When hidden, Assistant automatically closes itself to finish the previous
   // session. We delay this behavior to allow the user an opportunity to resume.
   base::OneShotTimer auto_close_timer_;
