@@ -6,6 +6,7 @@
 #define ASH_ASSISTANT_MODEL_ASSISTANT_UI_MODEL_OBSERVER_H_
 
 #include "base/macros.h"
+#include "ui/gfx/geometry/rect.h"
 
 namespace ash {
 
@@ -26,6 +27,11 @@ class AssistantUiModelObserver {
                                      AssistantVisibility old_visibility,
                                      AssistantSource source) {}
 
+  // Invoked when the usable display work area is changed. Observers should
+  // respond to this event by ensuring they are sized/positioned within the
+  // |usable_work_area|.
+  virtual void OnUsableWorkAreaChanged(const gfx::Rect& usable_work_area) {}
+
  protected:
   AssistantUiModelObserver() = default;
   virtual ~AssistantUiModelObserver() = default;
