@@ -67,12 +67,12 @@ AssistantHeaderView::~AssistantHeaderView() {
   assistant_controller_->interaction_controller()->RemoveModelObserver(this);
 }
 
-gfx::Size AssistantHeaderView::CalculatePreferredSize() const {
-  return gfx::Size(INT_MAX, GetHeightForWidth(INT_MAX));
+const char* AssistantHeaderView::GetClassName() const {
+  return "AssistantHeaderView";
 }
 
-void AssistantHeaderView::ChildVisibilityChanged(views::View* child) {
-  PreferredSizeChanged();
+gfx::Size AssistantHeaderView::CalculatePreferredSize() const {
+  return gfx::Size(INT_MAX, GetHeightForWidth(INT_MAX));
 }
 
 void AssistantHeaderView::InitLayout() {
@@ -96,7 +96,8 @@ void AssistantHeaderView::InitLayout() {
   AddChildView(molecule_icon_);
 }
 
-void AssistantHeaderView::OnResponseChanged(const AssistantResponse& response) {
+void AssistantHeaderView::OnResponseChanged(
+    const std::shared_ptr<AssistantResponse>& response) {
   // We only handle the first response when animating the molecule icon. For
   // all subsequent responses the molecule icon remains unchanged.
   if (!is_first_response_)
