@@ -36,7 +36,7 @@ namespace ash {
 namespace {
 
 // Appearance.
-constexpr int kGreetingLabelMarginTopDip = 32;
+constexpr int kGreetingLabelMarginTopDip = 28;
 constexpr int kProgressIndicatorMarginLeftDip = 32;
 constexpr int kProgressIndicatorMarginTopDip = 40;
 
@@ -104,19 +104,44 @@ constexpr base::TimeDelta kProgressAnimationFadeOutDuration =
 // StackLayout -----------------------------------------------------------------
 
 // A layout manager which lays out its views atop each other. This differs from
-// FillLayout in that we respect the preferred size of views during layout. In
-// contrast, FillLayout will cause its views to match the bounds of the host.
+// FillLayout in that we respect the preferred size of views during layout. It's
+// possible to explicitly specify which dimension to respect. In contrast,
+// FillLayout will cause its views to match the bounds of the host.
 class StackLayout : public views::LayoutManager {
  public:
+  enum class RespectDimension : uint32_t {
+    // Respect width. If enabled, child's preferred width will be used and will
+    // be horizontally center positioned. Otherwise, the child will be stretched
+    // to match parent width.
+    kWidth = 1,
+    // Repect height. If enabled, child's preferred height will be used.
+    // Otherwise, the child will be stretched to match parent height.
+    // Note that the child is always top-aligned.
+    kHeight = 1 << 1,
+    kAll = kWidth | kHeight,
+  };
+
   StackLayout() = default;
   ~StackLayout() override = default;
 
+  void Installed(views::View* host) override { host_ = host; }
+
+  void ViewRemoved(views::View* host, views::View* view) override {
+    DCHECK(view);
+    respect_dimension_map_.erase(view);
+  }
+
+  void SetRespectDimensionForView(views::View* view,
+                                  RespectDimension dimension) {
+    DCHECK(host_ && view->parent() == host_);
+    respect_dimension_map_[view] = dimension;
+  }
+
   gfx::Size GetPreferredSize(const views::View* host) const override {
     gfx::Size preferred_size;
 
     for (int i = 0; i < host->child_count(); ++i)
       preferred_size.SetToMax(host->child_at(i)->GetPreferredSize());
-
     return preferred_size;
   }
 
@@ -134,20 +159,36 @@ class StackLayout : public views::LayoutManager {
 
   void Layout(views::View* host) override {
     const int host_width = host->GetContentsBounds().width();
+    const int host_height = host->GetContentsBounds().height();
 
     for (int i = 0; i < host->child_count(); ++i) {
       views::View* child = host->child_at(i);
 
-      int child_width = std::min(child->GetPreferredSize().width(), host_width);
-      int child_height = child->GetHeightForWidth(child_width);
+      int child_width = host_width;
+      int child_height = host_height;
 
-      // Children are horizontally centered, top aligned.
-      child->SetBounds(/*x=*/(host_width - child_width) / 2, /*y=*/0,
-                       child_width, child_height);
+      int child_x = 0;
+      uint32_t dimension = static_cast<uint32_t>(RespectDimension::kAll);
+
+      if (respect_dimension_map_.find(child) != respect_dimension_map_.end())
+        dimension = static_cast<uint32_t>(respect_dimension_map_[child]);
+
+      if (dimension & static_cast<uint32_t>(RespectDimension::kWidth)) {
+        child_width = std::min(child->GetPreferredSize().width(), host_width);
+        child_x = (host_width - child_width) / 2;
+      }
+
+      if (dimension & static_cast<uint32_t>(RespectDimension::kHeight))
+        child_height = child->GetHeightForWidth(child_width);
+
+      child->SetBounds(child_x, /*y=*/0, child_width, child_height);
     }
   }
 
  private:
+  views::View* host_ = nullptr;
+  std::map<views::View*, RespectDimension> respect_dimension_map_;
+
   DISALLOW_COPY_AND_ASSIGN(StackLayout);
 };
 
@@ -185,11 +226,11 @@ AssistantMainStage::~AssistantMainStage() {
   assistant_controller_->interaction_controller()->RemoveModelObserver(this);
 }
 
-void AssistantMainStage::ChildPreferredSizeChanged(views::View* child) {
-  PreferredSizeChanged();
+const char* AssistantMainStage::GetClassName() const {
+  return "AssistantMainStage";
 }
 
-void AssistantMainStage::ChildVisibilityChanged(views::View* child) {
+void AssistantMainStage::ChildPreferredSizeChanged(views::View* child) {
   PreferredSizeChanged();
 }
 
@@ -254,6 +295,13 @@ void AssistantMainStage::InitContentLayoutContainer() {
   layout_manager->SetFlexForView(ui_element_container_, 1);
 
   // Footer.
+  // Note that the |footer_| is placed within its own view container so that as
+  // its visibility changes, its parent container will still reserve the same
+  // layout space. This prevents jank that would otherwise occur due to
+  // |ui_element_container_| claiming that empty space.
+  views::View* footer_container = new views::View();
+  footer_container->SetLayoutManager(std::make_unique<views::FillLayout>());
+
   footer_ = new AssistantFooterView(assistant_controller_);
   footer_->AddObserver(this);
 
@@ -261,7 +309,8 @@ void AssistantMainStage::InitContentLayoutContainer() {
   footer_->SetPaintToLayer();
   footer_->layer()->SetFillsBoundsOpaquely(false);
 
-  content_layout_container_->AddChildView(footer_);
+  footer_container->AddChildView(footer_);
+  content_layout_container_->AddChildView(footer_container);
 
   AddChildView(content_layout_container_);
 }
@@ -286,7 +335,9 @@ void AssistantMainStage::InitOverlayLayoutContainer() {
   // underlying views. Events pass through the overlay layout container.
   overlay_layout_container_ = new views::View();
   overlay_layout_container_->set_can_process_events_within_subtree(false);
-  overlay_layout_container_->SetLayoutManager(std::make_unique<StackLayout>());
+
+  auto* stack_layout = overlay_layout_container_->SetLayoutManager(
+      std::make_unique<StackLayout>());
 
   // Greeting label.
   greeting_label_ = new views::Label(
@@ -309,6 +360,12 @@ void AssistantMainStage::InitOverlayLayoutContainer() {
 
   overlay_layout_container_->AddChildView(greeting_label_);
 
+  // We need to stretch |greeting_label_| to match its parent so that it
+  // won't use heuristics in Label to infer line breaking, which seems to cause
+  // text clipping with DPI adjustment. See b/112843496.
+  stack_layout->SetRespectDimensionForView(
+      greeting_label_, StackLayout::RespectDimension::kHeight);
+
   // Progress indicator.
   progress_indicator_ = new AssistantProgressIndicator();
   progress_indicator_->SetBorder(
@@ -445,6 +502,12 @@ bool AssistantMainStage::OnActiveQueryExitAnimationEnded(
     const ui::CallbackLayerAnimationObserver& observer) {
   // The exited active query view will always be the first child of its parent.
   delete query_layout_container_->child_at(0);
+
+  // TODO(https://crbug.com/896079): Remove this when view.cc handles the
+  // event notification.
+  query_layout_container_->NotifyAccessibilityEvent(
+      ax::mojom::Event::kChildrenChanged, false);
+
   UpdateTopPadding();
 
   // Return false to prevent the observer from destroying itself.
@@ -501,7 +564,8 @@ void AssistantMainStage::OnPendingQueryCleared() {
     UpdateFooter();
 }
 
-void AssistantMainStage::OnResponseChanged(const AssistantResponse& response) {
+void AssistantMainStage::OnResponseChanged(
+    const std::shared_ptr<AssistantResponse>& response) {
   using assistant::util::CreateLayerAnimationSequence;
   using assistant::util::CreateOpacityElement;
 
@@ -565,6 +629,10 @@ void AssistantMainStage::OnUiVisibilityChanged(
                   ui::LayerAnimationElement::AnimatableProperty::OPACITY,
                   kFooterEntryAnimationFadeInDelay),
               CreateOpacityElement(1.f, kFooterEntryAnimationFadeInDuration)));
+    } else {
+      // A pending query is present so we simulate a change event to synchronize
+      // view state with interaction model state.
+      OnPendingQueryChanged(pending_query);
     }
 
     return;
