@@ -48,6 +48,10 @@ SuggestionContainerView::~SuggestionContainerView() {
   assistant_controller_->cache_controller()->RemoveModelObserver(this);
 }
 
+const char* SuggestionContainerView::GetClassName() const {
+  return "SuggestionContainerView";
+}
+
 gfx::Size SuggestionContainerView::CalculatePreferredSize() const {
   return gfx::Size(INT_MAX, GetHeightForWidth(INT_MAX));
 }
@@ -87,7 +91,7 @@ void SuggestionContainerView::OnConversationStartersChanged(
 }
 
 void SuggestionContainerView::OnResponseChanged(
-    const AssistantResponse& response) {
+    const std::shared_ptr<AssistantResponse>& response) {
   has_received_response_ = true;
 
   OnSuggestionsCleared();
@@ -96,7 +100,7 @@ void SuggestionContainerView::OnResponseChanged(
   layout_manager_->set_main_axis_alignment(
       views::BoxLayout::MainAxisAlignment::MAIN_AXIS_ALIGNMENT_START);
 
-  OnSuggestionsChanged(response.GetSuggestions());
+  OnSuggestionsChanged(response->GetSuggestions());
 }
 
 void SuggestionContainerView::OnResponseCleared() {
