@@ -11,26 +11,36 @@ namespace aura {
 class Window;
 }
 
-namespace gfx {
+namespace display {
 class Display;
-class Transform;
+class ManagedDisplayInfo;
+}
+
+namespace gfx {
+class Rect;
 }
 
 namespace ash {
-class DisplayInfo;
 class RootWindowTransformer;
 
 ASH_EXPORT RootWindowTransformer* CreateRootWindowTransformerForDisplay(
     aura::Window* root,
-    const gfx::Display& display);
+    const display::Display& display);
 
 // Creates a RootWindowTransformers for mirror root window.
 // |source_display_info| specifies the display being mirrored,
 // and |mirror_display_info| specifies the display used to
 // mirror the content.
 ASH_EXPORT RootWindowTransformer* CreateRootWindowTransformerForMirroredDisplay(
-    const DisplayInfo& source_display_info,
-    const DisplayInfo& mirror_display_info);
+    const display::ManagedDisplayInfo& source_display_info,
+    const display::ManagedDisplayInfo& mirror_display_info);
+
+// Creates a RootWindowTransformers for unified desktop mode.
+// |screen_bounds| specifies the unified desktop's bounds and
+// |display| specifies the display used to mirror the unified desktop.
+ASH_EXPORT RootWindowTransformer* CreateRootWindowTransformerForUnifiedDesktop(
+    const gfx::Rect& screen_bounds,
+    const display::Display& display);
 
 }  // namespace ash
 
