@@ -15,8 +15,10 @@
 #include "base/logging.h"
 #include "ui/aura/client/screen_position_client.h"
 #include "ui/aura/env.h"
+#include "ui/aura/mus/window_tree_host_mus.h"
 #include "ui/aura/window.h"
 #include "ui/aura/window_event_dispatcher.h"
+#include "ui/base/ui_base_features.h"
 #include "ui/display/display.h"
 #include "ui/display/display_finder.h"
 #include "ui/display/manager/display_manager.h"
@@ -38,7 +40,9 @@ class ScreenForShutdown : public display::Screen {
  public:
   explicit ScreenForShutdown(display::Screen* screen_ash)
       : display_list_(screen_ash->GetAllDisplays()),
-        primary_display_(screen_ash->GetPrimaryDisplay()) {}
+        primary_display_(screen_ash->GetPrimaryDisplay()) {
+    SetDisplayForNewWindows(primary_display_.id());
+  }
 
   // display::Screen overrides:
   gfx::Point GetCursorScreenPoint() override { return gfx::Point(); }
@@ -87,7 +91,7 @@ ScreenAsh::ScreenAsh() = default;
 ScreenAsh::~ScreenAsh() = default;
 
 gfx::Point ScreenAsh::GetCursorScreenPoint() {
-  return aura::Env::GetInstance()->last_mouse_location();
+  return Shell::Get()->aura_env()->last_mouse_location();
 }
 
 bool ScreenAsh::IsWindowUnderCursor(gfx::NativeWindow window) {
@@ -119,6 +123,17 @@ display::Display ScreenAsh::GetDisplayNearestWindow(
     gfx::NativeView window) const {
   if (!window)
     return GetPrimaryDisplay();
+
+  if (::features::IsSingleProcessMash()) {
+    // In IsSingleProcessMash() ScreenAsh is also called from non-ash code.
+    // Non-ash code creates aura Windows that are not parented to Ash's root
+    // Windows. Check for this first.
+    aura::WindowTreeHostMus* window_tree_host_mus =
+        aura::WindowTreeHostMus::ForWindow(window);
+    if (window_tree_host_mus)
+      return window_tree_host_mus->GetDisplay();
+  }
+
   const aura::Window* root_window = window->GetRootWindow();
   if (!root_window)
     return GetPrimaryDisplay();
