@@ -4,8 +4,10 @@
 
 #include "ash/first_run/desktop_cleaner.h"
 
+#include <memory>
+
+#include "ash/public/cpp/shell_window_ids.h"
 #include "ash/shell.h"
-#include "ash/shell_window_ids.h"
 #include "ui/aura/window_event_dispatcher.h"
 #include "ui/aura/window_observer.h"
 #include "ui/compositor/layer_animation_observer.h"
@@ -17,12 +19,10 @@ namespace ash {
 namespace {
 
 const int kContainerIdsToHide[] = {
-  kShellWindowId_DefaultContainer,
-  kShellWindowId_AlwaysOnTopContainer,
-  kShellWindowId_PanelContainer,
-  // TODO(dzhioev): uncomment this when issue with BrowserView::CanActivate
-  // will be fixed.
-  // kShellWindowId_SystemModalContainer
+    kShellWindowId_DefaultContainer, kShellWindowId_AlwaysOnTopContainer,
+    // TODO(dzhioev): uncomment this when issue with BrowserView::CanActivate
+    // will be fixed.
+    // kShellWindowId_SystemModalContainer
 };
 
 }  // namespace
@@ -31,8 +31,7 @@ class ContainerHider : public aura::WindowObserver,
                        public ui::ImplicitAnimationObserver {
  public:
   explicit ContainerHider(aura::Window* container)
-      : container_was_hidden_(!container->IsVisible()),
-        container_(container) {
+      : container_was_hidden_(!container->IsVisible()), container_(container) {
     if (container_was_hidden_)
       return;
     ui::Layer* layer = container_->layer();
@@ -41,7 +40,7 @@ class ContainerHider : public aura::WindowObserver,
     layer->SetOpacity(0.0);
   }
 
-  virtual ~ContainerHider() {
+  ~ContainerHider() override {
     if (container_was_hidden_ || !container_)
       return;
     if (!WasAnimationCompletedForProperty(ui::LayerAnimationElement::OPACITY)) {
@@ -57,12 +56,10 @@ class ContainerHider : public aura::WindowObserver,
 
  private:
   // Overriden from ui::ImplicitAnimationObserver.
-  virtual void OnImplicitAnimationsCompleted() OVERRIDE {
-    container_->Hide();
-  }
+  void OnImplicitAnimationsCompleted() override { container_->Hide(); }
 
   // Overriden from aura::WindowObserver.
-  virtual void OnWindowDestroying(aura::Window* window) OVERRIDE {
+  void OnWindowDestroying(aura::Window* window) override {
     DCHECK(window == container_);
     container_ = NULL;
   }
@@ -81,12 +78,12 @@ class NotificationBlocker : public message_center::NotificationBlocker {
     NotifyBlockingStateChanged();
   }
 
-  virtual ~NotificationBlocker() {};
+  ~NotificationBlocker() override = default;
 
  private:
   // Overriden from message_center::NotificationBlocker.
-  virtual bool ShouldShowNotificationAsPopup(
-      const message_center::NotifierId& notifier_id) const OVERRIDE {
+  bool ShouldShowNotificationAsPopup(
+      const message_center::Notification& notification) const override {
     return false;
   }
 
@@ -95,16 +92,16 @@ class NotificationBlocker : public message_center::NotificationBlocker {
 
 DesktopCleaner::DesktopCleaner() {
   // TODO(dzhioev): Add support for secondary displays.
-  aura::Window* root_window = Shell::GetInstance()->GetPrimaryRootWindow();
+  aura::Window* root_window = Shell::Get()->GetPrimaryRootWindow();
   for (size_t i = 0; i < arraysize(kContainerIdsToHide); ++i) {
     aura::Window* container =
         Shell::GetContainer(root_window, kContainerIdsToHide[i]);
-    container_hiders_.push_back(make_linked_ptr(new ContainerHider(container)));
+    container_hiders_.push_back(std::make_unique<ContainerHider>(container));
   }
   notification_blocker_.reset(new NotificationBlocker());
 }
 
-DesktopCleaner::~DesktopCleaner() {}
+DesktopCleaner::~DesktopCleaner() = default;
 
 // static
 std::vector<int> DesktopCleaner::GetContainersToHideForTest() {
@@ -113,4 +110,3 @@ std::vector<int> DesktopCleaner::GetContainersToHideForTest() {
 }
 
 }  // namespace ash
-
