@@ -8,7 +8,6 @@
 
 #include "ash/accessibility/accessibility_controller.h"
 #include "ash/ime/ime_controller.h"
-#include "ash/public/cpp/config.h"
 #include "ash/root_window_controller.h"
 #include "ash/session/session_controller.h"
 #include "ash/shell.h"
@@ -103,6 +102,10 @@ VirtualKeyboardController::VirtualKeyboardController()
       chromeos::input_method::mojom::ImeKeyset::kEmoji));
 
   keyboard::KeyboardController::Get()->AddObserver(this);
+
+  bluetooth_devices_observer_ = std::make_unique<BluetoothDevicesObserver>(
+      base::BindRepeating(&VirtualKeyboardController::UpdateBluetoothDevice,
+                          base::Unretained(this)));
 }
 
 VirtualKeyboardController::~VirtualKeyboardController() {
@@ -144,7 +147,7 @@ void VirtualKeyboardController::ToggleIgnoreExternalKeyboard() {
 
 void VirtualKeyboardController::MoveKeyboardToDisplay(
     const display::Display& display) {
-  DCHECK(keyboard::KeyboardController::Get()->enabled());
+  DCHECK(keyboard::KeyboardController::Get()->IsEnabled());
   DCHECK(display.is_valid());
 
   TRACE_EVENT0("vk", "MoveKeyboardToDisplay");
@@ -162,7 +165,7 @@ void VirtualKeyboardController::MoveKeyboardToDisplay(
 }
 
 void VirtualKeyboardController::MoveKeyboardToTouchableDisplay() {
-  DCHECK(keyboard::KeyboardController::Get()->enabled());
+  DCHECK(keyboard::KeyboardController::Get()->IsEnabled());
 
   TRACE_EVENT0("vk", "MoveKeyboardToTouchableDisplay");
 
@@ -214,8 +217,11 @@ void VirtualKeyboardController::UpdateDevices() {
     ui::InputDeviceType type = device.type;
     if (type == ui::InputDeviceType::INPUT_DEVICE_INTERNAL)
       has_internal_keyboard_ = true;
-    if (type == ui::InputDeviceType::INPUT_DEVICE_EXTERNAL)
+    if (type == ui::InputDeviceType::INPUT_DEVICE_USB ||
+        (type == ui::InputDeviceType::INPUT_DEVICE_BLUETOOTH &&
+         bluetooth_devices_observer_->IsConnectedBluetoothDevice(device))) {
       has_external_keyboard_ = true;
+    }
   }
   // Update keyboard state.
   UpdateKeyboardEnabled();
@@ -251,12 +257,14 @@ void VirtualKeyboardController::SetKeyboardEnabled(bool enabled) {
   } else {
     Shell::Get()->DisableKeyboard();
   }
+  for (VirtualKeyboardControllerObserver& observer : observers_)
+    observer.OnVirtualKeyboardStateChanged(is_enabled);
 }
 
 void VirtualKeyboardController::ForceShowKeyboard() {
   // If the virtual keyboard is enabled, show the keyboard directly.
   auto* keyboard_controller = keyboard::KeyboardController::Get();
-  if (keyboard_controller->enabled()) {
+  if (keyboard_controller->IsEnabled()) {
     keyboard_controller->ShowKeyboard(false /* locked */);
     return;
   }
@@ -265,9 +273,6 @@ void VirtualKeyboardController::ForceShowKeyboard() {
   DCHECK(!keyboard::GetKeyboardEnabledFromShelf());
   keyboard::SetKeyboardEnabledFromShelf(true);
   Shell::Get()->EnableKeyboard();
-
-  keyboard_controller = keyboard::KeyboardController::Get();
-  DCHECK(keyboard_controller->enabled());
   keyboard_controller->ShowKeyboard(false);
 }
 
@@ -294,4 +299,26 @@ void VirtualKeyboardController::OnActiveUserSessionChanged(
     Shell::Get()->EnableKeyboard();
 }
 
+void VirtualKeyboardController::AddObserver(
+    VirtualKeyboardControllerObserver* observer) {
+  observers_.AddObserver(observer);
+}
+
+void VirtualKeyboardController::RemoveObserver(
+    VirtualKeyboardControllerObserver* observer) {
+  observers_.RemoveObserver(observer);
+}
+
+void VirtualKeyboardController::UpdateBluetoothDevice(
+    device::BluetoothDevice* device) {
+  // We only care about keyboard type bluetooth device change.
+  if (device->GetDeviceType() != device::BluetoothDeviceType::KEYBOARD &&
+      device->GetDeviceType() !=
+          device::BluetoothDeviceType::KEYBOARD_MOUSE_COMBO) {
+    return;
+  }
+
+  UpdateDevices();
+}
+
 }  // namespace ash
