@@ -4,6 +4,7 @@
 
 #include "ash/login/login_screen_controller.h"
 
+#include "ash/focus_cycler.h"
 #include "ash/login/ui/lock_screen.h"
 #include "ash/login/ui/lock_window.h"
 #include "ash/login/ui/login_data_dispatcher.h"
@@ -81,16 +82,16 @@ bool LoginScreenController::IsAuthenticating() const {
   return authentication_stage_ != AuthenticationStage::kIdle;
 }
 
-void LoginScreenController::AuthenticateUser(const AccountId& account_id,
-                                             const std::string& password,
-                                             bool authenticated_by_pin,
-                                             OnAuthenticateCallback callback) {
+void LoginScreenController::AuthenticateUserWithPasswordOrPin(
+    const AccountId& account_id,
+    const std::string& password,
+    bool authenticated_by_pin,
+    OnAuthenticateCallback callback) {
   // It is an error to call this function while an authentication is in
   // progress.
-  LOG_IF(ERROR, IsAuthenticating())
+  LOG_IF(FATAL, IsAuthenticating())
       << "Duplicate authentication attempt; current authentication stage is "
       << static_cast<int>(authentication_stage_);
-  CHECK(!IsAuthenticating());
 
   if (!login_screen_client_) {
     std::move(callback).Run(base::nullopt);
@@ -127,10 +128,34 @@ void LoginScreenController::AuthenticateUser(const AccountId& account_id,
                          authenticated_by_pin, std::move(callback))));
 }
 
-void LoginScreenController::AttemptUnlock(const AccountId& account_id) {
+void LoginScreenController::AuthenticateUserWithExternalBinary(
+    const AccountId& account_id,
+    OnAuthenticateCallback callback) {
+  // It is an error to call this function while an authentication is in
+  // progress.
+  LOG_IF(FATAL, IsAuthenticating())
+      << "Duplicate authentication attempt; current authentication stage is "
+      << static_cast<int>(authentication_stage_);
+
+  if (!login_screen_client_) {
+    std::move(callback).Run(base::nullopt);
+    return;
+  }
+
+  authentication_stage_ = AuthenticationStage::kDoAuthenticate;
+  login_screen_client_->AuthenticateUserWithExternalBinary(
+      account_id,
+      base::BindOnce(&LoginScreenController::OnAuthenticateComplete,
+                     weak_factory_.GetWeakPtr(), std::move(callback)));
+}
+
+void LoginScreenController::AuthenticateUserWithEasyUnlock(
+    const AccountId& account_id) {
+  // TODO(jdufault): integrate this into authenticate stage after mojom is
+  // refactored to use a callback.
   if (!login_screen_client_)
     return;
-  login_screen_client_->AttemptUnlock(account_id);
+  login_screen_client_->AuthenticateUserWithEasyUnlock(account_id);
 }
 
 void LoginScreenController::HardlockPod(const AccountId& account_id) {
@@ -448,6 +473,21 @@ void LoginScreenController::SetShowGuestButtonForGaiaScreen(bool can_show) {
       ->SetShowGuestButtonForGaiaScreen(can_show);
 }
 
+void LoginScreenController::FocusLoginShelf(bool reverse) {
+  Shelf* shelf = Shelf::ForWindow(Shell::Get()->GetPrimaryRootWindow());
+  // Tell the focus direction to the status area or the shelf so they can focus
+  // the correct child view.
+  if (reverse) {
+    shelf->GetStatusAreaWidget()
+        ->status_area_widget_delegate()
+        ->set_default_last_focusable_child(reverse);
+    Shell::Get()->focus_cycler()->FocusWidget(shelf->GetStatusAreaWidget());
+  } else {
+    shelf->shelf_widget()->set_default_last_focusable_child(reverse);
+    Shell::Get()->focus_cycler()->FocusWidget(shelf->shelf_widget());
+  }
+}
+
 void LoginScreenController::SetAddUserButtonEnabled(bool enable) {
   Shelf::ForWindow(Shell::Get()->GetPrimaryRootWindow())
       ->shelf_widget()
@@ -471,17 +511,23 @@ void LoginScreenController::ShowAccountAccessHelpApp() {
   login_screen_client_->ShowAccountAccessHelpApp();
 }
 
+void LoginScreenController::FocusOobeDialog() {
+  login_screen_client_->FocusOobeDialog();
+}
+
 void LoginScreenController::DoAuthenticateUser(const AccountId& account_id,
                                                const std::string& password,
                                                bool authenticated_by_pin,
                                                OnAuthenticateCallback callback,
                                                const std::string& system_salt) {
+  // TODO(jdufault): Simplify this, system_salt is no longer used so fetching
+  // the system salt can be skipped.
   authentication_stage_ = AuthenticationStage::kDoAuthenticate;
 
   int dummy_value;
   bool is_pin =
       authenticated_by_pin && base::StringToInt(password, &dummy_value);
-  login_screen_client_->AuthenticateUser(
+  login_screen_client_->AuthenticateUserWithPasswordOrPin(
       account_id, password, is_pin,
       base::BindOnce(&LoginScreenController::OnAuthenticateComplete,
                      weak_factory_.GetWeakPtr(), base::Passed(&callback)));
