@@ -54,10 +54,11 @@ TEST_F(LoginScreenControllerTest, RequestAuthentication) {
   std::string password = "password";
   // Verify AuthenticateUser mojo call is run with the same account id, a
   // (hashed) password, and the correct PIN state.
-  EXPECT_CALL(*client, AuthenticateUser_(id, password, false, _));
+  EXPECT_CALL(*client,
+              AuthenticateUserWithPasswordOrPin_(id, password, false, _));
   base::Optional<bool> callback_result;
   base::RunLoop run_loop1;
-  controller->AuthenticateUser(
+  controller->AuthenticateUserWithPasswordOrPin(
       id, password, false,
       base::BindLambdaForTesting([&](base::Optional<bool> did_auth) {
         callback_result = did_auth;
@@ -74,9 +75,9 @@ TEST_F(LoginScreenControllerTest, RequestAuthentication) {
   EXPECT_TRUE(prefs->FindPreference(prefs::kQuickUnlockPinSalt));
 
   std::string pin = "123456";
-  EXPECT_CALL(*client, AuthenticateUser_(id, pin, true, _));
+  EXPECT_CALL(*client, AuthenticateUserWithPasswordOrPin_(id, pin, true, _));
   base::RunLoop run_loop2;
-  controller->AuthenticateUser(
+  controller->AuthenticateUserWithPasswordOrPin(
       id, pin, true,
       base::BindLambdaForTesting([&](base::Optional<bool> did_auth) {
         callback_result = did_auth;
@@ -95,8 +96,8 @@ TEST_F(LoginScreenControllerTest, RequestEasyUnlock) {
   AccountId id = AccountId::FromUserEmail("user1@test.com");
 
   // Verify AttemptUnlock mojo call is run with the same account id.
-  EXPECT_CALL(*client, AttemptUnlock(id));
-  controller->AttemptUnlock(id);
+  EXPECT_CALL(*client, AuthenticateUserWithEasyUnlock(id));
+  controller->AuthenticateUserWithEasyUnlock(id);
   base::RunLoop().RunUntilIdle();
 
   // Verify HardlockPod mojo call is run with the same account id.
