@@ -13,7 +13,6 @@
 #include "ash/login/ui/login_bubble.h"
 #include "ash/login/ui/login_test_base.h"
 #include "ash/login/ui/login_test_utils.h"
-#include "ash/public/cpp/config.h"
 #include "ash/root_window_controller.h"
 #include "ash/session/test_session_controller_client.h"
 #include "ash/shelf/shelf.h"
@@ -106,9 +105,9 @@ TEST_F(LockScreenSanityTest, PasswordSubmitCallsLoginScreenClient) {
   // Password submit runs mojo.
   std::unique_ptr<MockLoginScreenClient> client = BindMockLoginScreenClient();
   client->set_authenticate_user_callback_result(false);
-  EXPECT_CALL(
-      *client,
-      AuthenticateUser_(users()[0]->basic_user_info->account_id, _, false, _));
+  EXPECT_CALL(*client,
+              AuthenticateUserWithPasswordOrPin_(
+                  users()[0]->basic_user_info->account_id, _, false, _));
   ui::test::EventGenerator* generator = GetEventGenerator();
   generator->PressKey(ui::KeyboardCode::VKEY_A, 0);
   generator->PressKey(ui::KeyboardCode::VKEY_RETURN, 0);
@@ -130,12 +129,13 @@ TEST_F(LockScreenSanityTest,
   LoginPasswordView::TestApi password_test_api =
       MakeLoginPasswordTestApi(contents, AuthTarget::kPrimary);
 
-  MockLoginScreenClient::AuthenticateUserCallback callback;
+  MockLoginScreenClient::AuthenticateUserWithPasswordOrPinCallback callback;
   auto submit_password = [&]() {
     // Capture the authentication callback.
-    client->set_authenticate_user_callback_storage(&callback);
-    EXPECT_CALL(*client, AuthenticateUser_(testing::_, testing::_, testing::_,
-                                           testing::_));
+    client->set_authenticate_user_with_password_or_pin_callback_storage(
+        &callback);
+    EXPECT_CALL(*client, AuthenticateUserWithPasswordOrPin_(
+                             testing::_, testing::_, testing::_, testing::_));
 
     // Submit password with content 'a'. This creates a browser-process
     // authentication request stored in |callback|.
@@ -171,6 +171,7 @@ TEST_F(LockScreenSanityTest,
 // Verifies that tabbing from the lock screen will eventually focus the shelf.
 // Then, a shift+tab will bring focus back to the lock screen.
 TEST_F(LockScreenSanityTest, TabGoesFromLockToShelfAndBackToLock) {
+  std::unique_ptr<MockLoginScreenClient> client = BindMockLoginScreenClient();
   // Make lock screen shelf visible.
   GetSessionControllerClient()->SetSessionState(
       session_manager::SessionState::LOCKED);
