@@ -15,6 +15,7 @@
 #include "ash/login/ui/non_accessible_view.h"
 #include "ash/login/ui/views_utils.h"
 #include "ash/public/cpp/ash_constants.h"
+#include "ash/public/cpp/shell_window_ids.h"
 #include "ash/resources/vector_icons/vector_icons.h"
 #include "ash/shell.h"
 #include "ash/strings/grit/ash_strings.h"
@@ -53,8 +54,8 @@ constexpr int kAlertIconSizeDp = 20;
 constexpr SkAlpha kSubMessageColorAlpha = 0x89;
 
 // Color of the "Remove user" text.
-constexpr SkColor kRemoveUserInitialColor = SkColorSetRGB(0x7B, 0xAA, 0xF7);
-constexpr SkColor kRemoveUserConfirmColor = SkColorSetRGB(0xE6, 0x7C, 0x73);
+constexpr SkColor kRemoveUserInitialColor = gfx::kGoogleBlueDark400;
+constexpr SkColor kRemoveUserConfirmColor = gfx::kGoogleRedDark500;
 
 // Margin/inset of the entries for the user menu.
 constexpr int kUserMenuMarginWidth = 14;
@@ -93,8 +94,10 @@ views::Label* CreateLabel(const base::string16& message, SkColor color) {
 
 class LoginErrorBubbleView : public LoginBaseBubbleView {
  public:
-  LoginErrorBubbleView(views::View* content, views::View* anchor_view)
-      : LoginBaseBubbleView(anchor_view) {
+  LoginErrorBubbleView(views::View* content,
+                       views::View* anchor_view,
+                       aura::Window* container)
+      : LoginBaseBubbleView(anchor_view, container) {
     set_anchor_view_insets(
         gfx::Insets(kAnchorViewErrorBubbleVerticalSpacingDp, 0));
 
@@ -155,6 +158,24 @@ class ButtonWithContent : public views::Button {
   DISALLOW_COPY_AND_ASSIGN(ButtonWithContent);
 };
 
+// A view that has a customizable accessible name.
+class ViewWithAccessibleName : public views::View {
+ public:
+  ViewWithAccessibleName(const base::string16& accessible_name)
+      : accessible_name_(accessible_name) {}
+  ~ViewWithAccessibleName() override = default;
+
+  // views::View:
+  void GetAccessibleNodeData(ui::AXNodeData* node_data) override {
+    node_data->role = ax::mojom::Role::kStaticText;
+    node_data->SetName(accessible_name_);
+  }
+
+ private:
+  const base::string16 accessible_name_;
+  DISALLOW_COPY_AND_ASSIGN(ViewWithAccessibleName);
+};
+
 class LoginUserMenuView : public LoginBaseBubbleView,
                           public views::ButtonListener {
  public:
@@ -187,8 +208,7 @@ class LoginUserMenuView : public LoginBaseBubbleView,
         kUserMenuMarginHeight, kUserMenuMarginWidth,
         kUserMenuMarginHeight - kUserMenuMarginAroundRemoveUserButtonDp,
         kUserMenuMarginWidth);
-    auto create_and_add_horizontal_margin_container = [&]() {
-      auto* container = new NonAccessibleView("MarginContainer");
+    auto setup_horizontal_margin_container = [&](views::View* container) {
       container->SetLayoutManager(std::make_unique<views::BoxLayout>(
           views::BoxLayout::kVertical,
           gfx::Insets(0, margins.left(), 0, margins.right())));
@@ -214,7 +234,8 @@ class LoginUserMenuView : public LoginBaseBubbleView,
                                                 username)
                    : username;
 
-      views::View* container = create_and_add_horizontal_margin_container();
+      views::View* container = setup_horizontal_margin_container(
+          new NonAccessibleView("UsernameLabel MarginContainer"));
       username_label_ = CreateLabel(display_username, SK_ColorWHITE);
       // Do not change these two lines. Without them, the remove user button
       // will be pushed out of the box when the user has a long name.
@@ -222,8 +243,12 @@ class LoginUserMenuView : public LoginBaseBubbleView,
       username_label_->SetMaxLines(1);
       container->AddChildView(username_label_);
       add_space(container, kBubbleBetweenChildSpacingDp);
-      container->AddChildView(CreateLabel(
-          email, SkColorSetA(SK_ColorWHITE, kSubMessageColorAlpha)));
+      views::Label* email_label =
+          CreateLabel(email, SkColorSetA(SK_ColorWHITE, kSubMessageColorAlpha));
+      // Do not change these two lines for the same reasons as above.
+      email_label->SetMultiLine(true);
+      email_label->SetMaxLines(1);
+      container->AddChildView(email_label);
     }
 
     // Remove user.
@@ -251,8 +276,6 @@ class LoginUserMenuView : public LoginBaseBubbleView,
         return label;
       };
 
-      remove_user_confirm_data_ = create_and_add_horizontal_margin_container();
-      remove_user_confirm_data_->SetVisible(false);
       base::string16 part1 = l10n_util::GetStringUTF16(
           IDS_ASH_LOGIN_POD_NON_OWNER_USER_REMOVE_WARNING_PART_1);
       if (type == user_manager::UserType::USER_TYPE_SUPERVISED) {
@@ -260,6 +283,12 @@ class LoginUserMenuView : public LoginBaseBubbleView,
             IDS_ASH_LOGIN_POD_LEGACY_SUPERVISED_USER_REMOVE_WARNING,
             base::UTF8ToUTF16(ash::kLegacySupervisedUserManagementDisplayURL));
       }
+      base::string16 part2 = l10n_util::GetStringFUTF16(
+          IDS_ASH_LOGIN_POD_NON_OWNER_USER_REMOVE_WARNING_PART_2, email);
+
+      remove_user_confirm_data_ = setup_horizontal_margin_container(
+          new ViewWithAccessibleName(part1 + base::ASCIIToUTF16(" ") + part2));
+      remove_user_confirm_data_->SetVisible(false);
 
       // Account for margin that was removed below the separator for the add
       // user button.
@@ -268,15 +297,14 @@ class LoginUserMenuView : public LoginBaseBubbleView,
       remove_user_confirm_data_->AddChildView(make_label(part1));
       add_space(remove_user_confirm_data_,
                 kUserMenuVerticalDistanceBetweenLabelsDp);
-      remove_user_confirm_data_->AddChildView(
-          make_label(l10n_util::GetStringFUTF16(
-              IDS_ASH_LOGIN_POD_NON_OWNER_USER_REMOVE_WARNING_PART_2, email)));
+      remove_user_confirm_data_->AddChildView(make_label(part2));
       // Reduce margin since the remove user button comes next.
       add_space(remove_user_confirm_data_,
                 kUserMenuVerticalDistanceBetweenLabelsDp -
                     kUserMenuMarginAroundRemoveUserButtonDp);
 
-      auto* container = create_and_add_horizontal_margin_container();
+      auto* container = setup_horizontal_margin_container(
+          new NonAccessibleView("RemoveUserButton MarginContainer"));
       remove_user_label_ =
           CreateLabel(l10n_util::GetStringUTF16(
                           IDS_ASH_LOGIN_POD_MENU_REMOVE_ITEM_ACCESSIBLE_NAME),
@@ -285,6 +313,7 @@ class LoginUserMenuView : public LoginBaseBubbleView,
       remove_user_button_->SetFocusBehavior(views::View::FocusBehavior::ALWAYS);
       remove_user_button_->set_id(
           LoginBubble::kUserMenuRemoveUserButtonIdForTest);
+      remove_user_button_->SetAccessibleName(remove_user_label_->text());
       container->AddChildView(remove_user_button_);
     }
 
@@ -326,6 +355,14 @@ class LoginUserMenuView : public LoginBaseBubbleView,
       SetSize(GetPreferredSize());
       SizeToContents();
       Layout();
+
+      // Fire an accessibility alert to make ChromeVox read the warning message
+      // and remove button.
+      remove_user_confirm_data_->NotifyAccessibilityEvent(
+          ax::mojom::Event::kAlert, true /*send_native_event*/);
+      remove_user_button_->NotifyAccessibilityEvent(ax::mojom::Event::kAlert,
+                                                    true /*send_native_event*/);
+
       if (on_remove_user_warning_shown_)
         std::move(on_remove_user_warning_shown_).Run();
       return;
@@ -415,7 +452,9 @@ void LoginBubble::ShowErrorBubble(views::View* content,
     CloseImmediately();
 
   flags_ = flags;
-  bubble_view_ = new LoginErrorBubbleView(content, anchor_view);
+  aura::Window* menu_container = Shell::GetContainer(
+      Shell::GetPrimaryRootWindow(), kShellWindowId_MenuContainer);
+  bubble_view_ = new LoginErrorBubbleView(content, anchor_view, menu_container);
 
   Show();
 }
@@ -568,7 +607,8 @@ void LoginBubble::Show() {
   ScheduleAnimation(true /*visible*/);
 
   // Fire an alert so ChromeVox will read the contents of the bubble.
-  bubble_view_->NotifyAccessibilityEvent(ax::mojom::Event::kAlert, true);
+  bubble_view_->NotifyAccessibilityEvent(ax::mojom::Event::kAlert,
+                                         true /*send_native_event*/);
 }
 
 void LoginBubble::ProcessPressedEvent(const ui::LocatedEvent* event) {
