@@ -14,10 +14,10 @@
 #include "ash/public/cpp/window_properties.h"
 #include "base/metrics/histogram_macros.h"
 #include "ui/aura/window.h"
+#include "ui/aura/window_targeter.h"
 #include "ui/display/display.h"
 #include "ui/display/screen.h"
 #include "ui/events/base_event_utils.h"
-#include "ui/gfx/animation/slide_animation.h"
 #include "ui/gfx/geometry/point.h"
 #include "ui/gfx/geometry/rect.h"
 #include "ui/views/bubble/bubble_dialog_delegate_view.h"
@@ -28,6 +28,24 @@ namespace ash {
 
 namespace {
 
+// A window targeter installed on a Widget's window when it's in immersive mode.
+// This targeter insets the touch area for direct children of the window it's
+// installed on (see calls to SetInsets) so that gestures at the top of the
+// screen will be directed to the Widget window for triggering immersive reveal.
+// The insets are disabled while the top view is revealed.
+class ImmersiveWindowTargeter : public aura::WindowTargeter {
+ public:
+  ImmersiveWindowTargeter() = default;
+  ~ImmersiveWindowTargeter() override = default;
+
+  bool ShouldUseExtendedBounds(const aura::Window* target) const override {
+    return target->parent() == window();
+  }
+
+ private:
+  DISALLOW_COPY_AND_ASSIGN(ImmersiveWindowTargeter);
+};
+
 // Duration for the reveal show/hide slide animation. The slower duration is
 // used for the initial slide out to give the user more change to see what
 // happened.
@@ -68,19 +86,10 @@ bool ImmersiveFullscreenController::value_for_animations_disabled_for_test_ =
 
 ////////////////////////////////////////////////////////////////////////////////
 
-ImmersiveFullscreenController::ImmersiveFullscreenController()
-    : delegate_(NULL),
-      top_container_(NULL),
-      widget_(NULL),
-      event_observers_enabled_(false),
-      enabled_(false),
-      reveal_state_(CLOSED),
-      revealed_lock_count_(0),
-      mouse_x_when_hit_top_in_screen_(-1),
-      gesture_begun_(false),
-      animation_(new gfx::SlideAnimation(this)),
-      animations_disabled_for_test_(value_for_animations_disabled_for_test_),
-      weak_ptr_factory_(this) {}
+ImmersiveFullscreenController::ImmersiveFullscreenController(
+    ImmersiveContext* context)
+    : immersive_context_(context),
+      animations_disabled_for_test_(value_for_animations_disabled_for_test_) {}
 
 ImmersiveFullscreenController::~ImmersiveFullscreenController() {
   EnableEventObservers(false);
@@ -98,59 +107,10 @@ void ImmersiveFullscreenController::Init(
   delegate_ = delegate;
   top_container_ = top_container;
   widget_ = widget;
-  ImmersiveContext::Get()->InstallResizeHandleWindowTargeter(this);
 
   EnableWindowObservers(true);
 }
 
-void ImmersiveFullscreenController::SetEnabled(WindowType window_type,
-                                               bool enabled) {
-  if (enabled_ == enabled)
-    return;
-  enabled_ = enabled;
-
-  EnableEventObservers(enabled_);
-
-  ImmersiveContext::Get()->OnEnteringOrExitingImmersive(this, enabled);
-
-  if (enabled_) {
-    // Animate enabling immersive mode by sliding out the top-of-window views.
-    // No animation occurs if a lock is holding the top-of-window views open.
-
-    // Do a reveal to set the initial state for the animation. (And any
-    // required state in case the animation cannot run because of a lock holding
-    // the top-of-window views open.)
-    MaybeStartReveal(ANIMATE_NO);
-
-    // Reset the located event so that it does not affect whether the
-    // top-of-window views are hidden.
-    located_event_revealed_lock_.reset();
-
-    // Try doing the animation.
-    MaybeEndReveal(ANIMATE_SLOW);
-
-    if (reveal_state_ == REVEALED) {
-      // Reveal was unsuccessful. Reacquire the revealed locks if appropriate.
-      UpdateLocatedEventRevealedLock();
-      if (immersive_focus_watcher_)
-        immersive_focus_watcher_->UpdateFocusRevealedLock();
-    }
-
-    delegate_->OnImmersiveFullscreenEntered();
-  } else {
-    // Stop cursor-at-top tracking.
-    top_edge_hover_timer_.Stop();
-    reveal_state_ = CLOSED;
-
-    delegate_->OnImmersiveFullscreenExited();
-  }
-
-  if (enabled_) {
-    UMA_HISTOGRAM_ENUMERATION("Ash.ImmersiveFullscreen.WindowType", window_type,
-                              WINDOW_TYPE_COUNT);
-  }
-}
-
 bool ImmersiveFullscreenController::IsEnabled() const {
   return enabled_;
 }
@@ -208,9 +168,7 @@ void ImmersiveFullscreenController::OnTouchEvent(
   UpdateLocatedEventRevealedLock(&event, location_in_screen);
 }
 
-void ImmersiveFullscreenController::OnGestureEvent(
-    ui::GestureEvent* event,
-    const gfx::Point& location_in_screen) {
+void ImmersiveFullscreenController::OnGestureEvent(ui::GestureEvent* event) {
   if (!enabled_)
     return;
 
@@ -221,7 +179,8 @@ void ImmersiveFullscreenController::OnGestureEvent(
 
   switch (event->type()) {
     case ui::ET_GESTURE_SCROLL_BEGIN:
-      if (ShouldHandleGestureEvent(location_in_screen)) {
+      if (ShouldHandleGestureEvent(
+              event->target()->GetScreenLocation(*event))) {
         gesture_begun_ = true;
         // Do not consume the event. Otherwise, we end up consuming all
         // ui::ET_GESTURE_SCROLL_BEGIN events in the top-of-window views
@@ -272,10 +231,8 @@ void ImmersiveFullscreenController::OnWindowPropertyChanged(
     aura::Window* window,
     const void* key,
     intptr_t old) {
-  if (key == kImmersiveIsActive) {
-    SetEnabled(ImmersiveFullscreenController::WINDOW_TYPE_OTHER,
-               window->GetProperty(kImmersiveIsActive));
-  }
+  if (key == kImmersiveIsActive)
+    UpdateEnabled();
 }
 
 void ImmersiveFullscreenController::OnWindowDestroying(aura::Window* window) {
@@ -348,7 +305,9 @@ void ImmersiveFullscreenController::UnlockRevealedState() {
 // static
 void ImmersiveFullscreenController::EnableForWidget(views::Widget* widget,
                                                     bool enabled) {
-  widget->GetNativeWindow()->SetProperty(kImmersiveIsActive, enabled);
+  auto* window = widget->GetNativeWindow();
+  if (window->GetProperty(kImmersiveIsActive) != enabled)
+    widget->GetNativeWindow()->SetProperty(kImmersiveIsActive, enabled);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -380,22 +339,17 @@ void ImmersiveFullscreenController::EnableEventObservers(bool enable) {
         ImmersiveHandlerFactory::Get()->CreateFocusWatcher(this);
     immersive_gesture_handler_ =
         ImmersiveHandlerFactory::Get()->CreateGestureHandler(this);
-    ImmersiveContext::Get()->AddPointerWatcher(
+    immersive_context_->AddPointerWatcher(
         this, views::PointerWatcherEventTypes::MOVES);
   } else {
-    ImmersiveContext::Get()->RemovePointerWatcher(this);
+    immersive_context_->RemovePointerWatcher(this);
     immersive_gesture_handler_.reset();
     immersive_focus_watcher_.reset();
 
-    animation_->Stop();
+    animation_.Stop();
   }
 }
 
-bool ImmersiveFullscreenController::IsTargetForWidget(
-    views::Widget* target) const {
-  return target == widget_ || target == top_container_->GetWidget();
-}
-
 void ImmersiveFullscreenController::UpdateTopEdgeHoverTimer(
     const ui::MouseEvent& event,
     const gfx::Point& location_in_screen,
@@ -412,7 +366,7 @@ void ImmersiveFullscreenController::UpdateTopEdgeHoverTimer(
 
   // Mouse hover should not initiate revealing the top-of-window views while a
   // window has mouse capture.
-  if (ImmersiveContext::Get()->DoesAnyWindowHaveCapture())
+  if (immersive_context_->DoesAnyWindowHaveCapture())
     return;
 
   if (ShouldIgnoreMouseEventAtLocation(location_in_screen))
@@ -469,7 +423,7 @@ void ImmersiveFullscreenController::UpdateLocatedEventRevealedLock(
 
   // Ignore all events while a window has capture. This keeps the top-of-window
   // views revealed during a drag.
-  if (ImmersiveContext::Get()->DoesAnyWindowHaveCapture())
+  if (immersive_context_->DoesAnyWindowHaveCapture())
     return;
 
   if ((!event || event->IsMouseEvent()) &&
@@ -505,7 +459,7 @@ void ImmersiveFullscreenController::UpdateLocatedEventRevealedLock(
 }
 
 void ImmersiveFullscreenController::UpdateLocatedEventRevealedLock() {
-  if (!ImmersiveContext::Get()->IsMouseEventsEnabled()) {
+  if (!immersive_context_->IsMouseEventsEnabled()) {
     // If mouse events are disabled, the user's last interaction was probably
     // via touch. Do no do further processing in this case as there is no easy
     // way of retrieving the position of the user's last touch.
@@ -589,6 +543,8 @@ void ImmersiveFullscreenController::MaybeStartReveal(Animate animate) {
   RevealState previous_reveal_state = reveal_state_;
   reveal_state_ = SLIDING_OPEN;
   if (previous_reveal_state == CLOSED) {
+    EnableTouchInsets(false);
+
     delegate_->OnImmersiveRevealStarted();
 
     // Do not do any more processing if OnImmersiveRevealStarted() changed
@@ -598,11 +554,11 @@ void ImmersiveFullscreenController::MaybeStartReveal(Animate animate) {
   }
   // Slide in the reveal view.
   if (animate == ANIMATE_NO) {
-    animation_->Reset(1);
+    animation_.Reset(1);
     OnSlideOpenAnimationCompleted();
   } else {
-    animation_->SetSlideDuration(GetAnimationDuration(animate));
-    animation_->Show();
+    animation_.SetSlideDuration(GetAnimationDuration(animate));
+    animation_.Show();
   }
 }
 
@@ -633,10 +589,10 @@ void ImmersiveFullscreenController::MaybeEndReveal(Animate animate) {
   reveal_state_ = SLIDING_CLOSED;
   int duration_ms = GetAnimationDuration(animate);
   if (duration_ms > 0) {
-    animation_->SetSlideDuration(duration_ms);
-    animation_->Hide();
+    animation_.SetSlideDuration(duration_ms);
+    animation_.Hide();
   } else {
-    animation_->Reset(0);
+    animation_.Reset(0);
     OnSlideClosedAnimationCompleted();
   }
 }
@@ -644,6 +600,8 @@ void ImmersiveFullscreenController::MaybeEndReveal(Animate animate) {
 void ImmersiveFullscreenController::OnSlideClosedAnimationCompleted() {
   DCHECK_EQ(SLIDING_CLOSED, reveal_state_);
   reveal_state_ = CLOSED;
+
+  EnableTouchInsets(true);
   delegate_->OnImmersiveRevealEnded();
 }
 
@@ -717,7 +675,81 @@ bool ImmersiveFullscreenController::ShouldHandleGestureEvent(
 }
 
 gfx::Rect ImmersiveFullscreenController::GetDisplayBoundsInScreen() const {
-  return ImmersiveContext::Get()->GetDisplayBoundsInScreen(widget_);
+  return immersive_context_->GetDisplayBoundsInScreen(widget_);
+}
+
+bool ImmersiveFullscreenController::IsTargetForWidget(
+    views::Widget* target) const {
+  return target == widget_ || target == top_container_->GetWidget();
+}
+
+void ImmersiveFullscreenController::UpdateEnabled() {
+  if (!widget_)
+    return;
+
+  const bool enabled =
+      widget_->GetNativeWindow()->GetProperty(kImmersiveIsActive);
+
+  if (enabled_ == enabled)
+    return;
+  enabled_ = enabled;
+
+  EnableEventObservers(enabled_);
+
+  immersive_context_->OnEnteringOrExitingImmersive(this, enabled);
+
+  if (enabled_) {
+    // Animate enabling immersive mode by sliding out the top-of-window views.
+    // No animation occurs if a lock is holding the top-of-window views open.
+
+    normal_targeter_ = widget_->GetNativeWindow()->SetEventTargeter(
+        std::make_unique<ImmersiveWindowTargeter>());
+
+    // Do a reveal to set the initial state for the animation. (And any
+    // required state in case the animation cannot run because of a lock holding
+    // the top-of-window views open.)
+    MaybeStartReveal(ANIMATE_NO);
+
+    // Reset the located event so that it does not affect whether the
+    // top-of-window views are hidden.
+    located_event_revealed_lock_.reset();
+
+    // Try doing the animation.
+    MaybeEndReveal(ANIMATE_SLOW);
+
+    if (reveal_state_ == REVEALED) {
+      // Reveal was unsuccessful. Reacquire the revealed locks if appropriate.
+      UpdateLocatedEventRevealedLock();
+      if (immersive_focus_watcher_)
+        immersive_focus_watcher_->UpdateFocusRevealedLock();
+    }
+
+    delegate_->OnImmersiveFullscreenEntered();
+  } else {
+    // Stop cursor-at-top tracking.
+    top_edge_hover_timer_.Stop();
+    reveal_state_ = CLOSED;
+
+    widget_->GetNativeWindow()->SetEventTargeter(std::move(normal_targeter_));
+
+    delegate_->OnImmersiveFullscreenExited();
+  }
+
+  if (enabled_) {
+    UMA_HISTOGRAM_ENUMERATION(
+        "Ash.ImmersiveFullscreen.WindowType",
+        static_cast<WindowType>(
+            widget_->GetNativeWindow()->GetProperty(kImmersiveWindowType)),
+        WINDOW_TYPE_COUNT);
+  }
+}
+
+void ImmersiveFullscreenController::EnableTouchInsets(bool enable) {
+  if (!widget_->GetNativeWindow()->targeter())
+    return;
+
+  widget_->GetNativeWindow()->targeter()->SetInsets(
+      {}, gfx::Insets(enable ? kImmersiveFullscreenTopEdgeInset : 0, 0, 0, 0));
 }
 
 }  // namespace ash
