@@ -21,10 +21,6 @@ namespace network_icon {
 
 namespace {
 
-// Padding between outside of icon and edge of the canvas, in dp. This value
-// stays the same regardless of the canvas size.
-constexpr int kSignalStrengthImageInset = 2;
-
 // TODO(estade): share this alpha with other things in ash (battery, etc.).
 // See https://crbug.com/623987 and https://crbug.com/632827
 constexpr int kSignalStrengthImageBgAlpha = 0x4D;
@@ -102,11 +98,13 @@ bool NetworkIconImageSource::HasRepresentationAtAllScales() const {
 SignalStrengthImageSource::SignalStrengthImageSource(ImageType image_type,
                                                      SkColor color,
                                                      const gfx::Size& size,
-                                                     int signal_strength)
+                                                     int signal_strength,
+                                                     int padding)
     : CanvasImageSource(size, false /* is_opaque */),
       image_type_(image_type),
       color_(color),
-      signal_strength_(signal_strength) {
+      signal_strength_(signal_strength),
+      padding_(padding) {
   if (image_type_ == NONE)
     image_type_ = ARCS;
 
@@ -130,7 +128,7 @@ bool SignalStrengthImageSource::HasRepresentationAtAllScales() const {
 
 void SignalStrengthImageSource::DrawArcs(gfx::Canvas* canvas) {
   gfx::RectF oval_bounds((gfx::Rect(size())));
-  oval_bounds.Inset(gfx::Insets(kSignalStrengthImageInset));
+  oval_bounds.Inset(gfx::Insets(padding_));
   // Double the width and height. The new midpoint should be the former
   // bottom center.
   oval_bounds.Inset(-oval_bounds.width() / 2, 0, -oval_bounds.width() / 2,
@@ -174,12 +172,11 @@ void SignalStrengthImageSource::DrawBars(gfx::Canvas* canvas) {
 
   // Length of short side of an isosceles right triangle, in dip.
   const SkScalar kFullTriangleSide =
-      SkIntToScalar(size().width()) - kSignalStrengthImageInset * 2;
+      SkIntToScalar(size().width()) - padding_ * 2;
 
-  auto make_triangle = [scale, kFullTriangleSide](SkScalar side) {
+  auto make_triangle = [scale, kFullTriangleSide, this](SkScalar side) {
     SkPath triangle;
-    triangle.moveTo(scale(kSignalStrengthImageInset),
-                    scale(kSignalStrengthImageInset + kFullTriangleSide));
+    triangle.moveTo(scale(padding_), scale(padding_ + kFullTriangleSide));
     triangle.rLineTo(scale(side), 0);
     triangle.rLineTo(0, -scale(side));
     triangle.close();
