@@ -5,9 +5,9 @@
 """Presubmit script for Chromium Ash resources.
 
 See http://dev.chromium.org/developers/how-tos/depottools/presubmit-scripts
-for more details about the presubmit API built into gcl/git cl, and see
-http://www.chromium.org/developers/web-development-style-guide for the rules
-we're checking against here.
+for more details about the presubmit API built into depot_tools, and see
+https://chromium.googlesource.com/chromium/src/+/master/styleguide/web/web.md
+for the rules we're checking against here.
 """
 
 
