@@ -200,6 +200,14 @@ bool SessionController::IsUserChild() const {
   return active_user_type == user_manager::USER_TYPE_CHILD;
 }
 
+bool SessionController::IsUserPublicAccount() const {
+  if (!IsActiveUserSessionStarted())
+    return false;
+
+  user_manager::UserType active_user_type = GetUserSession(0)->user_info->type;
+  return active_user_type == user_manager::USER_TYPE_PUBLIC_ACCOUNT;
+}
+
 base::Optional<user_manager::UserType> SessionController::GetUserType() const {
   if (!IsActiveUserSessionStarted())
     return base::nullopt;
