@@ -9,7 +9,9 @@
 
 #include "ash/ash_export.h"
 #include "ash/lock_screen_action/lock_screen_action_background_observer.h"
+#include "ash/login/login_screen_controller_observer.h"
 #include "ash/public/interfaces/kiosk_app_info.mojom.h"
+#include "ash/public/interfaces/login_screen.mojom.h"
 #include "ash/shutdown_controller.h"
 #include "ash/tray_action/tray_action_observer.h"
 #include "base/scoped_observer.h"
@@ -29,6 +31,7 @@ namespace ash {
 class LockScreenActionBackgroundController;
 enum class LockScreenActionBackgroundState;
 class TrayAction;
+class LoginScreenController;
 
 class KioskAppsButton;
 
@@ -38,7 +41,8 @@ class ASH_EXPORT LoginShelfView : public views::View,
                                   public views::ButtonListener,
                                   public TrayActionObserver,
                                   public LockScreenActionBackgroundObserver,
-                                  public ShutdownController::Observer {
+                                  public ShutdownController::Observer,
+                                  public LoginScreenControllerObserver {
  public:
   enum ButtonId {
     kShutdown = 1,    // Shut down the device.
@@ -48,7 +52,6 @@ class ASH_EXPORT LoginShelfView : public views::View,
     kCancel,          // Cancel multiple user sign-in.
     kBrowseAsGuest,   // Use in guest mode.
     kAddUser,         // Add a new user.
-    kShowWebUiLogin,  // Show webui login.
     kApps,            // Show list of available kiosk apps.
   };
 
@@ -63,14 +66,17 @@ class ASH_EXPORT LoginShelfView : public views::View,
   // Sets the list of kiosk apps that can be launched from the login shelf.
   void SetKioskApps(std::vector<mojom::KioskAppInfoPtr> kiosk_apps);
 
-  // Sets if the login dialog is visible. This hides some of the buttons on the
-  // LoginShelf.
-  void SetLoginDialogVisible(bool visible);
+  // Sets the state of the login dialog.
+  void SetLoginDialogState(mojom::OobeDialogState state);
 
   // Sets if the guest button on the login shelf can be shown. Even if set to
   // true the button may still not be visible.
   void SetAllowLoginAsGuest(bool allow_guest);
 
+  // Sets if the guest button on the login shelf can be shown during gaia
+  // signin screen.
+  void SetShowGuestButtonForGaiaScreen(bool can_show);
+
   // Sets whether users can be added from the login screen.
   void SetAddUserButtonEnabled(bool enable_add_user);
 
@@ -94,6 +100,9 @@ class ASH_EXPORT LoginShelfView : public views::View,
   // ShutdownController::Observer:
   void OnShutdownPolicyChanged(bool reboot_on_shutdown) override;
 
+  // LoginScreenControllerObserver:
+  void OnOobeDialogStateChanged(mojom::OobeDialogState state) override;
+
  private:
   bool LockScreenActionBackgroundAnimating() const;
 
@@ -101,8 +110,9 @@ class ASH_EXPORT LoginShelfView : public views::View,
   // policy updates, session state changes etc.
   void UpdateUi();
 
-  bool dialog_visible_ = false;
+  mojom::OobeDialogState dialog_state_ = mojom::OobeDialogState::HIDDEN;
   bool allow_guest_ = true;
+  bool allow_guest_during_gaia_ = false;
 
   LockScreenActionBackgroundController* lock_screen_action_background_;
 
@@ -115,6 +125,9 @@ class ASH_EXPORT LoginShelfView : public views::View,
   ScopedObserver<ShutdownController, ShutdownController::Observer>
       shutdown_controller_observer_;
 
+  ScopedObserver<LoginScreenController, LoginScreenControllerObserver>
+      login_screen_controller_observer_;
+
   KioskAppsButton* kiosk_apps_button_ = nullptr;  // Owned by view hierarchy
 
   DISALLOW_COPY_AND_ASSIGN(LoginShelfView);
