@@ -15,15 +15,13 @@ namespace ash {
 
 // Size of the shelf when visible (height when the shelf is horizontal and
 // width when the shelf is vertical).
-constexpr int kShelfSize = 48;
-constexpr int kShelfSizeNewUi = 56;
+constexpr int kShelfSize = 56;
 
 // Size of the icons within shelf buttons.
-constexpr int kShelfButtonIconSize = 32;
-constexpr int kShelfButtonIconSizeNewUi = 44;
+constexpr int kShelfButtonIconSize = 44;
 
 // Size for controls like the app list button, back button, etc.
-constexpr int kShelfControlSizeNewUi = 40;
+constexpr int kShelfControlSize = 40;
 
 ASH_EXPORT constexpr SkColor kShelfControlPermanentHighlightBackground =
     SkColorSetA(SK_ColorWHITE, 26);  // 10%
@@ -36,8 +34,8 @@ constexpr int kWorkspaceAreaVisibleInset = 2;
 // user can drag the shelf out.
 constexpr int kWorkspaceAreaAutoHideInset = 5;
 
-// Size of the shelf when auto-hidden.
-ASH_EXPORT constexpr int kShelfAutoHideSize = 3;
+// Portion of the shelf that's within the screen bounds when auto-hidden.
+ASH_EXPORT constexpr int kHiddenShelfInScreenPortion = 3;
 
 // Animation duration for switching black shelf and dock background on and off.
 ASH_EXPORT constexpr int kTimeToSwitchBackgroundMs = 1000;
@@ -47,12 +45,10 @@ ASH_EXPORT constexpr int kTimeToSwitchBackgroundMs = 1000;
 ASH_EXPORT constexpr SkColor kShelfDefaultBaseColor = SK_ColorBLACK;
 
 // Size allocated for each app button on the shelf.
-ASH_EXPORT constexpr int kShelfButtonSize = 48;
-ASH_EXPORT constexpr int kShelfButtonSizeNewUi = 56;
+ASH_EXPORT constexpr int kShelfButtonSize = 56;
 
 // Size of the space between buttons on the shelf.
-ASH_EXPORT constexpr int kShelfButtonSpacing = 16;
-ASH_EXPORT constexpr int kShelfButtonSpacingNewUi = 8;
+ASH_EXPORT constexpr int kShelfButtonSpacing = 8;
 
 // Highlight color used for shelf button activated states.
 // TODO(bruthig|mohsen): Use of this color is temporary. Draw the active state
@@ -71,9 +67,12 @@ constexpr float kShelfInkDropVisibleOpacity = 0.2f;
 ASH_EXPORT constexpr SkColor kShelfIconColor = SK_ColorWHITE;
 
 // The alpha value for the shelf background.
-ASH_EXPORT constexpr int kShelfTranslucentOverAppList = 77;            // 30%
+ASH_EXPORT constexpr int kShelfTranslucentOverAppList = 51;            // 20%
 ASH_EXPORT constexpr int kShelfTranslucentAlpha = 153;                 // 60%
-ASH_EXPORT constexpr int kShelfTranslucentMaximizedWindowNewUi = 230;  // 90%
+// Using 0xFF causes clipping on the overlay candidate content, which prevent
+// HW overlay, probably due to a bug in compositor. Fix it and use 0xFF.
+// crbug.com/901538
+ASH_EXPORT constexpr int kShelfTranslucentMaximizedWindow = 254;       // ~100%
 
 // The alpha value used to darken a colorized shelf when the shelf is
 // translucent.
@@ -89,8 +88,7 @@ constexpr int kOverflowButtonSize = 32;
 constexpr int kOverflowButtonCornerRadiusOldUi = 2;
 
 // The distance between the edge of the shelf and the status indicators.
-constexpr int kStatusIndicatorOffsetFromShelfEdge = 3;
-constexpr int kStatusIndicatorOffsetFromShelfEdgeNewUi = 2;
+constexpr int kStatusIndicatorOffsetFromShelfEdge = 1;
 
 // The direction of the focus cycling.
 enum CycleDirection { CYCLE_FORWARD, CYCLE_BACKWARD };
@@ -99,51 +97,36 @@ class ShelfConstants {
  public:
   // Size of the shelf when visible (height when the shelf is horizontal and
   // width when the shelf is vertical).
-  static int shelf_size() { return UseNewUi() ? kShelfSizeNewUi : kShelfSize; }
+  static int shelf_size() { return kShelfSize; }
 
   // Size allocated for each app button on the shelf.
-  static int button_size() {
-    return UseNewUi() ? kShelfButtonSizeNewUi : kShelfButtonSize;
-  }
+  static int button_size() { return kShelfButtonSize; }
 
   // Size of the space between buttons on the shelf.
-  static int button_spacing() {
-    return UseNewUi() ? kShelfButtonSpacingNewUi : kShelfButtonSpacing;
-  }
+  static int button_spacing() { return kShelfButtonSpacing; }
 
   // Size of the icons within shelf buttons.
-  static int button_icon_size() {
-    return UseNewUi() ? kShelfButtonIconSizeNewUi : kShelfButtonIconSize;
-  }
+  static int button_icon_size() { return kShelfButtonIconSize; }
 
   // The width and height of the material design overflow button.
-  static int overflow_button_size() {
-    return UseNewUi() ? kShelfControlSizeNewUi : kOverflowButtonSize;
-  }
+  static int overflow_button_size() { return kShelfControlSize; }
 
   // The radius of the rounded corners of the overflow button.
   static int overflow_button_corner_radius() {
-    return UseNewUi() ? overflow_button_size() / 2
-                      : kOverflowButtonCornerRadiusOldUi;
+    return overflow_button_size() / 2;
   }
 
   // The radius of the circular material design app list button.
   static int app_list_button_radius() { return control_border_radius(); }
 
   // The radius of shelf control buttons.
-  static int control_border_radius() { return kShelfControlSizeNewUi / 2; }
+  static int control_border_radius() { return kShelfControlSize / 2; }
 
   // The distance between the edge of the shelf and the status indicators.
   static int status_indicator_offset_from_edge() {
-    return UseNewUi() ? kStatusIndicatorOffsetFromShelfEdgeNewUi
-                      : kStatusIndicatorOffsetFromShelfEdge;
+    return kStatusIndicatorOffsetFromShelfEdge;
   }
 
- private:
-  static bool UseNewUi() {
-    static bool use_new_ui = chromeos::switches::ShouldUseShelfNewUi();
-    return use_new_ui;
-  }
   DISALLOW_IMPLICIT_CONSTRUCTORS(ShelfConstants);
 };
 
