@@ -31,6 +31,8 @@
 #include "ash/shell.h"
 #include "ash/shell_delegate.h"
 #include "ash/strings/grit/ash_strings.h"
+#include "ash/system/model/system_tray_model.h"
+#include "ash/system/model/virtual_keyboard_model.h"
 #include "ash/system/status_area_widget.h"
 #include "ash/wm/mru_window_tracker.h"
 #include "ash/wm/root_window_finder.h"
@@ -351,6 +353,7 @@ ShelfView::ShelfView(ShelfModel* model, Shelf* shelf, ShelfWidget* shelf_widget)
   DCHECK(shelf_);
   DCHECK(shelf_widget_);
   Shell::Get()->tablet_mode_controller()->AddObserver(this);
+  Shell::Get()->system_tray_model()->virtual_keyboard()->AddObserver(this);
   bounds_animator_->AddObserver(this);
   set_context_menu_controller(this);
 }
@@ -359,6 +362,7 @@ ShelfView::~ShelfView() {
   // Shell destroys the TabletModeController before destroying all root windows.
   if (Shell::Get()->tablet_mode_controller())
     Shell::Get()->tablet_mode_controller()->RemoveObserver(this);
+  Shell::Get()->system_tray_model()->virtual_keyboard()->RemoveObserver(this);
   bounds_animator_->RemoveObserver(this);
   model_->RemoveObserver(this);
 }
@@ -368,15 +372,14 @@ void ShelfView::Init() {
 
   // Add the background view behind the app list and back buttons first, so
   // that other views will appear above it.
-  if (chromeos::switches::ShouldUseShelfNewUi()) {
-    back_and_app_list_background_ = new views::View();
-    back_and_app_list_background_->SetBackground(
-        CreateBackgroundFromPainter(views::Painter::CreateSolidRoundRectPainter(
-            kShelfControlPermanentHighlightBackground,
-            ShelfConstants::control_border_radius())));
-    ConfigureChildView(back_and_app_list_background_);
-    AddChildView(back_and_app_list_background_);
-  }
+  back_and_app_list_background_ = new views::View();
+  back_and_app_list_background_->set_can_process_events_within_subtree(false);
+  back_and_app_list_background_->SetBackground(
+      CreateBackgroundFromPainter(views::Painter::CreateSolidRoundRectPainter(
+          kShelfControlPermanentHighlightBackground,
+          ShelfConstants::control_border_radius())));
+  ConfigureChildView(back_and_app_list_background_);
+  AddChildView(back_and_app_list_background_);
 
   const ShelfItems& items(model_->items());
   for (ShelfItems::const_iterator i = items.begin(); i != items.end(); ++i) {
@@ -401,7 +404,6 @@ void ShelfView::Init() {
 }
 
 void ShelfView::OnShelfAlignmentChanged() {
-  overflow_button_->OnShelfAlignmentChanged();
   LayoutToIdealBounds();
   for (int i = 0; i < view_model_->view_size(); ++i) {
     if (i >= first_visible_index_ && i <= last_visible_index_)
@@ -445,7 +447,7 @@ bool ShelfView::IsShowingMenu() const {
          shelf_menu_model_adapter_->IsShowingMenu();
 }
 
-bool ShelfView::IsShowingMenuForView(views::View* view) const {
+bool ShelfView::IsShowingMenuForView(const views::View* view) const {
   return IsShowingMenu() &&
          shelf_menu_model_adapter_->IsShowingMenuForView(*view);
 }
@@ -505,8 +507,8 @@ bool ShelfView::ShouldShowTooltipForView(const views::View* view) const {
   // Don't show a tooltip for a view that's currently being dragged.
   if (view == drag_view_)
     return false;
-  const ShelfItem* item = ShelfItemForView(view);
-  return item != nullptr;
+
+  return ShelfItemForView(view) && !IsShowingMenuForView(view);
 }
 
 base::string16 ShelfView::GetTitleForView(const views::View* view) const {
@@ -537,7 +539,7 @@ void ShelfView::ButtonPressed(views::Button* sender,
     return;
 
   // Ensure the keyboard is hidden and stays hidden (as long as it isn't locked)
-  if (keyboard::KeyboardController::Get()->enabled())
+  if (keyboard::KeyboardController::Get()->IsEnabled())
     keyboard::KeyboardController::Get()->HideKeyboardExplicitlyBySystem();
 
   // Close the overflow bubble if an item on either shelf is clicked. Press
@@ -597,9 +599,9 @@ void ShelfView::ButtonPressed(views::Button* sender,
   // Notify the item of its selection; handle the result in AfterItemSelected.
   model_->GetShelfItemDelegate(item.id)->ItemSelected(
       ui::Event::Clone(event), GetDisplayIdForView(this), LAUNCH_FROM_UNKNOWN,
-      base::Bind(&ShelfView::AfterItemSelected, weak_factory_.GetWeakPtr(),
-                 item, sender, base::Passed(ui::Event::Clone(event)),
-                 ink_drop));
+      base::BindOnce(&ShelfView::AfterItemSelected, weak_factory_.GetWeakPtr(),
+                     item, sender, base::Passed(ui::Event::Clone(event)),
+                     ink_drop));
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -654,16 +656,23 @@ void ShelfView::OnTabletModeEnded() {
     shelf_menu_model_adapter_->Cancel();
 }
 
+void ShelfView::OnVirtualKeyboardVisibilityChanged() {
+  LayoutToIdealBounds();
+}
+
 void ShelfView::CreateDragIconProxyByLocationWithNoAnimation(
     const gfx::Point& origin_in_screen_coordinates,
     const gfx::ImageSkia& icon,
     views::View* replaced_view,
-    float scale_factor) {
+    float scale_factor,
+    int blur_radius) {
   drag_replaced_view_ = replaced_view;
   aura::Window* root_window =
       drag_replaced_view_->GetWidget()->GetNativeWindow()->GetRootWindow();
   drag_image_ = std::make_unique<DragImageView>(
       root_window, ui::DragDropTypes::DRAG_EVENT_SOURCE_MOUSE);
+  if (blur_radius > 0)
+    SetDragImageBlur(icon.size(), blur_radius);
   drag_image_->SetImage(icon);
   gfx::Size size = drag_image_->GetPreferredSize();
   size.set_width(size.width() * scale_factor);
@@ -913,8 +922,6 @@ bool ShelfView::IsItemPinned(const ShelfItem& item) const {
 }
 
 int ShelfView::GetSeparatorIndex() const {
-  if (!chromeos::switches::ShouldUseShelfNewUi())
-    return -1;
   for (int i = 0; i < model_->item_count() - 1; ++i) {
     if (IsItemPinned(model_->items()[i]) &&
         model_->items()[i + 1].type == TYPE_APP) {
@@ -924,7 +931,7 @@ int ShelfView::GetSeparatorIndex() const {
   return -1;
 }
 
-int ShelfView::GetDimensionOfCenteredShelfItemsInNewUi() const {
+int ShelfView::GetDimensionOfCenteredShelfItems() const {
   int size = 0;
   int added_items = 0;
   for (ShelfItem item : model_->items()) {
@@ -940,7 +947,6 @@ int ShelfView::GetDimensionOfCenteredShelfItemsInNewUi() const {
 
 void ShelfView::UpdateShelfItemBackground(SkColor color) {
   shelf_item_background_color_ = color;
-  overflow_button_->UpdateShelfItemBackground(color);
   SchedulePaint();
 }
 
@@ -964,10 +970,7 @@ void ShelfView::UpdateAllButtonsVisibilityInOverflowMode() {
 }
 
 void ShelfView::LayoutAppListAndBackButtonHighlight() const {
-  // Don't show anything if this is the overflow menu or if this is not the
-  // new UI.
-  if (!chromeos::switches::ShouldUseShelfNewUi())
-    return;
+  // Don't show anything if this is the overflow menu.
   if (is_overflow_mode()) {
     back_and_app_list_background_->SetVisible(false);
     return;
@@ -975,16 +978,16 @@ void ShelfView::LayoutAppListAndBackButtonHighlight() const {
   const int button_spacing = ShelfConstants::button_spacing();
   // "Secondary" as in "orthogonal to the shelf primary axis".
   const int control_secondary_padding =
-      (ShelfConstants::shelf_size() - kShelfControlSizeNewUi) / 2;
+      (ShelfConstants::shelf_size() - kShelfControlSize) / 2;
   const int back_and_app_list_background_size =
-      kShelfControlSizeNewUi +
-      (IsTabletModeEnabled() ? kShelfControlSizeNewUi + button_spacing : 0);
+      kShelfControlSize +
+      (IsTabletModeEnabled() ? kShelfControlSize + button_spacing : 0);
   back_and_app_list_background_->SetBounds(
       shelf_->PrimaryAxisValue(button_spacing, control_secondary_padding),
       shelf_->PrimaryAxisValue(control_secondary_padding, button_spacing),
       shelf_->PrimaryAxisValue(back_and_app_list_background_size,
-                               kShelfControlSizeNewUi),
-      shelf_->PrimaryAxisValue(kShelfControlSizeNewUi,
+                               kShelfControlSize),
+      shelf_->PrimaryAxisValue(kShelfControlSize,
                                back_and_app_list_background_size));
 }
 
@@ -996,10 +999,13 @@ void ShelfView::CalculateIdealBounds(gfx::Rect* overflow_bounds) const {
 
   const int available_size = shelf_->PrimaryAxisValue(width(), height());
   const int separator_index = GetSeparatorIndex();
+  const bool virtual_keyboard_visible =
+      Shell::Get()->system_tray_model()->virtual_keyboard()->visible();
   // Don't show the separator if it isn't needed, or would appear after all
   // visible items.
   separator_->SetVisible(separator_index != -1 &&
-                         separator_index < last_visible_index_);
+                         separator_index < last_visible_index_ &&
+                         !virtual_keyboard_visible);
   int app_list_button_position;
 
   int x = 0;
@@ -1014,12 +1020,11 @@ void ShelfView::CalculateIdealBounds(gfx::Rect* overflow_bounds) const {
       view_model_->set_ideal_bounds(i, gfx::Rect(x, y, 0, 0));
       continue;
     }
-    if (i == kAppListButtonIndex + 1 &&
-        chromeos::switches::ShouldUseShelfNewUi()) {
+    if (i == kAppListButtonIndex + 1) {
       // Start centering after we've laid out the app list button.
       // Center the shelf items on the whole shelf, including the status
       // area widget.
-      int centered_shelf_items_size = GetDimensionOfCenteredShelfItemsInNewUi();
+      int centered_shelf_items_size = GetDimensionOfCenteredShelfItems();
       StatusAreaWidget* status_widget = shelf_widget_->status_area_widget();
       int status_widget_size =
           status_widget ? shelf_->PrimaryAxisValue(
@@ -1052,17 +1057,15 @@ void ShelfView::CalculateIdealBounds(gfx::Rect* overflow_bounds) const {
 
     // In the new UI, padding between the back & app list buttons is smaller
     // than between all other shelf items.
-    if (i == kBackButtonIndex && chromeos::switches::ShouldUseShelfNewUi())
+    if (i == kBackButtonIndex)
       x -= button_spacing;
 
     if (i == kAppListButtonIndex) {
       app_list_button_position = shelf_->PrimaryAxisValue(x, y);
-      if (chromeos::switches::ShouldUseShelfNewUi()) {
-        // In the new UI, a larger minimum padding after the app list button
-        // is required: increment with the necessary extra amount.
-        x += shelf_->PrimaryAxisValue(kAppListButtonMargin - button_spacing, 0);
-        y += shelf_->PrimaryAxisValue(0, kAppListButtonMargin - button_spacing);
-      }
+      // A larger minimum padding after the app list button is required:
+      // increment with the necessary extra amount.
+      x += shelf_->PrimaryAxisValue(kAppListButtonMargin - button_spacing, 0);
+      y += shelf_->PrimaryAxisValue(0, kAppListButtonMargin - button_spacing);
     }
 
     if (i == separator_index) {
@@ -1106,7 +1109,13 @@ void ShelfView::CalculateIdealBounds(gfx::Rect* overflow_bounds) const {
     // FinalizeRipOffDrag().
     if (dragged_off_shelf_ && view_model_->view_at(i) == drag_view_)
       continue;
-    view_model_->view_at(i)->SetVisible(i <= last_visible_index_);
+    // If virtual keyboard is visible, only back button and app list button are
+    // shown.
+    const bool is_visible_item = !virtual_keyboard_visible ||
+                                 i == kBackButtonIndex ||
+                                 i == kAppListButtonIndex;
+    view_model_->view_at(i)->SetVisible(i <= last_visible_index_ &&
+                                        is_visible_item);
   }
 
   overflow_button_->SetVisible(show_overflow);
@@ -1802,12 +1811,6 @@ void ShelfView::GetAccessibleNodeData(ui::AXNodeData* node_data) {
   node_data->SetName(l10n_util::GetStringUTF8(IDS_ASH_SHELF_ACCESSIBLE_NAME));
 }
 
-void ShelfView::ViewHierarchyChanged(
-    const ViewHierarchyChangedDetails& details) {
-  if (details.is_add && details.child == this)
-    tooltip_.Init();
-}
-
 void ShelfView::OnGestureEvent(ui::GestureEvent* event) {
   // Do not forward events to |shelf_| (which forwards events to the shelf
   // layout manager) as we do not want gestures on the overflow to open the app
@@ -2054,6 +2057,12 @@ void ShelfView::AfterGetContextMenuItems(
 void ShelfView::ShowContextMenuForView(views::View* source,
                                        const gfx::Point& point,
                                        ui::MenuSourceType source_type) {
+  // Prevent multiple requests for context menus before the current request
+  // completes. If a second request is sent before the first one can respond,
+  // the Chrome side ShelfItemDelegate will become unresponsive
+  // (https://crbug.com/881886).
+  if (waiting_for_context_menu_options_)
+    return;
   last_pressed_index_ = -1;
   const ShelfItem* item = ShelfItemForView(source);
   const int64_t display_id = GetDisplayIdForView(this);
@@ -2066,6 +2075,7 @@ void ShelfView::ShowContextMenuForView(views::View* source,
     return;
   }
 
+  waiting_for_context_menu_options_ = true;
   // Get any custom entries; show the context menu in AfterGetContextMenuItems.
   model_->GetShelfItemDelegate(item->id)->GetContextMenuItems(
       display_id, base::Bind(&ShelfView::AfterGetContextMenuItems,
@@ -2079,6 +2089,7 @@ void ShelfView::ShowMenu(std::unique_ptr<ui::SimpleMenuModel> menu_model,
                          bool context_menu,
                          ui::MenuSourceType source_type) {
   DCHECK(!IsShowingMenu());
+  waiting_for_context_menu_options_ = false;
   if (menu_model->GetItemCount() == 0)
     return;
   menu_owner_ = source;
@@ -2222,9 +2233,29 @@ bool ShelfView::CanPrepareForDrag(Pointer pointer,
 }
 
 void ShelfView::UpdateBackButton() {
+  const bool virtual_keyboard_visible =
+      Shell::Get()->system_tray_model()->virtual_keyboard()->visible();
+  gfx::Transform rotation;
+  // Rotate the back button when virtual keyboard is visible.
+  if (virtual_keyboard_visible) {
+    rotation.Rotate(270.0);
+    rotation.Translate(-GetBackButton()->height(), 0);
+  }
   GetBackButton()->layer()->SetOpacity(IsTabletModeEnabled() ? 1.f : 0.f);
+  GetBackButton()->layer()->SetTransform(rotation);
   GetBackButton()->SetFocusBehavior(
       IsTabletModeEnabled() ? FocusBehavior::ALWAYS : FocusBehavior::NEVER);
 }
 
+void ShelfView::SetDragImageBlur(const gfx::Size& size, int blur_radius) {
+  drag_image_->SetPaintToLayer();
+  drag_image_->layer()->SetFillsBoundsOpaquely(false);
+  drag_image_mask_ = views::Painter::CreatePaintedLayer(
+      views::Painter::CreateSolidRoundRectPainter(SK_ColorBLACK,
+                                                  size.width() / 2.0f));
+  drag_image_mask_->layer()->SetBounds(gfx::Rect(size));
+  drag_image_->layer()->SetMaskLayer(drag_image_mask_->layer());
+  drag_image_->layer()->SetBackgroundBlur(blur_radius);
+}
+
 }  // namespace ash
