@@ -45,6 +45,7 @@ namespace {
 
 constexpr int kShelfRoundedCornerRadius = 28;
 constexpr int kShelfBlurRadius = 10;
+constexpr float kShelfBlurQuality = 0.33f;
 
 // Return the first or last focusable child of |root|.
 views::View* FindFirstOrLastFocusableChild(views::View* root,
@@ -189,13 +190,16 @@ void ShelfWidget::DelegateView::ReorderChildLayers(ui::Layer* parent_layer) {
 }
 
 void ShelfWidget::DelegateView::UpdateBackgroundBlur() {
+  // Blur only if the background is visible.
   const bool should_blur_background =
+      opaque_background_.visible() &&
       shelf_widget_->shelf_layout_manager()->ShouldBlurShelfBackground();
   if (should_blur_background == background_is_currently_blurred_)
     return;
 
   opaque_background_.SetBackgroundBlur(should_blur_background ? kShelfBlurRadius
                                                               : 0);
+  opaque_background_.SetBackdropFilterQuality(kShelfBlurQuality);
 
   background_is_currently_blurred_ = should_blur_background;
 }
@@ -204,37 +208,48 @@ void ShelfWidget::DelegateView::UpdateOpaqueBackground() {
   const gfx::Rect local_bounds = GetLocalBounds();
   gfx::Rect opaque_background_bounds = local_bounds;
 
-  if (chromeos::switches::ShouldUseShelfNewUi()) {
-    const Shelf* shelf = shelf_widget_->shelf();
-    const ShelfBackgroundType background_type =
-        shelf_widget_->GetBackgroundType();
+  const Shelf* shelf = shelf_widget_->shelf();
+  const ShelfBackgroundType background_type =
+      shelf_widget_->GetBackgroundType();
 
-    // Show rounded corners except in maximized and split modes.
-    if (background_type == SHELF_BACKGROUND_MAXIMIZED ||
-        background_type == SHELF_BACKGROUND_SPLIT_VIEW) {
-      mask_ = nullptr;
-      opaque_background_.SetMaskLayer(nullptr);
-    } else {
-      const int radius = kShelfRoundedCornerRadius;
-      // Extend the opaque layer a little bit so that only two rounded
-      // corners are visible.
-      // TODO(manucornet): Add functionality to skia to draw a rounded
-      // rectangle with four different radiuses.
-      opaque_background_bounds = gfx::Rect(
-          local_bounds.x() - shelf->SelectValueForShelfAlignment(0, radius, 0),
-          local_bounds.y(),
-          local_bounds.width() +
-              shelf->SelectValueForShelfAlignment(0, radius, radius),
-          local_bounds.height() +
-              shelf->SelectValueForShelfAlignment(radius, 0, 0));
-      // Only re-create the mask if the bounds have changed.
-      if (!mask_ || mask_->layer()->bounds() != opaque_background_bounds) {
-        mask_ = views::Painter::CreatePaintedLayer(
-            views::Painter::CreateSolidRoundRectPainter(SK_ColorBLACK, radius));
-        mask_->layer()->SetBounds(opaque_background_bounds);
-        opaque_background_.SetMaskLayer(mask_->layer());
-      }
+  // If the app list is showing in clamshell mode, we should hide the shelf.
+  // otherwise, we should show it again. This creates a 'blending' effect
+  // between the two
+  if (background_type == SHELF_BACKGROUND_APP_LIST) {
+    opaque_background_.SetVisible(false);
+    UpdateBackgroundBlur();
+    return;
+  }
+
+  if (!opaque_background_.visible()) {
+    opaque_background_.SetVisible(true);
+  }
+
+  // Show rounded corners except in maximized and split modes.
+  if (background_type == SHELF_BACKGROUND_MAXIMIZED ||
+      background_type == SHELF_BACKGROUND_SPLIT_VIEW) {
+    mask_ = nullptr;
+    opaque_background_.SetMaskLayer(nullptr);
+  } else {
+    const int radius = kShelfRoundedCornerRadius;
+    // Extend the opaque layer a little bit so that only two rounded
+    // corners are visible, even when gestures to show the shelf "overshoot"
+    // the standard shelf size a little bit. Extend the layer in the same
+    // direction where the shelf is aligned (downwards for a bottom
+    // shelf, etc.).
+    const int safety_margin = 3 * radius;
+    opaque_background_bounds.Inset(
+        -shelf->SelectValueForShelfAlignment(0, safety_margin, 0), 0,
+        -shelf->SelectValueForShelfAlignment(0, 0, safety_margin),
+        -shelf->SelectValueForShelfAlignment(safety_margin, 0, 0));
+    if (!mask_) {
+      mask_ = views::Painter::CreatePaintedLayer(
+          views::Painter::CreateSolidRoundRectPainter(SK_ColorBLACK, radius));
+      mask_->layer()->SetFillsBoundsOpaquely(false);
+      opaque_background_.SetMaskLayer(mask_->layer());
     }
+    if (mask_->layer()->bounds() != opaque_background_bounds)
+      mask_->layer()->SetBounds(opaque_background_bounds);
   }
   opaque_background_.SetBounds(opaque_background_bounds);
   UpdateBackgroundBlur();
@@ -277,10 +292,11 @@ ShelfWidget::ShelfWidget(aura::Window* shelf_container, Shelf* shelf)
   views::Widget::InitParams params(
       views::Widget::InitParams::TYPE_WINDOW_FRAMELESS);
   params.name = "ShelfWidget";
-  params.opacity = views::Widget::InitParams::TRANSLUCENT_WINDOW;
+  params.layer_type = ui::LAYER_NOT_DRAWN;
   params.ownership = views::Widget::InitParams::WIDGET_OWNS_NATIVE_WIDGET;
   params.delegate = delegate_view_;
   params.parent = shelf_container;
+
   Init(params);
 
   // The shelf should not take focus when initially shown.
@@ -524,4 +540,16 @@ void ShelfWidget::ShowIfHidden() {
     Show();
 }
 
+void ShelfWidget::OnMouseEvent(ui::MouseEvent* event) {
+  if (event->type() == ui::ET_MOUSE_PRESSED)
+    keyboard::KeyboardController::Get()->HideKeyboardImplicitlyByUser();
+  views::Widget::OnMouseEvent(event);
+}
+
+void ShelfWidget::OnGestureEvent(ui::GestureEvent* event) {
+  if (event->type() == ui::ET_GESTURE_TAP_DOWN)
+    keyboard::KeyboardController::Get()->HideKeyboardImplicitlyByUser();
+  views::Widget::OnGestureEvent(event);
+}
+
 }  // namespace ash
