@@ -2,10 +2,11 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#include "ash/session/session_state_delegate.h"
+#include "ash/public/cpp/shell_window_ids.h"
+#include "ash/session/session_controller.h"
 #include "ash/shell.h"
 #include "ash/shell/example_factory.h"
-#include "ash/shell_window_ids.h"
+#include "ash/shell/example_session_controller_client.h"
 #include "base/strings/utf_string_conversions.h"
 #include "ui/aura/window.h"
 #include "ui/aura/window_event_dispatcher.h"
@@ -13,44 +14,41 @@
 #include "ui/gfx/font_list.h"
 #include "ui/gfx/geometry/rect.h"
 #include "ui/gfx/text_utils.h"
-#include "ui/views/controls/button/label_button.h"
+#include "ui/views/controls/button/md_text_button.h"
 #include "ui/views/corewm/tooltip_controller.h"
 #include "ui/views/widget/widget.h"
 #include "ui/views/widget/widget_delegate.h"
 
-using ash::Shell;
-
 namespace ash {
 namespace shell {
 
 class LockView : public views::WidgetDelegateView,
                  public views::ButtonListener {
  public:
-  LockView() : unlock_button_(new views::LabelButton(
-                                  this, base::ASCIIToUTF16("Unlock"))) {
-    unlock_button_->SetStyle(views::Button::STYLE_BUTTON);
+  LockView()
+      : unlock_button_(
+            views::MdTextButton::Create(this, base::ASCIIToUTF16("Unlock"))) {
     AddChildView(unlock_button_);
-    unlock_button_->SetFocusable(true);
   }
-  virtual ~LockView() {}
+  ~LockView() override = default;
 
   // Overridden from views::View:
-  virtual gfx::Size GetPreferredSize() const OVERRIDE {
+  gfx::Size CalculatePreferredSize() const override {
     return gfx::Size(500, 400);
   }
 
  private:
   // Overridden from views::View:
-  virtual void OnPaint(gfx::Canvas* canvas) OVERRIDE {
+  void OnPaint(gfx::Canvas* canvas) override {
     canvas->FillRect(GetLocalBounds(), SK_ColorYELLOW);
     base::string16 text = base::ASCIIToUTF16("LOCKED!");
     int string_width = gfx::GetStringWidth(text, font_list_);
     canvas->DrawStringRect(text, font_list_, SK_ColorRED,
-                           gfx::Rect((width() - string_width)/ 2,
+                           gfx::Rect((width() - string_width) / 2,
                                      (height() - font_list_.GetHeight()) / 2,
                                      string_width, font_list_.GetHeight()));
   }
-  virtual void Layout() OVERRIDE {
+  void Layout() override {
     gfx::Rect bounds = GetLocalBounds();
     gfx::Size ps = unlock_button_->GetPreferredSize();
     bounds.set_y(bounds.bottom() - ps.height() - 5);
@@ -58,26 +56,25 @@ class LockView : public views::WidgetDelegateView,
     bounds.set_size(ps);
     unlock_button_->SetBoundsRect(bounds);
   }
-  virtual void ViewHierarchyChanged(
-      const ViewHierarchyChangedDetails& details) OVERRIDE {
+  void ViewHierarchyChanged(
+      const ViewHierarchyChangedDetails& details) override {
     if (details.is_add && details.child == this)
       unlock_button_->RequestFocus();
   }
 
   // Overridden from views::WidgetDelegateView:
-  virtual void WindowClosing() OVERRIDE {
-    Shell::GetInstance()->session_state_delegate()->UnlockScreen();
+  void WindowClosing() override {
+    ExampleSessionControllerClient::Get()->UnlockScreen();
   }
 
   // Overridden from views::ButtonListener:
-  virtual void ButtonPressed(views::Button* sender,
-                             const ui::Event& event) OVERRIDE {
+  void ButtonPressed(views::Button* sender, const ui::Event& event) override {
     DCHECK(sender == unlock_button_);
     GetWidget()->Close();
   }
 
   gfx::FontList font_list_;
-  views::LabelButton* unlock_button_;
+  views::Button* unlock_button_;
 
   DISALLOW_COPY_AND_ASSIGN(LockView);
 };
@@ -97,14 +94,12 @@ void CreateLockScreen() {
   params.parent = Shell::GetContainer(Shell::GetPrimaryRootWindow(),
                                       kShellWindowId_LockScreenContainer);
   widget->Init(params);
-  widget->SetContentsView(lock_view);
   widget->Show();
   widget->GetNativeView()->SetName("LockView");
   widget->GetNativeView()->Focus();
 
   // TODO: it shouldn't be necessary to invoke UpdateTooltip() here.
-  Shell::GetInstance()->tooltip_controller()->UpdateTooltip(
-      widget->GetNativeView());
+  Shell::Get()->tooltip_controller()->UpdateTooltip(widget->GetNativeView());
 }
 
 }  // namespace shell
