@@ -24,15 +24,11 @@ class ShellDelegateImpl : public ShellDelegate {
   ~ShellDelegateImpl() override;
 
   // ShellDelegate:
-  ::service_manager::Connector* GetShellConnector() const override;
   bool CanShowWindowForUser(aura::Window* window) const override;
-  void PreInit() override;
   std::unique_ptr<keyboard::KeyboardUI> CreateKeyboardUI() override;
-  void OpenUrlFromArc(const GURL& url) override;
-  NetworkingConfigDelegate* GetNetworkingConfigDelegate() override;
   std::unique_ptr<ScreenshotDelegate> CreateScreenshotDelegate() override;
   AccessibilityDelegate* CreateAccessibilityDelegate() override;
-  ui::InputDeviceControllerClient* GetInputDeviceControllerClient() override;
+  ws::InputDeviceControllerClient* GetInputDeviceControllerClient() override;
 
  private:
   DISALLOW_COPY_AND_ASSIGN(ShellDelegateImpl);
