@@ -11,7 +11,6 @@
 #include "ash/session/session_controller.h"
 #include "ash/shell.h"
 #include "ash/shell/example_factory.h"
-#include "ash/shell/panel_window.h"
 #include "ash/shell/toplevel_window.h"
 #include "ash/system/message_center/notification_tray.h"
 #include "ash/system/status_area_widget.h"
@@ -178,8 +177,6 @@ WindowTypeLauncher::WindowTypeLauncher(
     const base::Closure& show_views_examples_callback)
     : create_button_(
           MdTextButton::Create(this, base::ASCIIToUTF16("Create Window"))),
-      panel_button_(
-          MdTextButton::Create(this, base::ASCIIToUTF16("Create Panel"))),
       create_nonresizable_button_(MdTextButton::Create(
           this,
           base::ASCIIToUTF16("Create Non-Resizable Window"))),
@@ -219,7 +216,6 @@ WindowTypeLauncher::WindowTypeLauncher(
   column_set->AddColumn(views::GridLayout::LEADING, views::GridLayout::CENTER,
                         0, views::GridLayout::USE_PREF, 0, 0);
   AddViewToLayout(layout, create_button_);
-  AddViewToLayout(layout, panel_button_);
   AddViewToLayout(layout, create_nonresizable_button_);
   AddViewToLayout(layout, bubble_button_);
   AddViewToLayout(layout, lock_button_);
@@ -268,8 +264,6 @@ void WindowTypeLauncher::ButtonPressed(views::Button* sender,
     params.can_resize = true;
     params.can_maximize = true;
     ToplevelWindow::CreateToplevelWindow(params);
-  } else if (sender == panel_button_) {
-    PanelWindow::CreatePanelWindow(gfx::Rect());
   } else if (sender == create_nonresizable_button_) {
     ToplevelWindow::CreateToplevelWindow(ToplevelWindow::CreateParams());
   } else if (sender == bubble_button_) {
