@@ -4,17 +4,18 @@
 
 #include "ash/sticky_keys/sticky_keys_overlay.h"
 
+#include "ash/public/cpp/shell_window_ids.h"
 #include "ash/shell.h"
-#include "ash/shell_window_ids.h"
 #include "ash/sticky_keys/sticky_keys_controller.h"
+#include "ash/strings/grit/ash_strings.h"
 #include "base/strings/string_util.h"
 #include "base/strings/utf_string_conversions.h"
-#include "grit/ash_strings.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/base/resource/resource_bundle.h"
 #include "ui/compositor/scoped_layer_animation_settings.h"
 #include "ui/gfx/canvas.h"
 #include "ui/gfx/font_list.h"
+#include "ui/gfx/geometry/insets.h"
 #include "ui/views/border.h"
 #include "ui/views/controls/label.h"
 #include "ui/views/layout/box_layout.h"
@@ -39,15 +40,13 @@ const ui::ResourceBundle::FontStyle kKeyLabelFontStyle =
 // Duration of slide animation when overlay is shown or hidden.
 const int kSlideAnimationDurationMs = 100;
 
-}
-
 ///////////////////////////////////////////////////////////////////////////////
 //  StickyKeyOverlayLabel
 class StickyKeyOverlayLabel : public views::Label {
  public:
   explicit StickyKeyOverlayLabel(const std::string& key_name);
 
-  virtual ~StickyKeyOverlayLabel();
+  ~StickyKeyOverlayLabel() override;
 
   StickyKeyState state() const { return state_; }
 
@@ -67,14 +66,11 @@ StickyKeyOverlayLabel::StickyKeyOverlayLabel(const std::string& key_name)
   SetHorizontalAlignment(gfx::ALIGN_LEFT);
   SetFontList(rb->GetFontList(kKeyLabelFontStyle));
   SetAutoColorReadabilityEnabled(false);
-  SetFocusable(false);
   SetEnabledColor(SkColorSetARGB(0x80, 0xFF, 0xFF, 0xFF));
-  SetDisabledColor(SkColorSetARGB(0x80, 0xFF, 0xFF, 0xFF));
-  set_subpixel_rendering_enabled(false);
+  SetSubpixelRenderingEnabled(false);
 }
 
-StickyKeyOverlayLabel::~StickyKeyOverlayLabel() {
-}
+StickyKeyOverlayLabel::~StickyKeyOverlayLabel() = default;
 
 void StickyKeyOverlayLabel::SetKeyState(StickyKeyState state) {
   state_ = state;
@@ -95,20 +91,24 @@ void StickyKeyOverlayLabel::SetKeyState(StickyKeyState state) {
   }
 
   SetEnabledColor(label_color);
-  SetDisabledColor(label_color);
   SetFontList(font_list().DeriveWithStyle(style));
 }
 
+}  // namespace
+
 ///////////////////////////////////////////////////////////////////////////////
 //  StickyKeysOverlayView
-class StickyKeysOverlayView : public views::WidgetDelegateView {
+class StickyKeysOverlayView : public views::View {
  public:
+  // This object is not owned by the views hiearchy or by the widget. The
+  // StickyKeysOverlay is the only class that should create and destroy this
+  // view.
   StickyKeysOverlayView();
 
-  virtual ~StickyKeysOverlayView();
+  ~StickyKeysOverlayView() override;
 
-  // views::WidgetDelegateView overrides:
-  virtual void OnPaint(gfx::Canvas* canvas) OVERRIDE;
+  // views::View overrides:
+  void OnPaint(gfx::Canvas* canvas) override;
 
   void SetKeyState(ui::EventFlags modifier, StickyKeyState state);
 
@@ -127,6 +127,9 @@ class StickyKeysOverlayView : public views::WidgetDelegateView {
 };
 
 StickyKeysOverlayView::StickyKeysOverlayView() {
+  // The parent StickyKeysOverlay object owns this view.
+  set_owned_by_client();
+
   const gfx::Font& font =
       ui::ResourceBundle::GetSharedInstance().GetFont(kKeyLabelFontStyle);
   int font_size = font.GetFontSize();
@@ -138,30 +141,27 @@ StickyKeysOverlayView::StickyKeysOverlayView() {
   int vertical_spacing = font_size / 2 - font_padding;
   int child_spacing = font_size - 2 * font_padding;
 
-  SetLayoutManager(new views::BoxLayout(views::BoxLayout::kVertical,
-                                        horizontal_spacing,
-                                        vertical_spacing,
-                                        child_spacing));
+  SetLayoutManager(std::make_unique<views::BoxLayout>(
+      views::BoxLayout::kVertical,
+      gfx::Insets(vertical_spacing, horizontal_spacing), child_spacing));
   AddKeyLabel(ui::EF_CONTROL_DOWN,
               l10n_util::GetStringUTF8(IDS_ASH_CONTROL_KEY));
-  AddKeyLabel(ui::EF_ALT_DOWN,
-              l10n_util::GetStringUTF8(IDS_ASH_ALT_KEY));
-  AddKeyLabel(ui::EF_SHIFT_DOWN,
-              l10n_util::GetStringUTF8(IDS_ASH_SHIFT_KEY));
-  AddKeyLabel(ui::EF_ALTGR_DOWN,
-              l10n_util::GetStringUTF8(IDS_ASH_ALTGR_KEY));
-  AddKeyLabel(ui::EF_MOD3_DOWN,
-              l10n_util::GetStringUTF8(IDS_ASH_MOD3_KEY));
+  AddKeyLabel(ui::EF_ALT_DOWN, l10n_util::GetStringUTF8(IDS_ASH_ALT_KEY));
+  AddKeyLabel(ui::EF_SHIFT_DOWN, l10n_util::GetStringUTF8(IDS_ASH_SHIFT_KEY));
+  AddKeyLabel(ui::EF_COMMAND_DOWN,
+              l10n_util::GetStringUTF8(IDS_ASH_SEARCH_KEY));
+  AddKeyLabel(ui::EF_ALTGR_DOWN, l10n_util::GetStringUTF8(IDS_ASH_ALTGR_KEY));
+  AddKeyLabel(ui::EF_MOD3_DOWN, l10n_util::GetStringUTF8(IDS_ASH_MOD3_KEY));
 }
 
-StickyKeysOverlayView::~StickyKeysOverlayView() {}
+StickyKeysOverlayView::~StickyKeysOverlayView() = default;
 
 void StickyKeysOverlayView::OnPaint(gfx::Canvas* canvas) {
-  SkPaint paint;
-  paint.setStyle(SkPaint::kFill_Style);
-  paint.setColor(SkColorSetARGB(0xB3, 0x55, 0x55, 0x55));
-  canvas->DrawRoundRect(GetLocalBounds(), 2, paint);
-  views::WidgetDelegateView::OnPaint(canvas);
+  cc::PaintFlags flags;
+  flags.setStyle(cc::PaintFlags::kFill_Style);
+  flags.setColor(SkColorSetARGB(0xB3, 0x55, 0x55, 0x55));
+  canvas->DrawRoundRect(GetLocalBounds(), 2, flags);
+  views::View::OnPaint(canvas);
 }
 
 void StickyKeysOverlayView::SetKeyState(ui::EventFlags modifier,
@@ -213,18 +213,21 @@ StickyKeysOverlay::StickyKeysOverlay()
   params.accept_events = false;
   params.keep_on_top = true;
   params.remove_standard_frame = true;
-  params.delegate = overlay_view_;
   params.bounds = CalculateOverlayBounds();
-  params.parent = Shell::GetContainer(Shell::GetTargetRootWindow(),
+  params.parent = Shell::GetContainer(Shell::GetRootWindowForNewWindows(),
                                       kShellWindowId_OverlayContainer);
   overlay_widget_.reset(new views::Widget);
   overlay_widget_->Init(params);
   overlay_widget_->SetVisibilityChangedAnimationsEnabled(false);
-  overlay_widget_->SetContentsView(overlay_view_);
+  overlay_widget_->SetContentsView(overlay_view_.get());
   overlay_widget_->GetNativeView()->SetName("StickyKeysOverlay");
 }
 
-StickyKeysOverlay::~StickyKeysOverlay() {}
+StickyKeysOverlay::~StickyKeysOverlay() {
+  // Remove ourself from the animator to avoid being re-entrantly called in
+  // |overlay_widget_|'s destructor.
+  StopObservingImplicitAnimations();
+}
 
 void StickyKeysOverlay::Show(bool visible) {
   if (is_visible_ == visible)
@@ -236,7 +239,6 @@ void StickyKeysOverlay::Show(bool visible) {
   overlay_widget_->SetBounds(CalculateOverlayBounds());
 
   ui::LayerAnimator* animator = overlay_widget_->GetLayer()->GetAnimator();
-  animator->AddObserver(this);
 
   // Ensure transform is correct before beginning animation.
   if (!animator->is_animating()) {
@@ -248,6 +250,7 @@ void StickyKeysOverlay::Show(bool visible) {
   }
 
   ui::ScopedLayerAnimationSettings settings(animator);
+  settings.AddObserver(this);
   settings.SetPreemptionStrategy(
       ui::LayerAnimator::IMMEDIATELY_ANIMATE_TO_NEW_TARGET);
   settings.SetTweenType(visible ? gfx::Tween::EASE_OUT : gfx::Tween::EASE_IN);
@@ -272,34 +275,26 @@ void StickyKeysOverlay::SetModifierKeyState(ui::EventFlags modifier,
   overlay_view_->SetKeyState(modifier, state);
 }
 
-StickyKeyState StickyKeysOverlay::GetModifierKeyState(
-    ui::EventFlags modifier) {
+StickyKeyState StickyKeysOverlay::GetModifierKeyState(ui::EventFlags modifier) {
   return overlay_view_->GetKeyState(modifier);
 }
 
+views::Widget* StickyKeysOverlay::GetWidgetForTesting() {
+  return overlay_widget_.get();
+}
+
 gfx::Rect StickyKeysOverlay::CalculateOverlayBounds() {
   int x = is_visible_ ? kHorizontalOverlayOffset : -widget_size_.width();
   return gfx::Rect(gfx::Point(x, kVerticalOverlayOffset), widget_size_);
 }
 
-void StickyKeysOverlay::OnLayerAnimationEnded(
-    ui::LayerAnimationSequence* sequence) {
-  ui::LayerAnimator* animator = overlay_widget_->GetLayer()->GetAnimator();
-  if (animator)
-    animator->RemoveObserver(this);
+void StickyKeysOverlay::OnImplicitAnimationsCompleted() {
+  if (WasAnimationAbortedForProperty(ui::LayerAnimationElement::TRANSFORM))
+    return;
+  DCHECK(
+      WasAnimationCompletedForProperty(ui::LayerAnimationElement::TRANSFORM));
   if (!is_visible_)
     overlay_widget_->Hide();
 }
 
-void StickyKeysOverlay::OnLayerAnimationAborted(
-    ui::LayerAnimationSequence* sequence) {
-  ui::LayerAnimator* animator = overlay_widget_->GetLayer()->GetAnimator();
-  if (animator)
-    animator->RemoveObserver(this);
-}
-
-void StickyKeysOverlay::OnLayerAnimationScheduled(
-    ui::LayerAnimationSequence* sequence) {
-}
-
 }  // namespace ash
