@@ -4,50 +4,31 @@
 
 #include "ash/sticky_keys/sticky_keys_controller.h"
 
-#include <X11/Xlib.h>
-#undef None
-#undef Bool
-#undef RootWindow
-
 #include "ash/shell.h"
 #include "ash/test/ash_test_base.h"
 #include "base/bind.h"
 #include "base/callback.h"
-#include "base/memory/scoped_vector.h"
 #include "ui/aura/window.h"
 #include "ui/aura/window_tree_host.h"
 #include "ui/events/event_source.h"
-#include "ui/events/test/events_test_utils_x11.h"
+#include "ui/events/event_utils.h"
 
 namespace ash {
 
-namespace {
-
-// The device id of the test touchpad device.
-const unsigned int kTouchPadDeviceId = 1;
-
-}  // namespace
-
-class StickyKeysTest : public test::AshTestBase {
+class StickyKeysTest : public AshTestBase {
  protected:
-  StickyKeysTest()
-      : target_(NULL),
-        root_window_(NULL) {}
+  StickyKeysTest() : target_(NULL), root_window_(NULL) {}
 
-  virtual void SetUp() override {
-    test::AshTestBase::SetUp();
+  void SetUp() override {
+    AshTestBase::SetUp();
 
     // |target_| owned by root window of shell. It is still safe to delete
     // it ourselves.
     target_ = CreateTestWindowInShellWithId(0);
     root_window_ = target_->GetRootWindow();
-
-    ui::SetUpTouchPadForTest(kTouchPadDeviceId);
   }
 
-  virtual void TearDown() override {
-    test::AshTestBase::TearDown();
-  }
+  void TearDown() override { AshTestBase::TearDown(); }
 
   virtual void OnShortcutPressed() {
     if (target_) {
@@ -57,9 +38,7 @@ class StickyKeysTest : public test::AshTestBase {
   }
 
   ui::KeyEvent* GenerateKey(ui::EventType type, ui::KeyboardCode code) {
-    scoped_xevent_.InitKeyEvent(type, code, 0);
-    ui::KeyEvent* event = new ui::KeyEvent(scoped_xevent_);
-    return event;
+    return GenerateSynthesizedKeyEvent(type, code);
   }
 
   // Creates a mouse event backed by a native XInput2 generic button event.
@@ -72,48 +51,35 @@ class StickyKeysTest : public test::AshTestBase {
   // The |location| should be in physical pixels.
   ui::MouseEvent* GenerateMouseEventAt(ui::EventType type,
                                        const gfx::Point& location) {
-    scoped_xevent_.InitGenericButtonEvent(
-        kTouchPadDeviceId,
-        type,
-        location,
-        0);
-    ui::MouseEvent* event = new ui::MouseEvent(scoped_xevent_);
-    return event;
+    return GenerateSynthesizedMouseEventAt(type, location);
   }
 
   ui::MouseWheelEvent* GenerateMouseWheelEvent(int wheel_delta) {
-    EXPECT_NE(0, wheel_delta);
-    scoped_xevent_.InitGenericMouseWheelEvent(
-        kTouchPadDeviceId, wheel_delta, 0);
-    ui::MouseWheelEvent* event = new ui::MouseWheelEvent(scoped_xevent_);
-    ui::Event::DispatcherApi dispatcher(event);
-    dispatcher.set_target(target_);
-    return event;
+    return GenerateSynthesizedMouseWheelEvent(wheel_delta);
   }
 
   ui::ScrollEvent* GenerateScrollEvent(int scroll_delta) {
-    scoped_xevent_.InitScrollEvent(kTouchPadDeviceId, // deviceid
-                                   0,               // x_offset
-                                   scroll_delta,    // y_offset
-                                   0,               // x_offset_ordinal
-                                   scroll_delta,    // y_offset_ordinal
-                                   2);              // finger_count
-    ui::ScrollEvent* event = new ui::ScrollEvent(scoped_xevent_);
+    ui::ScrollEvent* event = new ui::ScrollEvent(
+        ui::ET_SCROLL, gfx::Point(0, 0), ui::EventTimeForNow(), ui::EF_NONE,
+        0,             // x_offset
+        scroll_delta,  // y_offset
+        0,             // x_offset_ordinal
+        scroll_delta,  // y_offset_ordinal
+        2);            // finger_count
     ui::Event::DispatcherApi dispatcher(event);
     dispatcher.set_target(target_);
     return event;
   }
 
-  ui::ScrollEvent* GenerateFlingScrollEvent(int fling_delta,
-                                            bool is_cancel) {
-    scoped_xevent_.InitFlingScrollEvent(
-        kTouchPadDeviceId, // deviceid
-        0,               // x_velocity
-        fling_delta,     // y_velocity
-        0,               // x_velocity_ordinal
-        fling_delta,     // y_velocity_ordinal
-        is_cancel);      // is_cancel
-    ui::ScrollEvent* event = new ui::ScrollEvent(scoped_xevent_);
+  ui::ScrollEvent* GenerateFlingScrollEvent(int fling_delta, bool is_cancel) {
+    ui::ScrollEvent* event = new ui::ScrollEvent(
+        is_cancel ? ui::ET_SCROLL_FLING_CANCEL : ui::ET_SCROLL_FLING_START,
+        gfx::Point(0, 0), ui::EventTimeForNow(), ui::EF_NONE,
+        0,            // x_velocity
+        fling_delta,  // y_velocity
+        0,            // x_velocity_ordinal
+        fling_delta,  // y_velocity_ordinal
+        11);          // finger_count
     ui::Event::DispatcherApi dispatcher(event);
     dispatcher.set_target(target_);
     return event;
@@ -128,11 +94,16 @@ class StickyKeysTest : public test::AshTestBase {
   // Creates a synthesized MouseEvent that is not backed by a native event.
   ui::MouseEvent* GenerateSynthesizedMouseEventAt(ui::EventType event_type,
                                                   const gfx::Point& location) {
-    ui::MouseEvent* event = new ui::MouseEvent(event_type,
-                                               location,
-                                               location,
-                                               ui::EF_LEFT_MOUSE_BUTTON,
-                                               ui::EF_LEFT_MOUSE_BUTTON);
+    ui::MouseEvent* event;
+    if (event_type == ui::ET_MOUSEWHEEL) {
+      event = new ui::MouseWheelEvent(
+          gfx::Vector2d(), location, location, ui::EventTimeForNow(),
+          ui::EF_LEFT_MOUSE_BUTTON, ui::EF_LEFT_MOUSE_BUTTON);
+    } else {
+      event = new ui::MouseEvent(
+          event_type, location, location, ui::EventTimeForNow(),
+          ui::EF_LEFT_MOUSE_BUTTON, ui::EF_LEFT_MOUSE_BUTTON);
+    }
     ui::Event::DispatcherApi dispatcher(event);
     dispatcher.set_target(target_);
     return event;
@@ -153,7 +124,7 @@ class StickyKeysTest : public test::AshTestBase {
 
   // Creates a synthesized MouseWHeel event.
   ui::MouseWheelEvent* GenerateSynthesizedMouseWheelEvent(int wheel_delta) {
-    scoped_ptr<ui::MouseEvent> mev(
+    std::unique_ptr<ui::MouseEvent> mev(
         GenerateSynthesizedMouseEventAt(ui::ET_MOUSEWHEEL, gfx::Point(0, 0)));
     ui::MouseWheelEvent* event = new ui::MouseWheelEvent(*mev, 0, wheel_delta);
     ui::Event::DispatcherApi dispatcher(event);
@@ -165,25 +136,25 @@ class StickyKeysTest : public test::AshTestBase {
                                     ui::KeyboardCode key_code) {
     bool released = false;
     int down_flags = 0;
-    scoped_ptr<ui::KeyEvent> ev;
+    std::unique_ptr<ui::KeyEvent> ev;
     ev.reset(GenerateKey(ui::ET_KEY_PRESSED, key_code));
-    handler->HandleKeyEvent(*ev.get(), key_code, &down_flags, &released);
+    handler->HandleKeyEvent(*ev.get(), &down_flags, &released);
     ev.reset(GenerateKey(ui::ET_KEY_RELEASED, key_code));
-    handler->HandleKeyEvent(*ev.get(), key_code, &down_flags, &released);
+    handler->HandleKeyEvent(*ev.get(), &down_flags, &released);
   }
 
   bool HandleKeyEvent(const ui::KeyEvent& key_event,
                       StickyKeysHandler* handler,
                       int* down,
                       bool* up) {
-    return handler->HandleKeyEvent(key_event, key_event.key_code(), down, up);
+    return handler->HandleKeyEvent(key_event, down, up);
   }
 
   int HandleKeyEventForDownFlags(const ui::KeyEvent& key_event,
                                  StickyKeysHandler* handler) {
     bool released = false;
     int down = 0;
-    handler->HandleKeyEvent(key_event, key_event.key_code(), &down, &released);
+    handler->HandleKeyEvent(key_event, &down, &released);
     return down;
   }
 
@@ -195,14 +166,11 @@ class StickyKeysTest : public test::AshTestBase {
   // The root window of |target_|. Not owned.
   aura::Window* root_window_;
 
-  // Used to construct the various X events.
-  ui::ScopedXI2Event scoped_xevent_;
-
   DISALLOW_COPY_AND_ASSIGN(StickyKeysTest);
 };
 
 TEST_F(StickyKeysTest, BasicOneshotScenarioTest) {
-  scoped_ptr<ui::KeyEvent> ev;
+  std::unique_ptr<ui::KeyEvent> ev;
   StickyKeysHandler sticky_key(ui::EF_SHIFT_DOWN);
 
   EXPECT_EQ(STICKY_KEY_STATE_DISABLED, sticky_key.current_state());
@@ -227,7 +195,7 @@ TEST_F(StickyKeysTest, BasicOneshotScenarioTest) {
 
   EXPECT_EQ(STICKY_KEY_STATE_DISABLED, sticky_key.current_state());
   // Making sure Shift up keyboard event is available.
-  scoped_ptr<ui::Event> up_event;
+  std::unique_ptr<ui::Event> up_event;
   ASSERT_EQ(0, sticky_key.GetModifierUpEvent(&up_event));
   EXPECT_TRUE(up_event.get());
   EXPECT_EQ(ui::ET_KEY_RELEASED, up_event->type());
@@ -245,7 +213,7 @@ TEST_F(StickyKeysTest, BasicOneshotScenarioTest) {
 }
 
 TEST_F(StickyKeysTest, BasicLockedScenarioTest) {
-  scoped_ptr<ui::KeyEvent> ev;
+  std::unique_ptr<ui::KeyEvent> ev;
   StickyKeysHandler sticky_key(ui::EF_SHIFT_DOWN);
 
   EXPECT_EQ(STICKY_KEY_STATE_DISABLED, sticky_key.current_state());
@@ -286,7 +254,7 @@ TEST_F(StickyKeysTest, BasicLockedScenarioTest) {
 }
 
 TEST_F(StickyKeysTest, NonTargetModifierTest) {
-  scoped_ptr<ui::KeyEvent> ev;
+  std::unique_ptr<ui::KeyEvent> ev;
   StickyKeysHandler sticky_key(ui::EF_SHIFT_DOWN);
 
   EXPECT_EQ(STICKY_KEY_STATE_DISABLED, sticky_key.current_state());
@@ -333,7 +301,7 @@ TEST_F(StickyKeysTest, NonTargetModifierTest) {
 
 TEST_F(StickyKeysTest, NormalShortcutTest) {
   // Sticky keys should not be enabled if we perform a normal shortcut.
-  scoped_ptr<ui::KeyEvent> ev;
+  std::unique_ptr<ui::KeyEvent> ev;
   StickyKeysHandler sticky_key(ui::EF_CONTROL_DOWN);
 
   EXPECT_EQ(STICKY_KEY_STATE_DISABLED, sticky_key.current_state());
@@ -370,8 +338,8 @@ TEST_F(StickyKeysTest, NormalShortcutTest) {
 }
 
 TEST_F(StickyKeysTest, NormalModifiedClickTest) {
-  scoped_ptr<ui::KeyEvent> kev;
-  scoped_ptr<ui::MouseEvent> mev;
+  std::unique_ptr<ui::KeyEvent> kev;
+  std::unique_ptr<ui::MouseEvent> mev;
   StickyKeysHandler sticky_key(ui::EF_CONTROL_DOWN);
 
   EXPECT_EQ(STICKY_KEY_STATE_DISABLED, sticky_key.current_state());
@@ -393,8 +361,8 @@ TEST_F(StickyKeysTest, NormalModifiedClickTest) {
 }
 
 TEST_F(StickyKeysTest, MouseMovedModifierTest) {
-  scoped_ptr<ui::KeyEvent> kev;
-  scoped_ptr<ui::MouseEvent> mev;
+  std::unique_ptr<ui::KeyEvent> kev;
+  std::unique_ptr<ui::MouseEvent> mev;
   StickyKeysHandler sticky_key(ui::EF_CONTROL_DOWN);
 
   EXPECT_EQ(STICKY_KEY_STATE_DISABLED, sticky_key.current_state());
@@ -416,8 +384,8 @@ TEST_F(StickyKeysTest, MouseMovedModifierTest) {
 }
 
 TEST_F(StickyKeysTest, NormalModifiedScrollTest) {
-  scoped_ptr<ui::KeyEvent> kev;
-  scoped_ptr<ui::ScrollEvent> sev;
+  std::unique_ptr<ui::KeyEvent> kev;
+  std::unique_ptr<ui::ScrollEvent> sev;
   StickyKeysHandler sticky_key(ui::EF_CONTROL_DOWN);
 
   EXPECT_EQ(STICKY_KEY_STATE_DISABLED, sticky_key.current_state());
@@ -441,8 +409,8 @@ TEST_F(StickyKeysTest, NormalModifiedScrollTest) {
 }
 
 TEST_F(StickyKeysTest, MouseEventOneshot) {
-  scoped_ptr<ui::MouseEvent> ev;
-  scoped_ptr<ui::KeyEvent> kev;
+  std::unique_ptr<ui::MouseEvent> ev;
+  std::unique_ptr<ui::KeyEvent> kev;
   StickyKeysHandler sticky_key(ui::EF_CONTROL_DOWN);
 
   EXPECT_EQ(STICKY_KEY_STATE_DISABLED, sticky_key.current_state());
@@ -467,7 +435,7 @@ TEST_F(StickyKeysTest, MouseEventOneshot) {
 
   // Making sure modifier key release event is dispatched in the right order.
   EXPECT_TRUE(released);
-  scoped_ptr<ui::Event> up_event;
+  std::unique_ptr<ui::Event> up_event;
   ASSERT_EQ(0, sticky_key.GetModifierUpEvent(&up_event));
   EXPECT_TRUE(up_event.get());
   EXPECT_EQ(ui::ET_KEY_RELEASED, up_event->type());
@@ -489,8 +457,8 @@ TEST_F(StickyKeysTest, MouseEventOneshot) {
 }
 
 TEST_F(StickyKeysTest, MouseEventLocked) {
-  scoped_ptr<ui::MouseEvent> ev;
-  scoped_ptr<ui::KeyEvent> kev;
+  std::unique_ptr<ui::MouseEvent> ev;
+  std::unique_ptr<ui::KeyEvent> kev;
   StickyKeysHandler sticky_key(ui::EF_CONTROL_DOWN);
 
   EXPECT_EQ(STICKY_KEY_STATE_DISABLED, sticky_key.current_state());
@@ -510,7 +478,7 @@ TEST_F(StickyKeysTest, MouseEventLocked) {
     EXPECT_TRUE(mod_down_flags & ui::EF_CONTROL_DOWN);
     ev.reset(GenerateMouseEvent(ui::ET_MOUSE_RELEASED));
     released = false;
-  mod_down_flags = 0;
+    mod_down_flags = 0;
     sticky_key.HandleMouseEvent(*ev.get(), &mod_down_flags, &released);
     EXPECT_TRUE(mod_down_flags & ui::EF_CONTROL_DOWN);
     EXPECT_EQ(STICKY_KEY_STATE_LOCKED, sticky_key.current_state());
@@ -524,7 +492,7 @@ TEST_F(StickyKeysTest, MouseEventLocked) {
     sticky_key.HandleMouseEvent(*ev.get(), &mod_down_flags, &released);
     ev.reset(GenerateMouseWheelEvent(-ui::MouseWheelEvent::kWheelDelta));
     released = false;
-  mod_down_flags = 0;
+    mod_down_flags = 0;
     sticky_key.HandleMouseEvent(*ev.get(), &mod_down_flags, &released);
     EXPECT_TRUE(mod_down_flags & ui::EF_CONTROL_DOWN);
     EXPECT_EQ(STICKY_KEY_STATE_LOCKED, sticky_key.current_state());
@@ -546,8 +514,8 @@ TEST_F(StickyKeysTest, MouseEventLocked) {
 }
 
 TEST_F(StickyKeysTest, ScrollEventOneshot) {
-  scoped_ptr<ui::ScrollEvent> ev;
-  scoped_ptr<ui::KeyEvent> kev;
+  std::unique_ptr<ui::ScrollEvent> ev;
+  std::unique_ptr<ui::KeyEvent> kev;
   StickyKeysHandler sticky_key(ui::EF_CONTROL_DOWN);
 
   int scroll_deltas[] = {-10, 10};
@@ -570,7 +538,7 @@ TEST_F(StickyKeysTest, ScrollEventOneshot) {
     for (int j = 0; j < 3; ++j) {
       ev.reset(GenerateScrollEvent(scroll_deltas[i]));
       released = false;
-  mod_down_flags = 0;
+      mod_down_flags = 0;
       sticky_key.HandleScrollEvent(*ev.get(), &mod_down_flags, &released);
       EXPECT_TRUE(mod_down_flags & ui::EF_CONTROL_DOWN);
       EXPECT_EQ(STICKY_KEY_STATE_ENABLED, sticky_key.current_state());
@@ -579,12 +547,12 @@ TEST_F(StickyKeysTest, ScrollEventOneshot) {
     // Fling start event ends scroll sequence.
     ev.reset(GenerateFlingScrollEvent(scroll_deltas[i], false));
     released = false;
-  mod_down_flags = 0;
+    mod_down_flags = 0;
     sticky_key.HandleScrollEvent(*ev.get(), &mod_down_flags, &released);
     EXPECT_TRUE(mod_down_flags & ui::EF_CONTROL_DOWN);
     EXPECT_EQ(STICKY_KEY_STATE_DISABLED, sticky_key.current_state());
 
-    scoped_ptr<ui::Event> up_event;
+    std::unique_ptr<ui::Event> up_event;
     EXPECT_TRUE(released);
     ASSERT_EQ(0, sticky_key.GetModifierUpEvent(&up_event));
     EXPECT_TRUE(up_event.get());
@@ -595,8 +563,8 @@ TEST_F(StickyKeysTest, ScrollEventOneshot) {
 }
 
 TEST_F(StickyKeysTest, ScrollDirectionChanged) {
-  scoped_ptr<ui::ScrollEvent> ev;
-  scoped_ptr<ui::KeyEvent> kev;
+  std::unique_ptr<ui::ScrollEvent> ev;
+  std::unique_ptr<ui::KeyEvent> kev;
   StickyKeysHandler sticky_key(ui::EF_CONTROL_DOWN);
 
   // Test direction change with both boundary value and negative value.
@@ -617,7 +585,7 @@ TEST_F(StickyKeysTest, ScrollDirectionChanged) {
     for (int j = 0; j < 3; ++j) {
       ev.reset(GenerateScrollEvent(10));
       released = false;
-  mod_down_flags = 0;
+      mod_down_flags = 0;
       sticky_key.HandleScrollEvent(*ev.get(), &mod_down_flags, &released);
       EXPECT_TRUE(mod_down_flags & ui::EF_CONTROL_DOWN);
       EXPECT_EQ(STICKY_KEY_STATE_ENABLED, sticky_key.current_state());
@@ -625,15 +593,15 @@ TEST_F(StickyKeysTest, ScrollDirectionChanged) {
 
     ev.reset(GenerateScrollEvent(direction_change_values[i]));
     released = false;
-  mod_down_flags = 0;
+    mod_down_flags = 0;
     sticky_key.HandleScrollEvent(*ev.get(), &mod_down_flags, &released);
     EXPECT_EQ(STICKY_KEY_STATE_DISABLED, sticky_key.current_state());
   }
 }
 
 TEST_F(StickyKeysTest, ScrollEventLocked) {
-  scoped_ptr<ui::ScrollEvent> ev;
-  scoped_ptr<ui::KeyEvent> kev;
+  std::unique_ptr<ui::ScrollEvent> ev;
+  std::unique_ptr<ui::KeyEvent> kev;
   StickyKeysHandler sticky_key(ui::EF_CONTROL_DOWN);
 
   // Lock sticky keys.
@@ -651,7 +619,7 @@ TEST_F(StickyKeysTest, ScrollEventLocked) {
 
     ev.reset(GenerateScrollEvent(10));
     released = false;
-  mod_down_flags = 0;
+    mod_down_flags = 0;
     sticky_key.HandleScrollEvent(*ev.get(), &mod_down_flags, &released);
     EXPECT_TRUE(mod_down_flags & ui::EF_CONTROL_DOWN);
     ev.reset(GenerateScrollEvent(-10));
@@ -672,7 +640,7 @@ TEST_F(StickyKeysTest, SynthesizedEvents) {
   StickyKeysHandler sticky_key(ui::EF_CONTROL_DOWN);
 
   // Test non-native key events.
-  scoped_ptr<ui::KeyEvent> kev;
+  std::unique_ptr<ui::KeyEvent> kev;
   SendActivateStickyKeyPattern(&sticky_key, ui::VKEY_CONTROL);
   EXPECT_EQ(STICKY_KEY_STATE_ENABLED, sticky_key.current_state());
 
@@ -690,7 +658,7 @@ TEST_F(StickyKeysTest, SynthesizedEvents) {
   SendActivateStickyKeyPattern(&sticky_key, ui::VKEY_CONTROL);
   EXPECT_EQ(STICKY_KEY_STATE_ENABLED, sticky_key.current_state());
 
-  scoped_ptr<ui::MouseEvent> mev;
+  std::unique_ptr<ui::MouseEvent> mev;
   mev.reset(GenerateSynthesizedMouseClickEvent(ui::ET_MOUSE_PRESSED,
                                                gfx::Point(0, 0)));
   bool released = false;
