@@ -6,6 +6,7 @@
 
 #include "ash/accessibility/accessibility_controller.h"
 #include "ash/metrics/user_metrics_recorder.h"
+#include "ash/public/interfaces/accessibility_controller.mojom.h"
 #include "ash/resources/vector_icons/vector_icons.h"
 #include "ash/shelf/shelf_constants.h"
 #include "ash/shell.h"
@@ -26,13 +27,8 @@ DictationButtonTray::DictationButtonTray(Shelf* shelf)
 
   SetInkDropMode(InkDropMode::ON);
 
-  if (chromeos::switches::ShouldUseShelfNewUi()) {
-    off_image_ = gfx::CreateVectorIcon(kDictationOffNewuiIcon, kShelfIconColor);
-    on_image_ = gfx::CreateVectorIcon(kDictationOnNewuiIcon, kShelfIconColor);
-  } else {
-    off_image_ = gfx::CreateVectorIcon(kDictationOffIcon, kShelfIconColor);
-    on_image_ = gfx::CreateVectorIcon(kDictationOnIcon, kShelfIconColor);
-  }
+  off_image_ = gfx::CreateVectorIcon(kDictationOffNewuiIcon, kShelfIconColor);
+  on_image_ = gfx::CreateVectorIcon(kDictationOnNewuiIcon, kShelfIconColor);
   icon_->SetImage(off_image_);
   const int vertical_padding = (kTrayItemSize - off_image_.height()) / 2;
   const int horizontal_padding = (kTrayItemSize - off_image_.width()) / 2;
@@ -51,11 +47,9 @@ DictationButtonTray::~DictationButtonTray() {
 }
 
 bool DictationButtonTray::PerformAction(const ui::Event& event) {
-  UserMetricsRecorder::RecordUserToggleDictation(
-      DictationToggleMethod::kToggleByButton);
+  Shell::Get()->accessibility_controller()->ToggleDictationFromSource(
+      mojom::DictationToggleSource::kButton);
 
-  Shell::Get()->accelerator_controller()->PerformActionIfEnabled(
-      AcceleratorAction::TOGGLE_DICTATION);
   CheckDictationStatusAndUpdateIcon();
   return true;
 }
@@ -80,7 +74,7 @@ base::string16 DictationButtonTray::GetAccessibleNameForTray() {
 }
 
 void DictationButtonTray::HideBubbleWithView(
-    const views::TrayBubbleView* bubble_view) {
+    const TrayBubbleView* bubble_view) {
   // This class has no bubbles to hide.
 }
 
