@@ -38,11 +38,16 @@ void ClockModel::SetUse24HourClock(bool use_24_hour) {
   NotifyDateFormatChanged();
 }
 
-bool ClockModel::IsLoggedIn() {
+bool ClockModel::IsLoggedIn() const {
   return Shell::Get()->session_controller()->login_status() !=
          LoginStatus::NOT_LOGGED_IN;
 }
 
+bool ClockModel::IsSettingsAvailable() const {
+  return Shell::Get()->session_controller()->ShouldEnableSettings() ||
+         can_set_time();
+}
+
 void ClockModel::ShowDateSettings() {
   Shell::Get()->system_tray_model()->client_ptr()->ShowDateSettings();
 }
