@@ -64,7 +64,7 @@ class ASH_EXPORT OverviewButtonTray : public TrayBackgroundView,
   // TrayBackgroundView:
   void ClickedOutsideBubble() override;
   base::string16 GetAccessibleNameForTray() override;
-  void HideBubbleWithView(const views::TrayBubbleView* bubble_view) override;
+  void HideBubbleWithView(const TrayBubbleView* bubble_view) override;
 
  private:
   friend class OverviewButtonTrayTest;
