@@ -9,7 +9,6 @@
 #include <utility>
 
 #include "ash/accelerators/accelerator_controller.h"
-#include "ash/public/cpp/ash_features.h"
 #include "ash/public/cpp/ash_switches.h"
 #include "ash/public/cpp/shell_window_ids.h"
 #include "ash/session/session_controller.h"
@@ -212,7 +211,7 @@ void PowerButtonController::OnPowerButtonEvent(
     const base::TimeTicks& timestamp) {
   if (down) {
     force_off_on_button_up_ = false;
-    if (in_tablet_mode_) {
+    if (UseTabletBehavior()) {
       force_off_on_button_up_ = true;
 
       // When the system resumes in response to the power button being pressed,
@@ -243,7 +242,7 @@ void PowerButtonController::OnPowerButtonEvent(
       return;
     }
 
-    if (!in_tablet_mode_) {
+    if (!UseTabletBehavior()) {
       StartPowerMenuAnimation();
     } else {
       base::TimeDelta timeout = screen_off_when_power_button_down_
@@ -268,23 +267,21 @@ void PowerButtonController::OnPowerButtonEvent(
     power_button_menu_timer_.Stop();
     pre_shutdown_timer_.Stop();
 
-    const bool menu_was_opened = IsMenuOpened();
-    if (!in_tablet_mode_) {
-      // Cancel the menu animation if it's still ongoing when the button is
-      // released on a laptop-mode device.
-      if (menu_was_opened && !show_menu_animation_done_) {
-        static_cast<PowerButtonMenuScreenView*>(menu_widget_->GetContentsView())
-            ->ScheduleShowHideAnimation(false);
-        up_state |= UP_SHOWING_ANIMATION_CANCELLED;
-      }
-
-      // If the button is tapped (i.e. not held long enough to start the
-      // cancellable shutdown animation) while the menu is open, dismiss the
-      // menu.
-      if (menu_shown_when_power_button_down_ && pre_shutdown_timer_was_running)
-        DismissMenu();
+    const bool menu_was_partially_opened =
+        IsMenuOpened() && !show_menu_animation_done_;
+    // Cancel the menu animation if it's still ongoing when the button is
+    // released.
+    if (menu_was_partially_opened) {
+      static_cast<PowerButtonMenuScreenView*>(menu_widget_->GetContentsView())
+          ->ScheduleShowHideAnimation(false);
+      up_state |= UP_SHOWING_ANIMATION_CANCELLED;
     }
 
+    // If the button is tapped (i.e. not held long enough to start the
+    // cancellable shutdown animation) while the menu is open, dismiss the menu.
+    if (menu_shown_when_power_button_down_ && pre_shutdown_timer_was_running)
+      DismissMenu();
+
     // Ignore the event if it comes too soon after the last one.
     if (timestamp - previous_up_time <= kIgnoreRepeatedButtonUpDelay)
       return;
@@ -294,7 +291,7 @@ void PowerButtonController::OnPowerButtonEvent(
         up_state |= UP_MENU_TIMER_WAS_RUNNING;
       if (pre_shutdown_timer_was_running)
         up_state |= UP_PRE_SHUTDOWN_TIMER_WAS_RUNNING;
-      if (menu_was_opened)
+      if (show_menu_animation_done_)
         up_state |= UP_MENU_WAS_OPENED;
       UpdatePowerButtonEventUMAHistogram(up_state);
     }
@@ -302,8 +299,9 @@ void PowerButtonController::OnPowerButtonEvent(
     if (screen_off_when_power_button_down_ || !force_off_on_button_up_)
       return;
 
-    if (menu_timer_was_running || (menu_shown_when_power_button_down_ &&
-                                   pre_shutdown_timer_was_running)) {
+    if (menu_timer_was_running || menu_was_partially_opened ||
+        (menu_shown_when_power_button_down_ &&
+         pre_shutdown_timer_was_running)) {
       display_controller_->SetBacklightsForcedOff(true);
       LockScreenIfRequired();
     }
@@ -353,6 +351,10 @@ void PowerButtonController::DismissMenu() {
       arrow_key_traversal_initially_enabled_);
 }
 
+void PowerButtonController::StopForcingBacklightsOff() {
+  display_controller_->SetBacklightsForcedOff(false);
+}
+
 void PowerButtonController::OnDisplayModeChanged(
     const display::DisplayConfigurator::DisplayStateList& display_states) {
   bool internal_display_off = false;
@@ -453,6 +455,10 @@ void PowerButtonController::OnLockStateEvent(
     lock_button_down_ = false;
 }
 
+bool PowerButtonController::UseTabletBehavior() const {
+  return in_tablet_mode_ || force_tablet_power_button_;
+}
+
 void PowerButtonController::StopTimersAndDismissMenu() {
   pre_shutdown_timer_.Stop();
   power_button_menu_timer_.Stop();
@@ -490,6 +496,7 @@ void PowerButtonController::ProcessCommandLine() {
                      ? ButtonType::LEGACY
                      : ButtonType::NORMAL;
   observe_accelerometer_events_ = cl->HasSwitch(switches::kAshEnableTabletMode);
+  force_tablet_power_button_ = cl->HasSwitch(switches::kForceTabletPowerButton);
 
   ParsePowerButtonPositionSwitch();
 }
