@@ -197,6 +197,10 @@ class ASH_EXPORT PowerStatus : public chromeos::PowerManagerClient::Observer {
   // empty string.
   std::pair<base::string16, base::string16> GetStatusStrings() const;
 
+  // Returns status strings that are generated by current PowerStatus.
+  // For example, "53% - 5:00 left".
+  base::string16 GetInlinedStatusString() const;
+
   // Updates |proto_|. Does not notify observers.
   void SetProtoForTesting(const power_manager::PowerSupplyProperties& proto);
 
