@@ -29,6 +29,7 @@ RotationLockFeaturePodController::~RotationLockFeaturePodController() {
 FeaturePodButton* RotationLockFeaturePodController::CreateButton() {
   DCHECK(!button_);
   button_ = new FeaturePodButton(this);
+  button_->DisableLabelButtonFocus();
   UpdateButton();
   return button_;
 }
@@ -71,25 +72,36 @@ void RotationLockFeaturePodController::UpdateButton() {
 
   button_->SetToggled(rotation_locked);
 
+  base::string16 tooltip_state;
+
   if (rotation_locked && is_portrait) {
     button_->SetVectorIcon(kUnifiedMenuRotationLockPortraitIcon);
     button_->SetLabel(l10n_util::GetStringUTF16(
         IDS_ASH_STATUS_TRAY_ROTATION_LOCK_LOCKED_LABEL));
     button_->SetSubLabel(l10n_util::GetStringUTF16(
         IDS_ASH_STATUS_TRAY_ROTATION_LOCK_LOCKED_VERTICAL_SUBLABEL));
+    tooltip_state = l10n_util::GetStringUTF16(
+        IDS_ASH_STATUS_TRAY_ROTATION_LOCK_LOCKED_VERTICAL_TOOLTIP);
   } else if (rotation_locked && !is_portrait) {
     button_->SetVectorIcon(kUnifiedMenuRotationLockLandscapeIcon);
     button_->SetLabel(l10n_util::GetStringUTF16(
         IDS_ASH_STATUS_TRAY_ROTATION_LOCK_LOCKED_LABEL));
     button_->SetSubLabel(l10n_util::GetStringUTF16(
         IDS_ASH_STATUS_TRAY_ROTATION_LOCK_LOCKED_HORIZONTAL_SUBLABEL));
+    tooltip_state = l10n_util::GetStringUTF16(
+        IDS_ASH_STATUS_TRAY_ROTATION_LOCK_LOCKED_HORIZONTAL_TOOLTIP);
   } else {
     button_->SetVectorIcon(kUnifiedMenuRotationLockAutoIcon);
     button_->SetLabel(l10n_util::GetStringUTF16(
         IDS_ASH_STATUS_TRAY_ROTATION_LOCK_AUTO_LABEL));
     button_->SetSubLabel(l10n_util::GetStringUTF16(
         IDS_ASH_STATUS_TRAY_ROTATION_LOCK_AUTO_SUBLABEL));
+    tooltip_state =
+        l10n_util::GetStringUTF16(IDS_ASH_STATUS_TRAY_ROTATION_LOCK_AUTO_LABEL);
   }
+
+  button_->SetIconAndLabelTooltips(l10n_util::GetStringFUTF16(
+      IDS_ASH_STATUS_TRAY_ROTATION_LOCK_TOOLTIP, tooltip_state));
 }
 
 }  // namespace ash
