@@ -98,6 +98,10 @@ constexpr int kTrayIconSize = 16;
 extern const SkColor kTrayIconColor;
 extern const SkColor kOobeTrayIconColor;
 
+// The padding around network tray icon in dip.
+constexpr int kTrayNetworkIconPadding = 2;
+constexpr int kUnifiedTrayNetworkIconPadding = 4;
+
 // The total visual padding at the start and end of the icon/label section
 // of the tray.
 constexpr int kTrayEdgePadding = 6;
@@ -166,8 +170,10 @@ constexpr SkColor kUnifiedFeaturePodHoverColor =
 constexpr gfx::Insets kUnifiedMenuItemPadding(0, 16, 16, 16);
 constexpr gfx::Insets kUnifiedSliderPadding(0, 16);
 
+constexpr int kUnifiedMenuVerticalPadding = 8;
 constexpr int kUnifiedNotificationCenterSpacing = 16;
 constexpr int kUnifiedTrayIconSize = 20;
+constexpr int kUnifiedTraySpacingBetweenIcons = 2;
 constexpr int kUnifiedTrayCornerRadius = 20;
 constexpr int kUnifiedTrayContentPadding = 5;
 constexpr int kUnifiedTopShortcutSpacing = 16;
@@ -234,18 +240,10 @@ constexpr int kUnifiedDetailedViewTitleRowHeight = 64;
 class TrayConstants {
  public:
   // Returns the width of a line used to separate tray items in the shelf.
-  static int separator_width() {
-    return UseNewUi() ? kSeparatorWidthNewUi : kSeparatorWidth;
-  }
+  static int separator_width() { return kSeparatorWidthNewUi; }
 
   static int GetTrayIconSize();
 
- private:
-  static bool UseNewUi() {
-    static bool use_new_ui = chromeos::switches::ShouldUseShelfNewUi();
-    return use_new_ui;
-  }
-
   DISALLOW_IMPLICIT_CONSTRUCTORS(TrayConstants);
 };
 
