@@ -4,6 +4,7 @@
 
 #include "ash/system/tray/tray_detailed_view.h"
 
+#include "ash/public/cpp/ash_features.h"
 #include "ash/public/cpp/ash_view_ids.h"
 #include "ash/strings/grit/ash_strings.h"
 #include "ash/system/tray/detailed_view_delegate.h"
@@ -111,8 +112,9 @@ class ScrollContentsView : public views::View {
     // that's below the header view so we don't get both a separator and a full
     // shadow.
     if (y() != 0 && !did_draw_shadow)
-      DrawShadow(paint_info.context(),
-                 gfx::Rect(0, 0, width(), -y() - kSeparatorWidth));
+      DrawShadow(
+          paint_info.context(),
+          gfx::Rect(0, 0, width(), -y() - TrayConstants::separator_width()));
   }
 
   void Layout() override {
@@ -370,7 +372,8 @@ void TrayDetailedView::SetupConnectingScrollListItem(HoverHighlightView* view) {
 
 TriView* TrayDetailedView::AddScrollListSubHeader(const gfx::VectorIcon& icon,
                                                   int text_id) {
-  TriView* header = TrayPopupUtils::CreateSubHeaderRowView(!icon.is_empty());
+  TriView* header = TrayPopupUtils::CreateSubHeaderRowView(
+      features::IsSystemTrayUnifiedEnabled() || !icon.is_empty());
   TrayPopupUtils::ConfigureAsStickyHeader(header);
 
   views::Label* label = TrayPopupUtils::CreateDefaultLabel();
@@ -379,7 +382,7 @@ TriView* TrayDetailedView::AddScrollListSubHeader(const gfx::VectorIcon& icon,
   style.SetupLabel(label);
   header->AddView(TriView::Container::CENTER, label);
 
-  if (!icon.is_empty()) {
+  if (features::IsSystemTrayUnifiedEnabled() || !icon.is_empty()) {
     views::ImageView* image_view = TrayPopupUtils::CreateMainImageView();
     image_view->SetImage(gfx::CreateVectorIcon(
         icon, GetNativeTheme()->GetSystemColor(
@@ -469,9 +472,4 @@ int TrayDetailedView::GetHeightForWidth(int width) const {
   return height();
 }
 
-void TrayDetailedView::RequestFocus() {
-  if (back_button_)
-    back_button_->RequestFocus();
-}
-
 }  // namespace ash
