@@ -9,6 +9,7 @@
 #include "ash/system/tray/system_tray.h"
 #include "ash/system/tray/system_tray_item.h"
 #include "ash/system/tray/tray_constants.h"
+#include "ui/accessibility/ax_node_data.h"
 #include "ui/compositor/layer.h"
 #include "ui/compositor/scoped_animation_duration_scale_mode.h"
 #include "ui/gfx/animation/slide_animation.h"
@@ -25,6 +26,14 @@ const int kTrayItemAnimationDurationMS = 200;
 
 }  // namespace
 
+void IconizedLabel::GetAccessibleNodeData(ui::AXNodeData* node_data) {
+  if (custom_accessible_name_.empty())
+    return Label::GetAccessibleNodeData(node_data);
+
+  node_data->role = ax::mojom::Role::kStaticText;
+  node_data->SetName(custom_accessible_name_);
+}
+
 TrayItemView::TrayItemView(SystemTrayItem* owner)
     : owner_(owner), label_(NULL), image_view_(NULL) {
   SetPaintToLayer();
@@ -35,7 +44,7 @@ TrayItemView::TrayItemView(SystemTrayItem* owner)
 TrayItemView::~TrayItemView() = default;
 
 void TrayItemView::CreateLabel() {
-  label_ = new views::Label;
+  label_ = new IconizedLabel;
   AddChildView(label_);
   PreferredSizeChanged();
 }
