@@ -10,6 +10,7 @@
 #include "ash/ash_export.h"
 #include "base/macros.h"
 #include "ui/gfx/animation/animation_delegate.h"
+#include "ui/views/controls/label.h"
 #include "ui/views/view.h"
 
 namespace gfx {
@@ -18,12 +19,28 @@ class SlideAnimation;
 
 namespace views {
 class ImageView;
-class Label;
 }
 
 namespace ash {
 class SystemTrayItem;
 
+// Lable view which can be given a different data from the visible label.
+// IME icons like "US" (US keyboard) or "あ(Google Japanese Input)" are
+// rendered as a label, but reading such text literally will not always be
+// understandable.
+class IconizedLabel : public views::Label {
+ public:
+  void SetCustomAccessibleName(const base::string16& name) {
+    custom_accessible_name_ = name;
+  }
+
+  // views::Label:
+  void GetAccessibleNodeData(ui::AXNodeData* node_data) override;
+
+ private:
+  base::string16 custom_accessible_name_;
+};
+
 // Base-class for items in the tray. It makes sure the widget is updated
 // correctly when the visibility/size of the tray item changes. It also adds
 // animation when showing/hiding the item in the tray.
@@ -39,7 +56,7 @@ class ASH_EXPORT TrayItemView : public views::View,
   void CreateImageView();
 
   SystemTrayItem* owner() const { return owner_; }
-  views::Label* label() const { return label_; }
+  IconizedLabel* label() const { return label_; }
   views::ImageView* image_view() const { return image_view_; }
 
   // Overridden from views::View.
@@ -63,7 +80,7 @@ class ASH_EXPORT TrayItemView : public views::View,
   SystemTrayItem* owner_;
   std::unique_ptr<gfx::SlideAnimation> animation_;
   // Only one of |label_| and |image_view_| should be non-null.
-  views::Label* label_;
+  IconizedLabel* label_;
   views::ImageView* image_view_;
 
   DISALLOW_COPY_AND_ASSIGN(TrayItemView);
