@@ -19,6 +19,7 @@
 #include "base/strings/utf_string_conversions.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/gfx/paint_vector_icon.h"
+#include "ui/strings/grit/ui_strings.h"
 #include "ui/views/border.h"
 #include "ui/views/controls/button/image_button.h"
 #include "ui/views/controls/button/label_button.h"
@@ -45,9 +46,7 @@ class CloseButton : public TopShortcutButton, public views::ButtonListener {
 };
 
 CloseButton::CloseButton(UnifiedSystemTrayController* controller)
-    : TopShortcutButton(this,
-                        views::kIcCloseIcon,
-                        IDS_ASH_WINDOW_CONTROL_ACCNAME_CLOSE),
+    : TopShortcutButton(this, views::kIcCloseIcon, IDS_APP_ACCNAME_CLOSE),
       controller_(controller) {}
 
 void CloseButton::ButtonPressed(views::Button* sender, const ui::Event& event) {
@@ -121,6 +120,18 @@ class Separator : public views::View {
   DISALLOW_COPY_AND_ASSIGN(Separator);
 };
 
+views::View* CreateAddUserErrorView(const base::string16& message) {
+  auto* label = new views::Label(message);
+  label->SetEnabledColor(kUnifiedMenuTextColor);
+  label->SetAutoColorReadabilityEnabled(false);
+  label->SetSubpixelRenderingEnabled(false);
+  label->SetBorder(
+      views::CreateEmptyBorder(gfx::Insets(kUnifiedTopShortcutSpacing)));
+  label->SetMultiLine(true);
+  label->SetHorizontalAlignment(gfx::HorizontalAlignment::ALIGN_LEFT);
+  return label;
+}
+
 }  // namespace
 
 views::View* CreateUserAvatarView(int user_index) {
@@ -148,6 +159,9 @@ base::string16 GetUserItemAccessibleString(int user_index) {
       Shell::Get()->session_controller()->GetUserSession(user_index);
   DCHECK(user_session);
 
+  if (user_session->user_info->type == user_manager::USER_TYPE_GUEST)
+    return l10n_util::GetStringUTF16(IDS_ASH_STATUS_TRAY_GUEST_LABEL);
+
   return l10n_util::GetStringFUTF16(
       IDS_ASH_STATUS_TRAY_USER_INFO_ACCESSIBILITY,
       base::UTF8ToUTF16(user_session->user_info->display_name),
@@ -255,9 +269,24 @@ UserChooserView::UserChooserView(UnifiedSystemTrayController* controller) {
     AddChildView(button);
     AddChildView(new Separator(i < num_users - 1));
   }
-  if (Shell::Get()->session_controller()->GetAddUserPolicy() ==
-      AddUserSessionPolicy::ALLOWED) {
-    AddChildView(new AddUserButton(controller));
+
+  switch (Shell::Get()->session_controller()->GetAddUserPolicy()) {
+    case AddUserSessionPolicy::ALLOWED:
+      AddChildView(new AddUserButton(controller));
+      break;
+    case AddUserSessionPolicy::ERROR_NOT_ALLOWED_PRIMARY_USER:
+      AddChildView(CreateAddUserErrorView(l10n_util::GetStringUTF16(
+          IDS_ASH_STATUS_TRAY_MESSAGE_NOT_ALLOWED_PRIMARY_USER)));
+      break;
+    case AddUserSessionPolicy::ERROR_MAXIMUM_USERS_REACHED:
+      AddChildView(CreateAddUserErrorView(l10n_util::GetStringFUTF16Int(
+          IDS_ASH_STATUS_TRAY_MESSAGE_CANNOT_ADD_USER,
+          session_manager::kMaximumNumberOfUserSessions)));
+      break;
+    case AddUserSessionPolicy::ERROR_NO_ELIGIBLE_USERS:
+      AddChildView(CreateAddUserErrorView(
+          l10n_util::GetStringUTF16(IDS_ASH_STATUS_TRAY_MESSAGE_OUT_OF_USERS)));
+      break;
   }
 
   Shell::Get()->media_controller()->AddObserver(this);
