@@ -17,14 +17,13 @@ namespace tray {
 class RoundedImageView : public views::View {
  public:
   // Constructs a new rounded image view with rounded corners of radius
-  // |corner_radius|. If |active_user| is set, the icon will be drawn in
-  // full colors - otherwise it will fade into the background.
-  RoundedImageView(int corner_radius, bool active_user);
+  // |corner_radius|.
+  explicit RoundedImageView(int corner_radius);
   ~RoundedImageView() override;
 
   // Set the image that should be displayed. The image contents is copied to the
   // receiver's image.
-  void SetImage(const gfx::ImageSkia& img, const gfx::Size& size);
+  void SetImage(const gfx::ImageSkia& image, const gfx::Size& size);
 
   // Set the radii of the corners independently.
   void SetCornerRadii(int top_left,
@@ -32,20 +31,18 @@ class RoundedImageView : public views::View {
                       int bottom_right,
                       int bottom_left);
 
- private:
   // Overridden from views::View.
-  gfx::Size GetPreferredSize() const override;
+  gfx::Size CalculatePreferredSize() const override;
   void OnPaint(gfx::Canvas* canvas) override;
 
-  gfx::ImageSkia image_;
-  gfx::ImageSkia resized_;
+  // Gets the image painted by RoundedImageView for test.
+  const gfx::ImageSkia& image_for_test() const { return resized_image_; }
+
+ private:
+  gfx::ImageSkia resized_image_;
   gfx::Size image_size_;
   int corner_radius_[4];
 
-  // True if the given user is the active user and the icon should get
-  // painted as active.
-  bool active_user_;
-
   DISALLOW_COPY_AND_ASSIGN(RoundedImageView);
 };
 
