@@ -5,20 +5,19 @@
 #ifndef ASH_SYSTEM_USER_USER_VIEW_H_
 #define ASH_SYSTEM_USER_USER_VIEW_H_
 
-#include "ash/session/session_state_delegate.h"
+#include <memory>
+
+#include "ash/public/cpp/session_types.h"
 #include "ash/system/tray/tray_constants.h"
-#include "ash/system/user/login_status.h"
 #include "ash/system/user/tray_user.h"
 #include "base/macros.h"
 #include "ui/views/controls/button/button.h"
 #include "ui/views/focus/focus_manager.h"
 #include "ui/views/layout/box_layout.h"
-#include "ui/views/mouse_watcher.h"
 #include "ui/views/view.h"
 
 namespace gfx {
 class Rect;
-class Size;
 }
 
 namespace views {
@@ -27,34 +26,29 @@ class FocusManager;
 
 namespace ash {
 
-class PopupMessage;
+enum class LoginStatus;
 class SystemTrayItem;
 
 namespace tray {
 
+class UserCardView;
+
 // The view of a user item in system tray bubble.
 class UserView : public views::View,
                  public views::ButtonListener,
-                 public views::MouseWatcherListener,
                  public views::FocusChangeListener {
  public:
-  UserView(SystemTrayItem* owner,
-           ash::user::LoginStatus login,
-           MultiProfileIndex index,
-           bool for_detailed_view);
+  UserView(SystemTrayItem* owner, LoginStatus login);
   ~UserView() override;
 
-  // Overridden from MouseWatcherListener:
-  void MouseMovedOutOfHost() override;
-
   TrayUser::TestState GetStateForTest() const;
   gfx::Rect GetBoundsInScreenOfUserButtonForTest();
 
+  views::View* user_card_view_for_test() const { return user_card_container_; }
+
  private:
   // Overridden from views::View.
-  gfx::Size GetPreferredSize() const override;
   int GetHeightForWidth(int width) const override;
-  void Layout() override;
 
   // Overridden from views::ButtonListener.
   void ButtonPressed(views::Button* sender, const ui::Event& event) override;
@@ -63,42 +57,39 @@ class UserView : public views::View,
   void OnWillChangeFocus(View* focused_before, View* focused_now) override;
   void OnDidChangeFocus(View* focused_before, View* focused_now) override;
 
-  void AddLogoutButton(user::LoginStatus login);
-  void AddUserCard(user::LoginStatus login);
+  void AddLogoutButton(LoginStatus login);
+  void AddUserCard(LoginStatus login);
 
-  // Create the menu option to add another user. If |disabled| is set the user
-  // cannot actively click on the item.
-  void ToggleAddUserMenuOption();
+  // Create the menu option to add another user.
+  void ToggleUserDropdownWidget(bool toggled_by_key_event);
 
   // Removes the add user menu option.
-  void RemoveAddUserMenuOption();
+  void HideUserDropdownWidget();
 
-  MultiProfileIndex multiprofile_index_;
-  // The view of the user card.
-  views::View* user_card_view_;
+  views::Widget* GetBubbleWidget();
+
+  // If |user_card_view_| is clickable, this is a ButtonFromView that wraps it.
+  // If |user_card_view_| is not clickable, this will be equal to
+  // |user_card_view_|.
+  views::View* user_card_container_ = nullptr;
+
+  // The |UserCardView| for the active user.
+  UserCardView* user_card_view_ = nullptr;
 
   // This is the owner system tray item of this view.
   SystemTrayItem* owner_;
 
-  // True if |user_card_view_| is a |ButtonFromView| - otherwise it is only
-  // a |UserCardView|.
-  bool is_user_card_button_;
-
-  views::View* logout_button_;
-  scoped_ptr<PopupMessage> popup_message_;
-  scoped_ptr<views::Widget> add_menu_option_;
+  views::View* logout_button_ = nullptr;
+  std::unique_ptr<views::Widget> user_dropdown_widget_;
+  // Tracks whether |user_dropdown_widget_| was opened with a key event. If
+  // true, HideUserDropdownWidget() will return focus to |user_card_container_|.
+  bool user_dropdown_widget_toggled_by_key_event_ = false;
 
   // False when the add user panel is visible but not activatable.
-  bool add_user_enabled_;
-
-  // True if this view will be used inside detailed view.
-  bool for_detailed_view_;
-
-  // The mouse watcher which takes care of out of window hover events.
-  scoped_ptr<views::MouseWatcher> mouse_watcher_;
+  bool add_user_enabled_ = true;
 
   // The focus manager which we use to detect focus changes.
-  views::FocusManager* focus_manager_;
+  views::FocusManager* focus_manager_ = nullptr;
 
   DISALLOW_COPY_AND_ASSIGN(UserView);
 };
