@@ -39,20 +39,13 @@ void EnableMouseWarp(bool enable) {
 
 // Returns the target for the specified event ignorning any capture windows.
 aura::Window* FindWindowForEvent(const ui::LocatedEvent& event) {
-  aura::Window* target = static_cast<aura::Window*>(event.target());
-  aura::Window* target_root = target->GetRootWindow();
-
-  aura::client::ScreenPositionClient* position_client =
-      aura::client::GetScreenPositionClient(target_root);
-  gfx::Point location = event.location();
-  position_client->ConvertPointToScreen(target, &location);
-
+  gfx::Point location = event.target()->GetScreenLocation(event);
   display::Display display =
       display::Screen::GetScreen()->GetDisplayNearestPoint(location);
 
-  aura::Window* root_window = Shell::GetRootWindowForDisplayId(display.id());
-
-  position_client->ConvertPointFromScreen(root_window, &location);
+  aura::Window* root = Shell::GetRootWindowForDisplayId(display.id());
+  auto* screen_position_client = aura::client::GetScreenPositionClient(root);
+  screen_position_client->ConvertPointFromScreen(root, &location);
 
   std::unique_ptr<ui::Event> cloned_event = ui::Event::Clone(event);
   ui::LocatedEvent* cloned_located_event = cloned_event->AsLocatedEvent();
@@ -60,15 +53,14 @@ aura::Window* FindWindowForEvent(const ui::LocatedEvent& event) {
 
   // Ignore capture window when finding the target for located event.
   aura::client::CaptureClient* original_capture_client =
-      aura::client::GetCaptureClient(root_window);
-  aura::client::SetCaptureClient(root_window, nullptr);
+      aura::client::GetCaptureClient(root);
+  aura::client::SetCaptureClient(root, nullptr);
 
-  aura::Window* selected =
-      static_cast<aura::Window*>(aura::WindowTargeter().FindTargetForEvent(
-          root_window, cloned_located_event));
+  aura::Window* selected = static_cast<aura::Window*>(
+      aura::WindowTargeter().FindTargetForEvent(root, cloned_located_event));
 
   // Restore State.
-  aura::client::SetCaptureClient(root_window, original_capture_client);
+  aura::client::SetCaptureClient(root, original_capture_client);
   return selected;
 }
 
