@@ -6,10 +6,8 @@
 #define ASH_WM_DRAG_DETAILS_H_
 
 #include "ash/ash_export.h"
-#include "ash/wm/wm_types.h"
-#include "base/basictypes.h"
-#include "base/memory/scoped_ptr.h"
-#include "ui/gfx/rect.h"
+#include "ash/public/interfaces/window_state_type.mojom.h"
+#include "ui/gfx/geometry/rect.h"
 #include "ui/wm/public/window_move_client.h"
 
 namespace aura {
@@ -18,24 +16,21 @@ class Window;
 
 namespace ash {
 
-namespace wm {
-class WindowState;
-}
-
 struct ASH_EXPORT DragDetails {
   DragDetails(aura::Window* window,
               const gfx::Point& location,
               int window_component,
-              aura::client::WindowMoveSource source);
+              // TODO(sky): make wm type.
+              ::wm::WindowMoveSource source);
   ~DragDetails();
 
-  ash::wm::WindowStateType initial_state_type;
+  ash::mojom::WindowStateType initial_state_type;
 
   // Initial bounds of the window in parent coordinates.
   const gfx::Rect initial_bounds_in_parent;
 
   // Restore bounds (in screen coordinates) of the window before the drag
-  // started. Only set if the window is normal and is being dragged.
+  // started. Only set if the window is being dragged.
   gfx::Rect restore_bounds;
 
   // Location passed to the constructor, in |window->parent()|'s coordinates.
@@ -60,7 +55,7 @@ struct ASH_EXPORT DragDetails {
   const bool is_resizable;
 
   // Source of the event initiating the drag.
-  const aura::client::WindowMoveSource source;
+  const ::wm::WindowMoveSource source;
 
   // True if the window should attach to the shelf after releasing.
   bool should_attach_to_shelf;
