@@ -86,14 +86,14 @@ class LockLayoutManagerTest : public AshTestBase {
   // Show or hide the keyboard.
   void ShowKeyboard(bool show) {
     auto* keyboard = keyboard::KeyboardController::Get();
-    ASSERT_TRUE(keyboard->enabled());
+    ASSERT_TRUE(keyboard->IsEnabled());
     if (show == keyboard->IsKeyboardVisible())
       return;
 
     if (show) {
       keyboard->ShowKeyboard(false);
-      if (keyboard->ui()->GetKeyboardWindow()->bounds().height() == 0) {
-        keyboard->ui()->GetKeyboardWindow()->SetBounds(
+      if (keyboard->GetKeyboardWindow()->bounds().height() == 0) {
+        keyboard->GetKeyboardWindow()->SetBounds(
             keyboard::KeyboardBoundsFromRootBounds(
                 Shell::GetPrimaryRootWindow()->bounds(),
                 kVirtualKeyboardHeight));
@@ -105,6 +105,13 @@ class LockLayoutManagerTest : public AshTestBase {
 
     DCHECK_EQ(show, keyboard->IsKeyboardVisible());
   }
+
+  void SetKeyboardOverscrollBehavior(
+      keyboard::mojom::KeyboardOverscrollBehavior overscroll_behavior) {
+    auto config = keyboard::KeyboardController::Get()->keyboard_config();
+    config.overscroll_behavior = overscroll_behavior;
+    keyboard::KeyboardController::Get()->UpdateKeyboardConfig(config);
+  }
 };
 
 TEST_F(LockLayoutManagerTest, NorwmalWindowBoundsArePreserved) {
@@ -232,22 +239,22 @@ TEST_F(LockLayoutManagerTest, KeyboardBounds) {
 
   // When virtual keyboard overscroll is enabled keyboard bounds should not
   // affect window bounds.
-  keyboard::SetKeyboardOverscrollOverride(
-      keyboard::KEYBOARD_OVERSCROLL_OVERRIDE_ENABLED);
+  keyboard::KeyboardController* keyboard = keyboard::KeyboardController::Get();
+  SetKeyboardOverscrollBehavior(
+      keyboard::mojom::KeyboardOverscrollBehavior::kEnabled);
   ShowKeyboard(true);
   EXPECT_EQ(screen_bounds.ToString(), window->GetBoundsInScreen().ToString());
-  gfx::Rect keyboard_bounds =
-      keyboard::KeyboardController::Get()->visual_bounds_in_screen();
+  gfx::Rect keyboard_bounds = keyboard->visual_bounds_in_screen();
   EXPECT_NE(keyboard_bounds, gfx::Rect());
   ShowKeyboard(false);
 
   // When keyboard is hidden make sure that rotating the screen gives 100% of
   // screen size to window.
   // Repro steps for http://crbug.com/401667:
-  // 1. Set up login screen defaults: VK override disabled
+  // 1. Set up login screen defaults: VK overscroll disabled
   // 2. Show/hide keyboard, make sure that no stale keyboard bounds are cached.
-  keyboard::SetKeyboardOverscrollOverride(
-      keyboard::KEYBOARD_OVERSCROLL_OVERRIDE_DISABLED);
+  SetKeyboardOverscrollBehavior(
+      keyboard::mojom::KeyboardOverscrollBehavior::kDisabled);
   ShowKeyboard(true);
   ShowKeyboard(false);
   display_manager()->SetDisplayRotation(
@@ -262,21 +269,20 @@ TEST_F(LockLayoutManagerTest, KeyboardBounds) {
 
   // When virtual keyboard overscroll is disabled keyboard bounds do
   // affect window bounds.
-  keyboard::SetKeyboardOverscrollOverride(
-      keyboard::KEYBOARD_OVERSCROLL_OVERRIDE_DISABLED);
+  SetKeyboardOverscrollBehavior(
+      keyboard::mojom::KeyboardOverscrollBehavior::kDisabled);
   ShowKeyboard(true);
-  keyboard::KeyboardController* keyboard = keyboard::KeyboardController::Get();
+
   primary_display = display::Screen::GetScreen()->GetPrimaryDisplay();
   screen_bounds = primary_display.bounds();
   gfx::Rect target_bounds(screen_bounds);
-  target_bounds.set_height(
-      target_bounds.height() -
-      keyboard->ui()->GetKeyboardWindow()->bounds().height());
+  target_bounds.set_height(target_bounds.height() -
+                           keyboard->GetKeyboardWindow()->bounds().height());
   EXPECT_EQ(target_bounds.ToString(), window->GetBoundsInScreen().ToString());
   ShowKeyboard(false);
 
-  keyboard::SetKeyboardOverscrollOverride(
-      keyboard::KEYBOARD_OVERSCROLL_OVERRIDE_NONE);
+  SetKeyboardOverscrollBehavior(
+      keyboard::mojom::KeyboardOverscrollBehavior::kDefault);
 
   keyboard->SetContainerType(keyboard::ContainerType::FLOATING,
                              base::nullopt /* target_bounds */,
