@@ -12,6 +12,7 @@
 #include "third_party/skia/include/core/SkColor.h"
 #include "ui/compositor/layer_type.h"
 #include "ui/gfx/geometry/rect.h"
+#include "ui/gfx/transform.h"
 
 namespace aura {
 class Window;
@@ -69,6 +70,18 @@ std::unique_ptr<views::Widget> CreateBackgroundWidget(aura::Window* root_window,
 // header to be hidden if |top_inset| is not zero.
 gfx::Rect GetTransformedBounds(aura::Window* transformed_window, int top_inset);
 
+// Returns the original target bounds of |window|. The bounds are a union of all
+// regular (normal and panel) windows in the window's transient hierarchy.
+gfx::Rect GetTargetBoundsInScreen(aura::Window* window);
+
+// Applies the |transform| to |window| and all of its transient children. Note
+// |transform| is the transform that is applied to |window| and needs to be
+// adjusted for the transient child windows.
+void SetTransform(aura::Window* window, const gfx::Transform& transform);
+
+// Checks if we are currently in sliding up on the shelf to hide overview mode.
+bool IsSlidingOutOverviewFromShelf();
+
 }  // namespace ash
 
 #endif  // ASH_WM_OVERVIEW_OVERVIEW_UTILS_H_
