@@ -12,7 +12,9 @@
 #include "ash/wm/overview/window_selector.h"
 #include "ash/wm/overview/window_selector_delegate.h"
 #include "base/macros.h"
+#include "base/memory/weak_ptr.h"
 #include "base/time/time.h"
+#include "ui/aura/window_occlusion_tracker.h"
 
 namespace ash {
 class WindowSelector;
@@ -22,6 +24,11 @@ class WindowSelectorTest;
 // allows selecting a window to activate it.
 class ASH_EXPORT WindowSelectorController : public WindowSelectorDelegate {
  public:
+  enum class AnimationCompleteReason {
+    kCompleted,
+    kCanceled,
+  };
+
   WindowSelectorController();
   ~WindowSelectorController() override;
 
@@ -35,15 +42,18 @@ class ASH_EXPORT WindowSelectorController : public WindowSelectorDelegate {
   static bool CanSelect();
 
   // Attempts to toggle overview mode and returns true if successful (showing
-  // overview would be unsuccessful if there are no windows to show). If
-  // |toggled_from_home_launcher| is true, enter/exit overview with a different
-  // animation to accommodate the home launcher. |toggled_from_home_launcher|
-  // should only be true if the home launcher button is pressed.
-  bool ToggleOverview(bool toggled_from_home_launcher = false);
+  // overview would be unsuccessful if there are no windows to show). Depending
+  // on |type| the enter/exit animation will look different.
+  bool ToggleOverview(WindowSelector::EnterExitOverviewType type =
+                          WindowSelector::EnterExitOverviewType::kNormal);
 
   // Returns true if window selection mode is active.
   bool IsSelecting() const;
 
+  // Returns true if overview has been shutdown, but is still animating to the
+  // end state ui.
+  bool IsCompletingShutdownAnimations();
+
   // Moves the current selection by |increment| items. Positive values of
   // |increment| move the selection forward, negative values move it backward.
   void IncrementSelection(int increment);
@@ -69,6 +79,10 @@ class ASH_EXPORT WindowSelectorController : public WindowSelectorDelegate {
       std::unique_ptr<DelayedAnimationObserver> animation) override;
   void RemoveAndDestroyAnimationObserver(
       DelayedAnimationObserver* animation) override;
+  void AddStartAnimationObserver(
+      std::unique_ptr<DelayedAnimationObserver> animation_observer) override;
+  void RemoveAndDestroyStartAnimationObserver(
+      DelayedAnimationObserver* animation_observer) override;
 
   WindowSelector* window_selector() { return window_selector_.get(); }
 
@@ -77,6 +91,7 @@ class ASH_EXPORT WindowSelectorController : public WindowSelectorDelegate {
   friend class WindowSelectorTest;
   FRIEND_TEST_ALL_PREFIXES(TabletModeControllerTest,
                            DisplayDisconnectionDuringOverview);
+  FRIEND_TEST_ALL_PREFIXES(WindowSelectorTest, OverviewExitAnimationObserver);
 
   // There is no need to blur or unblur the wallpaper for tests.
   static void SetDoNotChangeWallpaperBlurForTests();
@@ -84,11 +99,22 @@ class ASH_EXPORT WindowSelectorController : public WindowSelectorDelegate {
   // Dispatched when window selection begins.
   void OnSelectionStarted();
 
+  void OnStartingAnimationComplete(bool canceled);
+  void OnEndingAnimationComplete(bool canceled);
+  void ResetPauser();
+
   // Collection of DelayedAnimationObserver objects that own widgets that may be
   // still animating after overview mode ends. If shell needs to shut down while
   // those animations are in progress, the animations are shut down and the
   // widgets destroyed.
   std::vector<std::unique_ptr<DelayedAnimationObserver>> delayed_animations_;
+  // Collection of DelayedAnimationObserver objects. When this becomes empty,
+  // notify shell that the starting animations have been completed.
+  std::vector<std::unique_ptr<DelayedAnimationObserver>> start_animations_;
+
+  std::unique_ptr<aura::WindowOcclusionTracker::ScopedPause>
+      occlusion_tracker_pauser_;
+
   std::unique_ptr<WindowSelector> window_selector_;
   base::Time last_selection_time_;
 
@@ -99,6 +125,10 @@ class ASH_EXPORT WindowSelectorController : public WindowSelectorDelegate {
   // Animates the blurring if necessary.
   std::unique_ptr<OverviewBlurController> overview_blur_controller_;
 
+  base::CancelableOnceClosure reset_pauser_task_;
+
+  base::WeakPtrFactory<WindowSelectorController> weak_ptr_factory_;
+
   DISALLOW_COPY_AND_ASSIGN(WindowSelectorController);
 };
 
