@@ -5,36 +5,30 @@
 #ifndef ASH_WM_SYSTEM_GESTURE_EVENT_FILTER_H_
 #define ASH_WM_SYSTEM_GESTURE_EVENT_FILTER_H_
 
-#include "base/memory/scoped_ptr.h"
+#include <memory>
+
+#include "base/macros.h"
 #include "ui/events/event_handler.h"
 
 namespace ash {
-class LongPressAffordanceHandler;
 class OverviewGestureHandler;
-class ShelfGestureHandler;
-
-namespace test {
-class SystemGestureEventFilterTest;
-}
 
 // An event filter which handles system level gesture events.
 class SystemGestureEventFilter : public ui::EventHandler {
  public:
   SystemGestureEventFilter();
-  virtual ~SystemGestureEventFilter();
+  ~SystemGestureEventFilter() override;
 
   // Overridden from ui::EventHandler:
-  virtual void OnMouseEvent(ui::MouseEvent* event) OVERRIDE;
-  virtual void OnScrollEvent(ui::ScrollEvent* event) OVERRIDE;
-  virtual void OnTouchEvent(ui::TouchEvent* event) OVERRIDE;
-  virtual void OnGestureEvent(ui::GestureEvent* event) OVERRIDE;
+  void OnMouseEvent(ui::MouseEvent* event) override;
+  void OnScrollEvent(ui::ScrollEvent* event) override;
+  void OnTouchEvent(ui::TouchEvent* event) override;
+  void OnGestureEvent(ui::GestureEvent* event) override;
 
  private:
-  friend class ash::test::SystemGestureEventFilterTest;
+  friend class SystemGestureEventFilterTest;
 
-  scoped_ptr<LongPressAffordanceHandler> long_press_affordance_;
-  scoped_ptr<OverviewGestureHandler> overview_gesture_handler_;
-  scoped_ptr<ShelfGestureHandler> shelf_gesture_handler_;
+  std::unique_ptr<OverviewGestureHandler> overview_gesture_handler_;
 
   DISALLOW_COPY_AND_ASSIGN(SystemGestureEventFilter);
 };
