@@ -8,6 +8,7 @@
 
 #include "ash/app_list/app_list_controller_impl.h"
 #include "ash/root_window_controller.h"
+#include "ash/scoped_animation_disabler.h"
 #include "ash/shell.h"
 #include "ash/wallpaper/wallpaper_widget_controller.h"
 #include "ash/wm/mru_window_tracker.h"
@@ -17,9 +18,9 @@
 #include "ash/wm/splitview/split_view_constants.h"
 #include "ash/wm/tablet_mode/tablet_mode_browser_window_drag_controller.h"
 #include "ash/wm/tablet_mode/tablet_mode_window_state.h"
+#include "ash/wm/window_util.h"
 #include "ui/aura/window.h"
 #include "ui/compositor/layer_animation_observer.h"
-#include "ui/compositor/layer_observer.h"
 #include "ui/compositor/scoped_layer_animation_settings.h"
 #include "ui/display/screen.h"
 #include "ui/views/widget/widget.h"
@@ -35,100 +36,67 @@ namespace {
 // threshold.
 constexpr float kSourceWindowScale = 0.85;
 
-// Values of the blurred scrim.
-constexpr SkColor kScrimBackgroundColor = SK_ColorGRAY;
-constexpr float kScrimOpacity = 0.8;
-constexpr float kScrimBlur = 5.f;
-constexpr int kScrimTransitionInMs = 250;
-constexpr int kScrimRoundRectRadiusDp = 4;
+// Threshold of the fling velocity to keep the dragged window as a new separate
+// window after drag ends and do not try to merge it back into source window.
+constexpr float kFlingToStayAsNewWindowThreshold = 2000.f;
 
-// The threshold to compute the vertical distance to create/reset the scrim. The
-// scrim is placed below the current dragged window. This value is smaller than
-// kIndicatorsThreshouldRatio to prevent the dragged window to merge back to
-// its source window during its source window's animation.
-constexpr float kScrimResetThresholdRatio = 0.05;
-
-// Returns the window selector if overview mode is active, otherwise returns
-// nullptr.
-WindowSelector* GetWindowSelector() {
-  return Shell::Get()->window_selector_controller()->IsSelecting()
-             ? Shell::Get()->window_selector_controller()->window_selector()
-             : nullptr;
-}
-
-// Creates a transparent scrim which is placed below |dragged_window|.
-std::unique_ptr<views::Widget> CreateScrim(aura::Window* dragged_window,
-                                           const gfx::Rect& bounds) {
-  std::unique_ptr<views::Widget> widget = CreateBackgroundWidget(
-      /*root_window=*/dragged_window->GetRootWindow(),
-      /*layer_type=*/ui::LAYER_TEXTURED,
-      /*background_color=*/kScrimBackgroundColor,
-      /*border_thickness=*/0,
-      /*border_radius=*/kScrimRoundRectRadiusDp,
-      /*border_color=*/SK_ColorTRANSPARENT,
-      /*initial_opacity=*/0.f,
-      /*parent=*/dragged_window->parent(),
-      /*stack_on_top=*/false);
-  widget->SetBounds(bounds);
-  return widget;
-}
-
-// When the dragged window is dragged past this value, a transparent scrim will
-// be created to place below the current dragged window to prevent the dragged
-// window to merge into any browser window beneath it and when it's dragged back
-// toward the top of the screen, the scrim will be destroyed.
-int GetScrimVerticalThreshold(const gfx::Rect& work_area_bounds) {
-  return work_area_bounds.y() +
-         work_area_bounds.height() * kScrimResetThresholdRatio;
-}
-
-// The class to observe the source window's bounds change animation. When the
-// bounds animation is running, set the dragged window not be able to attach to
-// any window to prevent it accidently attach into the animating source window.
+// The class to observe the source window's bounds change animation. It's used
+// to prevent the dragged window to merge back into the source window during
+// dragging. Only when the source window restores to its maximized window size,
+// the dragged window can be merged back into the source window.
 class SourceWindowAnimationObserver : public ui::ImplicitAnimationObserver,
-                                      public ui::LayerObserver,
                                       public aura::WindowObserver {
  public:
-  SourceWindowAnimationObserver(ui::Layer* source_window_layer,
+  SourceWindowAnimationObserver(aura::Window* source_window,
                                 aura::Window* dragged_window)
-      : source_window_layer_(source_window_layer),
-        dragged_window_(dragged_window) {
-    source_window_layer_->AddObserver(this);
+      : source_window_(source_window), dragged_window_(dragged_window) {
+    source_window_->AddObserver(this);
     dragged_window_->AddObserver(this);
   }
 
-  ~SourceWindowAnimationObserver() override {
-    if (source_window_layer_)
-      source_window_layer_->RemoveObserver(this);
-
-    if (dragged_window_) {
-      dragged_window_->RemoveObserver(this);
-      dragged_window_->ClearProperty(ash::kCanAttachToAnotherWindowKey);
-    }
-  }
+  ~SourceWindowAnimationObserver() override { StopObserving(); }
 
   // ui::ImplicitAnimationObserver:
   void OnLayerAnimationStarted(ui::LayerAnimationSequence* sequence) override {
-    DCHECK(dragged_window_);
+    DCHECK(dragged_window_ && source_window_);
     dragged_window_->SetProperty(ash::kCanAttachToAnotherWindowKey, false);
   }
 
-  void OnImplicitAnimationsCompleted() override { delete this; }
-
-  // ui::LayerObserver:
-  void LayerDestroyed(ui::Layer* layer) override {
-    DCHECK_EQ(source_window_layer_, layer);
-    delete this;
+  void OnImplicitAnimationsCompleted() override {
+    DCHECK(dragged_window_ && source_window_);
+    // When arriving here, we know the source window bounds change animation
+    // just ended. Only clear the property ash::kCanAttachToAnotherWindowKey if
+    // the source window bounds restores to its maximized window size.
+    gfx::Rect work_area_bounds = display::Screen::GetScreen()
+                                     ->GetDisplayNearestWindow(source_window_)
+                                     .work_area();
+    ::wm::ConvertRectFromScreen(source_window_->parent(), &work_area_bounds);
+    if (source_window_->bounds() == work_area_bounds)
+      StopObserving();
   }
 
   // aura::WindowObserver:
   void OnWindowDestroying(aura::Window* window) override {
-    DCHECK_EQ(dragged_window_, window);
-    delete this;
+    DCHECK(window == source_window_ || window == dragged_window_);
+    StopObserving();
   }
 
  private:
-  ui::Layer* source_window_layer_;
+  void StopObserving() {
+    StopObservingImplicitAnimations();
+    if (source_window_) {
+      source_window_->RemoveObserver(this);
+      source_window_ = nullptr;
+    }
+
+    if (dragged_window_) {
+      dragged_window_->RemoveObserver(this);
+      dragged_window_->ClearProperty(ash::kCanAttachToAnotherWindowKey);
+      dragged_window_ = nullptr;
+    }
+  }
+
+  aura::Window* source_window_;
   aura::Window* dragged_window_;
 
   DISALLOW_COPY_AND_ASSIGN(SourceWindowAnimationObserver);
@@ -169,16 +137,17 @@ class TabletModeBrowserWindowDragDelegate::WindowsHider
       }
 
       window_visibility_map_.emplace(window, window->IsVisible());
-      if (window->IsVisible())
+      if (window->IsVisible()) {
+        ScopedAnimationDisabler disabler(window);
         window->Hide();
+      }
       window->AddObserver(this);
     }
 
     // Hide the home launcher if it's enabled during dragging.
-    AppListControllerImpl* app_list_controller =
-        Shell::Get()->app_list_controller();
-    if (app_list_controller->IsHomeLauncherEnabledInTabletMode())
-      app_list_controller->DismissAppList();
+    // TODO(xdai): Move the hide/show home launcher logic to a general place in
+    // TabletModeWindowDragDelegate.
+    Shell::Get()->app_list_controller()->OnWindowDragStarted();
 
     // Blurs the wallpaper background.
     RootWindowController::ForWindow(root_window)
@@ -211,17 +180,16 @@ class TabletModeBrowserWindowDragDelegate::WindowsHider
     for (auto iter = window_visibility_map_.begin();
          iter != window_visibility_map_.end(); ++iter) {
       iter->first->RemoveObserver(this);
-      if (iter->second)
+      if (iter->second) {
+        ScopedAnimationDisabler disabler(iter->first);
         iter->first->Show();
+      }
     }
 
     DCHECK(!Shell::Get()->window_selector_controller()->IsSelecting());
 
-    // Reshow the home launcher if it's enabled after dragging.
-    AppListControllerImpl* app_list_controller =
-        Shell::Get()->app_list_controller();
-    if (app_list_controller->IsHomeLauncherEnabledInTabletMode())
-      app_list_controller->ShowAppList();
+    // May reshow the home launcher after dragging.
+    Shell::Get()->app_list_controller()->OnWindowDragEnded();
 
     // Clears the background wallpaper blur.
     RootWindowController::ForWindow(dragged_window_->GetRootWindow())
@@ -277,7 +245,7 @@ TabletModeBrowserWindowDragDelegate::TabletModeBrowserWindowDragDelegate() =
 TabletModeBrowserWindowDragDelegate::~TabletModeBrowserWindowDragDelegate() =
     default;
 
-void TabletModeBrowserWindowDragDelegate::PrepareForDraggedWindow(
+void TabletModeBrowserWindowDragDelegate::PrepareWindowDrag(
     const gfx::Point& location_in_screen) {
   DCHECK(dragged_window_);
 
@@ -285,18 +253,15 @@ void TabletModeBrowserWindowDragDelegate::PrepareForDraggedWindow(
   window_state->OnDragStarted(window_state->drag_details()->window_component);
 }
 
-void TabletModeBrowserWindowDragDelegate::UpdateForDraggedWindow(
+void TabletModeBrowserWindowDragDelegate::UpdateWindowDrag(
     const gfx::Point& location_in_screen) {
   DCHECK(dragged_window_);
 
   // Update the source window if necessary.
   UpdateSourceWindow(location_in_screen);
-
-  // Update the scrim that beneath the dragged window if necessary.
-  UpdateScrim(location_in_screen);
 }
 
-void TabletModeBrowserWindowDragDelegate::EndingForDraggedWindow(
+void TabletModeBrowserWindowDragDelegate::EndingWindowDrag(
     wm::WmToplevelWindowEventHandler::DragResult result,
     const gfx::Point& location_in_screen) {
   if (result == wm::WmToplevelWindowEventHandler::DragResult::SUCCESS)
@@ -312,10 +277,30 @@ void TabletModeBrowserWindowDragDelegate::EndingForDraggedWindow(
     TabletModeWindowState::UpdateWindowPosition(
         wm::GetWindowState(source_window));
   }
-  scrim_.reset();
   windows_hider_.reset();
 }
 
+void TabletModeBrowserWindowDragDelegate::EndedWindowDrag(
+    const gfx::Point& location_in_screen) {
+  MergeBackToSourceWindowIfApplicable(location_in_screen);
+}
+
+void TabletModeBrowserWindowDragDelegate::StartFling(
+    const ui::GestureEvent* event) {
+  if (ShouldFlingIntoOverview(event)) {
+    DCHECK(Shell::Get()->window_selector_controller()->IsSelecting());
+    Shell::Get()->window_selector_controller()->window_selector()->AddItem(
+        dragged_window_, /*reposition=*/true, /*animate=*/false);
+  } else {
+    aura::Window* source_window =
+        dragged_window_->GetProperty(ash::kTabDraggingSourceWindowKey);
+    if (source_window &&
+        event->details().velocity_y() > kFlingToStayAsNewWindowThreshold) {
+      can_merge_back_to_source_window_ = false;
+    }
+  }
+}
+
 bool TabletModeBrowserWindowDragDelegate::ShouldOpenOverviewWhenDragStarts() {
   DCHECK(dragged_window_);
   aura::Window* source_window =
@@ -333,8 +318,7 @@ void TabletModeBrowserWindowDragDelegate::UpdateSourceWindow(
   if (!source_window || source_window == dragged_window_ ||
       source_window == split_view_controller_->left_window() ||
       source_window == split_view_controller_->right_window() ||
-      (GetWindowSelector() &&
-       GetWindowSelector()->IsWindowInOverview(source_window))) {
+      source_window->GetProperty(ash::kIsShowingInOverviewKey)) {
     return;
   }
 
@@ -373,93 +357,69 @@ void TabletModeBrowserWindowDragDelegate::UpdateSourceWindow(
         source_window->layer()->GetAnimator());
     settings.SetPreemptionStrategy(
         ui::LayerAnimator::IMMEDIATELY_ANIMATE_TO_NEW_TARGET);
-    settings.AddObserver(new SourceWindowAnimationObserver(
-        source_window->layer(), dragged_window_));
+    source_window_bounds_observer_ =
+        std::make_unique<SourceWindowAnimationObserver>(source_window,
+                                                        dragged_window_);
+    settings.AddObserver(source_window_bounds_observer_.get());
     source_window->SetBounds(expected_bounds);
   }
 }
 
-void TabletModeBrowserWindowDragDelegate::UpdateScrim(
+void TabletModeBrowserWindowDragDelegate::MergeBackToSourceWindowIfApplicable(
     const gfx::Point& location_in_screen) {
+  // No need to merge back if we're not in tab dragging process.
+  if (!wm::IsDraggingTabs(dragged_window_))
+    return;
+
+  aura::Window* source_window =
+      dragged_window_->GetProperty(ash::kTabDraggingSourceWindowKey);
+  // Do not merge back if there is no source window or the source window or
+  // the dragged window is currently in overview.
+  if (!source_window ||
+      source_window->GetProperty(ash::kIsShowingInOverviewKey) ||
+      dragged_window_->GetProperty(ash::kIsShowingInOverviewKey)) {
+    return;
+  }
+
+  // Do not merge back if the dragged window is not capable of merging back.
+  // This may happen if the drag ends because of a fling event and the fling
+  // velocity has exceeded kFlingToStayAsNewWindowThreshold.
+  if (!can_merge_back_to_source_window_)
+    return;
+
+  // Do not merge back if the window has dragged farther than half of the screen
+  // height.
   const gfx::Rect work_area_bounds =
       display::Screen::GetScreen()
           ->GetDisplayNearestWindow(dragged_window_)
           .work_area();
-  if (location_in_screen.y() < GetScrimVerticalThreshold(work_area_bounds)) {
-    // Remove |scrim_| entirely so that the dragged window can be merged back
-    // to the source window when the dragged window is dragged back toward the
-    // top area of the screen.
-    scrim_.reset();
+  if (location_in_screen.y() >= work_area_bounds.CenterPoint().y())
+    return;
+
+  SplitViewController::SnapPosition desired_snap_position =
+      GetSnapPosition(location_in_screen);
+  // If splitscreen is not active, do not merge back if the dragged window is
+  // in the drag-to-snap preview area.
+  if (!split_view_controller_->IsSplitViewModeActive() &&
+      desired_snap_position != SplitViewController::NONE) {
     return;
   }
 
-  // If overview mode is active, do not show the scrim on the overview side of
-  // the screen.
-  if (Shell::Get()->window_selector_controller()->IsSelecting()) {
-    WindowGrid* window_grid = GetWindowSelector()->GetGridWithRootWindow(
-        dragged_window_->GetRootWindow());
-    if (window_grid && window_grid->bounds().Contains(location_in_screen)) {
-      scrim_.reset();
+  // If source window is currently showing in splitscreen, do not merge back if
+  // the dragged window has been dragged to the other side of the split.
+  if (split_view_controller_->IsSplitViewModeActive() &&
+      wm::GetWindowState(source_window)->IsSnapped()) {
+    if ((source_window == split_view_controller_->left_window() &&
+         desired_snap_position == SplitViewController::RIGHT) ||
+        (source_window == split_view_controller_->right_window() &&
+         desired_snap_position == SplitViewController::LEFT)) {
       return;
     }
   }
 
-  SplitViewController::SnapPosition snap_position =
-      GetSnapPosition(location_in_screen);
-  gfx::Rect expected_bounds(work_area_bounds);
-  if (split_view_controller_->IsSplitViewModeActive()) {
-    expected_bounds = split_view_controller_->GetSnappedWindowBoundsInScreen(
-        dragged_window_, snap_position);
-  } else {
-    expected_bounds.Inset(kHighlightScreenEdgePaddingDp,
-                          kHighlightScreenEdgePaddingDp);
-  }
-
-  bool should_show_blurred_scrim = false;
-  if (location_in_screen.y() >=
-      GetMaximizeVerticalThreshold(work_area_bounds)) {
-    if (split_view_controller_->IsSplitViewModeActive() !=
-        (snap_position == SplitViewController::NONE)) {
-      should_show_blurred_scrim = true;
-    }
-  }
-  // When the event is between |indicators_vertical_threshold| and
-  // |maximize_vertical_threshold|, the scrim is still shown but is invisible
-  // to the user (transparent). It's needed to prevent the dragged window to
-  // merge into the scaled down source window.
-  ShowScrim(should_show_blurred_scrim ? kScrimOpacity : 0.f,
-            should_show_blurred_scrim ? kScrimBlur : 0.f, expected_bounds);
-}
-
-void TabletModeBrowserWindowDragDelegate::ShowScrim(
-    float opacity,
-    float blur,
-    const gfx::Rect& bounds_in_screen) {
-  gfx::Rect bounds(bounds_in_screen);
-  ::wm::ConvertRectFromScreen(dragged_window_->parent(), &bounds);
-
-  if (scrim_ && scrim_->GetLayer()->GetTargetOpacity() == opacity &&
-      scrim_->GetNativeWindow()->bounds() == bounds) {
-    return;
-  }
-
-  if (!scrim_)
-    scrim_ = CreateScrim(dragged_window_, bounds);
-  dragged_window_->parent()->StackChildBelow(scrim_->GetNativeWindow(),
-                                             dragged_window_);
-  scrim_->GetLayer()->SetBackgroundBlur(blur);
-
-  if (scrim_->GetNativeWindow()->bounds() != bounds) {
-    scrim_->SetOpacity(0.f);
-    scrim_->SetBounds(bounds);
-  }
-  ui::ScopedLayerAnimationSettings animation(scrim_->GetLayer()->GetAnimator());
-  animation.SetTweenType(gfx::Tween::EASE_IN_OUT);
-  animation.SetTransitionDuration(
-      base::TimeDelta::FromMilliseconds(kScrimTransitionInMs));
-  animation.SetPreemptionStrategy(
-      ui::LayerAnimator::IMMEDIATELY_ANIMATE_TO_NEW_TARGET);
-  scrim_->SetOpacity(opacity);
+  // Arriving here we know the dragged window should merge back into its source
+  // window.
+  source_window->SetProperty(ash::kIsDeferredTabDraggingTargetWindowKey, true);
 }
 
 }  // namespace ash
