@@ -30,6 +30,14 @@ class TabletModeWindowDragDelegate {
   // into overview.
   static constexpr float kDragPositionToOverviewRatio = 0.5f;
 
+  // Threshold of the fling velocity to drop the dragged window into overview if
+  // fling from the top of the display or from the caption area of the window.
+  static constexpr float kFlingToOverviewThreshold = 2000.f;
+
+  // Threshold of the fling velocity to drop the dragged window into overview if
+  // fling inside preview area or when splitview is active.
+  static constexpr float kFlingToOverviewFromSnappingAreaThreshold = 1000.f;
+
   enum class UpdateDraggedWindowType {
     UPDATE_BOUNDS,
     UPDATE_TRANSFORM,
@@ -54,6 +62,12 @@ class TabletModeWindowDragDelegate {
   void EndWindowDrag(wm::WmToplevelWindowEventHandler::DragResult result,
                      const gfx::Point& location_in_screen);
 
+  // Calls when a window ends dragging because of fling or swipe.
+  void FlingOrSwipe(ui::GestureEvent* event);
+
+  // Return the location of |event| in screen coordinates.
+  gfx::Point GetEventLocationInScreen(const ui::GestureEvent* event) const;
+
   // Returns the IndicatorState according to |location_in_screen|.
   IndicatorState GetIndicatorState(const gfx::Point& location_in_screen) const;
 
@@ -64,14 +78,16 @@ class TabletModeWindowDragDelegate {
   }
 
  protected:
-  // These three methods are used by its child class to do its special handling
+  // These four methods are used by its child class to do its special handling
   // before/during/after dragging.
-  virtual void PrepareForDraggedWindow(
-      const gfx::Point& location_in_screen) = 0;
-  virtual void UpdateForDraggedWindow(const gfx::Point& location_in_screen) = 0;
-  virtual void EndingForDraggedWindow(
+  virtual void PrepareWindowDrag(const gfx::Point& location_in_screen) = 0;
+  virtual void UpdateWindowDrag(const gfx::Point& location_in_screen) = 0;
+  virtual void EndingWindowDrag(
       wm::WmToplevelWindowEventHandler::DragResult result,
       const gfx::Point& location_in_screen) = 0;
+  virtual void EndedWindowDrag(const gfx::Point& location_in_screen) = 0;
+  // Calls when a fling event starts.
+  virtual void StartFling(const ui::GestureEvent* event) = 0;
 
   // Returns true if we should open overview behind the dragged window when drag
   // starts.
@@ -81,23 +97,21 @@ class TabletModeWindowDragDelegate {
   // will show up.
   int GetIndicatorsVerticalThreshold(const gfx::Rect& work_area_bounds) const;
 
-  // When the dragged window is dragged past this value, a blured scrim will
-  // show up, indicating the dragged window will be maximized after releasing.
-  int GetMaximizeVerticalThreshold(const gfx::Rect& work_area_bounds) const;
-
   // Gets the desired snap position for |location_in_screen|.
   SplitViewController::SnapPosition GetSnapPosition(
       const gfx::Point& location_in_screen) const;
 
-  // Update the dragged window's transform during dragging.
+  // Updates the dragged window's transform during dragging.
   void UpdateDraggedWindowTransform(const gfx::Point& location_in_screen);
 
-  // Returns true if |dragged_window_| has been dragged more than half of the
-  // distance from top of the display to the top of the new selector item in
-  // overview, except that preview area is shown or splitview is active.
-  bool ShouldDropWindowIntoOverviewOnDragPosition(
+  // Returns true if the dragged window should be dropped into overview on drag
+  // end.
+  bool ShouldDropWindowIntoOverview(
       SplitViewController::SnapPosition snap_position,
-      int end_y_position_in_screen) const;
+      const gfx::Point& location_in_screen);
+
+  // Returns true if fling event should drop the window into overview grid.
+  bool ShouldFlingIntoOverview(const ui::GestureEvent* event) const;
 
   SplitViewController* const split_view_controller_;
 
@@ -115,11 +129,11 @@ class TabletModeWindowDragDelegate {
 
   gfx::Point initial_location_in_screen_;
 
-  // Overview mode will be triggered if a window is being dragged, and a new
-  // selector item will be created in the overview grid. The variable stores
-  // the bounds of the selected new selector item in overview and will be used
-  // to calculate the desired window transform during dragging.
-  gfx::Rect bounds_of_selected_new_selector_item_;
+  // Overview mode will be triggered if a window is being dragged, and the drop
+  // target will be created in the overview grid. The variable stores the bounds
+  // of the selected drop target in overview and will be used to calculate the
+  // desired window transform during dragging.
+  gfx::Rect bounds_of_selected_drop_target_;
 
   // Flag to indicate whether a window is considered as moved. A window needs to
   // be dragged vertically a small amount of distance to be considered as moved.
