@@ -68,8 +68,6 @@ class ASH_EXPORT WindowCycleList : public aura::WindowObserver,
   void OnWindowDestroying(aura::Window* window) override;
 
   // display::DisplayObserver overrides:
-  void OnDisplayAdded(const display::Display& new_display) override;
-  void OnDisplayRemoved(const display::Display& old_display) override;
   void OnDisplayMetricsChanged(const display::Display& display,
                                uint32_t changed_metrics) override;
 
