@@ -21,6 +21,7 @@
 #include "ash/wm/tablet_mode/tablet_mode_controller.h"
 #include "ash/wm/window_positioning_utils.h"
 #include "ash/wm/window_state.h"
+#include "ash/wm/window_util.h"
 #include "ash/wm/wm_event.h"
 #include "ash/wm/workspace/phantom_window_controller.h"
 #include "ash/wm/workspace/two_step_edge_cycler.h"
@@ -39,6 +40,56 @@
 #include "ui/wm/core/coordinate_conversion.h"
 #include "ui/wm/core/cursor_manager.h"
 
+namespace {
+
+constexpr double kMinHorizVelocityForWindowSwipe = 1100;
+constexpr double kMinVertVelocityForWindowMinimize = 1000;
+
+// Returns true if |window| can be dragged from the top of the screen in tablet
+// mode.
+bool CanDragInTabletMode(aura::Window* window, int window_component) {
+  ash::wm::WindowState* window_state = ash::wm::GetWindowState(window);
+  // Pip window can't be dragged.
+  if (window_state->IsPip())
+    return false;
+
+  // Only maximized/fullscreen/snapped window can be dragged from the top of
+  // the screen.
+  if (!window_state->IsMaximized() && !window_state->IsFullscreen() &&
+      !window_state->IsSnapped()) {
+    return false;
+  }
+
+  // Only allow drag that happens on caption or top area. Note: for a maxmized
+  // or fullscreen window, the window component here is always HTCAPTION, but
+  // for a snapped window, the window component here can either be HTCAPTION or
+  // HTTOP.
+  if (window_component != HTCAPTION && window_component != HTTOP)
+    return false;
+
+  // Note: only browser windows and chrome app windows are included here.
+  // For browser windows, this piece of codes will be called no matter the
+  // drag happens on the tab(s) or on the non-tabstrip caption or top area.
+  // But for app window, this piece of codes will only be called if the chrome
+  // app window has its customized caption area and can't be hidden in tablet
+  // mode (and thus the drag for this type of chrome app window always happens
+  // on caption or top area). If the caption area of the chrome app window can
+  // be hidden, ImmersiveGestureHandlerClassic will handle the window drag
+  // through TabletModeAppWindowDragController.
+  // TODO(xdai, minch): Merge the logic in ImmersiveGestureHandlerClassic into
+  // CreateWindowResizer() in future.
+  ash::AppType app_type =
+      static_cast<ash::AppType>(window->GetProperty(aura::client::kAppType));
+  if (app_type != ash::AppType::BROWSER &&
+      app_type != ash::AppType::CHROME_APP) {
+    return false;
+  }
+
+  return true;
+}
+
+}  // namespace
+
 namespace ash {
 
 std::unique_ptr<WindowResizer> CreateWindowResizer(
@@ -70,15 +121,8 @@ std::unique_ptr<WindowResizer> CreateWindowResizer(
           ->tablet_mode_controller()
           ->IsTabletModeWindowManagerEnabled() &&
       !window_state->IsPip()) {
-    // We still don't allow any dragging or resizing happening on the area other
-    // then caption or top area. Note: for a maxmized or fullscreen window, the
-    // window component here is always HTCAPTION, but for a snapped window, the
-    // window component here can either be HTCAPTION or HTTOP.
-    if ((window_component != HTCAPTION && window_component != HTTOP) ||
-        window->GetProperty(aura::client::kAppType) !=
-            static_cast<int>(AppType::BROWSER)) {
+    if (!CanDragInTabletMode(window, window_component))
       return nullptr;
-    }
 
     window_state->CreateDragDetails(point_in_parent, window_component, source);
     window_resizer =
@@ -500,6 +544,67 @@ void WorkspaceWindowResizer::RevertDrag() {
   }
 }
 
+void WorkspaceWindowResizer::FlingOrSwipe(ui::GestureEvent* event) {
+  if (event->type() != ui::ET_SCROLL_FLING_START &&
+      event->type() != ui::ET_GESTURE_SWIPE) {
+    return;
+  }
+
+  if (event->type() == ui::ET_SCROLL_FLING_START) {
+    CompleteDrag();
+
+    // TODO(pkotwicz): Fix tests which inadvertently start flings and check
+    // window_resizer_->IsMove() instead of the hittest component at |event|'s
+    // location.
+    if (wm::GetNonClientComponent(GetTarget(), event->location()) !=
+            HTCAPTION ||
+        !wm::GetWindowState(GetTarget())->IsNormalOrSnapped()) {
+      return;
+    }
+
+    if (event->details().velocity_y() > kMinVertVelocityForWindowMinimize) {
+      SetWindowStateTypeFromGesture(GetTarget(),
+                                    mojom::WindowStateType::MINIMIZED);
+    } else if (event->details().velocity_y() <
+               -kMinVertVelocityForWindowMinimize) {
+      SetWindowStateTypeFromGesture(GetTarget(),
+                                    mojom::WindowStateType::MAXIMIZED);
+    } else if (event->details().velocity_x() >
+               kMinHorizVelocityForWindowSwipe) {
+      SetWindowStateTypeFromGesture(GetTarget(),
+                                    mojom::WindowStateType::RIGHT_SNAPPED);
+    } else if (event->details().velocity_x() <
+               -kMinHorizVelocityForWindowSwipe) {
+      SetWindowStateTypeFromGesture(GetTarget(),
+                                    mojom::WindowStateType::LEFT_SNAPPED);
+    }
+  } else {
+    DCHECK_EQ(event->type(), ui::ET_GESTURE_SWIPE);
+    DCHECK_GT(event->details().touch_points(), 0);
+    if (event->details().touch_points() == 1)
+      return;
+    if (!wm::GetWindowState(GetTarget())->IsNormalOrSnapped())
+      return;
+
+    CompleteDrag();
+
+    if (event->details().swipe_down()) {
+      SetWindowStateTypeFromGesture(GetTarget(),
+                                    mojom::WindowStateType::MINIMIZED);
+    } else if (event->details().swipe_up()) {
+      SetWindowStateTypeFromGesture(GetTarget(),
+                                    mojom::WindowStateType::MAXIMIZED);
+    } else if (event->details().swipe_right()) {
+      SetWindowStateTypeFromGesture(GetTarget(),
+                                    mojom::WindowStateType::RIGHT_SNAPPED);
+    } else {
+      SetWindowStateTypeFromGesture(GetTarget(),
+                                    mojom::WindowStateType::LEFT_SNAPPED);
+    }
+  }
+  event->StopPropagation();
+}
+
 WorkspaceWindowResizer::WorkspaceWindowResizer(
     wm::WindowState* window_state,
     const std::vector<aura::Window*>& attached_windows)
@@ -550,6 +655,8 @@ WorkspaceWindowResizer::WorkspaceWindowResizer(
   }
   instance = this;
 
+  pre_drag_window_bounds_ = window_state->window()->bounds();
+
   window_state->OnDragStarted(details().window_component);
 }
 
@@ -1003,4 +1110,44 @@ bool WorkspaceWindowResizer::AreBoundsValidSnappedBounds(
   return bounds_in_parent == snapped_bounds;
 }
 
+void WorkspaceWindowResizer::SetWindowStateTypeFromGesture(
+    aura::Window* window,
+    mojom::WindowStateType new_state_type) {
+  wm::WindowState* window_state = wm::GetWindowState(window);
+  // TODO(oshima): Move extra logic (set_unminimize_to_restore_bounds,
+  // SetRestoreBoundsInParent) that modifies the window state
+  // into WindowState.
+  switch (new_state_type) {
+    case mojom::WindowStateType::MINIMIZED:
+      if (window_state->CanMinimize()) {
+        window_state->Minimize();
+        window_state->set_unminimize_to_restore_bounds(true);
+        window_state->SetRestoreBoundsInParent(pre_drag_window_bounds_);
+      }
+      break;
+    case mojom::WindowStateType::MAXIMIZED:
+      if (window_state->CanMaximize()) {
+        window_state->SetRestoreBoundsInParent(pre_drag_window_bounds_);
+        window_state->Maximize();
+      }
+      break;
+    case mojom::WindowStateType::LEFT_SNAPPED:
+      if (window_state->CanSnap()) {
+        window_state->SetRestoreBoundsInParent(pre_drag_window_bounds_);
+        const wm::WMEvent event(wm::WM_EVENT_SNAP_LEFT);
+        window_state->OnWMEvent(&event);
+      }
+      break;
+    case mojom::WindowStateType::RIGHT_SNAPPED:
+      if (window_state->CanSnap()) {
+        window_state->SetRestoreBoundsInParent(pre_drag_window_bounds_);
+        const wm::WMEvent event(wm::WM_EVENT_SNAP_RIGHT);
+        window_state->OnWMEvent(&event);
+      }
+      break;
+    default:
+      NOTREACHED();
+  }
+}
+
 }  // namespace ash
