@@ -368,19 +368,19 @@ public class ChildProcessConnectionTest {
         mFirstServiceConnection = null;
 
         assertArrayEquals(
-                connection0.bindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 0, 0});
+                connection0.remainingBindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 0, 0});
 
         connection0.start(false /* useStrongBinding */, null /* serviceCallback */);
         assertArrayEquals(
-                connection0.bindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 0});
+                connection0.remainingBindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 0, 0});
 
         connection1.start(true /* useStrongBinding */, null /* serviceCallback */);
         assertArrayEquals(
-                connection0.bindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 1});
+                connection0.remainingBindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 0, 1});
 
         connection2.start(false /* useStrongBinding */, null /* serviceCallback */);
         assertArrayEquals(
-                connection0.bindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 2, 1});
+                connection0.remainingBindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 1});
 
         Binder binder0 = new Binder();
         Binder binder1 = new Binder();
@@ -396,30 +396,30 @@ public class ChildProcessConnectionTest {
         // Add and remove moderate binding works as expected.
         connection2.removeModerateBinding();
         assertArrayEquals(
-                connection0.bindingStateCountsCurrentOrWhenDied(), new int[] {0, 1, 1, 1});
+                connection0.remainingBindingStateCountsCurrentOrWhenDied(), new int[] {0, 1, 0, 1});
         connection2.addModerateBinding();
         assertArrayEquals(
-                connection0.bindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 2, 1});
+                connection0.remainingBindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 1});
 
         // Add and remove strong binding works as expected.
         connection0.addStrongBinding();
         assertArrayEquals(
-                connection0.bindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 2});
+                connection0.remainingBindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 1});
         connection0.removeStrongBinding();
         assertArrayEquals(
-                connection0.bindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 2, 1});
+                connection0.remainingBindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 1});
 
         // Stopped connection should no longe update.
         connection0.stop();
         assertArrayEquals(
-                connection0.bindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 1});
+                connection0.remainingBindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 1});
         assertArrayEquals(
-                connection1.bindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 1});
+                connection1.remainingBindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 0});
 
         connection2.removeModerateBinding();
         assertArrayEquals(
-                connection0.bindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 1});
+                connection0.remainingBindingStateCountsCurrentOrWhenDied(), new int[] {0, 0, 1, 1});
         assertArrayEquals(
-                connection1.bindingStateCountsCurrentOrWhenDied(), new int[] {0, 1, 0, 1});
+                connection1.remainingBindingStateCountsCurrentOrWhenDied(), new int[] {0, 1, 0, 0});
     }
 }
