@@ -8,6 +8,7 @@
 #include "base/android/library_loader/anchor_functions_buildflags.h"
 #include "base/android/library_loader/library_load_from_apk_status_codes.h"
 #include "base/android/library_loader/library_prefetcher.h"
+#include "base/android/orderfile/orderfile_buildflags.h"
 #include "base/at_exit.h"
 #include "base/base_switches.h"
 #include "base/command_line.h"
@@ -16,6 +17,10 @@
 #include "base/metrics/histogram_macros.h"
 #include "jni/LibraryLoader_jni.h"
 
+#if BUILDFLAG(ORDERFILE_INSTRUMENTATION)
+#include "base/android/orderfile/orderfile_instrumentation.h"
+#endif
+
 namespace base {
 namespace android {
 
@@ -176,6 +181,10 @@ static jboolean JNI_LibraryLoader_LibraryLoaded(
     JNIEnv* env,
     const JavaParamRef<jobject>& jcaller,
     jint library_process_type) {
+#if BUILDFLAG(ORDERFILE_INSTRUMENTATION)
+  orderfile::StartDelayedDump();
+#endif
+
 #if BUILDFLAG(SUPPORTS_CODE_ORDERING)
   if (ShouldDoOrderfileMemoryOptimization()) {
     NativeLibraryPrefetcher::MadviseForOrderfile();
@@ -202,13 +211,8 @@ static void JNI_LibraryLoader_ForkAndPrefetchNativeLibrary(
     JNIEnv* env,
     const JavaParamRef<jclass>& clazz) {
 #if BUILDFLAG(SUPPORTS_CODE_ORDERING)
-  if (!ShouldDoOrderfileMemoryOptimization() ||
-      CommandLine::ForCurrentProcess()->HasSwitch(
-          switches::kForceNativePrefetch)) {
-    NativeLibraryPrefetcher::ForkAndPrefetchNativeLibrary(
-        CommandLine::ForCurrentProcess()->HasSwitch(
-            switches::kNativePrefetchOrderedOnly));
-  }
+  return NativeLibraryPrefetcher::ForkAndPrefetchNativeLibrary(
+      ShouldDoOrderfileMemoryOptimization());
 #endif
 }
 
