@@ -30,6 +30,15 @@
 #endif  // OS_WIN
 
 #if defined(OS_FUCHSIA)
+#include <lib/zx/event.h>
+#include <lib/zx/port.h>
+#include <lib/zx/process.h>
+#include <lib/zx/thread.h>
+#include <lib/zx/time.h>
+#include <zircon/process.h>
+#include <zircon/syscalls/debug.h>
+#include <zircon/syscalls/port.h>
+#include <zircon/types.h>
 #include "base/fuchsia/fuchsia_logging.h"
 #endif
 
@@ -279,9 +288,128 @@ TEST_F(LoggingTest, CheckCausesDistinctBreakpoints) {
   EXPECT_NE(addr1, addr3);
   EXPECT_NE(addr2, addr3);
 }
+#elif defined(OS_FUCHSIA)
 
+// CHECK causes a direct crash (without jumping to another function) only in
+// official builds. Unfortunately, continuous test coverage on official builds
+// is lower. Furthermore, since the Fuchsia implementation uses threads, it is
+// not possible to rely on an implementation of CHECK that calls abort(), which
+// takes down the whole process, preventing the thread exception handler from
+// handling the exception. DO_CHECK here falls back on IMMEDIATE_CRASH() in
+// non-official builds, to catch regressions earlier in the CQ.
+#if defined(OFFICIAL_BUILD)
+#define DO_CHECK CHECK
+#else
+#define DO_CHECK(cond) \
+  if (!(cond)) {       \
+    IMMEDIATE_CRASH(); \
+  }
+#endif
+
+static const unsigned int kExceptionPortKey = 1u;
+static const unsigned int kThreadEndedPortKey = 2u;
+
+struct thread_data_t {
+  // For signaling the thread ended properly.
+  zx::unowned_event event;
+  // For registering thread termination.
+  zx::unowned_port port;
+  // Location where the thread is expected to crash.
+  int death_location;
+};
+
+void* CrashThread(void* arg) {
+  zx_status_t status;
+
+  thread_data_t* data = (thread_data_t*)arg;
+  int death_location = data->death_location;
+
+  // Register the exception handler on the port.
+  status = zx::thread::self()->bind_exception_port(*data->port,
+                                                   kExceptionPortKey, 0);
+  if (status != ZX_OK) {
+    data->event->signal(0, ZX_USER_SIGNAL_0);
+    return nullptr;
+  }
+
+  DO_CHECK(death_location != 1);
+  DO_CHECK(death_location != 2);
+  DO_CHECK(death_location != 3);
+
+  // We should never reach this point, signal the thread incorrectly ended
+  // properly.
+  data->event->signal(0, ZX_USER_SIGNAL_0);
+  return nullptr;
+}
+
+// Runs the CrashThread function in a separate thread.
+void SpawnCrashThread(int death_location, uintptr_t* child_crash_addr) {
+  zx::port port;
+  zx::event event;
+  zx_status_t status;
+
+  status = zx::port::create(0, &port);
+  ASSERT_EQ(status, ZX_OK);
+  status = zx::event::create(0, &event);
+  ASSERT_EQ(status, ZX_OK);
+
+  // Register the thread ended event on the port.
+  status = event.wait_async(port, kThreadEndedPortKey, ZX_USER_SIGNAL_0,
+                            ZX_WAIT_ASYNC_ONCE);
+  ASSERT_EQ(status, ZX_OK);
+
+  // Run the thread.
+  thread_data_t thread_data = {zx::unowned_event(event), zx::unowned_port(port),
+                               death_location};
+  pthread_t thread;
+  int ret = pthread_create(&thread, nullptr, CrashThread, &thread_data);
+  ASSERT_EQ(ret, 0);
+
+  // Wait on the port.
+  zx_port_packet_t packet;
+  status = port.wait(zx::time::infinite(), &packet);
+  ASSERT_EQ(status, ZX_OK);
+  // Check the thread did crash and not terminate.
+  ASSERT_EQ(packet.key, kExceptionPortKey);
+
+  // Get the crash address.
+  zx::thread zircon_thread;
+  status = zx::process::self()->get_child(packet.exception.tid,
+                                          ZX_RIGHT_SAME_RIGHTS, &zircon_thread);
+  ASSERT_EQ(status, ZX_OK);
+  zx_thread_state_general_regs_t buffer;
+  status = zircon_thread.read_state(ZX_THREAD_STATE_GENERAL_REGS, &buffer,
+                                    sizeof(buffer));
+  ASSERT_EQ(status, ZX_OK);
+#if defined(ARCH_CPU_X86_64)
+  *child_crash_addr = static_cast<uintptr_t>(buffer.rip);
+#elif defined(ARCH_CPU_ARM64)
+  *child_crash_addr = static_cast<uintptr_t>(buffer.pc);
+#else
+#error Unsupported architecture
+#endif
+
+  status = zircon_thread.kill();
+  ASSERT_EQ(status, ZX_OK);
+}
+
+TEST_F(LoggingTest, CheckCausesDistinctBreakpoints) {
+  uintptr_t child_crash_addr_1 = 0;
+  uintptr_t child_crash_addr_2 = 0;
+  uintptr_t child_crash_addr_3 = 0;
+
+  SpawnCrashThread(1, &child_crash_addr_1);
+  SpawnCrashThread(2, &child_crash_addr_2);
+  SpawnCrashThread(3, &child_crash_addr_3);
+
+  ASSERT_NE(0u, child_crash_addr_1);
+  ASSERT_NE(0u, child_crash_addr_2);
+  ASSERT_NE(0u, child_crash_addr_3);
+  ASSERT_NE(child_crash_addr_1, child_crash_addr_2);
+  ASSERT_NE(child_crash_addr_1, child_crash_addr_3);
+  ASSERT_NE(child_crash_addr_2, child_crash_addr_3);
+}
 #elif defined(OS_POSIX) && !defined(OS_NACL) && !defined(OS_IOS) && \
-    !defined(OS_FUCHSIA) &&                                         \
     (defined(ARCH_CPU_X86_FAMILY) || defined(ARCH_CPU_ARM_FAMILY))
 
 int g_child_crash_pipe;
@@ -671,6 +799,36 @@ TEST_F(LoggingTest, FuchsiaLogging) {
 }
 #endif  // defined(OS_FUCHSIA)
 
+TEST_F(LoggingTest, LogPrefix) {
+  // Set up a callback function to capture the log output string.
+  auto old_log_message_handler = GetLogMessageHandler();
+  // Use a static because only captureless lambdas can be converted to a
+  // function pointer for SetLogMessageHandler().
+  static std::string* log_string_ptr = nullptr;
+  std::string log_string;
+  log_string_ptr = &log_string;
+  SetLogMessageHandler([](int severity, const char* file, int line,
+                          size_t start, const std::string& str) -> bool {
+    *log_string_ptr = str;
+    return true;
+  });
+
+  // Logging with a prefix includes the prefix string after the opening '['.
+  const char kPrefix[] = "prefix";
+  SetLogPrefix(kPrefix);
+  LOG(ERROR) << "test";  // Writes into |log_string|.
+  EXPECT_EQ(1u, log_string.find(kPrefix));
+
+  // Logging without a prefix does not include the prefix string.
+  SetLogPrefix(nullptr);
+  LOG(ERROR) << "test";  // Writes into |log_string|.
+  EXPECT_EQ(std::string::npos, log_string.find(kPrefix));
+
+  // Clean up.
+  SetLogMessageHandler(old_log_message_handler);
+  log_string_ptr = nullptr;
+}
+
 }  // namespace
 
 }  // namespace logging
