@@ -116,9 +116,8 @@ class TaskQueueSelectorTest : public testing::Test {
     for (size_t i = 0; i < num_tasks; i++) {
       changed_queue_set.insert(queue_indices[i]);
       task_queues_[queue_indices[i]]->immediate_work_queue()->Push(
-          TaskQueueImpl::Task(TaskQueue::PostedTask(test_closure_, FROM_HERE),
-                              TimeTicks(), EnqueueOrder(),
-                              enqueue_order_generator.GenerateNext()));
+          Task(PostedTask(test_closure_, FROM_HERE), TimeTicks(),
+               EnqueueOrder(), enqueue_order_generator.GenerateNext()));
     }
   }
 
@@ -128,11 +127,9 @@ class TaskQueueSelectorTest : public testing::Test {
     std::set<size_t> changed_queue_set;
     for (size_t i = 0; i < num_tasks; i++) {
       changed_queue_set.insert(queue_indices[i]);
-      task_queues_[queue_indices[i]]->immediate_work_queue()->Push(
-          TaskQueueImpl::Task(
-              TaskQueue::PostedTask(test_closure_, FROM_HERE), TimeTicks(),
-              EnqueueOrder(),
-              EnqueueOrder::FromIntForTesting(enqueue_orders[i])));
+      task_queues_[queue_indices[i]]->immediate_work_queue()->Push(Task(
+          PostedTask(test_closure_, FROM_HERE), TimeTicks(), EnqueueOrder(),
+          EnqueueOrder::FromIntForTesting(enqueue_orders[i])));
     }
   }
 
@@ -738,9 +735,9 @@ TEST_F(TaskQueueSelectorTest, ChooseOldestWithPriority_Empty) {
 }
 
 TEST_F(TaskQueueSelectorTest, ChooseOldestWithPriority_OnlyDelayed) {
-  task_queues_[0]->delayed_work_queue()->Push(TaskQueueImpl::Task(
-      TaskQueue::PostedTask(test_closure_, FROM_HERE), TimeTicks(),
-      EnqueueOrder(), EnqueueOrder::FromIntForTesting(2)));
+  task_queues_[0]->delayed_work_queue()->Push(
+      Task(PostedTask(test_closure_, FROM_HERE), TimeTicks(), EnqueueOrder(),
+           EnqueueOrder::FromIntForTesting(2)));
 
   WorkQueue* chosen_work_queue = nullptr;
   bool chose_delayed_over_immediate = false;
@@ -752,9 +749,9 @@ TEST_F(TaskQueueSelectorTest, ChooseOldestWithPriority_OnlyDelayed) {
 }
 
 TEST_F(TaskQueueSelectorTest, ChooseOldestWithPriority_OnlyImmediate) {
-  task_queues_[0]->immediate_work_queue()->Push(TaskQueueImpl::Task(
-      TaskQueue::PostedTask(test_closure_, FROM_HERE), TimeTicks(),
-      EnqueueOrder(), EnqueueOrder::FromIntForTesting(2)));
+  task_queues_[0]->immediate_work_queue()->Push(
+      Task(PostedTask(test_closure_, FROM_HERE), TimeTicks(), EnqueueOrder(),
+           EnqueueOrder::FromIntForTesting(2)));
 
   WorkQueue* chosen_work_queue = nullptr;
   bool chose_delayed_over_immediate = false;
@@ -778,9 +775,8 @@ TEST_F(TaskQueueSelectorTest, TestObserverWithOneBlockedQueue) {
   task_queue->SetQueueEnabledForTest(false);
   selector.DisableQueue(task_queue.get());
 
-  TaskQueueImpl::Task task(TaskQueue::PostedTask(test_closure_, FROM_HERE),
-                           TimeTicks(), EnqueueOrder(),
-                           EnqueueOrder::FromIntForTesting(2));
+  Task task(PostedTask(test_closure_, FROM_HERE), TimeTicks(), EnqueueOrder(),
+            EnqueueOrder::FromIntForTesting(2));
   task_queue->immediate_work_queue()->Push(std::move(task));
 
   WorkQueue* chosen_work_queue;
@@ -809,12 +805,12 @@ TEST_F(TaskQueueSelectorTest, TestObserverWithTwoBlockedQueues) {
 
   selector.SetQueuePriority(task_queue2.get(), TaskQueue::kControlPriority);
 
-  TaskQueueImpl::Task task1(TaskQueue::PostedTask(test_closure_, FROM_HERE),
-                            TimeTicks(), EnqueueOrder::FromIntForTesting(2),
-                            EnqueueOrder::FromIntForTesting(2));
-  TaskQueueImpl::Task task2(TaskQueue::PostedTask(test_closure_, FROM_HERE),
-                            TimeTicks(), EnqueueOrder::FromIntForTesting(3),
-                            EnqueueOrder::FromIntForTesting(3));
+  Task task1(PostedTask(test_closure_, FROM_HERE), TimeTicks(),
+             EnqueueOrder::FromIntForTesting(2),
+             EnqueueOrder::FromIntForTesting(2));
+  Task task2(PostedTask(test_closure_, FROM_HERE), TimeTicks(),
+             EnqueueOrder::FromIntForTesting(3),
+             EnqueueOrder::FromIntForTesting(3));
   task_queue->immediate_work_queue()->Push(std::move(task1));
   task_queue2->immediate_work_queue()->Push(std::move(task2));
 
@@ -858,14 +854,14 @@ class ChooseOldestWithPriorityTest
       public testing::WithParamInterface<ChooseOldestWithPriorityTestParam> {};
 
 TEST_P(ChooseOldestWithPriorityTest, RoundRobinTest) {
-  task_queues_[0]->immediate_work_queue()->Push(TaskQueueImpl::Task(
-      TaskQueue::PostedTask(test_closure_, FROM_HERE), TimeTicks(),
+  task_queues_[0]->immediate_work_queue()->Push(Task(
+      PostedTask(test_closure_, FROM_HERE), TimeTicks(),
       EnqueueOrder::FromIntForTesting(GetParam().immediate_task_enqueue_order),
       EnqueueOrder::FromIntForTesting(
           GetParam().immediate_task_enqueue_order)));
 
-  task_queues_[0]->delayed_work_queue()->Push(TaskQueueImpl::Task(
-      TaskQueue::PostedTask(test_closure_, FROM_HERE), TimeTicks(),
+  task_queues_[0]->delayed_work_queue()->Push(Task(
+      PostedTask(test_closure_, FROM_HERE), TimeTicks(),
       EnqueueOrder::FromIntForTesting(GetParam().delayed_task_enqueue_order),
       EnqueueOrder::FromIntForTesting(GetParam().delayed_task_enqueue_order)));
 
