@@ -16,7 +16,6 @@
 #include "base/cfi_buildflags.h"
 #include "base/debug/stack_trace.h"
 #include "base/macros.h"
-#include "base/memory/ptr_util.h"
 #include "base/metrics/field_trial.h"
 #include "base/metrics/field_trial_params.h"
 #include "base/synchronization/waitable_event.h"
@@ -94,8 +93,8 @@ void VerifyTaskEnvironment(const TaskTraits& traits) {
   EXPECT_NE(std::string::npos, current_thread_name.find("TaskScheduler"));
 
   if (current_thread_name.find("SingleThread") != std::string::npos) {
-    // For now, single-threaded background tasks run on their own threads.
-    // TODO(fdoray): Run single-threaded background tasks on foreground workers
+    // For now, single-threaded best-effort tasks run on their own threads.
+    // TODO(fdoray): Run single-threaded best-effort tasks on foreground workers
     // on platforms that don't support background thread priority.
     EXPECT_NE(
         std::string::npos,
@@ -451,9 +450,9 @@ TEST_F(TaskSchedulerImplTest, MultipleTraitsExecutionModePairs) {
   StartTaskScheduler();
   std::vector<std::unique_ptr<ThreadPostingTasks>> threads_posting_tasks;
   for (const auto& traits_execution_mode_pair : GetTraitsExecutionModePairs()) {
-    threads_posting_tasks.push_back(WrapUnique(
-        new ThreadPostingTasks(&scheduler_, traits_execution_mode_pair.traits,
-                               traits_execution_mode_pair.execution_mode)));
+    threads_posting_tasks.push_back(std::make_unique<ThreadPostingTasks>(
+        &scheduler_, traits_execution_mode_pair.traits,
+        traits_execution_mode_pair.execution_mode));
     threads_posting_tasks.back()->Start();
   }
 
