@@ -35,6 +35,7 @@ const char* const kDumpProviderWhitelist[] = {
     "gpu::TextureManager",
     "FontCaches",
     "HistoryReport",
+    "HistoryService",
     "IPCChannel",
     "IndexedDBBackingStore",
     "InMemoryURLIndex",
@@ -94,10 +95,11 @@ const char* const kAllocatorDumpNameWhitelist[] = {
     "extensions/value_store/Extensions.Database.Value.Restore/0x?",
     "font_caches/font_platform_data_cache",
     "font_caches/shape_caches",
-    "gpu/gl/buffers/share_group_0x?",
-    "gpu/gl/renderbuffers/share_group_0x?",
-    "gpu/gl/textures/share_group_0x?",
+    "gpu/gl/buffers/context_group_0x?",
+    "gpu/gl/renderbuffers/context_group_0x?",
+    "gpu/gl/textures/context_group_0x?",
     "history/delta_file_service/leveldb_0x?",
+    "history/history_service",
     "history/usage_reports_buffer/leveldb_0x?",
     "java_heap",
     "java_heap/allocated_objects",
@@ -261,19 +263,44 @@ const char* const kAllocatorDumpNameWhitelist[] = {
     "sqlite",
     "ui/resource_manager_0x?/default_resource/0x?",
     "ui/resource_manager_0x?/tinted_resource",
-    "v8/isolate_0x?/contexts/detached_context",
-    "v8/isolate_0x?/contexts/native_context",
-    "v8/isolate_0x?/heap_spaces",
-    "v8/isolate_0x?/heap_spaces/code_space",
-    "v8/isolate_0x?/heap_spaces/large_object_space",
-    "v8/isolate_0x?/heap_spaces/map_space",
-    "v8/isolate_0x?/heap_spaces/new_space",
-    "v8/isolate_0x?/heap_spaces/new_large_object_space",
-    "v8/isolate_0x?/heap_spaces/old_space",
-    "v8/isolate_0x?/heap_spaces/read_only_space",
-    "v8/isolate_0x?/malloc",
-    "v8/isolate_0x?/zapped_for_debug",
     "site_storage/blob_storage/0x?",
+    "v8/main/code_stats",
+    "v8/main/contexts/detached_context",
+    "v8/main/contexts/native_context",
+    "v8/main/heap/code_space",
+    "v8/main/heap/code_stats",
+    "v8/main/heap/large_object_space",
+    "v8/main/heap/map_space",
+    "v8/main/heap/new_large_object_space",
+    "v8/main/heap/new_space",
+    "v8/main/heap/old_space",
+    "v8/main/heap/read_only_space",
+    "v8/main/malloc",
+    "v8/main/zapped_for_debug",
+    "v8/utility/code_stats",
+    "v8/utility/contexts/detached_context",
+    "v8/utility/contexts/native_context",
+    "v8/utility/heap/code_space",
+    "v8/utility/heap/large_object_space",
+    "v8/utility/heap/map_space",
+    "v8/utility/heap/new_large_object_space",
+    "v8/utility/heap/new_space",
+    "v8/utility/heap/old_space",
+    "v8/utility/heap/read_only_space",
+    "v8/utility/malloc",
+    "v8/utility/zapped_for_debug",
+    "v8/workers/code_stats/isolate_0x?",
+    "v8/workers/contexts/detached_context/isolate_0x?",
+    "v8/workers/contexts/native_context/isolate_0x?",
+    "v8/workers/heap/code_space/isolate_0x?",
+    "v8/workers/heap/large_object_space/isolate_0x?",
+    "v8/workers/heap/map_space/isolate_0x?",
+    "v8/workers/heap/new_large_object_space/isolate_0x?",
+    "v8/workers/heap/new_space/isolate_0x?",
+    "v8/workers/heap/old_space/isolate_0x?",
+    "v8/workers/heap/read_only_space/isolate_0x?",
+    "v8/workers/malloc/isolate_0x?",
+    "v8/workers/zapped_for_debug/isolate_0x?",
     "site_storage/index_db/db_0x?",
     "site_storage/index_db/memenv_0x?",
     "site_storage/localstorage/0x?/cache_size",
