@@ -7,40 +7,53 @@
 #include <algorithm>
 #include <cmath>
 #include <limits>
+#if defined(ARCH_CPU_X86_FAMILY)
+#include <xmmintrin.h>
+#endif
 
+#include "base/trace_event/trace_event_argument.h"
 #include "base/values.h"
-#include "ui/gfx/quad_f.h"
-#include "ui/gfx/rect.h"
-#include "ui/gfx/rect_conversions.h"
-#include "ui/gfx/rect_f.h"
+#include "ui/gfx/geometry/angle_conversions.h"
+#include "ui/gfx/geometry/quad_f.h"
+#include "ui/gfx/geometry/rect.h"
+#include "ui/gfx/geometry/rect_conversions.h"
+#include "ui/gfx/geometry/rect_f.h"
+#include "ui/gfx/geometry/vector2d_f.h"
+#include "ui/gfx/geometry/vector3d_f.h"
 #include "ui/gfx/transform.h"
-#include "ui/gfx/vector2d_f.h"
 
 namespace cc {
 
-const double MathUtil::kPiDouble = 3.14159265358979323846;
-const float MathUtil::kPiFloat = 3.14159265358979323846f;
-
 static HomogeneousCoordinate ProjectHomogeneousPoint(
     const gfx::Transform& transform,
     const gfx::PointF& p) {
+  SkMScalar z =
+      -(transform.matrix().get(2, 0) * p.x() +
+        transform.matrix().get(2, 1) * p.y() + transform.matrix().get(2, 3)) /
+      transform.matrix().get(2, 2);
+
   // In this case, the layer we are trying to project onto is perpendicular to
   // ray (point p and z-axis direction) that we are trying to project. This
   // happens when the layer is rotated so that it is infinitesimally thin, or
   // when it is co-planar with the camera origin -- i.e. when the layer is
   // invisible anyway.
-  if (!transform.matrix().get(2, 2))
+  if (!std::isfinite(z))
     return HomogeneousCoordinate(0.0, 0.0, 0.0, 1.0);
 
-  SkMScalar z = -(transform.matrix().get(2, 0) * p.x() +
-             transform.matrix().get(2, 1) * p.y() +
-             transform.matrix().get(2, 3)) /
-             transform.matrix().get(2, 2);
   HomogeneousCoordinate result(p.x(), p.y(), z, 1.0);
   transform.matrix().mapMScalars(result.vec, result.vec);
   return result;
 }
 
+static HomogeneousCoordinate ProjectHomogeneousPoint(
+    const gfx::Transform& transform,
+    const gfx::PointF& p,
+    bool* clipped) {
+  HomogeneousCoordinate h = ProjectHomogeneousPoint(transform, p);
+  *clipped = h.w() <= 0;
+  return h;
+}
+
 static HomogeneousCoordinate MapHomogeneousPoint(
     const gfx::Transform& transform,
     const gfx::Point3F& p) {
@@ -49,38 +62,84 @@ static HomogeneousCoordinate MapHomogeneousPoint(
   return result;
 }
 
-static HomogeneousCoordinate ComputeClippedPointForEdge(
+static void homogenousLimitAtZero(SkMScalar a1,
+                                  SkMScalar w1,
+                                  SkMScalar a2,
+                                  SkMScalar w2,
+                                  float t,
+                                  float* limit) {
+  // This is the tolerance for detecting an eyepoint-aligned edge.
+  static const float kStationaryPointEplison = 0.00001f;
+  // This needs to be big enough to not be the limit of clipping, but not so
+  // big that using it as a size destroys the offset in a rect.
+  static const float kInfiniteCoordinate = 1000000.0f;
+
+  if (std::abs(a1 * w2 / w1 / a2 - 1.0f) > kStationaryPointEplison) {
+    // We are going to explode towards an infity, but we choose the one that
+    // corresponds to the one on the positive side of w.
+    if (((1.0f - t) * a1 + t * a2) > 0) {
+      *limit = kInfiniteCoordinate;
+    } else {
+      *limit = -kInfiniteCoordinate;
+    }
+  } else {
+    *limit = a1 / w1;  // (== a2 / w2) && == (1.0f - t) * a1 / w1 + t * a2 / w2
+  }
+}
+
+static gfx::PointF ComputeClippedCartesianPoint2dForEdge(
     const HomogeneousCoordinate& h1,
     const HomogeneousCoordinate& h2) {
   // Points h1 and h2 form a line in 4d, and any point on that line can be
   // represented as an interpolation between h1 and h2:
   //    p = (1-t) h1 + (t) h2
   //
-  // We want to compute point p such that p.w == epsilon, where epsilon is a
-  // small non-zero number. (but the smaller the number is, the higher the risk
-  // of overflow)
-  // To do this, we solve for t in the following equation:
-  //    p.w = epsilon = (1-t) * h1.w + (t) * h2.w
+  // We want to compute the limit in 2 space of
+  //    x = ((1-t) h1.x + (t) h2.x) / ((1-t) h1.w + (t) h2.w)
+  //    y = ((1-t) h1.y + (t) h2.y) / ((1-t) h1.w + (t) h2.w)
+  // as ((1-t) h1.w + (t) h2.w) -> 0+
+
+  // The only answers to this are h1.x/h1.w == h2.x/h2.w, +/- infinity
+  // i.e., either the coordinate is not moving, or is trending to one
+  // infinity or the other.
+
+  float t = h1.w() / (h1.w() - h2.w());
+  float x;
+  float y;
+
+  homogenousLimitAtZero(h1.x(), h1.w(), h2.x(), h2.w(), t, &x);
+  homogenousLimitAtZero(h1.y(), h1.w(), h2.y(), h2.w(), t, &y);
+
+  return gfx::PointF(x, y);
+}
+
+static gfx::Point3F ComputeClippedCartesianPoint3dForEdge(
+    const HomogeneousCoordinate& h1,
+    const HomogeneousCoordinate& h2) {
+  // Points h1 and h2 form a line in 4d, and any point on that line can be
+  // represented as an interpolation between h1 and h2:
+  //    p = (1-t) h1 + (t) h2
   //
-  // Once paramter t is known, the rest of p can be computed via
-  //    p = (1-t) h1 + (t) h2.
+  // We want to compute the limit in 3 space of
+  //    x = ((1-t) h1.x + (t) h2.x) / ((1-t) h1.w + (t) h2.w)
+  //    y = ((1-t) h1.y + (t) h2.y) / ((1-t) h1.w + (t) h2.w)
+  //    z = ((1-t) h1.z + (t) h2.z) / ((1-t) h1.w + (t) h2.w)
+  // as ((1-t) h1.w + (t) h2.w) -> 0+
 
-  // Technically this is a special case of the following assertion, but its a
-  // good idea to keep it an explicit sanity check here.
-  DCHECK_NE(h2.w(), h1.w());
-  // Exactly one of h1 or h2 (but not both) must be on the negative side of the
-  // w plane when this is called.
-  DCHECK(h1.ShouldBeClipped() ^ h2.ShouldBeClipped());
+  // The only answers to this are h1.x/h1.w == h2.x/h2.w, +/- infinity
+  // i.e., either the coordinate is not moving, or is trending to one
+  // infinity or the other.
 
-  // ...or any positive non-zero small epsilon
-  SkMScalar w = 0.00001f;
-  SkMScalar t = (w - h1.w()) / (h2.w() - h1.w());
+  float t = h1.w() / (h1.w() - h2.w());
+  float x;
+  float y;
+  float z;
 
-  SkMScalar x = (SK_MScalar1 - t) * h1.x() + t * h2.x();
-  SkMScalar y = (SK_MScalar1 - t) * h1.y() + t * h2.y();
-  SkMScalar z = (SK_MScalar1 - t) * h1.z() + t * h2.z();
+  homogenousLimitAtZero(h1.x(), h1.w(), h2.x(), h2.w(), t, &x);
+  homogenousLimitAtZero(h1.y(), h1.w(), h2.y(), h2.w(), t, &y);
+  homogenousLimitAtZero(h1.z(), h1.w(), h2.z(), h2.w(), t, &z);
 
-  return HomogeneousCoordinate(x, y, z, w);
+  return gfx::Point3F(x, y, z);
 }
 
 static inline void ExpandBoundsToIncludePoint(float* xmin,
@@ -94,9 +153,36 @@ static inline void ExpandBoundsToIncludePoint(float* xmin,
   *ymax = std::max(p.y(), *ymax);
 }
 
-static inline void AddVertexToClippedQuad(const gfx::PointF& new_vertex,
-                                          gfx::PointF clipped_quad[8],
-                                          int* num_vertices_in_clipped_quad) {
+static inline bool IsNearlyTheSame(float f, float g) {
+  // The idea behind this is to use this fraction of the larger of the
+  // two numbers as the limit of the difference.  This breaks down near
+  // zero, so we reuse this as the minimum absolute size we will use
+  // for the base of the scale too.
+  static const float epsilon_scale = 0.00001f;
+  return std::abs(f - g) <
+         epsilon_scale *
+             std::max(std::max(std::abs(f), std::abs(g)), epsilon_scale);
+}
+
+static inline bool IsNearlyTheSame(const gfx::PointF& lhs,
+                                   const gfx::PointF& rhs) {
+  return IsNearlyTheSame(lhs.x(), rhs.x()) && IsNearlyTheSame(lhs.y(), rhs.y());
+}
+
+static inline bool IsNearlyTheSame(const gfx::Point3F& lhs,
+                                   const gfx::Point3F& rhs) {
+  return IsNearlyTheSame(lhs.x(), rhs.x()) &&
+         IsNearlyTheSame(lhs.y(), rhs.y()) && IsNearlyTheSame(lhs.z(), rhs.z());
+}
+
+static inline void AddVertexToClippedQuad3d(const gfx::Point3F& new_vertex,
+                                            gfx::Point3F clipped_quad[6],
+                                            int* num_vertices_in_clipped_quad) {
+  if (*num_vertices_in_clipped_quad > 0 &&
+      IsNearlyTheSame(clipped_quad[*num_vertices_in_clipped_quad - 1],
+                      new_vertex))
+    return;
+
   clipped_quad[*num_vertices_in_clipped_quad] = new_vertex;
   (*num_vertices_in_clipped_quad)++;
 }
@@ -104,21 +190,26 @@ static inline void AddVertexToClippedQuad(const gfx::PointF& new_vertex,
 gfx::Rect MathUtil::MapEnclosingClippedRect(const gfx::Transform& transform,
                                             const gfx::Rect& src_rect) {
   if (transform.IsIdentityOrIntegerTranslation()) {
-    return src_rect +
-           gfx::Vector2d(
-               static_cast<int>(SkMScalarToFloat(transform.matrix().get(0, 3))),
-               static_cast<int>(
-                   SkMScalarToFloat(transform.matrix().get(1, 3))));
+    gfx::Vector2d offset(static_cast<int>(transform.matrix().getFloat(0, 3)),
+                         static_cast<int>(transform.matrix().getFloat(1, 3)));
+    return src_rect + offset;
   }
-  return gfx::ToEnclosingRect(MapClippedRect(transform, gfx::RectF(src_rect)));
+  gfx::RectF mapped_rect = MapClippedRect(transform, gfx::RectF(src_rect));
+
+  // gfx::ToEnclosingRect crashes if called on a RectF with any NaN coordinate.
+  if (std::isnan(mapped_rect.x()) || std::isnan(mapped_rect.y()) ||
+      std::isnan(mapped_rect.right()) || std::isnan(mapped_rect.bottom()))
+    return gfx::Rect();
+
+  return gfx::ToEnclosingRect(mapped_rect);
 }
 
 gfx::RectF MathUtil::MapClippedRect(const gfx::Transform& transform,
                                     const gfx::RectF& src_rect) {
   if (transform.IsIdentityOrTranslation()) {
-    return src_rect +
-           gfx::Vector2dF(SkMScalarToFloat(transform.matrix().get(0, 3)),
-                          SkMScalarToFloat(transform.matrix().get(1, 3)));
+    gfx::Vector2dF offset(transform.matrix().getFloat(0, 3),
+                          transform.matrix().getFloat(1, 3));
+    return src_rect + offset;
   }
 
   // Apply the transform, but retain the result in homogeneous coordinates.
@@ -146,22 +237,27 @@ gfx::RectF MathUtil::MapClippedRect(const gfx::Transform& transform,
 gfx::Rect MathUtil::ProjectEnclosingClippedRect(const gfx::Transform& transform,
                                                 const gfx::Rect& src_rect) {
   if (transform.IsIdentityOrIntegerTranslation()) {
-    return src_rect +
-           gfx::Vector2d(
-               static_cast<int>(SkMScalarToFloat(transform.matrix().get(0, 3))),
-               static_cast<int>(
-                   SkMScalarToFloat(transform.matrix().get(1, 3))));
+    gfx::Vector2d offset(static_cast<int>(transform.matrix().getFloat(0, 3)),
+                         static_cast<int>(transform.matrix().getFloat(1, 3)));
+    return src_rect + offset;
   }
-  return gfx::ToEnclosingRect(
-      ProjectClippedRect(transform, gfx::RectF(src_rect)));
+  gfx::RectF projected_rect =
+      ProjectClippedRect(transform, gfx::RectF(src_rect));
+
+  // gfx::ToEnclosingRect crashes if called on a RectF with any NaN coordinate.
+  if (std::isnan(projected_rect.x()) || std::isnan(projected_rect.y()) ||
+      std::isnan(projected_rect.right()) || std::isnan(projected_rect.bottom()))
+    return gfx::Rect();
+
+  return gfx::ToEnclosingRect(projected_rect);
 }
 
 gfx::RectF MathUtil::ProjectClippedRect(const gfx::Transform& transform,
                                         const gfx::RectF& src_rect) {
   if (transform.IsIdentityOrTranslation()) {
-    return src_rect +
-           gfx::Vector2dF(SkMScalarToFloat(transform.matrix().get(0, 3)),
-                          SkMScalarToFloat(transform.matrix().get(1, 3)));
+    gfx::Vector2dF offset(transform.matrix().getFloat(0, 3),
+                          transform.matrix().getFloat(1, 3));
+    return src_rect + offset;
   }
 
   // Perform the projection, but retain the result in homogeneous coordinates.
@@ -174,10 +270,61 @@ gfx::RectF MathUtil::ProjectClippedRect(const gfx::Transform& transform,
   return ComputeEnclosingClippedRect(h1, h2, h3, h4);
 }
 
-void MathUtil::MapClippedQuad(const gfx::Transform& transform,
-                              const gfx::QuadF& src_quad,
-                              gfx::PointF clipped_quad[8],
-                              int* num_vertices_in_clipped_quad) {
+gfx::QuadF MathUtil::InverseMapQuadToLocalSpace(
+    const gfx::Transform& device_transform,
+    const gfx::QuadF& device_quad) {
+  gfx::Transform inverse_device_transform(gfx::Transform::kSkipInitialization);
+  DCHECK(device_transform.IsInvertible());
+  bool did_invert = device_transform.GetInverse(&inverse_device_transform);
+  DCHECK(did_invert);
+  bool clipped = false;
+  gfx::QuadF local_quad =
+      MathUtil::MapQuad(inverse_device_transform, device_quad, &clipped);
+  // We should not DCHECK(!clipped) here, because anti-aliasing inflation may
+  // cause device_quad to become clipped. To our knowledge this scenario does
+  // not need to be handled differently than the unclipped case.
+  return local_quad;
+}
+
+gfx::Rect MathUtil::MapEnclosedRectWith2dAxisAlignedTransform(
+    const gfx::Transform& transform,
+    const gfx::Rect& rect) {
+  DCHECK(transform.Preserves2dAxisAlignment());
+
+  if (transform.IsIdentityOrIntegerTranslation()) {
+    gfx::Vector2d offset(static_cast<int>(transform.matrix().getFloat(0, 3)),
+                         static_cast<int>(transform.matrix().getFloat(1, 3)));
+    return rect + offset;
+  }
+  if (transform.IsIdentityOrTranslation()) {
+    gfx::Vector2dF offset(transform.matrix().getFloat(0, 3),
+                          transform.matrix().getFloat(1, 3));
+    return gfx::ToEnclosedRect(gfx::RectF(rect) + offset);
+  }
+
+  SkMScalar quad[2 * 2];  // input: 2 x 2D points
+  quad[0] = rect.x();
+  quad[1] = rect.y();
+  quad[2] = rect.right();
+  quad[3] = rect.bottom();
+
+  SkMScalar result[4 * 2];  // output: 2 x 4D homogeneous points
+  transform.matrix().map2(quad, 2, result);
+
+  HomogeneousCoordinate hc0(result[0], result[1], result[2], result[3]);
+  HomogeneousCoordinate hc1(result[4], result[5], result[6], result[7]);
+  DCHECK(!hc0.ShouldBeClipped());
+  DCHECK(!hc1.ShouldBeClipped());
+
+  gfx::PointF top_left(hc0.CartesianPoint2d());
+  gfx::PointF bottom_right(hc1.CartesianPoint2d());
+  return gfx::ToEnclosedRect(gfx::BoundingRect(top_left, bottom_right));
+}
+
+bool MathUtil::MapClippedQuad3d(const gfx::Transform& transform,
+                                const gfx::QuadF& src_quad,
+                                gfx::Point3F clipped_quad[6],
+                                int* num_vertices_in_clipped_quad) {
   HomogeneousCoordinate h1 =
       MapHomogeneousPoint(transform, gfx::Point3F(src_quad.p1()));
   HomogeneousCoordinate h2 =
@@ -193,54 +340,52 @@ void MathUtil::MapClippedQuad(const gfx::Transform& transform,
   *num_vertices_in_clipped_quad = 0;
 
   if (!h1.ShouldBeClipped()) {
-    AddVertexToClippedQuad(
-        h1.CartesianPoint2d(), clipped_quad, num_vertices_in_clipped_quad);
+    AddVertexToClippedQuad3d(
+        h1.CartesianPoint3d(), clipped_quad, num_vertices_in_clipped_quad);
   }
 
   if (h1.ShouldBeClipped() ^ h2.ShouldBeClipped()) {
-    AddVertexToClippedQuad(
-        ComputeClippedPointForEdge(h1, h2).CartesianPoint2d(),
-        clipped_quad,
-        num_vertices_in_clipped_quad);
+    AddVertexToClippedQuad3d(ComputeClippedCartesianPoint3dForEdge(h1, h2),
+                             clipped_quad, num_vertices_in_clipped_quad);
   }
 
   if (!h2.ShouldBeClipped()) {
-    AddVertexToClippedQuad(
-        h2.CartesianPoint2d(), clipped_quad, num_vertices_in_clipped_quad);
+    AddVertexToClippedQuad3d(
+        h2.CartesianPoint3d(), clipped_quad, num_vertices_in_clipped_quad);
   }
 
   if (h2.ShouldBeClipped() ^ h3.ShouldBeClipped()) {
-    AddVertexToClippedQuad(
-        ComputeClippedPointForEdge(h2, h3).CartesianPoint2d(),
-        clipped_quad,
-        num_vertices_in_clipped_quad);
+    AddVertexToClippedQuad3d(ComputeClippedCartesianPoint3dForEdge(h2, h3),
+                             clipped_quad, num_vertices_in_clipped_quad);
   }
 
   if (!h3.ShouldBeClipped()) {
-    AddVertexToClippedQuad(
-        h3.CartesianPoint2d(), clipped_quad, num_vertices_in_clipped_quad);
+    AddVertexToClippedQuad3d(
+        h3.CartesianPoint3d(), clipped_quad, num_vertices_in_clipped_quad);
   }
 
   if (h3.ShouldBeClipped() ^ h4.ShouldBeClipped()) {
-    AddVertexToClippedQuad(
-        ComputeClippedPointForEdge(h3, h4).CartesianPoint2d(),
-        clipped_quad,
-        num_vertices_in_clipped_quad);
+    AddVertexToClippedQuad3d(ComputeClippedCartesianPoint3dForEdge(h3, h4),
+                             clipped_quad, num_vertices_in_clipped_quad);
   }
 
   if (!h4.ShouldBeClipped()) {
-    AddVertexToClippedQuad(
-        h4.CartesianPoint2d(), clipped_quad, num_vertices_in_clipped_quad);
+    AddVertexToClippedQuad3d(
+        h4.CartesianPoint3d(), clipped_quad, num_vertices_in_clipped_quad);
   }
 
   if (h4.ShouldBeClipped() ^ h1.ShouldBeClipped()) {
-    AddVertexToClippedQuad(
-        ComputeClippedPointForEdge(h4, h1).CartesianPoint2d(),
-        clipped_quad,
-        num_vertices_in_clipped_quad);
+    AddVertexToClippedQuad3d(ComputeClippedCartesianPoint3dForEdge(h4, h1),
+                             clipped_quad, num_vertices_in_clipped_quad);
   }
 
-  DCHECK_LE(*num_vertices_in_clipped_quad, 8);
+  if (*num_vertices_in_clipped_quad > 2 &&
+      IsNearlyTheSame(clipped_quad[0],
+                      clipped_quad[*num_vertices_in_clipped_quad - 1]))
+    *num_vertices_in_clipped_quad -= 1;
+
+  DCHECK_LE(*num_vertices_in_clipped_quad, 6);
+  return (*num_vertices_in_clipped_quad >= 4);
 }
 
 gfx::RectF MathUtil::ComputeEnclosingRectOfVertices(
@@ -297,48 +442,32 @@ gfx::RectF MathUtil::ComputeEnclosingClippedRect(
                                h1.CartesianPoint2d());
 
   if (h1.ShouldBeClipped() ^ h2.ShouldBeClipped())
-    ExpandBoundsToIncludePoint(&xmin,
-                               &xmax,
-                               &ymin,
-                               &ymax,
-                               ComputeClippedPointForEdge(h1, h2)
-                                   .CartesianPoint2d());
+    ExpandBoundsToIncludePoint(&xmin, &xmax, &ymin, &ymax,
+                               ComputeClippedCartesianPoint2dForEdge(h1, h2));
 
   if (!h2.ShouldBeClipped())
     ExpandBoundsToIncludePoint(&xmin, &xmax, &ymin, &ymax,
                                h2.CartesianPoint2d());
 
   if (h2.ShouldBeClipped() ^ h3.ShouldBeClipped())
-    ExpandBoundsToIncludePoint(&xmin,
-                               &xmax,
-                               &ymin,
-                               &ymax,
-                               ComputeClippedPointForEdge(h2, h3)
-                                   .CartesianPoint2d());
+    ExpandBoundsToIncludePoint(&xmin, &xmax, &ymin, &ymax,
+                               ComputeClippedCartesianPoint2dForEdge(h2, h3));
 
   if (!h3.ShouldBeClipped())
     ExpandBoundsToIncludePoint(&xmin, &xmax, &ymin, &ymax,
                                h3.CartesianPoint2d());
 
   if (h3.ShouldBeClipped() ^ h4.ShouldBeClipped())
-    ExpandBoundsToIncludePoint(&xmin,
-                               &xmax,
-                               &ymin,
-                               &ymax,
-                               ComputeClippedPointForEdge(h3, h4)
-                                   .CartesianPoint2d());
+    ExpandBoundsToIncludePoint(&xmin, &xmax, &ymin, &ymax,
+                               ComputeClippedCartesianPoint2dForEdge(h3, h4));
 
   if (!h4.ShouldBeClipped())
     ExpandBoundsToIncludePoint(&xmin, &xmax, &ymin, &ymax,
                                h4.CartesianPoint2d());
 
   if (h4.ShouldBeClipped() ^ h1.ShouldBeClipped())
-    ExpandBoundsToIncludePoint(&xmin,
-                               &xmax,
-                               &ymin,
-                               &ymax,
-                               ComputeClippedPointForEdge(h4, h1)
-                                   .CartesianPoint2d());
+    ExpandBoundsToIncludePoint(&xmin, &xmax, &ymin, &ymax,
+                               ComputeClippedCartesianPoint2dForEdge(h4, h1));
 
   return gfx::RectF(gfx::PointF(xmin, ymin),
                     gfx::SizeF(xmax - xmin, ymax - ymin));
@@ -349,9 +478,8 @@ gfx::QuadF MathUtil::MapQuad(const gfx::Transform& transform,
                              bool* clipped) {
   if (transform.IsIdentityOrTranslation()) {
     gfx::QuadF mapped_quad(q);
-    mapped_quad +=
-        gfx::Vector2dF(SkMScalarToFloat(transform.matrix().get(0, 3)),
-                       SkMScalarToFloat(transform.matrix().get(1, 3)));
+    mapped_quad += gfx::Vector2dF(transform.matrix().getFloat(0, 3),
+                                  transform.matrix().getFloat(1, 3));
     *clipped = false;
     return mapped_quad;
   }
@@ -400,72 +528,30 @@ gfx::PointF MathUtil::MapPoint(const gfx::Transform& transform,
   return h.CartesianPoint2d();
 }
 
-gfx::Point3F MathUtil::MapPoint(const gfx::Transform& transform,
-                                const gfx::Point3F& p,
-                                bool* clipped) {
-  HomogeneousCoordinate h = MapHomogeneousPoint(transform, p);
-
-  if (h.w() > 0) {
-    *clipped = false;
-    return h.CartesianPoint3d();
-  }
-
-  // The cartesian coordinates will be invalid after dividing by w.
-  *clipped = true;
-
-  // Avoid dividing by w if w == 0.
-  if (!h.w())
-    return gfx::Point3F();
-
-  // This return value will be invalid because clipped == true, but (1) users of
-  // this code should be ignoring the return value when clipped == true anyway,
-  // and (2) this behavior is more consistent with existing behavior of WebKit
-  // transforms if the user really does not ignore the return value.
-  return h.CartesianPoint3d();
-}
-
-gfx::QuadF MathUtil::ProjectQuad(const gfx::Transform& transform,
-                                 const gfx::QuadF& q,
-                                 bool* clipped) {
-  gfx::QuadF projected_quad;
-  bool clipped_point;
-  projected_quad.set_p1(ProjectPoint(transform, q.p1(), &clipped_point));
-  *clipped = clipped_point;
-  projected_quad.set_p2(ProjectPoint(transform, q.p2(), &clipped_point));
-  *clipped |= clipped_point;
-  projected_quad.set_p3(ProjectPoint(transform, q.p3(), &clipped_point));
-  *clipped |= clipped_point;
-  projected_quad.set_p4(ProjectPoint(transform, q.p4(), &clipped_point));
-  *clipped |= clipped_point;
-
-  return projected_quad;
-}
-
 gfx::PointF MathUtil::ProjectPoint(const gfx::Transform& transform,
                                    const gfx::PointF& p,
                                    bool* clipped) {
-  HomogeneousCoordinate h = ProjectHomogeneousPoint(transform, p);
-
-  if (h.w() > 0) {
-    // The cartesian coordinates will be valid in this case.
-    *clipped = false;
-    return h.CartesianPoint2d();
-  }
-
-  // The cartesian coordinates will be invalid after dividing by w.
-  *clipped = true;
-
+  HomogeneousCoordinate h = ProjectHomogeneousPoint(transform, p, clipped);
   // Avoid dividing by w if w == 0.
   if (!h.w())
     return gfx::PointF();
 
-  // This return value will be invalid because clipped == true, but (1) users of
+  // This return value will be invalid if clipped == true, but (1) users of
   // this code should be ignoring the return value when clipped == true anyway,
   // and (2) this behavior is more consistent with existing behavior of WebKit
   // transforms if the user really does not ignore the return value.
   return h.CartesianPoint2d();
 }
 
+gfx::Point3F MathUtil::ProjectPoint3D(const gfx::Transform& transform,
+                                      const gfx::PointF& p,
+                                      bool* clipped) {
+  HomogeneousCoordinate h = ProjectHomogeneousPoint(transform, p, clipped);
+  if (!h.w())
+    return gfx::Point3F();
+  return h.CartesianPoint3d();
+}
+
 gfx::RectF MathUtil::ScaleRectProportional(const gfx::RectF& input_outer_rect,
                                            const gfx::RectF& scale_outer_rect,
                                            const gfx::RectF& scale_inner_rect) {
@@ -486,13 +572,17 @@ gfx::RectF MathUtil::ScaleRectProportional(const gfx::RectF& input_outer_rect,
   return output_inner_rect;
 }
 
+static inline bool NearlyZero(double value) {
+  return std::abs(value) < std::numeric_limits<double>::epsilon();
+}
+
 static inline float ScaleOnAxis(double a, double b, double c) {
-  if (!b && !c)
-    return a;
-  if (!a && !c)
-    return b;
-  if (!a && !b)
-    return c;
+  if (NearlyZero(b) && NearlyZero(c))
+    return std::abs(a);
+  if (NearlyZero(a) && NearlyZero(c))
+    return std::abs(b);
+  if (NearlyZero(a) && NearlyZero(b))
+    return std::abs(c);
 
   // Do the sqrt as a double to not lose precision.
   return static_cast<float>(std::sqrt(a * a + b * b + c * c));
@@ -512,12 +602,18 @@ gfx::Vector2dF MathUtil::ComputeTransform2dScaleComponents(
   return gfx::Vector2dF(x_scale, y_scale);
 }
 
+float MathUtil::ComputeApproximateMaxScale(const gfx::Transform& transform) {
+  gfx::RectF unit(0.f, 0.f, 1.f, 1.f);
+  transform.TransformRect(&unit);
+  return std::max(unit.width(), unit.height());
+}
+
 float MathUtil::SmallestAngleBetweenVectors(const gfx::Vector2dF& v1,
                                             const gfx::Vector2dF& v2) {
   double dot_product = gfx::DotProduct(v1, v2) / v1.Length() / v2.Length();
   // Clamp to compensate for rounding errors.
   dot_product = std::max(-1.0, std::min(1.0, dot_product));
-  return static_cast<float>(Rad2Deg(std::acos(dot_product)));
+  return static_cast<float>(gfx::RadToDeg(std::acos(dot_product)));
 }
 
 gfx::Vector2dF MathUtil::ProjectVector(const gfx::Vector2dF& source,
@@ -528,31 +624,24 @@ gfx::Vector2dF MathUtil::ProjectVector(const gfx::Vector2dF& source,
                         projected_length * destination.y());
 }
 
-scoped_ptr<base::Value> MathUtil::AsValue(const gfx::Size& s) {
-  scoped_ptr<base::DictionaryValue> res(new base::DictionaryValue());
+std::unique_ptr<base::Value> MathUtil::AsValue(const gfx::Size& s) {
+  std::unique_ptr<base::DictionaryValue> res(new base::DictionaryValue());
   res->SetDouble("width", s.width());
   res->SetDouble("height", s.height());
-  return res.PassAs<base::Value>();
+  return std::move(res);
 }
 
-scoped_ptr<base::Value> MathUtil::AsValue(const gfx::SizeF& s) {
-  scoped_ptr<base::DictionaryValue> res(new base::DictionaryValue());
-  res->SetDouble("width", s.width());
-  res->SetDouble("height", s.height());
-  return res.PassAs<base::Value>();
-}
-
-scoped_ptr<base::Value> MathUtil::AsValue(const gfx::Rect& r) {
-  scoped_ptr<base::ListValue> res(new base::ListValue());
+std::unique_ptr<base::Value> MathUtil::AsValue(const gfx::Rect& r) {
+  std::unique_ptr<base::ListValue> res(new base::ListValue());
   res->AppendInteger(r.x());
   res->AppendInteger(r.y());
   res->AppendInteger(r.width());
   res->AppendInteger(r.height());
-  return res.PassAs<base::Value>();
+  return std::move(res);
 }
 
 bool MathUtil::FromValue(const base::Value* raw_value, gfx::Rect* out_rect) {
-  const base::ListValue* value = NULL;
+  const base::ListValue* value = nullptr;
   if (!raw_value->GetAsList(&value))
     return false;
 
@@ -572,15 +661,101 @@ bool MathUtil::FromValue(const base::Value* raw_value, gfx::Rect* out_rect) {
   return true;
 }
 
-scoped_ptr<base::Value> MathUtil::AsValue(const gfx::PointF& pt) {
-  scoped_ptr<base::ListValue> res(new base::ListValue());
+std::unique_ptr<base::Value> MathUtil::AsValue(const gfx::PointF& pt) {
+  std::unique_ptr<base::ListValue> res(new base::ListValue());
   res->AppendDouble(pt.x());
   res->AppendDouble(pt.y());
-  return res.PassAs<base::Value>();
+  return std::move(res);
 }
 
-scoped_ptr<base::Value> MathUtil::AsValue(const gfx::QuadF& q) {
-  scoped_ptr<base::ListValue> res(new base::ListValue());
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::Size& s,
+                                base::trace_event::TracedValue* res) {
+  res->BeginDictionary(name);
+  res->SetDouble("width", s.width());
+  res->SetDouble("height", s.height());
+  res->EndDictionary();
+}
+
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::SizeF& s,
+                                base::trace_event::TracedValue* res) {
+  res->BeginDictionary(name);
+  res->SetDouble("width", s.width());
+  res->SetDouble("height", s.height());
+  res->EndDictionary();
+}
+
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::Rect& r,
+                                base::trace_event::TracedValue* res) {
+  res->BeginArray(name);
+  res->AppendInteger(r.x());
+  res->AppendInteger(r.y());
+  res->AppendInteger(r.width());
+  res->AppendInteger(r.height());
+  res->EndArray();
+}
+
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::Point& pt,
+                                base::trace_event::TracedValue* res) {
+  res->BeginArray(name);
+  res->AppendInteger(pt.x());
+  res->AppendInteger(pt.y());
+  res->EndArray();
+}
+
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::PointF& pt,
+                                base::trace_event::TracedValue* res) {
+  res->BeginArray(name);
+  res->AppendDouble(pt.x());
+  res->AppendDouble(pt.y());
+  res->EndArray();
+}
+
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::Point3F& pt,
+                                base::trace_event::TracedValue* res) {
+  res->BeginArray(name);
+  res->AppendDouble(pt.x());
+  res->AppendDouble(pt.y());
+  res->AppendDouble(pt.z());
+  res->EndArray();
+}
+
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::Vector2d& v,
+                                base::trace_event::TracedValue* res) {
+  res->BeginArray(name);
+  res->AppendInteger(v.x());
+  res->AppendInteger(v.y());
+  res->EndArray();
+}
+
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::Vector2dF& v,
+                                base::trace_event::TracedValue* res) {
+  res->BeginArray(name);
+  res->AppendDouble(v.x());
+  res->AppendDouble(v.y());
+  res->EndArray();
+}
+
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::ScrollOffset& v,
+                                base::trace_event::TracedValue* res) {
+  res->BeginArray(name);
+  res->AppendDouble(v.x());
+  res->AppendDouble(v.y());
+  res->EndArray();
+}
+
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::QuadF& q,
+                                base::trace_event::TracedValue* res) {
+  res->BeginArray(name);
   res->AppendDouble(q.p1().x());
   res->AppendDouble(q.p1().y());
   res->AppendDouble(q.p2().x());
@@ -589,47 +764,91 @@ scoped_ptr<base::Value> MathUtil::AsValue(const gfx::QuadF& q) {
   res->AppendDouble(q.p3().y());
   res->AppendDouble(q.p4().x());
   res->AppendDouble(q.p4().y());
-  return res.PassAs<base::Value>();
+  res->EndArray();
 }
 
-scoped_ptr<base::Value> MathUtil::AsValue(const gfx::RectF& rect) {
-  scoped_ptr<base::ListValue> res(new base::ListValue());
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::RectF& rect,
+                                base::trace_event::TracedValue* res) {
+  res->BeginArray(name);
   res->AppendDouble(rect.x());
   res->AppendDouble(rect.y());
   res->AppendDouble(rect.width());
   res->AppendDouble(rect.height());
-  return res.PassAs<base::Value>();
+  res->EndArray();
 }
 
-scoped_ptr<base::Value> MathUtil::AsValue(const gfx::Transform& transform) {
-  scoped_ptr<base::ListValue> res(new base::ListValue());
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::Transform& transform,
+                                base::trace_event::TracedValue* res) {
+  res->BeginArray(name);
   const SkMatrix44& m = transform.matrix();
   for (int row = 0; row < 4; ++row) {
     for (int col = 0; col < 4; ++col)
       res->AppendDouble(m.getDouble(row, col));
   }
-  return res.PassAs<base::Value>();
+  res->EndArray();
 }
 
-scoped_ptr<base::Value> MathUtil::AsValue(const gfx::BoxF& box) {
-  scoped_ptr<base::ListValue> res(new base::ListValue());
+void MathUtil::AddToTracedValue(const char* name,
+                                const gfx::BoxF& box,
+                                base::trace_event::TracedValue* res) {
+  res->BeginArray(name);
   res->AppendInteger(box.x());
   res->AppendInteger(box.y());
   res->AppendInteger(box.z());
   res->AppendInteger(box.width());
   res->AppendInteger(box.height());
   res->AppendInteger(box.depth());
-  return res.PassAs<base::Value>();
+  res->EndArray();
 }
 
-scoped_ptr<base::Value> MathUtil::AsValueSafely(double value) {
-  return scoped_ptr<base::Value>(base::Value::CreateDoubleValue(
-      std::min(value, std::numeric_limits<double>::max())));
+double MathUtil::AsDoubleSafely(double value) {
+  return std::min(value, std::numeric_limits<double>::max());
 }
 
-scoped_ptr<base::Value> MathUtil::AsValueSafely(float value) {
-  return scoped_ptr<base::Value>(base::Value::CreateDoubleValue(
-      std::min(value, std::numeric_limits<float>::max())));
+float MathUtil::AsFloatSafely(float value) {
+  return std::min(value, std::numeric_limits<float>::max());
+}
+
+gfx::Vector3dF MathUtil::GetXAxis(const gfx::Transform& transform) {
+  return gfx::Vector3dF(transform.matrix().getFloat(0, 0),
+                        transform.matrix().getFloat(1, 0),
+                        transform.matrix().getFloat(2, 0));
+}
+
+gfx::Vector3dF MathUtil::GetYAxis(const gfx::Transform& transform) {
+  return gfx::Vector3dF(transform.matrix().getFloat(0, 1),
+                        transform.matrix().getFloat(1, 1),
+                        transform.matrix().getFloat(2, 1));
+}
+
+ScopedSubnormalFloatDisabler::ScopedSubnormalFloatDisabler() {
+#if defined(ARCH_CPU_X86_FAMILY)
+  // Turn on "subnormals are zero" and "flush to zero" CSR flags.
+  orig_state_ = _mm_getcsr();
+  _mm_setcsr(orig_state_ | 0x8040);
+#endif
+}
+
+ScopedSubnormalFloatDisabler::~ScopedSubnormalFloatDisabler() {
+#if defined(ARCH_CPU_X86_FAMILY)
+  _mm_setcsr(orig_state_);
+#endif
+}
+
+bool MathUtil::IsFloatNearlyTheSame(float left, float right) {
+  return IsNearlyTheSame(left, right);
+}
+
+bool MathUtil::IsNearlyTheSameForTesting(const gfx::PointF& left,
+                                         const gfx::PointF& right) {
+  return IsNearlyTheSame(left, right);
+}
+
+bool MathUtil::IsNearlyTheSameForTesting(const gfx::Point3F& left,
+                                         const gfx::Point3F& right) {
+  return IsNearlyTheSame(left, right);
 }
 
 }  // namespace cc
