@@ -67,8 +67,6 @@ class PictureLayer;
 // from parents to children.
 class CC_EXPORT Layer : public base::RefCounted<Layer> {
  public:
-  using LayerListType = LayerList;
-
   // An invalid layer id, as all layer ids are positive.
   enum LayerIdLabels {
     INVALID_ID = -1,
@@ -118,6 +116,9 @@ class CC_EXPORT Layer : public base::RefCounted<Layer> {
   // Removes all children from this layer's list of children, removing ownership
   // of those children.
   void RemoveAllChildren();
+  // Sets the children while minimizing changes to layers that are already
+  // children of this layer.
+  void SetChildLayerList(LayerList children);
   // Returns true if |ancestor| is this layer's parent or higher ancestor.
   bool HasAncestor(const Layer* ancestor) const;
 
@@ -282,6 +283,11 @@ class CC_EXPORT Layer : public base::RefCounted<Layer> {
     return inputs_.background_filters;
   }
 
+  void SetBackdropFilterQuality(const float quality);
+  float backdrop_filter_quality() const {
+    return inputs_.backdrop_filter_quality;
+  }
+
   // Set or get an optimization hint that the contents of this layer are fully
   // opaque or not. If true, every pixel of content inside the layer's bounds
   // must be opaque or visual errors can occur. This applies only to this layer
@@ -394,6 +400,9 @@ class CC_EXPORT Layer : public base::RefCounted<Layer> {
     return inputs_.scroll_container_bounds;
   }
 
+  void SetIsScrollbar(bool is_scrollbar);
+  bool is_scrollbar() const { return inputs_.is_scrollbar; }
+
   // Set or get if this layer is able to be scrolled along each axis. These are
   // independant of the scrollable state, or size of the scrollable area
   // specified in SetScrollable(), as these may be enabled or disabled
@@ -755,6 +764,10 @@ class CC_EXPORT Layer : public base::RefCounted<Layer> {
     return should_flatten_screen_space_transform_from_property_tree_;
   }
 
+  void set_is_rounded_corner_mask(bool rounded) {
+    is_rounded_corner_mask_ = rounded;
+  }
+
  protected:
   friend class LayerImpl;
   friend class TreeSynchronizer;
@@ -889,6 +902,7 @@ class CC_EXPORT Layer : public base::RefCounted<Layer> {
     FilterOperations filters;
     FilterOperations background_filters;
     gfx::PointF filters_origin;
+    float backdrop_filter_quality;
 
     gfx::ScrollOffset scroll_offset;
 
@@ -900,6 +914,9 @@ class CC_EXPORT Layer : public base::RefCounted<Layer> {
     // |scroll_container_bounds|).
     bool scrollable : 1;
 
+    // Indicates that this layer is a scrollbar.
+    bool is_scrollbar : 1;
+
     bool user_scrollable_horizontal : 1;
     bool user_scrollable_vertical : 1;
 
@@ -971,6 +988,7 @@ class CC_EXPORT Layer : public base::RefCounted<Layer> {
   bool may_contain_video_ : 1;
   bool needs_show_scrollbars_ : 1;
   bool has_transform_node_ : 1;
+  bool is_rounded_corner_mask_ : 1;
   // This value is valid only when LayerTreeHost::has_copy_request() is true
   bool subtree_has_copy_request_ : 1;
   SkColor safe_opaque_background_color_;
