@@ -13,7 +13,6 @@
 #include "cc/paint/paint_image_builder.h"
 #include "cc/paint/paint_op_buffer.h"
 #include "cc/paint/paint_shader.h"
-#include "cc/paint/paint_typeface_transfer_cache_entry.h"
 #include "cc/paint/path_transfer_cache_entry.h"
 #include "cc/paint/shader_transfer_cache_entry.h"
 #include "cc/paint/transfer_cache_deserialize_helper.h"
@@ -82,6 +81,8 @@ bool PaintOpReader::ReadAndValidateOpHeader(const volatile void* input,
                                             size_t input_size,
                                             uint8_t* type,
                                             uint32_t* skip) {
+  if (input_size < 4)
+    return false;
   uint32_t first_word = reinterpret_cast<const volatile uint32_t*>(input)[0];
   *type = static_cast<uint8_t>(first_word & 0xFF);
   *skip = first_word >> 8;
@@ -394,7 +395,7 @@ void PaintOpReader::Read(scoped_refptr<PaintTextBlob>* paint_blob) {
   }
 
   *paint_blob = base::MakeRefCounted<PaintTextBlob>(
-      std::move(blob), std::vector<PaintTypeface>());
+      std::move(blob), std::vector<sk_sp<SkTypeface>>());
   memory_ += data_bytes;
   remaining_bytes_ -= data_bytes;
 }
@@ -461,6 +462,8 @@ void PaintOpReader::Read(sk_sp<PaintShader>* shader) {
     size_t record_size = Read(&ref.record_);
     size_t post_size = options_.transfer_cache->GetTotalEntrySizes();
     shader_size = post_size - pre_size + record_size;
+
+    ref.id_ = shader_id;
   }
   decltype(ref.colors_)::size_type colors_size = 0;
   ReadSize(&colors_size);
