@@ -10,8 +10,9 @@
 #include "base/macros.h"
 #include "base/memory/ref_counted.h"
 #include "cc/paint/paint_export.h"
-#include "cc/paint/paint_typeface.h"
+#include "third_party/skia/include/core/SkRefCnt.h"
 #include "third_party/skia/include/core/SkTextBlob.h"
+#include "third_party/skia/include/core/SkTypeface.h"
 
 namespace cc {
 
@@ -19,10 +20,11 @@ class CC_PAINT_EXPORT PaintTextBlob
     : public base::RefCountedThreadSafe<PaintTextBlob> {
  public:
   PaintTextBlob();
-  PaintTextBlob(sk_sp<SkTextBlob> blob, std::vector<PaintTypeface> typefaces);
+  PaintTextBlob(sk_sp<SkTextBlob> blob,
+                std::vector<sk_sp<SkTypeface>> typefaces);
 
   const sk_sp<SkTextBlob>& ToSkTextBlob() const { return sk_blob_; }
-  const std::vector<PaintTypeface>& typefaces() const { return typefaces_; }
+  const std::vector<sk_sp<SkTypeface>>& typefaces() const { return typefaces_; }
 
   operator bool() const { return !!sk_blob_; }
 
@@ -32,7 +34,7 @@ class CC_PAINT_EXPORT PaintTextBlob
   ~PaintTextBlob();
 
   sk_sp<SkTextBlob> sk_blob_;
-  std::vector<PaintTypeface> typefaces_;
+  std::vector<sk_sp<SkTypeface>> typefaces_;
 
   DISALLOW_COPY_AND_ASSIGN(PaintTextBlob);
 };
