@@ -469,11 +469,10 @@ TEST_F(ResourcePoolTest, PurgedMemory) {
   EXPECT_EQ(0u, resource_pool_->GetBusyResourceCountForTesting());
 
   // Purging and suspending should not impact an in-use resource.
-  resource_pool_->OnPurgeMemory();
-  resource_pool_->OnMemoryStateChange(base::MemoryState::SUSPENDED);
+  resource_pool_->OnMemoryPressure(
+      base::MemoryPressureListener::MEMORY_PRESSURE_LEVEL_CRITICAL);
   EXPECT_EQ(1u, resource_pool_->GetTotalResourceCountForTesting());
   EXPECT_EQ(0u, resource_pool_->GetBusyResourceCountForTesting());
-  resource_pool_->OnMemoryStateChange(base::MemoryState::NORMAL);
 
   // Export the resource to the display compositor, so it will be busy once
   // released.
@@ -482,77 +481,25 @@ TEST_F(ResourcePoolTest, PurgedMemory) {
                                           &transfers, context_provider_.get());
 
   // Release the resource making it busy.
-  resource_pool_->OnMemoryStateChange(base::MemoryState::NORMAL);
   resource_pool_->ReleaseResource(std::move(resource));
   EXPECT_EQ(1u, resource_pool_->GetTotalResourceCountForTesting());
   EXPECT_EQ(1u, resource_pool_->GetBusyResourceCountForTesting());
 
   // Purging and suspending should not impact a busy resource either.
-  resource_pool_->OnPurgeMemory();
-  resource_pool_->OnMemoryStateChange(base::MemoryState::SUSPENDED);
+  resource_pool_->OnMemoryPressure(
+      base::MemoryPressureListener::MEMORY_PRESSURE_LEVEL_CRITICAL);
   EXPECT_EQ(1u, resource_pool_->GetTotalResourceCountForTesting());
   EXPECT_EQ(1u, resource_pool_->GetBusyResourceCountForTesting());
 
   // The resource moves from busy to available.
-  resource_pool_->OnMemoryStateChange(base::MemoryState::NORMAL);
   resource_provider_->ReceiveReturnsFromParent(
       viz::TransferableResource::ReturnResources(transfers));
   EXPECT_EQ(1u, resource_pool_->GetTotalResourceCountForTesting());
   EXPECT_EQ(0u, resource_pool_->GetBusyResourceCountForTesting());
 
   // Purging and suspending should drop unused resources.
-  resource_pool_->OnPurgeMemory();
-  resource_pool_->OnMemoryStateChange(base::MemoryState::SUSPENDED);
-  EXPECT_EQ(0u, resource_pool_->GetTotalResourceCountForTesting());
-  EXPECT_EQ(0u, resource_pool_->GetBusyResourceCountForTesting());
-}
-
-TEST_F(ResourcePoolTest, MemoryStateSuspended) {
-  // Limits high enough to not be hit by this test.
-  size_t bytes_limit = 10 * 1024 * 1024;
-  size_t count_limit = 100;
-  resource_pool_->SetResourceUsageLimits(bytes_limit, count_limit);
-
-  gfx::Size size(100, 100);
-  viz::ResourceFormat format = viz::RGBA_8888;
-  gfx::ColorSpace color_space = gfx::ColorSpace::CreateSRGB();
-  ResourcePool::InUsePoolResource resource =
-      resource_pool_->AcquireResource(size, format, color_space);
-  SetBackingOnResource(resource);
-  resource_pool_->PrepareForExport(resource);
-
-  EXPECT_EQ(1u, resource_pool_->GetTotalResourceCountForTesting());
-  EXPECT_EQ(0u, resource_pool_->GetBusyResourceCountForTesting());
-
-  // Purging and suspending should not impact an in-use resource.
-  resource_pool_->OnPurgeMemory();
-  resource_pool_->OnMemoryStateChange(base::MemoryState::SUSPENDED);
-  EXPECT_EQ(1u, resource_pool_->GetTotalResourceCountForTesting());
-  EXPECT_EQ(0u, resource_pool_->GetBusyResourceCountForTesting());
-  resource_pool_->OnMemoryStateChange(base::MemoryState::NORMAL);
-
-  // Export the resource to the display compositor, so it will be busy once
-  // released.
-  std::vector<viz::TransferableResource> transfers;
-  resource_provider_->PrepareSendToParent({resource.resource_id_for_export()},
-                                          &transfers, context_provider_.get());
-
-  // Release the resource making it busy.
-  resource_pool_->OnMemoryStateChange(base::MemoryState::NORMAL);
-  resource_pool_->ReleaseResource(std::move(resource));
-  EXPECT_EQ(1u, resource_pool_->GetTotalResourceCountForTesting());
-  EXPECT_EQ(1u, resource_pool_->GetBusyResourceCountForTesting());
-
-  // Purging and suspending should not impact a busy resource either.
-  resource_pool_->OnPurgeMemory();
-  resource_pool_->OnMemoryStateChange(base::MemoryState::SUSPENDED);
-  EXPECT_EQ(1u, resource_pool_->GetTotalResourceCountForTesting());
-  EXPECT_EQ(1u, resource_pool_->GetBusyResourceCountForTesting());
-
-  // The resource moves from busy to available, but since we are SUSPENDED
-  // it is not kept.
-  resource_provider_->ReceiveReturnsFromParent(
-      viz::TransferableResource::ReturnResources(transfers));
+  resource_pool_->OnMemoryPressure(
+      base::MemoryPressureListener::MEMORY_PRESSURE_LEVEL_CRITICAL);
   EXPECT_EQ(0u, resource_pool_->GetTotalResourceCountForTesting());
   EXPECT_EQ(0u, resource_pool_->GetBusyResourceCountForTesting());
 }
@@ -668,7 +615,7 @@ TEST_F(ResourcePoolTest, MetadataSentToDisplayCompositor) {
 
   // These values are all non-default values so we can tell they are propagated.
   gfx::Size size(100, 101);
-  viz::ResourceFormat format = viz::ETC1;
+  viz::ResourceFormat format = viz::RGBA_4444;
   EXPECT_NE(gfx::BufferFormat::RGBA_8888, viz::BufferFormat(format));
   gfx::ColorSpace color_space = gfx::ColorSpace::CreateSRGB();
   uint32_t target = 5;
