@@ -5,7 +5,6 @@
 #include "cc/test/fake_painted_scrollbar_layer.h"
 
 #include "base/auto_reset.h"
-#include "cc/resources/resource_update_queue.h"
 #include "cc/test/fake_scrollbar.h"
 
 namespace cc {
@@ -13,18 +12,30 @@ namespace cc {
 scoped_refptr<FakePaintedScrollbarLayer> FakePaintedScrollbarLayer::Create(
     bool paint_during_update,
     bool has_thumb,
-    int scrolling_layer_id) {
-  FakeScrollbar* fake_scrollbar = new FakeScrollbar(
-      paint_during_update, has_thumb, false);
-  return make_scoped_refptr(new FakePaintedScrollbarLayer(
-      fake_scrollbar, scrolling_layer_id));
+    ElementId scrolling_element_id) {
+  return Create(paint_during_update, has_thumb, HORIZONTAL, false, false,
+                scrolling_element_id);
+}
+
+scoped_refptr<FakePaintedScrollbarLayer> FakePaintedScrollbarLayer::Create(
+    bool paint_during_update,
+    bool has_thumb,
+    ScrollbarOrientation orientation,
+    bool is_left_side_vertical_scrollbar,
+    bool is_overlay,
+    ElementId scrolling_element_id) {
+  FakeScrollbar* fake_scrollbar =
+      new FakeScrollbar(paint_during_update, has_thumb, orientation,
+                        is_left_side_vertical_scrollbar, is_overlay);
+  return base::WrapRefCounted(
+      new FakePaintedScrollbarLayer(fake_scrollbar, scrolling_element_id));
 }
 
 FakePaintedScrollbarLayer::FakePaintedScrollbarLayer(
     FakeScrollbar* fake_scrollbar,
-    int scrolling_layer_id)
-    : PaintedScrollbarLayer(scoped_ptr<Scrollbar>(fake_scrollbar).Pass(),
-                            scrolling_layer_id),
+    ElementId scrolling_element_id)
+    : PaintedScrollbarLayer(std::unique_ptr<Scrollbar>(fake_scrollbar),
+                            scrolling_element_id),
       update_count_(0),
       push_properties_count_(0),
       fake_scrollbar_(fake_scrollbar) {
@@ -32,12 +43,10 @@ FakePaintedScrollbarLayer::FakePaintedScrollbarLayer(
   SetIsDrawable(true);
 }
 
-FakePaintedScrollbarLayer::~FakePaintedScrollbarLayer() {}
+FakePaintedScrollbarLayer::~FakePaintedScrollbarLayer() = default;
 
-bool FakePaintedScrollbarLayer::Update(
-    ResourceUpdateQueue* queue,
-    const OcclusionTracker<Layer>* occlusion) {
-  bool updated = PaintedScrollbarLayer::Update(queue, occlusion);
+bool FakePaintedScrollbarLayer::Update() {
+  bool updated = PaintedScrollbarLayer::Update();
   ++update_count_;
   return updated;
 }
@@ -47,10 +56,10 @@ void FakePaintedScrollbarLayer::PushPropertiesTo(LayerImpl* layer) {
   ++push_properties_count_;
 }
 
-scoped_ptr<base::AutoReset<bool> >
+std::unique_ptr<base::AutoReset<bool>>
 FakePaintedScrollbarLayer::IgnoreSetNeedsCommit() {
-  return make_scoped_ptr(
-      new base::AutoReset<bool>(&ignore_set_needs_commit_, true));
+  return std::make_unique<base::AutoReset<bool>>(&ignore_set_needs_commit_,
+                                                 true);
 }
 
 }  // namespace cc
