@@ -5,10 +5,13 @@
 #include "base/bind.h"
 #include "base/test/launcher/unit_test_launcher.h"
 #include "cc/test/cc_test_suite.h"
+#include "mojo/core/embedder/embedder.h"
 
 int main(int argc, char** argv) {
   cc::CCTestSuite test_suite(argc, argv);
 
+  mojo::core::Init();
+
   return base::LaunchUnitTests(
       argc,
       argv,
