@@ -11,7 +11,6 @@
 
 #include "base/containers/mru_cache.h"
 #include "base/memory/discardable_memory.h"
-#include "base/memory/memory_coordinator_client.h"
 #include "base/memory/memory_pressure_listener.h"
 #include "base/synchronization/lock.h"
 #include "base/trace_event/memory_dump_provider.h"
@@ -98,8 +97,7 @@ namespace cc {
 //
 class CC_EXPORT GpuImageDecodeCache
     : public ImageDecodeCache,
-      public base::trace_event::MemoryDumpProvider,
-      public base::MemoryCoordinatorClient {
+      public base::trace_event::MemoryDumpProvider {
  public:
   enum class DecodeTaskType { kPartOfUploadTask, kStandAloneDecodeTask };
 
@@ -137,10 +135,6 @@ class CC_EXPORT GpuImageDecodeCache
   bool OnMemoryDump(const base::trace_event::MemoryDumpArgs& args,
                     base::trace_event::ProcessMemoryDump* pmd) override;
 
-  // base::MemoryCoordinatorClient overrides.
-  void OnMemoryStateChange(base::MemoryState state) override;
-  void OnPurgeMemory() override;
-
   // TODO(gyuyoung): OnMemoryPressure is deprecated. So this should be removed
   // when the memory coordinator is enabled by default.
   void OnMemoryPressure(
@@ -511,7 +505,6 @@ class CC_EXPORT GpuImageDecodeCache
   size_t max_working_set_items_ = 0;
   size_t working_set_bytes_ = 0;
   size_t working_set_items_ = 0;
-  base::MemoryState memory_state_ = base::MemoryState::NORMAL;
   bool aggressively_freeing_resources_ = false;
 
   // We can't modify GPU backed SkImages without holding the context lock, so
