@@ -11,7 +11,6 @@
 #include <unordered_map>
 
 #include "base/containers/mru_cache.h"
-#include "base/memory/memory_coordinator_client.h"
 #include "base/memory/memory_pressure_listener.h"
 #include "base/memory/ref_counted.h"
 #include "base/numerics/safe_math.h"
@@ -25,8 +24,7 @@ namespace cc {
 
 class CC_EXPORT SoftwareImageDecodeCache
     : public ImageDecodeCache,
-      public base::trace_event::MemoryDumpProvider,
-      public base::MemoryCoordinatorClient {
+      public base::trace_event::MemoryDumpProvider {
  public:
   using Utils = SoftwareImageDecodeCacheUtils;
   using CacheKey = Utils::CacheKey;
@@ -114,12 +112,6 @@ class CC_EXPORT SoftwareImageDecodeCache
   // reduced within the given limit.
   void ReduceCacheUsageUntilWithinLimit(size_t limit);
 
-  // Overriden from base::MemoryCoordinatorClient.
-  void OnMemoryStateChange(base::MemoryState state) override;
-  void OnPurgeMemory() override;
-
-  // TODO(gyuyoung): OnMemoryPressure is deprecated. So this should be removed
-  // when the memory coordinator is enabled by default.
   void OnMemoryPressure(
       base::MemoryPressureListener::MemoryPressureLevel level);
 
