@@ -72,6 +72,17 @@ class UkmRecorderFactory;
 struct RenderingStats;
 struct ScrollAndScaleSet;
 
+// Returned from LayerTreeHost::DeferCommits. Automatically un-defers on
+// destruction.
+class CC_EXPORT ScopedDeferCommits {
+ public:
+  explicit ScopedDeferCommits(LayerTreeHost* host);
+  ~ScopedDeferCommits();
+
+ private:
+  base::WeakPtr<LayerTreeHost> host_;
+};
+
 class CC_EXPORT LayerTreeHost : public MutatorHostClient {
  public:
   struct CC_EXPORT InitParams {
@@ -90,15 +101,27 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
 
     InitParams();
     ~InitParams();
+
+    InitParams(InitParams&&);
+    InitParams& operator=(InitParams&&);
   };
 
+  // Constructs a LayerTreeHost with a compositor thread where scrolling and
+  // animation take place. This is used for the web compositor in the renderer
+  // process to move work off the main thread which javascript can dominate.
   static std::unique_ptr<LayerTreeHost> CreateThreaded(
       scoped_refptr<base::SingleThreadTaskRunner> impl_task_runner,
-      InitParams* params);
+      InitParams params);
 
+  // Constructs a LayerTreeHost without a separate compositor thread, but which
+  // behaves and looks the same as a threaded compositor externally, with the
+  // exception of the additional client interface. This is used in other cases
+  // where the main thread creating this instance can be expected to not become
+  // blocked, so moving work to another thread and the overhead it adds are not
+  // required.
   static std::unique_ptr<LayerTreeHost> CreateSingleThreaded(
       LayerTreeHostSingleThreadClient* single_thread_client,
-      InitParams* params);
+      InitParams params);
 
   virtual ~LayerTreeHost();
 
@@ -106,7 +129,9 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
   int GetId() const;
 
   // The current source frame number. This is incremented for each main frame
-  // update(commit) pushed to the compositor thread.
+  // update(commit) pushed to the compositor thread. The initial frame number
+  // is 0, and it is incremented once commit is completed (which is before the
+  // compositor-thread-side submits its frame for the commit).
   int SourceFrameNumber() const;
 
   // Returns the UIResourceManager used to create UIResources for
@@ -117,26 +142,38 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
   // thread task runners.
   TaskRunnerProvider* GetTaskRunnerProvider() const;
 
-  // Returns the settings used by this host.
+  // Returns the settings used by this host. These settings are constants given
+  // at startup.
   const LayerTreeSettings& GetSettings() const;
 
   // Sets the LayerTreeMutator interface used to directly mutate the compositor
   // state on the compositor thread. (Compositor-Worker)
   void SetLayerTreeMutator(std::unique_ptr<LayerTreeMutator> mutator);
 
-  // Call this function when you expect there to be a swap buffer.
+  // Attachs a SwapPromise to the Layer tree, that passes through the
+  // LayerTreeHost and LayerTreeHostImpl with the next commit and frame
+  // submission, which can be used to observe that progress. This also
+  // causes a main frame to be requested.
   // See swap_promise.h for how to use SwapPromise.
   void QueueSwapPromise(std::unique_ptr<SwapPromise> swap_promise);
 
-  // Returns the SwapPromiseManager used to create SwapPromiseMonitors for this
-  // host.
+  // Returns the SwapPromiseManager, used to insert SwapPromises dynamically
+  // when a main frame is requested.
   SwapPromiseManager* GetSwapPromiseManager();
 
-  // Sets whether the content is suitable to use Gpu Rasterization.
+  // Sets whether the content is suitable to use Gpu Rasterization. This flag is
+  // used to enable gpu rasterization, and can be modified at any time to change
+  // the setting based on content.
   void SetHasGpuRasterizationTrigger(bool has_trigger);
 
   // Visibility and LayerTreeFrameSink -------------------------------
 
+  // Sets or gets if the LayerTreeHost is visible. When not visible it will:
+  // - Not request a new LayerTreeFrameSink from the client.
+  // - Stop submitting frames to the display compositor.
+  // - Stop producing main frames and committing them.
+  // The LayerTreeHost is not visible when first created, so this must be called
+  // to make it visible before it will attempt to start producing output.
   void SetVisible(bool visible);
   bool IsVisible() const;
 
@@ -182,12 +219,15 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
   // requested.
   bool CommitRequested() const;
 
-  // Enables/disables the compositor from requesting main frame updates from the
-  // client.
-  void SetDeferCommits(bool defer_commits);
-  // Returns the value last passed to SetDeferCommits(), though commits may be
-  // deferred also when the local_surface_id_from_parent() is not valid.
-  bool defer_commits() const { return defer_commits_; }
+  // Prevents the compositor from requesting main frame updates from the client
+  // until the ScopedDeferCommits object is destroyed, or StopDeferringCommits
+  // is called.
+  std::unique_ptr<ScopedDeferCommits> DeferCommits();
+
+  // Returns whether there are any outstanding ScopedDeferCommits, though
+  // commits may be deferred also when the local_surface_id_from_parent() is not
+  // valid.
+  bool defer_commits() const { return defer_commits_count_; }
 
   // Synchronously performs a main frame update and layer updates. Used only in
   // single threaded mode when the compositor's internal scheduling is disabled.
@@ -235,16 +275,12 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
   // Returns true if the message was successfully delivered and handled.
   bool SendMessageToMicroBenchmark(int id, std::unique_ptr<base::Value> value);
 
-  // When the main thread informs the impl thread that it is ready to commit,
-  // generally it would remain blocked till the main thread state is copied to
-  // the pending tree. Calling this would ensure that the main thread remains
-  // blocked till the pending tree is activated.
+  // When the main thread informs the compositor thread that it is ready to
+  // commit, generally it would remain blocked until the main thread state is
+  // copied to the pending tree. Calling this would ensure that the main thread
+  // remains blocked until the pending tree is activated.
   void SetNextCommitWaitsForActivation();
 
-  // The LayerTreeHost tracks whether the content is suitable for Gpu raster.
-  // Calling this will reset it back to not suitable state.
-  void ResetGpuRasterizationTracking();
-
   // Registers a callback that is run when the next frame successfully makes it
   // to the screen (it's entirely possible some frames may be dropped between
   // the time this is called and the callback is run).
@@ -252,10 +288,18 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
       base::OnceCallback<void(const gfx::PresentationFeedback&)>;
   void RequestPresentationTimeForNextFrame(PresentationTimeCallback callback);
 
+  // Layer tree accessors and modifiers ------------------------
+
+  // Sets or gets the root of the Layer tree. Children of the root Layer are
+  // attached to it and will be added/removed along with the root Layer. The
+  // LayerTreeHost retains ownership of a reference to the root Layer.
   void SetRootLayer(scoped_refptr<Layer> root_layer);
   Layer* root_layer() { return root_layer_.get(); }
   const Layer* root_layer() const { return root_layer_.get(); }
 
+  // Viewport Layers are used to identify key layers to the compositor thread,
+  // so that it can perform viewport-based scrolling independently, such as
+  // for pinch-zoom or overscroll elasticity.
   struct CC_EXPORT ViewportLayers {
     ViewportLayers();
     ~ViewportLayers();
@@ -266,6 +310,8 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
     scoped_refptr<Layer> inner_viewport_scroll;
     scoped_refptr<Layer> outer_viewport_scroll;
   };
+  // Sets or gets the collection of viewport Layers, defined to allow pinch-zoom
+  // transformations on the compositor thread.
   void RegisterViewportLayers(const ViewportLayers& viewport_layers);
   ElementId overscroll_elasticity_element_id() const {
     return viewport_layers_.overscroll_elasticity_element_id;
@@ -284,14 +330,28 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
     return viewport_layers_.outer_viewport_scroll.get();
   }
 
+  // Sets or gets the position of touch handles for a text selection. These are
+  // submitted to the display compositor along with the Layer tree's contents
+  // allowing it to present the selection handles. This is done because the
+  // handles are a UI widget above, and not clipped to, the viewport of this
+  // LayerTreeHost.
   void RegisterSelection(const LayerSelection& selection);
   const LayerSelection& selection() const { return selection_; }
 
+  // Sets or gets if the client has any scroll event handlers registered. This
+  // allows the threaded compositor to prioritize main frames even when
+  // servicing a touch scroll on the compositor thread, in order to give the
+  // event handler a chance to be part of each frame.
   void SetHaveScrollEventHandlers(bool have_event_handlers);
   bool have_scroll_event_handlers() const {
     return have_scroll_event_handlers_;
   }
 
+  // Set or get what event handlers exist on the layer tree in order to inform
+  // the compositor thread if it is able to handle an input event, or it needs
+  // to pass it to the main thread to be handled. The class is the type of input
+  // event, and for each class there is a properties defining if the compositor
+  // thread can handle the event.
   void SetEventListenerProperties(EventListenerClass event_class,
                                   EventListenerProperties event_properties);
   EventListenerProperties event_listener_properties(
@@ -394,15 +454,24 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
   void RemoveSurfaceRange(const viz::SurfaceRange& surface_range);
   base::flat_set<viz::SurfaceRange> SurfaceRanges() const;
 
+  // Marks or unmarks a layer are needing PushPropertiesTo in the next commit.
+  // These are internal methods, called from the Layer itself when changing a
+  // property or completing a PushPropertiesTo.
   void AddLayerShouldPushProperties(Layer* layer);
   void RemoveLayerShouldPushProperties(Layer* layer);
-  std::unordered_set<Layer*>& LayersThatShouldPushProperties();
-  bool LayerNeedsPushPropertiesForTesting(Layer* layer) const;
+  void ClearLayersThatShouldPushProperties();
+  // The current set of all Layers attached to the LayerTreeHost's tree that
+  // have been marked as needing PushPropertiesTo in the next commit.
+  const base::flat_set<Layer*>& LayersThatShouldPushProperties() {
+    return layers_that_should_push_properties_;
+  }
 
   void SetPageScaleFromImplSide(float page_scale);
   void SetElasticOverscrollFromImplSide(gfx::Vector2dF elastic_overscroll);
   gfx::Vector2dF elastic_overscroll() const { return elastic_overscroll_; }
 
+  // Ensures a HUD layer exists if it is needed, and updates the layer bounds.
+  // If a HUD layer exists but is no longer needed, it is destroyed.
   void UpdateHudLayer(bool show_hud_info);
   HeadsUpDisplayLayer* hud_layer() const { return hud_layer_.get(); }
 
@@ -445,9 +514,7 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
   void BeginMainFrameNotExpectedSoon();
   void BeginMainFrameNotExpectedUntil(base::TimeTicks time);
   void AnimateLayers(base::TimeTicks monotonic_frame_begin_time);
-  using VisualStateUpdate = LayerTreeHostClient::VisualStateUpdate;
-  void RequestMainFrameUpdate(
-      VisualStateUpdate requested_update = VisualStateUpdate::kAll);
+  void RequestMainFrameUpdate();
   void FinishCommitOnImplThread(LayerTreeHostImpl* host_impl);
   void WillCommit();
   void CommitComplete();
@@ -469,6 +536,7 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
   // Called when the compositor completed page scale animation.
   void DidCompletePageScaleAnimation();
   void ApplyScrollAndScale(ScrollAndScaleSet* info);
+  void RecordEndOfFrameMetrics(base::TimeTicks frame_begin_time);
 
   LayerTreeHostClient* client() { return client_; }
 
@@ -540,7 +608,7 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
       std::unique_ptr<RenderFrameMetadataObserver> observer);
 
  protected:
-  LayerTreeHost(InitParams* params, CompositorMode mode);
+  LayerTreeHost(InitParams params, CompositorMode mode);
 
   void InitializeThreaded(
       scoped_refptr<base::SingleThreadTaskRunner> main_task_runner,
@@ -573,13 +641,14 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
 
  private:
   friend class LayerTreeHostSerializationTest;
+  friend class ScopedDeferCommits;
 
   // This is the number of consecutive frames in which we want the content to be
   // free of slow-paths before toggling the flag.
   enum { kNumFramesToConsiderBeforeRemovingSlowPathFlag = 60 };
 
-  void ApplyViewportDeltas(ScrollAndScaleSet* info);
-  void RecordWheelAndTouchScrollingCount(ScrollAndScaleSet* info);
+  void ApplyViewportDeltas(const ScrollAndScaleSet& info);
+  void RecordWheelAndTouchScrollingCount(const ScrollAndScaleSet& info);
   void ApplyPageScaleDeltaFromImplSide(float page_scale_delta);
   void InitializeProxy(std::unique_ptr<Proxy> proxy);
 
@@ -661,7 +730,7 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
   // Used to detect surface invariant violations.
   bool has_pushed_local_surface_id_from_parent_ = false;
   bool new_local_surface_id_request_ = false;
-  bool defer_commits_ = false;
+  uint32_t defer_commits_count_ = 0;
 
   SkColor background_color_ = SK_ColorWHITE;
 
@@ -692,7 +761,7 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
   base::flat_map<viz::SurfaceRange, int> surface_ranges_;
 
   // Set of layers that need to push properties.
-  std::unordered_set<Layer*> layers_that_should_push_properties_;
+  base::flat_set<Layer*> layers_that_should_push_properties_;
 
   // Layer id to Layer map.
   std::unordered_map<int, Layer*> layer_id_map_;
@@ -717,6 +786,9 @@ class CC_EXPORT LayerTreeHost : public MutatorHostClient {
   // added here.
   std::vector<PresentationTimeCallback> pending_presentation_time_callbacks_;
 
+  // Used to vend weak pointers to LayerTreeHost to ScopedDeferCommits objects.
+  base::WeakPtrFactory<LayerTreeHost> defer_commits_weak_ptr_factory_;
+
   DISALLOW_COPY_AND_ASSIGN(LayerTreeHost);
 };
 
