@@ -280,7 +280,7 @@
 #define IDC_CONTENT_CONTEXT_INSPECTBACKGROUNDPAGE 50161
 #define IDC_CONTENT_CONTEXT_RELOAD_PACKAGED_APP 50162
 #define IDC_CONTENT_CONTEXT_RESTART_PACKAGED_APP 50163
-#define IDC_CONTENT_CONTEXT_FORCESAVEPASSWORD 50165
+// A gap here. Feel free to insert a new ID.
 #define IDC_CONTENT_CONTEXT_GENERATEPASSWORD 50166
 #define IDC_CONTENT_CONTEXT_EXIT_FULLSCREEN 50167
 #define IDC_CONTENT_CONTEXT_SHOWALLSAVEDPASSWORDS 50168
@@ -339,6 +339,7 @@
 #define IDC_MEDIA_ROUTER_MANAGE_DEVICES 51206
 #define IDC_MEDIA_ROUTER_SHOWN_BY_POLICY 51207
 #define IDC_MEDIA_ROUTER_SHOW_IN_TOOLBAR 51208
+#define IDC_MEDIA_ROUTER_TOGGLE_MEDIA_REMOTING 51209
 
 // Context menu items for media stream status tray
 #define IDC_MEDIA_STREAM_DEVICE_STATUS_TRAY 51300
