@@ -11,7 +11,6 @@
 #include "base/command_line.h"
 #include "base/cpu.h"
 #include "base/files/file_path.h"
-#include "base/files/file_util.h"
 #include "base/i18n/rtl.h"
 #include "base/lazy_instance.h"
 #include "base/macros.h"
@@ -25,6 +24,7 @@
 #include "base/trace_event/trace_event_impl.h"
 #include "build/build_config.h"
 #include "chrome/browser/chrome_content_browser_client.h"
+#include "chrome/browser/chrome_resource_bundle_helper.h"
 #include "chrome/browser/defaults.h"
 #include "chrome/common/buildflags.h"
 #include "chrome/common/channel_info.h"
@@ -50,6 +50,7 @@
 #include "components/nacl/common/buildflags.h"
 #include "components/services/heap_profiling/public/cpp/allocator_shim.h"
 #include "components/services/heap_profiling/public/cpp/stream.h"
+#include "components/tracing/common/tracing_sampler_profiler.h"
 #include "components/version_info/version_info.h"
 #include "content/public/common/content_client.h"
 #include "content/public/common/content_paths.h"
@@ -72,7 +73,7 @@
 #include "base/debug/close_handle_hook_win.h"
 #include "base/win/atl.h"
 #include "chrome/browser/downgrade/user_data_downgrade.h"
-#include "chrome/child/v8_breakpad_support_win.h"
+#include "chrome/child/v8_crashpad_support_win.h"
 #include "chrome/common/child_process_logging.h"
 #include "chrome_elf/chrome_elf_main.h"
 #include "sandbox/win/src/sandbox.h"
@@ -115,7 +116,6 @@
 #include "base/android/java_exception_reporter.h"
 #include "chrome/browser/android/crash/pure_java_exception_handler.h"
 #include "chrome/common/descriptors_android.h"
-#include "ui/base/resource/resource_bundle_android.h"
 #else
 // Diagnostics is only available on non-android platforms.
 #include "chrome/browser/diagnostics/diagnostics_controller.h"
@@ -506,9 +506,21 @@ ChromeMainDelegate::~ChromeMainDelegate() {
 }
 
 #if !defined(CHROME_MULTIPLE_DLL_CHILD)
-void ChromeMainDelegate::PostEarlyInitialization() {
+void ChromeMainDelegate::PostEarlyInitialization(bool is_running_tests) {
   DCHECK(chrome_feature_list_creator_);
   chrome_feature_list_creator_->CreateFeatureList();
+
+  // Initializes the resouce bundle and determines the locale.
+  std::string actual_locale =
+      LoadLocalState(chrome_feature_list_creator_.get(), is_running_tests);
+  chrome_feature_list_creator_->SetApplicationLocale(actual_locale);
+
+  tracing_sampler_profiler_->OnMessageLoopStarted();
+}
+
+bool ChromeMainDelegate::ShouldCreateFeatureList() {
+  // Chrome creates the FeatureList, so content should not.
+  return false;
 }
 #endif
 
@@ -535,7 +547,6 @@ bool ChromeMainDelegate::BasicStartupComplete(int* exit_code) {
   const bool is_browser = !command_line.HasSwitch(switches::kProcessType);
   ObjcEvilDoers::ZombieEnable(true, is_browser ? 10000 : 1000);
 
-  SetUpBundleOverrides();
   chrome::common::mac::EnableCFBundleBlocker();
 #endif
 
@@ -544,8 +555,12 @@ bool ChromeMainDelegate::BasicStartupComplete(int* exit_code) {
   base::trace_event::TraceLog::GetInstance()->SetArgumentFilterPredicate(
       base::Bind(&IsTraceEventArgsWhitelisted));
 
+  // Setup tracing sampler profiler as early as possible at startup if needed.
+  tracing_sampler_profiler_ = std::make_unique<tracing::TracingSamplerProfiler>(
+      base::PlatformThread::CurrentId());
+
 #if defined(OS_WIN) && !defined(CHROME_MULTIPLE_DLL_BROWSER)
-  v8_breakpad_support::SetUp();
+  v8_crashpad_support::SetUp();
 #endif
 #if defined(OS_LINUX)
   breakpad::SetFirstChanceExceptionHandler(v8::V8::TryHandleSignal);
@@ -734,7 +749,7 @@ void ChromeMainDelegate::InitMacCrashReporter(
     CHECK(command_line.HasSwitch(switches::kProcessType) &&
           !process_type.empty())
         << "Helper application requires --type.";
-  } else {
+  } else if (base::mac::AmIBundled()) {
     CHECK(!command_line.HasSwitch(switches::kProcessType) &&
           process_type.empty())
         << "Main application forbids --type, saw " << process_type;
@@ -1060,13 +1075,11 @@ ChromeMainDelegate::CreateContentBrowserClient() {
   return NULL;
 #else
   if (chrome_content_browser_client_ == nullptr) {
-    DCHECK(service_manifest_data_pack_);
     DCHECK(!chrome_feature_list_creator_);
     chrome_feature_list_creator_ = std::make_unique<ChromeFeatureListCreator>();
 
     chrome_content_browser_client_ =
         std::make_unique<ChromeContentBrowserClient>(
-            std::move(service_manifest_data_pack_),
             chrome_feature_list_creator_.get());
   }
   return chrome_content_browser_client_.get();
@@ -1099,33 +1112,6 @@ ChromeMainDelegate::CreateContentUtilityClient() {
 #endif
 }
 
-ui::DataPack* ChromeMainDelegate::LoadServiceManifestDataPack() {
-  DCHECK(!service_manifest_data_pack_ && !chrome_content_browser_client_);
-  const base::CommandLine& command_line =
-      *base::CommandLine::ForCurrentProcess();
-  std::string process_type =
-      command_line.GetSwitchValueASCII(switches::kProcessType);
-  DCHECK(process_type.empty());
-
-#if defined(OS_MACOSX)
-  SetUpBundleOverrides();
-#endif
-
-  base::FilePath resources_pack_path;
-  base::PathService::Get(chrome::FILE_RESOURCES_PACK, &resources_pack_path);
-
-#if defined(OS_ANDROID)
-  service_manifest_data_pack_ =
-      ui::GetDataPackFromPackFile("assets/resources.pak", resources_pack_path);
-#else
-  if (base::PathExists(resources_pack_path)) {
-    service_manifest_data_pack_.reset(new ui::DataPack(ui::SCALE_FACTOR_NONE));
-    service_manifest_data_pack_->LoadFromPath(resources_pack_path);
-  }
-#endif  // defined(OS_ANDROID)
-  return service_manifest_data_pack_.get();
-}
-
 bool ChromeMainDelegate::ShouldEnableProfilerRecording() {
   switch (chrome::GetChannel()) {
     case version_info::Channel::UNKNOWN:
@@ -1162,5 +1148,15 @@ void ChromeMainDelegate::PreCreateMainMessageLoop() {
 
   // Initialize NSApplication using the custom subclass.
   chrome_browser_application_mac::RegisterBrowserCrApp();
+
+  if (l10n_util::GetLocaleOverride().empty()) {
+    // The browser process only wants to support the language Cocoa will use,
+    // so force the app locale to be overridden with that value. This must
+    // happen before the ResourceBundle is loaded, which happens in
+    // ChromeBrowserMainParts::PreEarlyInitialization().
+    // Don't do this if the locale is already set, which is done by integration
+    // tests to ensure tests always run with the same locale.
+    l10n_util::OverrideLocaleWithCocoaLocale();
+  }
 #endif
 }
