@@ -13,16 +13,19 @@
 #include "build/build_config.h"
 #include "chrome/common/chrome_content_client.h"
 #include "content/public/app/content_main_delegate.h"
-#include "ui/base/resource/data_pack.h"
 
 #if !defined(CHROME_MULTIPLE_DLL_CHILD)
-#include "chrome/browser/chrome_feature_list_creator.h"
+#include "chrome/browser/metrics/chrome_feature_list_creator.h"
 #endif
 
 namespace base {
 class CommandLine;
 }
 
+namespace tracing {
+class TracingSamplerProfiler;
+}
+
 class ChromeContentBrowserClient;
 
 // Chrome implementation of ContentMainDelegate.
@@ -62,14 +65,14 @@ class ChromeMainDelegate : public content::ContentMainDelegate {
   service_manager::ProcessType OverrideProcessType() override;
   void PreCreateMainMessageLoop() override;
 #if !defined(CHROME_MULTIPLE_DLL_CHILD)
-  void PostEarlyInitialization() override;
+  void PostEarlyInitialization(bool is_running_tests) override;
+  bool ShouldCreateFeatureList() override;
 #endif
 
   content::ContentBrowserClient* CreateContentBrowserClient() override;
   content::ContentGpuClient* CreateContentGpuClient() override;
   content::ContentRendererClient* CreateContentRendererClient() override;
   content::ContentUtilityClient* CreateContentUtilityClient() override;
-  ui::DataPack* LoadServiceManifestDataPack() override;
 
 #if defined(OS_MACOSX)
   void InitMacCrashReporter(const base::CommandLine& command_line,
@@ -81,14 +84,12 @@ class ChromeMainDelegate : public content::ContentMainDelegate {
 
   std::unique_ptr<ChromeContentBrowserClient> chrome_content_browser_client_;
 
-  // This field is loaded by LoadServiceManifestDataPack() and passed to
-  // ContentBrowserClient in CreateContentBrowserClient()
-  std::unique_ptr<ui::DataPack> service_manifest_data_pack_;
-
 #if !defined(CHROME_MULTIPLE_DLL_CHILD)
   std::unique_ptr<ChromeFeatureListCreator> chrome_feature_list_creator_;
 #endif
 
+  std::unique_ptr<tracing::TracingSamplerProfiler> tracing_sampler_profiler_;
+
   DISALLOW_COPY_AND_ASSIGN(ChromeMainDelegate);
 };
 
