@@ -16,25 +16,27 @@ extern const base::Feature kAdjustWebApkInstallationSpace;
 extern const base::Feature kAndroidPayIntegrationV1;
 extern const base::Feature kAndroidPayIntegrationV2;
 extern const base::Feature kAndroidPaymentApps;
+extern const base::Feature kAndroidSiteSettingsUI;
 extern const base::Feature kAutofillAssistant;
 extern const base::Feature kBackgroundTaskComponentUpdate;
+extern const base::Feature kCastDeviceFilter;
 extern const base::Feature kCCTBackgroundTab;
 extern const base::Feature kCCTExternalLinkHandling;
 extern const base::Feature kCCTModule;
+extern const base::Feature kCCTModuleCache;
 extern const base::Feature kCCTParallelRequest;
 extern const base::Feature kCCTPostMessageAPI;
 extern const base::Feature kCCTRedirectPreconnect;
+extern const base::Feature kCCTReportParallelRequestStatus;
 extern const base::Feature kCCTResourcePrefetch;
 extern const base::Feature kChromeDuetFeature;
 extern const base::Feature kChromeHomeSwipeLogic;
 extern const base::Feature kChromeHomeSwipeLogicVelocity;
 extern const base::Feature kChromeMemexFeature;
-extern const base::Feature kChromeModernAlternateCardLayout;
 extern const base::Feature kChromeModernFullRoll;
 extern const base::Feature kChromeSmartSelection;
 extern const base::Feature kCommandLineOnNonRooted;
 extern const base::Feature kContentSuggestionsScrollToLoad;
-extern const base::Feature kContentSuggestionsSettings;
 extern const base::Feature kContentSuggestionsThumbnailDominantColor;
 extern const base::Feature kContextualSearchMlTapSuppression;
 extern const base::Feature kContextualSearchSecondTap;
@@ -56,9 +58,9 @@ extern const base::Feature kHomepageTile;
 extern const base::Feature kHorizontalTabSwitcherAndroid;
 extern const base::Feature kImprovedA2HS;
 extern const base::Feature kInflateToolbarOnBackgroundThread;
+extern const base::Feature kJellyBeanSupported;
 extern const base::Feature kLanguagesPreference;
 extern const base::Feature kLongPressBackForHistory;
-extern const base::Feature kLongPressBackNewDesign;
 extern const base::Feature kModalPermissionDialogView;
 extern const base::Feature kSearchEnginePromoExistingDevice;
 extern const base::Feature kSearchEnginePromoNewDevice;
@@ -67,7 +69,6 @@ extern const base::Feature kNewPhotoPicker;
 extern const base::Feature kNoCreditCardAbort;
 extern const base::Feature kNTPButton;
 extern const base::Feature kNTPLaunchAfterInactivity;
-extern const base::Feature kNTPModernLayoutFeature;
 extern const base::Feature kOmniboxSpareRenderer;
 extern const base::Feature kOmniboxVoiceSearchAlwaysVisible;
 extern const base::Feature kPayWithGoogleV1;
@@ -87,7 +88,6 @@ extern const base::Feature kTrustedWebActivityPostMessage;
 extern const base::Feature kUserMediaScreenCapturing;
 extern const base::Feature kVideoPersistence;
 extern const base::Feature kVrBrowsingFeedback;
-extern const base::Feature kVrBrowsingNativeAndroidUi;
 extern const base::Feature kVrBrowsingTabsView;
 
 }  // namespace android
