@@ -36,7 +36,8 @@
 #include "content/public/browser/web_contents.h"
 #include "net/base/escape.h"
 #include "net/http/http_status_code.h"
-#include "net/url_request/url_fetcher.h"
+#include "services/network/public/cpp/shared_url_loader_factory.h"
+#include "services/network/public/cpp/simple_url_loader.h"
 #include "url/gurl.h"
 
 using content::RenderFrameHost;
@@ -73,20 +74,19 @@ const char kDoPreventPreloadValue[] = "1";
 // The version of the Contextual Cards API that we want to invoke.
 const int kContextualCardsUrlActions = 3;
 
-}  // namespace
+const int kResponseCodeUninitialized = -1;
 
-// URLFetcher ID, only used for tests: we only have one kind of fetcher.
-const int ContextualSearchDelegate::kContextualSearchURLFetcherID = 1;
+}  // namespace
 
 // Handles tasks for the ContextualSearchManager in a separable, testable way.
 ContextualSearchDelegate::ContextualSearchDelegate(
-    net::URLRequestContextGetter* url_request_context,
+    scoped_refptr<network::SharedURLLoaderFactory> url_loader_factory,
     TemplateURLService* template_url_service,
     const ContextualSearchDelegate::SearchTermResolutionCallback&
         search_term_callback,
     const ContextualSearchDelegate::SurroundingTextCallback&
         surrounding_text_callback)
-    : url_request_context_(url_request_context),
+    : url_loader_factory_(std::move(url_loader_factory)),
       template_url_service_(template_url_service),
       search_term_callback_(search_term_callback),
       surrounding_text_callback_(surrounding_text_callback) {
@@ -132,7 +132,7 @@ void ContextualSearchDelegate::StartSearchTermResolutionRequest(
 
   // Immediately cancel any request that's in flight, since we're building a new
   // context (and the response disposes of any existing context).
-  search_term_fetcher_.reset();
+  url_loader_.reset();
 
   // Decide if the URL should be sent with the context.
   GURL page_url(web_contents->GetURL());
@@ -149,47 +149,47 @@ void ContextualSearchDelegate::ResolveSearchTermFromContext() {
   GURL request_url(BuildRequestUrl(context_->GetHomeCountry()));
   DCHECK(request_url.is_valid());
 
-  // Reset will delete any previous fetcher, and we won't get any callback.
-  search_term_fetcher_.reset(
-      net::URLFetcher::Create(kContextualSearchURLFetcherID, request_url,
-                              net::URLFetcher::GET, this).release());
-  search_term_fetcher_->SetRequestContext(url_request_context_);
+  auto resource_request = std::make_unique<network::ResourceRequest>();
+  resource_request->url = request_url;
 
-  // Add Chrome experiment state to the request headers.
-  net::HttpRequestHeaders headers;
-  variations::AppendVariationHeadersUnknownSignedIn(
-      search_term_fetcher_->GetOriginalURL(),
-      variations::InIncognito::kNo,  // Impossible to be incognito at this
-                                     // point.
-      &headers);
-  search_term_fetcher_->SetExtraRequestHeaders(headers.ToString());
-
-  SetDiscourseContextAndAddToHeader(*context_);
+  // Populates the discourse context and adds it to the HTTP header of the
+  // search term resolution request.
+  resource_request->headers.AddHeadersFromString(
+      GetDiscourseContext(*context_));
 
   // Disable cookies for this request.
-  search_term_fetcher_->SetAllowCredentials(false);
+  resource_request->allow_credentials = false;
 
-  search_term_fetcher_->Start();
+  // Add Chrome experiment state to the request headers.
+  // Reset will delete any previous loader, and we won't get any callback.
+  url_loader_ =
+      variations::CreateSimpleURLLoaderWithVariationsHeadersUnknownSignedIn(
+          std::move(resource_request),
+          variations::InIncognito::kNo,  // Impossible to be incognito at this
+                                         // point.
+          NO_TRAFFIC_ANNOTATION_YET);
+
+  url_loader_->DownloadToStringOfUnboundedSizeUntilCrashAndDie(
+      url_loader_factory_.get(),
+      base::BindOnce(&ContextualSearchDelegate::OnUrlLoadComplete,
+                     base::Unretained(this)));
 }
 
-void ContextualSearchDelegate::OnURLFetchComplete(
-    const net::URLFetcher* source) {
-  if (context_ == nullptr)
+void ContextualSearchDelegate::OnUrlLoadComplete(
+    std::unique_ptr<std::string> response_body) {
+  if (!context_)
     return;
 
-  DCHECK(source == search_term_fetcher_.get());
-  int response_code = source->GetResponseCode();
+  int response_code = kResponseCodeUninitialized;
+  if (url_loader_->ResponseInfo() && url_loader_->ResponseInfo()->headers) {
+    response_code = url_loader_->ResponseInfo()->headers->response_code();
+  }
 
   std::unique_ptr<ResolvedSearchTerm> resolved_search_term(
       new ResolvedSearchTerm(response_code));
-  if (source->GetStatus().is_success() && response_code == net::HTTP_OK) {
-    std::string response;
-    bool has_string_response = source->GetResponseAsString(&response);
-    DCHECK(has_string_response);
-    if (has_string_response && context_ != nullptr) {
-      resolved_search_term =
-          GetResolvedSearchTermFromJson(response_code, response);
-    }
+  if (response_body && response_code == net::HTTP_OK) {
+    resolved_search_term =
+        GetResolvedSearchTermFromJson(response_code, *response_body);
   }
   search_term_callback_.Run(*resolved_search_term);
 }
@@ -234,7 +234,7 @@ ContextualSearchDelegate::GetResolvedSearchTermFromJson(
       end_adjust = mention_end - context_->GetEndOffset();
     }
   }
-  bool is_invalid = response_code == net::URLFetcher::RESPONSE_CODE_INVALID;
+  bool is_invalid = response_code == kResponseCodeUninitialized;
   return std::unique_ptr<ResolvedSearchTerm>(new ResolvedSearchTerm(
       is_invalid, response_code, search_term, display_text, alternate_term, mid,
       prevent_preload == kDoPreventPreloadValue, start_adjust, end_adjust,
@@ -325,11 +325,6 @@ void ContextualSearchDelegate::OnTextSurroundingSelectionAvailable(
                                  selection_end);
 }
 
-void ContextualSearchDelegate::SetDiscourseContextAndAddToHeader(
-    const ContextualSearchContext& context) {
-  search_term_fetcher_->AddExtraRequestHeader(GetDiscourseContext(context));
-}
-
 std::string ContextualSearchDelegate::GetDiscourseContext(
     const ContextualSearchContext& context) {
   discourse_context::ClientDiscourseContext proto;
