@@ -7,6 +7,7 @@
 #include <memory>
 
 #include "base/android/jni_string.h"
+#include "base/android/path_utils.h"
 #include "base/location.h"
 #include "base/metrics/field_trial_params.h"
 #include "base/single_thread_task_runner.h"
@@ -18,10 +19,16 @@
 #include "chrome/browser/chrome_notification_types.h"
 #include "chrome/browser/download/download_core_service.h"
 #include "chrome/browser/download/download_core_service_factory.h"
+#include "chrome/browser/download/offline_item_utils.h"
+#include "chrome/browser/net/system_network_context_manager.h"
 #include "chrome/browser/profiles/profile_manager.h"
+#include "chrome/common/chrome_constants.h"
 #include "components/download/public/common/download_item.h"
+#include "components/download/public/common/download_item_impl.h"
+#include "components/download/public/common/download_url_loader_factory_getter_impl.h"
 #include "content/public/browser/browser_context.h"
 #include "content/public/browser/download_item_utils.h"
+#include "content/public/browser/network_service_instance.h"
 #include "content/public/browser/notification_service.h"
 #include "jni/DownloadInfo_jni.h"
 #include "jni/DownloadItem_jni.h"
@@ -32,6 +39,7 @@
 using base::android::JavaParamRef;
 using base::android::ConvertJavaStringToUTF8;
 using base::android::ConvertUTF8ToJavaString;
+using base::android::ConvertUTF16ToJavaString;
 using base::android::ScopedJavaLocalRef;
 
 namespace {
@@ -53,7 +61,8 @@ ScopedJavaLocalRef<jobject> JNI_DownloadManagerService_CreateJavaDownloadItem(
   DCHECK(!item->IsTransient());
   return Java_DownloadItem_createDownloadItem(
       env, DownloadManagerService::CreateJavaDownloadInfo(env, item),
-      item->GetStartTime().ToJavaTime(), item->GetFileExternallyRemoved());
+      item->GetStartTime().ToJavaTime(), item->GetEndTime().ToJavaTime(),
+      item->GetFileExternallyRemoved());
 }
 
 class ServiceImpl : public service_manager::Service {
@@ -137,7 +146,10 @@ ScopedJavaLocalRef<jobject> DownloadManagerService::CreateJavaDownloadInfo(
       ConvertUTF8ToJavaString(env, item->GetReferrerUrl().spec()),
       time_remaining_known ? time_delta.InMilliseconds()
                            : kUnknownRemainingTime,
-      item->GetLastAccessTime().ToJavaTime(), item->IsDangerous());
+      item->GetLastAccessTime().ToJavaTime(), item->IsDangerous(),
+      static_cast<int>(
+          OfflineItemUtils::ConvertDownloadInterruptReasonToFailState(
+              item->GetLastReason())));
 }
 
 static jlong JNI_DownloadManagerService_Init(JNIEnv* env,
@@ -152,8 +164,8 @@ static jlong JNI_DownloadManagerService_Init(JNIEnv* env,
 
 DownloadManagerService::DownloadManagerService()
     : is_history_query_complete_(false),
-      pending_get_downloads_actions_(NONE) {
-}
+      is_pending_downloads_loaded_(false),
+      pending_get_downloads_actions_(NONE) {}
 
 DownloadManagerService::~DownloadManagerService() {}
 
@@ -164,8 +176,7 @@ DownloadManagerService::CreateServiceManagerServiceInstance() {
 
 void DownloadManagerService::NotifyServiceStarted(
     std::unique_ptr<service_manager::Connector> connector) {
-  // TODO: Additional initialization, e.g. connect to Network Service using
-  // |connector| if the minimal download manager path is enabled by flag.
+  connector_ = std::move(connector);
 }
 
 void DownloadManagerService::Init(
@@ -214,7 +225,10 @@ void DownloadManagerService::Observe(
 download::InProgressDownloadManager*
 DownloadManagerService::RetriveInProgressDownloadManager(
     content::BrowserContext* context) {
-  // TODO(qinmin): return pre-created InProgressDownloadManager here.
+  if (in_progress_manager_) {
+    DCHECK(!context->IsOffTheRecord());
+    return in_progress_manager_.release();
+  }
   return nullptr;
 }
 
@@ -260,7 +274,7 @@ void DownloadManagerService::ResumeDownload(
     const JavaParamRef<jstring>& jdownload_guid,
     bool is_off_the_record) {
   std::string download_guid = ConvertJavaStringToUTF8(env, jdownload_guid);
-  if (is_history_query_complete_ || is_off_the_record)
+  if (is_pending_downloads_loaded_ || is_off_the_record)
     ResumeDownloadInternal(download_guid, is_off_the_record);
   else
     EnqueueDownloadAction(download_guid, RESUME);
@@ -272,7 +286,7 @@ void DownloadManagerService::PauseDownload(
     const JavaParamRef<jstring>& jdownload_guid,
     bool is_off_the_record) {
   std::string download_guid = ConvertJavaStringToUTF8(env, jdownload_guid);
-  if (is_history_query_complete_ || is_off_the_record)
+  if (is_pending_downloads_loaded_ || is_off_the_record)
     PauseDownloadInternal(download_guid, is_off_the_record);
   else
     EnqueueDownloadAction(download_guid, PAUSE);
@@ -368,7 +382,7 @@ void DownloadManagerService::CancelDownload(
   std::string download_guid = ConvertJavaStringToUTF8(env, jdownload_guid);
   DownloadController::RecordDownloadCancelReason(
       DownloadController::CANCEL_REASON_ACTION_BUTTON);
-  if (is_history_query_complete_ || is_off_the_record)
+  if (is_pending_downloads_loaded_ || is_off_the_record)
     CancelDownloadInternal(download_guid, is_off_the_record);
   else
     EnqueueDownloadAction(download_guid, CANCEL);
@@ -376,26 +390,7 @@ void DownloadManagerService::CancelDownload(
 
 void DownloadManagerService::OnHistoryQueryComplete() {
   is_history_query_complete_ = true;
-  for (auto iter = pending_actions_.begin(); iter != pending_actions_.end();
-       ++iter) {
-    DownloadAction action = iter->second;
-    std::string download_guid = iter->first;
-    switch (action) {
-      case RESUME:
-        ResumeDownloadInternal(download_guid, false);
-        break;
-      case PAUSE:
-        PauseDownloadInternal(download_guid, false);
-        break;
-      case CANCEL:
-        CancelDownloadInternal(download_guid, false);
-        break;
-      default:
-        NOTREACHED();
-        break;
-    }
-  }
-  pending_actions_.clear();
+  OnPendingDownloadsLoaded();
 
   // Respond to any requests to get all downloads.
   if (pending_get_downloads_actions_ & REGULAR)
@@ -467,10 +462,7 @@ void DownloadManagerService::ResumeDownloadInternal(
 
 void DownloadManagerService::CancelDownloadInternal(
     const std::string& download_guid, bool is_off_the_record) {
-  content::DownloadManager* manager = GetDownloadManager(is_off_the_record);
-  if (!manager)
-    return;
-  download::DownloadItem* item = manager->GetDownloadByGuid(download_guid);
+  download::DownloadItem* item = GetDownload(download_guid, is_off_the_record);
   if (item) {
     // Remove the observer first to avoid item->Cancel() causing re-entrance
     // issue.
@@ -481,10 +473,7 @@ void DownloadManagerService::CancelDownloadInternal(
 
 void DownloadManagerService::PauseDownloadInternal(
     const std::string& download_guid, bool is_off_the_record) {
-  content::DownloadManager* manager = GetDownloadManager(is_off_the_record);
-  if (!manager)
-    return;
-  download::DownloadItem* item = manager->GetDownloadByGuid(download_guid);
+  download::DownloadItem* item = GetDownload(download_guid, is_off_the_record);
   if (item) {
     item->Pause();
     item->RemoveObserver(DownloadControllerBase::Get());
@@ -493,10 +482,7 @@ void DownloadManagerService::PauseDownloadInternal(
 
 void DownloadManagerService::RemoveDownloadInternal(
     const std::string& download_guid, bool is_off_the_record) {
-  content::DownloadManager* manager = GetDownloadManager(is_off_the_record);
-  if (!manager)
-    return;
-  download::DownloadItem* item = manager->GetDownloadByGuid(download_guid);
+  download::DownloadItem* item = GetDownload(download_guid, is_off_the_record);
   if (item)
     item->Remove();
 }
@@ -550,6 +536,64 @@ void DownloadManagerService::OnResumptionFailedInternal(
     resume_callback_for_testing_.Run(false);
 }
 
+download::DownloadItem* DownloadManagerService::GetDownload(
+    const std::string& download_guid,
+    bool is_off_the_record) {
+  if (in_progress_manager_) {
+    DCHECK(!is_off_the_record);
+    return in_progress_manager_->GetInProgressDownload(download_guid);
+  }
+
+  content::DownloadManager* manager = GetDownloadManager(is_off_the_record);
+  if (manager)
+    return manager->GetDownloadByGuid(download_guid);
+  return nullptr;
+}
+
+void DownloadManagerService::CreateInProgressDownloadManager() {
+  DCHECK(!in_progress_manager_);
+  base::FilePath data_dir;
+  base::android::GetDataDirectory(&data_dir);
+  in_progress_manager_ = std::make_unique<download::InProgressDownloadManager>(
+      nullptr, data_dir.Append(chrome::kInitialProfile),
+      download::InProgressDownloadManager::IsOriginSecureCallback());
+  content::GetNetworkServiceFromConnector(connector_.get());
+  scoped_refptr<network::SharedURLLoaderFactory> factory =
+      SystemNetworkContextManager::GetInstance()->GetSharedURLLoaderFactory();
+  in_progress_manager_->set_url_loader_factory_getter(
+      base::MakeRefCounted<download::DownloadURLLoaderFactoryGetterImpl>(
+          factory->Clone()));
+  in_progress_manager_->NotifyWhenInitialized(
+      base::BindOnce(&DownloadManagerService::OnPendingDownloadsLoaded,
+                     base::Unretained(this)));
+  in_progress_manager_->set_download_start_observer(
+      DownloadControllerBase::Get());
+}
+
+void DownloadManagerService::OnPendingDownloadsLoaded() {
+  is_pending_downloads_loaded_ = true;
+  for (auto iter = pending_actions_.begin(); iter != pending_actions_.end();
+       ++iter) {
+    DownloadAction action = iter->second;
+    std::string download_guid = iter->first;
+    switch (action) {
+      case RESUME:
+        ResumeDownloadInternal(download_guid, false);
+        break;
+      case PAUSE:
+        PauseDownloadInternal(download_guid, false);
+        break;
+      case CANCEL:
+        CancelDownloadInternal(download_guid, false);
+        break;
+      default:
+        NOTREACHED();
+        break;
+    }
+  }
+  pending_actions_.clear();
+}
+
 content::DownloadManager* DownloadManagerService::GetDownloadManager(
     bool is_off_the_record) {
   Profile* profile = ProfileManager::GetActiveUserProfile();
