@@ -4,6 +4,8 @@
 
 #include "chrome/browser/android/feedback/process_id_feedback_source.h"
 
+#include "base/task/post_task.h"
+#include "content/public/browser/browser_task_traits.h"
 #include "jni/ProcessIdFeedbackSource_jni.h"
 
 #include "base/android/jni_array.h"
@@ -55,8 +57,8 @@ void ProcessIdFeedbackSource::PrepareProcessIds() {
     process_ids_[content::PROCESS_TYPE_RENDERER].push_back(
         host->GetProcess().Pid());
   }
-  BrowserThread::PostTask(
-      BrowserThread::IO, FROM_HERE,
+  base::PostTaskWithTraits(
+      FROM_HERE, {BrowserThread::IO},
       base::BindOnce(&ProcessIdFeedbackSource::PrepareProcessIdsOnIOThread,
                      this));
 }
@@ -68,8 +70,8 @@ void ProcessIdFeedbackSource::PrepareProcessIdsOnIOThread() {
     process_ids_[iter.GetData().process_type].push_back(
         iter.GetData().GetHandle());
 
-  BrowserThread::PostTask(
-      BrowserThread::UI, FROM_HERE,
+  base::PostTaskWithTraits(
+      FROM_HERE, {BrowserThread::UI},
       base::BindOnce(&ProcessIdFeedbackSource::PrepareCompleted, this));
 }
 
