@@ -48,11 +48,8 @@ class ForeignSessionHelper : public syncer::SyncServiceObserver {
       const base::android::JavaParamRef<jstring>& session_tag);
 
   // syncer::SyncServiceObserver implementation
-  void OnStateChanged() override {}
-  void OnSyncConfigurationCompleted() override;
-  void OnForeignSessionUpdated() override;
-
-  static bool RegisterForeignSessionHelper(JNIEnv* env);
+  void OnSyncConfigurationCompleted(syncer::SyncService* sync) override;
+  void OnForeignSessionUpdated(syncer::SyncService* sync) override;
 
  private:
   ~ForeignSessionHelper() override;
