@@ -1,4 +1,3 @@
-
 // Copyright 2015 The Chromium Authors. All rights reserved.
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
@@ -10,12 +9,15 @@
 
 #include "chrome/browser/android/proto/delta_file.pb.h"
 #include "net/base/url_util.h"
+#include "third_party/leveldatabase/src/include/leveldb/db.h"
+#include "third_party/leveldatabase/src/include/leveldb/iterator.h"
+#include "third_party/leveldatabase/src/include/leveldb/options.h"
 #include "url/gurl.h"
 
 namespace history_report {
 namespace usage_report_util {
 
-// Returns a levelDb key for a report. It's a concatenation of timestamp and id
+// Returns a LevelDB key for a report. It's a concatenation of timestamp and id
 // fields of a report.
 std::string ReportToKey(const history_report::UsageReport& report) {
   std::stringstream key;
@@ -46,5 +48,15 @@ bool ShouldIgnoreUrl(const GURL& url) {
   return false;
 }
 
+int DatabaseEntries(leveldb::DB* db) {
+  std::unique_ptr<leveldb::Iterator> db_iter(
+      db->NewIterator(leveldb::ReadOptions()));
+
+  int count = 0;
+  for (db_iter->SeekToFirst(); db_iter->Valid(); db_iter->Next())
+    count++;
+  return count;
+}
+
 }  // namespace usage_report_util
 }  // namespace history_report
