@@ -31,11 +31,14 @@ class PasswordAccessoryViewAndroid : public PasswordAccessoryViewInterface {
   void OnAutomaticGenerationStatusChanged(bool available) override;
   void CloseAccessorySheet() override;
   void SwapSheetWithKeyboard() override;
+  void ShowWhenKeyboardIsVisible() override;
+  void Hide() override;
 
   // Called from Java via JNI:
   void OnFaviconRequested(
       JNIEnv* env,
       const base::android::JavaParamRef<jobject>& obj,
+      jint desiredSizeInPx,
       const base::android::JavaParamRef<jobject>& j_callback);
   void OnFillingTriggered(
       JNIEnv* env,
