@@ -4,17 +4,16 @@
 
 #include "chrome/browser/android/tab_state.h"
 
-#include <jni.h>
 #include <stddef.h>
 #include <stdint.h>
+
 #include <limits>
+#include <memory>
 #include <vector>
 
 #include "base/android/jni_android.h"
 #include "base/android/jni_string.h"
 #include "base/logging.h"
-#include "base/memory/scoped_ptr.h"
-#include "base/memory/scoped_vector.h"
 #include "base/pickle.h"
 #include "chrome/browser/android/tab_android.h"
 #include "chrome/browser/profiles/profile.h"
@@ -24,24 +23,26 @@
 #include "components/sessions/core/session_command.h"
 #include "content/public/browser/navigation_controller.h"
 #include "content/public/browser/navigation_entry.h"
+#include "content/public/browser/restore_type.h"
 #include "content/public/browser/web_contents.h"
 #include "jni/TabState_jni.h"
 
 using base::android::ConvertUTF16ToJavaString;
 using base::android::ConvertUTF8ToJavaString;
+using base::android::JavaParamRef;
 using base::android::ScopedJavaLocalRef;
 using content::NavigationController;
 using content::WebContents;
 
 namespace {
 
-bool WriteStateHeaderToPickle(bool off_the_record,
+void WriteStateHeaderToPickle(bool off_the_record,
                               int entry_count,
                               int current_entry_index,
                               base::Pickle* pickle) {
-  return pickle->WriteBool(off_the_record) &&
-      pickle->WriteInt(entry_count) &&
-      pickle->WriteInt(current_entry_index);
+  pickle->WriteBool(off_the_record);
+  pickle->WriteInt(entry_count);
+  pickle->WriteInt(current_entry_index);
 }
 
 // Migrates a pickled SerializedNavigationEntry from Android tab version 0 to
@@ -281,69 +282,24 @@ bool ExtractNavigationEntries(
   return true;
 }
 
-};  // anonymous namespace
-
-ScopedJavaLocalRef<jobject> WebContentsState::GetContentsStateAsByteBuffer(
-    JNIEnv* env, TabAndroid* tab) {
-  Profile* profile = tab->GetProfile();
-  if (!profile)
-    return ScopedJavaLocalRef<jobject>();
-
-  content::NavigationController& controller =
-      tab->web_contents()->GetController();
-  const int pending_index = controller.GetPendingEntryIndex();
-  int entry_count = controller.GetEntryCount();
-  if (entry_count == 0 && pending_index == 0)
-    entry_count++;
-
-  if (entry_count == 0)
-    return ScopedJavaLocalRef<jobject>();
-
-  int current_entry = controller.GetLastCommittedEntryIndex();
-  if (current_entry == -1 && entry_count > 0)
-    current_entry = 0;
-
-  std::vector<content::NavigationEntry*> navigations(entry_count);
-  for (int i = 0; i < entry_count; ++i) {
-    content::NavigationEntry* entry = (i == pending_index) ?
-        controller.GetPendingEntry() : controller.GetEntryAtIndex(i);
-    navigations[i] = entry;
-  }
-
-  return WebContentsState::WriteNavigationsAsByteBuffer(
-      env,
-      profile->IsOffTheRecord(),
-      navigations,
-      current_entry);
-}
-
-// Common implementation for GetContentsStateAsByteBuffer() and
-// CreateContentsStateAsByteBuffer(). Does not assume ownership of the
-// navigations.
-ScopedJavaLocalRef<jobject> WebContentsState::WriteNavigationsAsByteBuffer(
+ScopedJavaLocalRef<jobject> WriteSerializedNavigationsAsByteBuffer(
     JNIEnv* env,
     bool is_off_the_record,
-    const std::vector<content::NavigationEntry*>& navigations,
+    const std::vector<sessions::SerializedNavigationEntry>& navigations,
     int current_entry) {
   base::Pickle pickle;
-  if (!WriteStateHeaderToPickle(is_off_the_record, navigations.size(),
-                                current_entry, &pickle)) {
-    LOG(ERROR) << "Failed to serialize tab state (entry count=" <<
-        navigations.size() << ").";
-    return ScopedJavaLocalRef<jobject>();
-  }
+  WriteStateHeaderToPickle(is_off_the_record, navigations.size(),
+                           current_entry, &pickle);
 
   // Write out all of the NavigationEntrys.
-  for (size_t i = 0; i < navigations.size(); ++i) {
+  for (const auto& navigation : navigations) {
     // Write each SerializedNavigationEntry as a separate pickle to avoid
     // optional reads of one tab bleeding into the next tab's data.
     base::Pickle tab_navigation_pickle;
     // Max size taken from BaseSessionService::CreateUpdateTabNavigationCommand.
     static const size_t max_state_size =
         std::numeric_limits<sessions::SessionCommand::size_type>::max() - 1024;
-    sessions::ContentSerializedNavigationBuilder::FromNavigationEntry(
-        i, *navigations[i])
-        .WriteToPickle(max_state_size, &tab_navigation_pickle);
+    navigation.WriteToPickle(max_state_size, &tab_navigation_pickle);
     pickle.WriteInt(tab_navigation_pickle.size());
     pickle.WriteBytes(tab_navigation_pickle.data(),
                       tab_navigation_pickle.size());
@@ -366,6 +322,115 @@ ScopedJavaLocalRef<jobject> WebContentsState::WriteNavigationsAsByteBuffer(
   return jb;
 }
 
+// Common implementation for GetContentsStateAsByteBuffer() and
+// CreateContentsStateAsByteBuffer(). Does not assume ownership of the
+// navigations.
+ScopedJavaLocalRef<jobject> WriteNavigationsAsByteBuffer(
+    JNIEnv* env,
+    bool is_off_the_record,
+    const std::vector<content::NavigationEntry*>& navigations,
+    int current_entry) {
+  std::vector<sessions::SerializedNavigationEntry> serialized;
+  for (size_t i = 0; i < navigations.size(); ++i) {
+    serialized.push_back(
+        sessions::ContentSerializedNavigationBuilder::FromNavigationEntry(
+            i, *navigations[i]));
+  }
+  return WriteSerializedNavigationsAsByteBuffer(env, is_off_the_record,
+                                                serialized, current_entry);
+}
+
+// Restores a WebContents from the passed in state.
+WebContents* RestoreContentsFromByteBuffer(void* data,
+                                           int size,
+                                           int saved_state_version,
+                                           bool initially_hidden) {
+  bool is_off_the_record;
+  int current_entry_index;
+  std::vector<sessions::SerializedNavigationEntry> navigations;
+  bool success = ExtractNavigationEntries(data, size, saved_state_version,
+                                          &is_off_the_record,
+                                          &current_entry_index, &navigations);
+  if (!success)
+    return NULL;
+
+  Profile* profile = ProfileManager::GetActiveUserProfile();
+  std::vector<std::unique_ptr<content::NavigationEntry>> entries =
+      sessions::ContentSerializedNavigationBuilder::ToNavigationEntries(
+          navigations, profile);
+
+  if (is_off_the_record)
+    profile = profile->GetOffTheRecordProfile();
+  WebContents::CreateParams params(profile);
+  params.initially_hidden = initially_hidden;
+  std::unique_ptr<WebContents> web_contents(WebContents::Create(params));
+  web_contents->GetController().Restore(
+      current_entry_index, content::RestoreType::CURRENT_SESSION, &entries);
+  return web_contents.release();
+}
+
+};  // anonymous namespace
+
+ScopedJavaLocalRef<jobject> WebContentsState::GetContentsStateAsByteBuffer(
+    JNIEnv* env,
+    TabAndroid* tab) {
+  Profile* profile = tab->GetProfile();
+  if (!profile)
+    return ScopedJavaLocalRef<jobject>();
+
+  content::NavigationController& controller =
+      tab->web_contents()->GetController();
+  const int entry_count = controller.GetEntryCount();
+  if (entry_count == 0)
+    return ScopedJavaLocalRef<jobject>();
+
+  std::vector<content::NavigationEntry*> navigations(entry_count);
+  for (int i = 0; i < entry_count; ++i) {
+    navigations[i] = controller.GetEntryAtIndex(i);
+  }
+
+  return WriteNavigationsAsByteBuffer(env, profile->IsOffTheRecord(),
+                                      navigations,
+                                      controller.GetLastCommittedEntryIndex());
+}
+
+ScopedJavaLocalRef<jobject>
+WebContentsState::DeleteNavigationEntriesFromByteBuffer(
+    JNIEnv* env,
+    void* data,
+    int size,
+    int saved_state_version,
+    const DeletionPredicate& predicate) {
+  bool is_off_the_record;
+  int current_entry_index;
+  std::vector<sessions::SerializedNavigationEntry> navigations;
+  bool success = ExtractNavigationEntries(data, size, saved_state_version,
+                                          &is_off_the_record,
+                                          &current_entry_index, &navigations);
+  if (!success)
+    return ScopedJavaLocalRef<jobject>();
+
+  std::vector<sessions::SerializedNavigationEntry> new_navigations;
+  int deleted_navigations = 0;
+  for (auto& navigation : navigations) {
+    if (current_entry_index != navigation.index() &&
+        predicate.Run(navigation)) {
+      deleted_navigations++;
+    } else {
+      // Adjust indices according to number of deleted navigations.
+      if (current_entry_index == navigation.index())
+        current_entry_index -= deleted_navigations;
+      navigation.set_index(navigation.index() - deleted_navigations);
+      new_navigations.push_back(std::move(navigation));
+    }
+  }
+  if (deleted_navigations == 0)
+    return ScopedJavaLocalRef<jobject>();
+
+  return WriteSerializedNavigationsAsByteBuffer(
+      env, is_off_the_record, new_navigations, current_entry_index);
+}
+
 ScopedJavaLocalRef<jstring>
 WebContentsState::GetDisplayTitleFromByteBuffer(JNIEnv* env,
                                                 void* data,
@@ -410,39 +475,6 @@ WebContentsState::GetVirtualUrlFromByteBuffer(JNIEnv* env,
   return ConvertUTF8ToJavaString(env, nav_entry.virtual_url().spec());
 }
 
-WebContents* WebContentsState::RestoreContentsFromByteBuffer(
-    void* data,
-    int size,
-    int saved_state_version,
-    bool initially_hidden) {
-  bool is_off_the_record;
-  int current_entry_index;
-  std::vector<sessions::SerializedNavigationEntry> navigations;
-  bool success = ExtractNavigationEntries(data,
-                                          size,
-                                          saved_state_version,
-                                          &is_off_the_record,
-                                          &current_entry_index,
-                                          &navigations);
-  if (!success)
-    return NULL;
-
-  Profile* profile = ProfileManager::GetActiveUserProfile();
-  std::vector<scoped_ptr<content::NavigationEntry>> entries =
-      sessions::ContentSerializedNavigationBuilder::ToNavigationEntries(
-          navigations, profile);
-
-  if (is_off_the_record)
-    profile = profile->GetOffTheRecordProfile();
-  WebContents::CreateParams params(profile);
-  params.initially_hidden = initially_hidden;
-  scoped_ptr<WebContents> web_contents(WebContents::Create(params));
-  web_contents->GetController().Restore(
-      current_entry_index, NavigationController::RESTORE_CURRENT_SESSION,
-      &entries);
-  return web_contents.release();
-}
-
 ScopedJavaLocalRef<jobject> WebContentsState::RestoreContentsFromByteBuffer(
     JNIEnv* env,
     jclass clazz,
@@ -452,11 +484,8 @@ ScopedJavaLocalRef<jobject> WebContentsState::RestoreContentsFromByteBuffer(
   void* data = env->GetDirectBufferAddress(state);
   int size = env->GetDirectBufferCapacity(state);
 
-  WebContents* web_contents = WebContentsState::RestoreContentsFromByteBuffer(
-      data,
-      size,
-      saved_state_version,
-      initially_hidden);
+  WebContents* web_contents = ::RestoreContentsFromByteBuffer(
+      data, size, saved_state_version, initially_hidden);
 
   if (web_contents)
     return web_contents->GetJavaWebContents();
@@ -477,34 +506,32 @@ ScopedJavaLocalRef<jobject>
         GURL(base::android::ConvertJavaStringToUTF8(env, referrer_url)),
         static_cast<blink::WebReferrerPolicy>(referrer_policy));
   }
-  scoped_ptr<content::NavigationEntry> entry(
+  std::unique_ptr<content::NavigationEntry> entry(
       content::NavigationController::CreateNavigationEntry(
-          GURL(base::android::ConvertJavaStringToUTF8(env, url)),
-          referrer,
+          GURL(base::android::ConvertJavaStringToUTF8(env, url)), referrer,
           ui::PAGE_TRANSITION_LINK,
           true,  // is_renderer_initiated
           "",    // extra_headers
-          ProfileManager::GetActiveUserProfile()));
+          ProfileManager::GetActiveUserProfile(),
+          nullptr /* blob_url_loader_factory */));
 
   std::vector<content::NavigationEntry*> navigations(1);
   navigations[0] = entry.get();
 
-  return WebContentsState::WriteNavigationsAsByteBuffer(env,
-                                                        is_off_the_record,
-                                                        navigations,
-                                                        0);
+  return WriteNavigationsAsByteBuffer(env, is_off_the_record, navigations, 0);
 }
 
 // Static JNI methods.
 
-static void FreeWebContentsStateBuffer(JNIEnv* env,
-                                       const JavaParamRef<jclass>& clazz,
-                                       const JavaParamRef<jobject>& obj) {
+static void JNI_TabState_FreeWebContentsStateBuffer(
+    JNIEnv* env,
+    const JavaParamRef<jclass>& clazz,
+    const JavaParamRef<jobject>& obj) {
   void* data = env->GetDirectBufferAddress(obj);
   free(data);
 }
 
-static ScopedJavaLocalRef<jobject> RestoreContentsFromByteBuffer(
+static ScopedJavaLocalRef<jobject> JNI_TabState_RestoreContentsFromByteBuffer(
     JNIEnv* env,
     const JavaParamRef<jclass>& clazz,
     const JavaParamRef<jobject>& state,
@@ -517,7 +544,7 @@ static ScopedJavaLocalRef<jobject> RestoreContentsFromByteBuffer(
                                                          initially_hidden);
 }
 
-static ScopedJavaLocalRef<jobject> GetContentsStateAsByteBuffer(
+static ScopedJavaLocalRef<jobject> JNI_TabState_GetContentsStateAsByteBuffer(
     JNIEnv* env,
     const JavaParamRef<jclass>& clazz,
     const JavaParamRef<jobject>& jtab) {
@@ -525,7 +552,24 @@ static ScopedJavaLocalRef<jobject> GetContentsStateAsByteBuffer(
   return WebContentsState::GetContentsStateAsByteBuffer(env, tab_android);
 }
 
-static ScopedJavaLocalRef<jobject> CreateSingleNavigationStateAsByteBuffer(
+static base::android::ScopedJavaLocalRef<jobject>
+JNI_TabState_DeleteNavigationEntries(
+    JNIEnv* env,
+    const JavaParamRef<jclass>& clazz,
+    const base::android::JavaParamRef<jobject>& state,
+    jint saved_state_version,
+    jlong predicate_ptr) {
+  void* data = env->GetDirectBufferAddress(state);
+  int size = env->GetDirectBufferCapacity(state);
+  const auto* predicate =
+      reinterpret_cast<WebContentsState::DeletionPredicate*>(predicate_ptr);
+
+  return WebContentsState::DeleteNavigationEntriesFromByteBuffer(
+      env, data, size, saved_state_version, *predicate);
+}
+
+static ScopedJavaLocalRef<jobject>
+JNI_TabState_CreateSingleNavigationStateAsByteBuffer(
     JNIEnv* env,
     const JavaParamRef<jclass>& clazz,
     const JavaParamRef<jstring>& url,
@@ -536,7 +580,7 @@ static ScopedJavaLocalRef<jobject> CreateSingleNavigationStateAsByteBuffer(
       env, url, referrer_url, referrer_policy, is_off_the_record);
 }
 
-static ScopedJavaLocalRef<jstring> GetDisplayTitleFromByteBuffer(
+static ScopedJavaLocalRef<jstring> JNI_TabState_GetDisplayTitleFromByteBuffer(
     JNIEnv* env,
     const JavaParamRef<jclass>& clazz,
     const JavaParamRef<jobject>& state,
@@ -550,7 +594,7 @@ static ScopedJavaLocalRef<jstring> GetDisplayTitleFromByteBuffer(
   return result;
 }
 
-static ScopedJavaLocalRef<jstring> GetVirtualUrlFromByteBuffer(
+static ScopedJavaLocalRef<jstring> JNI_TabState_GetVirtualUrlFromByteBuffer(
     JNIEnv* env,
     const JavaParamRef<jclass>& clazz,
     const JavaParamRef<jobject>& state,
@@ -565,18 +609,13 @@ static ScopedJavaLocalRef<jstring> GetVirtualUrlFromByteBuffer(
 
 // Creates a historical tab entry from the serialized tab contents contained
 // within |state|.
-static void CreateHistoricalTab(JNIEnv* env,
-                                const JavaParamRef<jclass>& clazz,
-                                const JavaParamRef<jobject>& state,
-                                jint saved_state_version) {
-  scoped_ptr<WebContents> web_contents(WebContents::FromJavaWebContents(
-      WebContentsState::RestoreContentsFromByteBuffer(env, clazz, state,
-                                                      saved_state_version, true)
-          .obj()));
+static void JNI_TabState_CreateHistoricalTab(JNIEnv* env,
+                                             const JavaParamRef<jclass>& clazz,
+                                             const JavaParamRef<jobject>& state,
+                                             jint saved_state_version) {
+  std::unique_ptr<WebContents> web_contents(WebContents::FromJavaWebContents(
+      WebContentsState::RestoreContentsFromByteBuffer(
+          env, clazz, state, saved_state_version, true)));
   if (web_contents.get())
     TabAndroid::CreateHistoricalTabFromContents(web_contents.get());
 }
-
-bool RegisterTabState(JNIEnv* env) {
-  return RegisterNativesImpl(env);
-}
