@@ -67,7 +67,7 @@ mojom::VRDisplayInfoPtr CreateVRDisplayInfo(mojom::XRDeviceId device_id) {
 
 }  // namespace
 
-ARCoreDevice::ARCoreDevice()
+ArCoreDevice::ArCoreDevice()
     : VRDeviceBase(mojom::XRDeviceId::ARCORE_DEVICE_ID),
       main_thread_task_runner_(base::ThreadTaskRunnerHandle::Get()),
       mailbox_bridge_(std::make_unique<vr::MailboxToSurfaceBridge>()),
@@ -78,15 +78,14 @@ ARCoreDevice::ARCoreDevice()
 
   // TODO(https://crbug.com/836524) clean up usage of mailbox bridge
   // and extract the methods in this class that interact with ARCore API
-  // into a separate class that implements the ARCore interface.
+  // into a separate class that implements the ArCore interface.
   mailbox_bridge_->CreateUnboundContextProvider(
-      base::BindOnce(&ARCoreDevice::OnMailboxBridgeReady, GetWeakPtr()));
+      base::BindOnce(&ArCoreDevice::OnMailboxBridgeReady, GetWeakPtr()));
 }
 
-ARCoreDevice::~ARCoreDevice() {
-}
+ArCoreDevice::~ArCoreDevice() {}
 
-void ARCoreDevice::PauseTracking() {
+void ArCoreDevice::PauseTracking() {
   DCHECK(IsOnMainThread());
 
   if (is_paused_)
@@ -98,10 +97,10 @@ void ARCoreDevice::PauseTracking() {
     return;
 
   PostTaskToGlThread(base::BindOnce(
-      &ARCoreGl::Pause, arcore_gl_thread_->GetARCoreGl()->GetWeakPtr()));
+      &ArCoreGl::Pause, arcore_gl_thread_->GetArCoreGl()->GetWeakPtr()));
 }
 
-void ARCoreDevice::ResumeTracking() {
+void ArCoreDevice::ResumeTracking() {
   DCHECK(IsOnMainThread());
 
   if (!is_paused_)
@@ -109,174 +108,209 @@ void ARCoreDevice::ResumeTracking() {
 
   is_paused_ = false;
 
-  if (!deferred_request_install_supported_arcore_callbacks_.empty())
-    CallDeferredRequestInstallSupportedARCore();
+  // TODO(crbug.com/883046): ResumeTracking does not fire after ArCore has been
+  // updated/installed or the update/installation was cancelled. Thus, we never
+  // handle queued up session requests.
+  if (on_request_arcore_install_or_update_result_callback_)
+    std::move(on_request_arcore_install_or_update_result_callback_)
+        .Run(!arcore_java_utils_->ShouldRequestInstallSupportedArCore());
 
   if (!is_arcore_gl_initialized_)
     return;
 
   PostTaskToGlThread(base::BindOnce(
-      &ARCoreGl::Resume, arcore_gl_thread_->GetARCoreGl()->GetWeakPtr()));
+      &ArCoreGl::Resume, arcore_gl_thread_->GetArCoreGl()->GetWeakPtr()));
 }
 
-void ARCoreDevice::OnMailboxBridgeReady() {
+void ArCoreDevice::OnMailboxBridgeReady() {
   DCHECK(IsOnMainThread());
   DCHECK(!arcore_gl_thread_);
   // MailboxToSurfaceBridge's destructor's call to DestroyContext must
   // happen on the GL thread, so transferring it to that thread is appropriate.
   // TODO(https://crbug.com/836553): use same GL thread as GVR.
-  arcore_gl_thread_ = std::make_unique<ARCoreGlThread>(
+  arcore_gl_thread_ = std::make_unique<ArCoreGlThread>(
       std::move(mailbox_bridge_),
       CreateMainThreadCallback(base::BindOnce(
-          &ARCoreDevice::OnARCoreGlThreadInitialized, GetWeakPtr())));
+          &ArCoreDevice::OnArCoreGlThreadInitialized, GetWeakPtr())));
   arcore_gl_thread_->Start();
 }
 
-void ARCoreDevice::OnARCoreGlThreadInitialized() {
+void ArCoreDevice::OnArCoreGlThreadInitialized() {
   DCHECK(IsOnMainThread());
 
   is_arcore_gl_thread_initialized_ = true;
 
-  if (pending_request_session_callback_) {
-    std::move(pending_request_session_callback_).Run();
+  if (pending_request_ar_module_callback_) {
+    std::move(pending_request_ar_module_callback_).Run();
   }
 }
 
-void ARCoreDevice::RequestSession(
+void ArCoreDevice::RequestSession(
     mojom::XRRuntimeSessionOptionsPtr options,
     mojom::XRRuntime::RequestSessionCallback callback) {
   DCHECK(IsOnMainThread());
 
+  // If we are currently handling another request defer this request. All
+  // deferred requests will be processed once handling is complete.
+  deferred_request_session_callbacks_.push_back(std::move(callback));
+  if (deferred_request_session_callbacks_.size() > 1) {
+    return;
+  }
+
   // TODO(https://crbug.com/849568): Instead of splitting the initialization
   // of this class between construction and RequestSession, perform all the
   // initialization at once on the first successful RequestSession call.
   if (!is_arcore_gl_thread_initialized_) {
-    if (pending_request_session_callback_) {
-      // We can only store one request at a time, so reject any further
-      // requests.
-      // TODO(http://crbug.com/836496) Make this queue session requests.
-      std::move(callback).Run(nullptr, nullptr);
-    }
-
-    pending_request_session_callback_ =
-        base::BindOnce(&ARCoreDevice::RequestSession, GetWeakPtr(),
-                       std::move(options), std::move(callback));
+    pending_request_ar_module_callback_ =
+        base::BindOnce(&ArCoreDevice::RequestArModule, GetWeakPtr(),
+                       options->render_process_id, options->render_frame_id,
+                       options->has_user_activation);
     return;
   }
 
-  auto preconditions_complete_callback =
-      base::BindOnce(&ARCoreDevice::OnRequestSessionPreconditionsComplete,
-                     GetWeakPtr(), std::move(callback));
-
-  SatisfyRequestSessionPreconditions(
-      options->render_process_id, options->render_frame_id,
-      options->has_user_activation, std::move(preconditions_complete_callback));
+  RequestArModule(options->render_process_id, options->render_frame_id,
+                  options->has_user_activation);
 }
 
-void ARCoreDevice::SatisfyRequestSessionPreconditions(
-    int render_process_id,
-    int render_frame_id,
-    bool has_user_activation,
-    base::OnceCallback<void(bool)> callback) {
-  DCHECK(IsOnMainThread());
-  DCHECK(is_arcore_gl_thread_initialized_);
-
-  if (!arcore_java_utils_->ShouldRequestInstallSupportedArCore()) {
-    // TODO(https://crbug.com/845792): Consider calling a method to ask for the
-    // appropriate permissions.
-    // ARCore sessions require camera permission.
-    RequestCameraPermission(
-        render_process_id, render_frame_id, has_user_activation,
-        base::BindOnce(&ARCoreDevice::OnRequestCameraPermissionComplete,
-                       GetWeakPtr(), std::move(callback)));
+void ArCoreDevice::RequestArModule(int render_process_id,
+                                   int render_frame_id,
+                                   bool has_user_activation) {
+  if (arcore_java_utils_->ShouldRequestInstallArModule()) {
+    arcore_java_utils_->RequestInstallArModule();
     return;
   }
 
-  // ARCore is not installed or requires an update. Store the callback to be
-  // processed later and only the first request session will trigger the
-  // request to install or update of the ARCore APK.
-  auto deferred_callback =
-      base::BindOnce(&ARCoreDevice::OnRequestARCoreInstallOrUpdateComplete,
-                     GetWeakPtr(), render_process_id, render_frame_id,
-                     has_user_activation, std::move(callback));
-  deferred_request_install_supported_arcore_callbacks_.push_back(
-      std::move(deferred_callback));
-  if (deferred_request_install_supported_arcore_callbacks_.size() > 1)
+  OnRequestArModuleResult(render_process_id, render_frame_id,
+                          has_user_activation, true);
+}
+
+void ArCoreDevice::OnRequestArModuleResult(int render_process_id,
+                                           int render_frame_id,
+                                           bool has_user_activation,
+                                           bool success) {
+  if (!success) {
+    CallDeferredRequestSessionCallbacks(/*success=*/false);
     return;
-
-  content::RenderFrameHost* render_frame_host =
-      content::RenderFrameHost::FromID(render_process_id, render_frame_id);
-  DCHECK(render_frame_host);
-
-  content::WebContents* web_contents =
-      content::WebContents::FromRenderFrameHost(render_frame_host);
-  DCHECK(web_contents);
-
-  TabAndroid* tab_android = TabAndroid::FromWebContents(web_contents);
-  DCHECK(tab_android);
-
-  base::android::ScopedJavaLocalRef<jobject> j_tab_android =
-      tab_android->GetJavaObject();
-  DCHECK(!j_tab_android.is_null());
-
-  arcore_java_utils_->RequestInstallSupportedArCore(j_tab_android);
-}
-
-void ARCoreDevice::OnRequestInstallSupportedARCoreCanceled() {
-  DCHECK(IsOnMainThread());
-  DCHECK(is_arcore_gl_thread_initialized_);
-  DCHECK(!deferred_request_install_supported_arcore_callbacks_.empty());
-
-  CallDeferredRequestInstallSupportedARCore();
-}
-
-void ARCoreDevice::CallDeferredRequestInstallSupportedARCore() {
-  DCHECK(IsOnMainThread());
-  DCHECK(is_arcore_gl_thread_initialized_);
-  DCHECK(!deferred_request_install_supported_arcore_callbacks_.empty());
-
-  for (auto& deferred_callback :
-       deferred_request_install_supported_arcore_callbacks_) {
-    std::move(deferred_callback).Run();
   }
-  deferred_request_install_supported_arcore_callbacks_.clear();
+
+  RequestArCoreInstallOrUpdate(render_process_id, render_frame_id,
+                               has_user_activation);
 }
 
-void ARCoreDevice::OnRequestARCoreInstallOrUpdateComplete(
-    int render_process_id,
-    int render_frame_id,
-    bool has_user_activation,
-    base::OnceCallback<void(bool)> callback) {
+void ArCoreDevice::RequestArCoreInstallOrUpdate(int render_process_id,
+                                                int render_frame_id,
+                                                bool has_user_activation) {
   DCHECK(IsOnMainThread());
   DCHECK(is_arcore_gl_thread_initialized_);
+  DCHECK(!on_request_arcore_install_or_update_result_callback_);
 
   if (arcore_java_utils_->ShouldRequestInstallSupportedArCore()) {
-    std::move(callback).Run(false);
+    // ARCore is not installed or requires an update. Store the callback to be
+    // processed later once installation/update is complete or got cancelled.
+    on_request_arcore_install_or_update_result_callback_ = base::BindOnce(
+        &ArCoreDevice::OnRequestArCoreInstallOrUpdateResult, GetWeakPtr(),
+        render_process_id, render_frame_id, has_user_activation);
+
+    content::RenderFrameHost* render_frame_host =
+        content::RenderFrameHost::FromID(render_process_id, render_frame_id);
+    DCHECK(render_frame_host);
+
+    content::WebContents* web_contents =
+        content::WebContents::FromRenderFrameHost(render_frame_host);
+    DCHECK(web_contents);
+
+    TabAndroid* tab_android = TabAndroid::FromWebContents(web_contents);
+    DCHECK(tab_android);
+
+    base::android::ScopedJavaLocalRef<jobject> j_tab_android =
+        tab_android->GetJavaObject();
+    DCHECK(!j_tab_android.is_null());
+
+    arcore_java_utils_->RequestInstallSupportedArCore(j_tab_android);
     return;
   }
 
-  RequestCameraPermission(
-      render_process_id, render_frame_id, has_user_activation,
-      base::BindOnce(&ARCoreDevice::OnRequestCameraPermissionComplete,
-                     GetWeakPtr(), std::move(callback)));
+  OnRequestArCoreInstallOrUpdateResult(render_process_id, render_frame_id,
+                                       has_user_activation, true);
 }
 
-void ARCoreDevice::OnRequestCameraPermissionComplete(
-    base::OnceCallback<void(bool)> callback,
+void ArCoreDevice::OnRequestInstallSupportedArCoreCanceled() {
+  DCHECK(IsOnMainThread());
+  DCHECK(is_arcore_gl_thread_initialized_);
+  DCHECK(on_request_arcore_install_or_update_result_callback_);
+
+  std::move(on_request_arcore_install_or_update_result_callback_).Run(false);
+}
+
+void ArCoreDevice::CallDeferredRequestSessionCallbacks(bool success) {
+  DCHECK(IsOnMainThread());
+  DCHECK(is_arcore_gl_thread_initialized_);
+  DCHECK(!deferred_request_session_callbacks_.empty());
+
+  for (auto& deferred_callback : deferred_request_session_callbacks_) {
+    mojom::XRSessionControllerPtr controller;
+    mojom::XRSessionPtr session;
+    if (success) {
+      mojom::XRFrameDataProviderPtr data_provider;
+      mojom::XREnvironmentIntegrationProviderPtr environment_provider;
+      magic_window_sessions_.push_back(std::make_unique<VRDisplayImpl>(
+          this, mojo::MakeRequest(&data_provider),
+          mojo::MakeRequest(&environment_provider),
+          mojo::MakeRequest(&controller)));
+
+      session = mojom::XRSession::New();
+      session->data_provider = data_provider.PassInterface();
+      session->environment_provider = environment_provider.PassInterface();
+      session->display_info = display_info_.Clone();
+    }
+    // We don't expect this call to alter deferred_request_session_callbacks_.
+    // The call may request another session, which should be handled right here
+    // in this loop as well.
+    std::move(deferred_callback).Run(std::move(session), std::move(controller));
+  }
+  deferred_request_session_callbacks_.clear();
+}
+
+void ArCoreDevice::OnRequestArCoreInstallOrUpdateResult(
+    int render_process_id,
+    int render_frame_id,
+    bool has_user_activation,
     bool success) {
   DCHECK(IsOnMainThread());
   DCHECK(is_arcore_gl_thread_initialized_);
 
-  // By this point ARCore has already been set up, so just return whether the
-  // permission request was a success.
-  std::move(callback).Run(success);
+  if (!success) {
+    CallDeferredRequestSessionCallbacks(/*success=*/false);
+    return;
+  }
+
+  // TODO(https://crbug.com/845792): Consider calling a method to ask for the
+  // appropriate permissions.
+  // ARCore sessions require camera permission.
+  RequestCameraPermission(
+      render_process_id, render_frame_id, has_user_activation,
+      base::BindOnce(&ArCoreDevice::OnRequestCameraPermissionComplete,
+                     GetWeakPtr()));
 }
 
-bool ARCoreDevice::ShouldPauseTrackingWhenFrameDataRestricted() {
+void ArCoreDevice::OnRequestCameraPermissionComplete(bool success) {
+  DCHECK(IsOnMainThread());
+  DCHECK(is_arcore_gl_thread_initialized_);
+
+  if (!success) {
+    CallDeferredRequestSessionCallbacks(/*success=*/false);
+    return;
+  }
+
+  // By this point ARCore has already been set up, so continue handling request.
+  RequestArCoreGlInitialization();
+}
+
+bool ArCoreDevice::ShouldPauseTrackingWhenFrameDataRestricted() {
   return true;
 }
 
-void ARCoreDevice::OnMagicWindowFrameDataRequest(
+void ArCoreDevice::OnMagicWindowFrameDataRequest(
     mojom::XRFrameDataProvider::GetFrameDataCallback callback) {
   TRACE_EVENT0("gpu", __FUNCTION__);
   DCHECK(IsOnMainThread());
@@ -306,31 +340,31 @@ void ARCoreDevice::OnMagicWindowFrameDataRequest(
   }
 
   PostTaskToGlThread(base::BindOnce(
-      &ARCoreGl::ProduceFrame, arcore_gl_thread_->GetARCoreGl()->GetWeakPtr(),
+      &ArCoreGl::ProduceFrame, arcore_gl_thread_->GetArCoreGl()->GetWeakPtr(),
       max_size, rotation, CreateMainThreadCallback(std::move(callback))));
 }
 
-void ARCoreDevice::RequestHitTest(
+void ArCoreDevice::RequestHitTest(
     mojom::XRRayPtr ray,
     mojom::XREnvironmentIntegrationProvider::RequestHitTestCallback callback) {
   DCHECK(IsOnMainThread());
 
   PostTaskToGlThread(base::BindOnce(
-      &ARCoreGl::RequestHitTest, arcore_gl_thread_->GetARCoreGl()->GetWeakPtr(),
+      &ArCoreGl::RequestHitTest, arcore_gl_thread_->GetArCoreGl()->GetWeakPtr(),
       std::move(ray), CreateMainThreadCallback(std::move(callback))));
 }
 
-void ARCoreDevice::PostTaskToGlThread(base::OnceClosure task) {
+void ArCoreDevice::PostTaskToGlThread(base::OnceClosure task) {
   DCHECK(IsOnMainThread());
-  arcore_gl_thread_->GetARCoreGl()->GetGlThreadTaskRunner()->PostTask(
+  arcore_gl_thread_->GetArCoreGl()->GetGlThreadTaskRunner()->PostTask(
       FROM_HERE, std::move(task));
 }
 
-bool ARCoreDevice::IsOnMainThread() {
+bool ArCoreDevice::IsOnMainThread() {
   return main_thread_task_runner_->BelongsToCurrentThread();
 }
 
-void ARCoreDevice::RequestCameraPermission(
+void ArCoreDevice::RequestCameraPermission(
     int render_process_id,
     int render_frame_id,
     bool has_user_activation,
@@ -356,11 +390,11 @@ void ARCoreDevice::RequestCameraPermission(
   permission_manager->RequestPermission(
       CONTENT_SETTINGS_TYPE_MEDIASTREAM_CAMERA, rfh, web_contents->GetURL(),
       has_user_activation,
-      base::BindRepeating(&ARCoreDevice::OnRequestCameraPermissionResult,
+      base::BindRepeating(&ArCoreDevice::OnRequestCameraPermissionResult,
                           GetWeakPtr(), web_contents, base::Passed(&callback)));
 }
 
-void ARCoreDevice::OnRequestCameraPermissionResult(
+void ArCoreDevice::OnRequestCameraPermissionResult(
     content::WebContents* web_contents,
     base::OnceCallback<void(bool)> callback,
     ContentSetting content_setting) {
@@ -389,7 +423,7 @@ void ARCoreDevice::OnRequestCameraPermissionResult(
       // Show the Android camera permission info bar.
       PermissionUpdateInfoBarDelegate::Create(
           web_contents, content_settings_types,
-          base::BindOnce(&ARCoreDevice::OnRequestAndroidCameraPermissionResult,
+          base::BindOnce(&ArCoreDevice::OnRequestAndroidCameraPermissionResult,
                          GetWeakPtr(), base::Passed(&callback)));
       return;
     case ShowPermissionInfoBarState::CANNOT_SHOW_PERMISSION_INFOBAR:
@@ -400,37 +434,27 @@ void ARCoreDevice::OnRequestCameraPermissionResult(
   NOTREACHED() << "Unknown show permission infobar state.";
 }
 
-void ARCoreDevice::OnRequestSessionPreconditionsComplete(
-    mojom::XRRuntime::RequestSessionCallback callback,
-    bool success) {
+void ArCoreDevice::RequestArCoreGlInitialization() {
   DCHECK(IsOnMainThread());
   DCHECK(is_arcore_gl_thread_initialized_);
 
-  if (!success) {
-    std::move(callback).Run(nullptr, nullptr);
+  if (!is_arcore_gl_initialized_) {
+    PostTaskToGlThread(base::BindOnce(
+        &ArCoreGl::Initialize, arcore_gl_thread_->GetArCoreGl()->GetWeakPtr(),
+        CreateMainThreadCallback(base::BindOnce(
+            &ArCoreDevice::OnArCoreGlInitializationComplete, GetWeakPtr()))));
     return;
   }
 
-  if (is_arcore_gl_initialized_) {
-    OnARCoreGlInitializationComplete(std::move(callback), true);
-    return;
-  }
-
-  PostTaskToGlThread(base::BindOnce(
-      &ARCoreGl::Initialize, arcore_gl_thread_->GetARCoreGl()->GetWeakPtr(),
-      CreateMainThreadCallback(
-          base::BindOnce(&ARCoreDevice::OnARCoreGlInitializationComplete,
-                         GetWeakPtr(), std::move(callback)))));
+  OnArCoreGlInitializationComplete(true);
 }
 
-void ARCoreDevice::OnARCoreGlInitializationComplete(
-    mojom::XRRuntime::RequestSessionCallback callback,
-    bool success) {
+void ArCoreDevice::OnArCoreGlInitializationComplete(bool success) {
   DCHECK(IsOnMainThread());
   DCHECK(is_arcore_gl_thread_initialized_);
 
   if (!success) {
-    std::move(callback).Run(nullptr, nullptr);
+    CallDeferredRequestSessionCallbacks(/*success=*/false);
     return;
   }
 
@@ -438,26 +462,13 @@ void ARCoreDevice::OnARCoreGlInitializationComplete(
 
   if (!is_paused_) {
     PostTaskToGlThread(base::BindOnce(
-        &ARCoreGl::Resume, arcore_gl_thread_->GetARCoreGl()->GetWeakPtr()));
+        &ArCoreGl::Resume, arcore_gl_thread_->GetArCoreGl()->GetWeakPtr()));
   }
 
-  mojom::XRFrameDataProviderPtr data_provider;
-  mojom::XREnvironmentIntegrationProviderPtr environment_provider;
-  mojom::XRSessionControllerPtr controller;
-  magic_window_sessions_.push_back(
-      std::make_unique<VRDisplayImpl>(this, mojo::MakeRequest(&data_provider),
-                                      mojo::MakeRequest(&environment_provider),
-                                      mojo::MakeRequest(&controller)));
-
-  auto session = mojom::XRSession::New();
-  session->data_provider = data_provider.PassInterface();
-  session->environment_provider = environment_provider.PassInterface();
-  session->display_info = display_info_.Clone();
-
-  std::move(callback).Run(std::move(session), std::move(controller));
+  CallDeferredRequestSessionCallbacks(/*success=*/true);
 }
 
-void ARCoreDevice::OnRequestAndroidCameraPermissionResult(
+void ArCoreDevice::OnRequestAndroidCameraPermissionResult(
     base::OnceCallback<void(bool)> callback,
     bool was_android_camera_permission_granted) {
   DCHECK(IsOnMainThread());
