@@ -15,7 +15,6 @@
 #include "base/cancelable_callback.h"
 #include "base/macros.h"
 #include "chrome/browser/android/vr/vr_core_info.h"
-#include "chrome/browser/vr/content_input_delegate.h"
 #include "chrome/browser/vr/metrics/session_metrics_helper.h"
 #include "device/vr/android/gvr/gvr_delegate_provider.h"
 #include "device/vr/public/mojom/vr_service.mojom.h"
@@ -68,11 +67,7 @@ class VrShellDelegate : public device::GvrDelegateProvider {
 
   device::GvrDevice* GetDevice();
 
-  void SendRequestPresentReply(
-      bool success,
-      device::mojom::VRSubmitFrameClientRequest request,
-      device::mojom::VRPresentationProviderPtr provider,
-      device::mojom::VRDisplayFrameTransportOptionsPtr);
+  void SendRequestPresentReply(device::mojom::XRSessionPtr session);
 
   // device::GvrDelegateProvider implementation.
   void ExitWebVRPresent() override;
@@ -80,10 +75,10 @@ class VrShellDelegate : public device::GvrDelegateProvider {
  private:
   // device::GvrDelegateProvider implementation.
   bool ShouldDisableGvrDevice() override;
-  void SetDeviceId(unsigned int device_id) override;
+  void SetDeviceId(device::mojom::XRDeviceId device_id) override;
   void StartWebXRPresentation(
       device::mojom::VRDisplayInfoPtr display_info,
-      device::mojom::XRDeviceRuntimeSessionOptionsPtr options,
+      device::mojom::XRRuntimeSessionOptionsPtr options,
       base::OnceCallback<void(device::mojom::XRSessionPtr)> callback) override;
   void OnListeningForActivateChanged(bool listening) override;
 
@@ -91,14 +86,15 @@ class VrShellDelegate : public device::GvrDelegateProvider {
   void SetListeningForActivate(bool listening);
   void OnPresentResult(
       device::mojom::VRDisplayInfoPtr display_info,
-      device::mojom::XRDeviceRuntimeSessionOptionsPtr options,
+      device::mojom::XRRuntimeSessionOptionsPtr options,
       base::OnceCallback<void(device::mojom::XRSessionPtr)> callback,
       bool success);
 
   std::unique_ptr<VrCoreInfo> MakeVrCoreInfo(JNIEnv* env);
 
   base::android::ScopedJavaGlobalRef<jobject> j_vr_shell_delegate_;
-  unsigned int device_id_ = 0;
+  device::mojom::XRDeviceId device_id_ =
+      device::mojom::XRDeviceId::GVR_DEVICE_ID;
   VrShell* vr_shell_ = nullptr;
 
   // Deferred callback stored for later use in cases where vr_shell
