@@ -27,6 +27,7 @@
 #include "content/public/browser/background_fetch_description.h"
 #include "content/public/browser/background_fetch_response.h"
 #include "content/public/browser/browser_thread.h"
+#include "third_party/blink/public/platform/modules/background_fetch/background_fetch.mojom.h"
 #include "third_party/skia/include/core/SkBitmap.h"
 #include "ui/gfx/geometry/size.h"
 #include "ui/gfx/image/image_skia.h"
@@ -43,6 +44,10 @@ BackgroundFetchDelegateImpl::BackgroundFetchDelegateImpl(
   DCHECK(profile_);
   DCHECK(!provider_namespace_.empty());
   offline_content_aggregator_->RegisterProvider(provider_namespace_, this);
+
+  // Ensure that downloads UI components are initialized to handle the UI
+  // updates.
+  content::BrowserContext::GetDownloadManager(profile_);
 }
 
 BackgroundFetchDelegateImpl::~BackgroundFetchDelegateImpl() {
@@ -70,12 +75,15 @@ BackgroundFetchDelegateImpl::JobDetails::JobDetails(JobDetails&&) = default;
 
 BackgroundFetchDelegateImpl::JobDetails::JobDetails(
     std::unique_ptr<content::BackgroundFetchDescription> fetch_description,
-    const std::string& provider_namespace)
-    : cancelled(false),
+    const std::string& provider_namespace,
+    bool is_off_the_record)
+    : paused(fetch_description->start_paused),
       offline_item(offline_items_collection::ContentId(
           provider_namespace,
           fetch_description->job_unique_id)),
       fetch_description(std::move(fetch_description)) {
+  offline_item.is_off_the_record = is_off_the_record;
+  offline_item.original_url = this->fetch_description->origin.GetURL();
   UpdateOfflineItem();
 }
 
@@ -101,17 +109,10 @@ void BackgroundFetchDelegateImpl::JobDetails::UpdateOfflineItem() {
   offline_item.progress.unit =
       offline_items_collection::OfflineItemProgressUnit::PERCENTAGE;
 
-  if (fetch_description->title.empty()) {
-    offline_item.title = fetch_description->origin.Serialize();
-  } else {
-    // TODO(crbug.com/774612): Make sure that the origin is displayed completely
-    // in all cases so that long titles cannot obscure it.
-    offline_item.title =
-        base::StringPrintf("%s (%s)", fetch_description->title.c_str(),
-                           fetch_description->origin.Serialize().c_str());
-  }
-  // TODO(delphick): Figure out what to put in offline_item.description.
+  offline_item.title = fetch_description->title;
+  offline_item.promote_origin = true;
   offline_item.is_transient = true;
+  offline_item.is_resumable = true;
 
   using OfflineItemState = offline_items_collection::OfflineItemState;
   if (cancelled) {
@@ -122,6 +123,8 @@ void BackgroundFetchDelegateImpl::JobDetails::UpdateOfflineItem() {
     // response was an HTTP error, e.g. 404.
     offline_item.state = OfflineItemState::COMPLETE;
     offline_item.is_openable = true;
+  } else if (started && paused) {
+    offline_item.state = OfflineItemState::PAUSED;
   } else {
     offline_item.state = OfflineItemState::IN_PROGRESS;
   }
@@ -174,8 +177,12 @@ void BackgroundFetchDelegateImpl::GetPermissionForOrigin(
 
     // The fetch should be thought of as one download. So the origin will be
     // used as the URL, and the |request_method| is set to GET.
-    limiter->CanDownload(wc_getter, origin.GetURL(), "GET",
-                         base::AdaptCallbackForRepeating(std::move(callback)));
+    limiter->CanDownload(
+        wc_getter, origin.GetURL(), "GET",
+        base::AdaptCallbackForRepeating(base::BindOnce(
+            &BackgroundFetchDelegateImpl::
+                DidGetPermissionFromDownloadRequestLimiter,
+            weak_ptr_factory_.GetWeakPtr(), std::move(callback))));
     return;
   }
 
@@ -183,26 +190,37 @@ void BackgroundFetchDelegateImpl::GetPermissionForOrigin(
       HostContentSettingsMapFactory::GetForProfile(profile_);
   DCHECK(host_content_settings_map);
 
-  // This is running from a worker context, use the Automatic Downloads
-  // permission.
+  // This is running from a non-top level frame, use the Automatic Downloads
+  // content setting.
   ContentSetting content_setting = host_content_settings_map->GetContentSetting(
       origin.GetURL(), origin.GetURL(),
       CONTENT_SETTINGS_TYPE_AUTOMATIC_DOWNLOADS,
       std::string() /* resource_identifier */);
 
-  if (content_setting != CONTENT_SETTING_ALLOW) {
-    std::move(callback).Run(/* has_permission= */ false);
-    return;
+  // The set of valid settings for automatic downloads is set to
+  // {CONTENT_SETTING_ALLOW, CONTENT_SETTING_ASK, CONTENT_SETTING_BLOCK}.
+  switch (content_setting) {
+    case CONTENT_SETTING_ALLOW:
+    case CONTENT_SETTING_ASK:
+      std::move(callback).Run(content::BackgroundFetchPermission::ASK);
+      return;
+    case CONTENT_SETTING_BLOCK:
+      std::move(callback).Run(content::BackgroundFetchPermission::BLOCKED);
+      return;
+    case CONTENT_SETTING_DEFAULT:
+    case CONTENT_SETTING_SESSION_ONLY:
+    case CONTENT_SETTING_DETECT_IMPORTANT_CONTENT:
+    case CONTENT_SETTING_NUM_SETTINGS:
+      NOTREACHED();
   }
+}
 
-  // Also make sure that Background Sync has permission.
-  // TODO(crbug.com/616321): Remove this check after Automatic Downloads
-  // permissions can be modified from Android.
-  content_setting = host_content_settings_map->GetContentSetting(
-      origin.GetURL(), origin.GetURL(), CONTENT_SETTINGS_TYPE_BACKGROUND_SYNC,
-      std::string() /* resource_identifier */);
-
-  std::move(callback).Run(content_setting == CONTENT_SETTING_ALLOW);
+void BackgroundFetchDelegateImpl::DidGetPermissionFromDownloadRequestLimiter(
+    GetPermissionForOriginCallback callback,
+    bool has_permission) {
+  std::move(callback).Run(has_permission
+                              ? content::BackgroundFetchPermission::ALLOWED
+                              : content::BackgroundFetchPermission::BLOCKED);
 }
 
 void BackgroundFetchDelegateImpl::CreateDownloadJob(
@@ -211,23 +229,10 @@ void BackgroundFetchDelegateImpl::CreateDownloadJob(
 
   std::string job_unique_id = fetch_description->job_unique_id;
   DCHECK(!job_details_map_.count(job_unique_id));
-  auto emplace_result = job_details_map_.emplace(
+  job_details_map_.emplace(
       job_unique_id,
-      JobDetails(std::move(fetch_description), provider_namespace_));
-
-  const JobDetails& details = emplace_result.first->second;
-  for (const auto& download_guid : details.fetch_description->current_guids) {
-    DCHECK(!download_job_unique_id_map_.count(download_guid));
-    download_job_unique_id_map_.emplace(download_guid, job_unique_id);
-    if (GetDownloadService()->GetStatus() ==
-        download::DownloadService::ServiceStatus::READY) {
-      GetDownloadService()->ResumeDownload(download_guid);
-    }
-  }
-
-  for (auto* observer : observers_) {
-    observer->OnItemsAdded({details.offline_item});
-  }
+      JobDetails(std::move(fetch_description), provider_namespace_,
+                 profile_->IsOffTheRecord()));
 }
 
 void BackgroundFetchDelegateImpl::DownloadUrl(
@@ -238,13 +243,9 @@ void BackgroundFetchDelegateImpl::DownloadUrl(
     const net::NetworkTrafficAnnotationTag& traffic_annotation,
     const net::HttpRequestHeaders& headers) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
-
   DCHECK(job_details_map_.count(job_unique_id));
   DCHECK(!download_job_unique_id_map_.count(download_guid));
 
-  JobDetails& job_details = job_details_map_.find(job_unique_id)->second;
-  job_details.current_download_guids.insert(download_guid);
-
   download_job_unique_id_map_.emplace(download_guid, job_unique_id);
 
   download::DownloadParams params;
@@ -258,6 +259,32 @@ void BackgroundFetchDelegateImpl::DownloadUrl(
   params.traffic_annotation =
       net::MutableNetworkTrafficAnnotationTag(traffic_annotation);
 
+  JobDetails& job_details = job_details_map_.find(job_unique_id)->second;
+
+  if (!job_details.started) {
+    // Create a notification.
+    for (auto* observer : observers_)
+      observer->OnItemsAdded({job_details.offline_item});
+    job_details.started = true;
+  }
+
+  if (job_details.paused) {
+    job_details.on_resume =
+        base::BindOnce(&BackgroundFetchDelegateImpl::StartDownload,
+                       GetWeakPtr(), job_unique_id, params);
+  } else {
+    StartDownload(job_unique_id, params);
+  }
+
+  UpdateOfflineItemAndUpdateObservers(&job_details);
+}
+
+void BackgroundFetchDelegateImpl::StartDownload(
+    const std::string& job_unique_id,
+    const download::DownloadParams& params) {
+  DCHECK(job_details_map_.count(job_unique_id));
+  JobDetails& job_details = job_details_map_.find(job_unique_id)->second;
+  job_details.current_download_guids.insert(params.guid);
   GetDownloadService()->StartDownload(params);
 }
 
@@ -359,12 +386,9 @@ void BackgroundFetchDelegateImpl::OnDownloadUpdated(
 
 void BackgroundFetchDelegateImpl::OnDownloadFailed(
     const std::string& download_guid,
-    download::Client::FailureReason reason) {
+    std::unique_ptr<content::BackgroundFetchResult> result) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
 
-  using FailureReason = content::BackgroundFetchResult::FailureReason;
-  FailureReason failure_reason;
-
   auto download_job_unique_id_iter =
       download_job_unique_id_map_.find(download_guid);
   // TODO(crbug.com/779012): When DownloadService fixes cancelled jobs
@@ -378,45 +402,24 @@ void BackgroundFetchDelegateImpl::OnDownloadFailed(
   ++job_details.fetch_description->completed_parts;
   UpdateOfflineItemAndUpdateObservers(&job_details);
 
-  switch (reason) {
-    case download::Client::FailureReason::NETWORK:
-      failure_reason = FailureReason::NETWORK;
-      break;
-    case download::Client::FailureReason::TIMEDOUT:
-      failure_reason = FailureReason::TIMEDOUT;
-      break;
-    case download::Client::FailureReason::UNKNOWN:
-      failure_reason = FailureReason::UNKNOWN;
-      break;
-
-    case download::Client::FailureReason::ABORTED:
-    case download::Client::FailureReason::CANCELLED:
-      // The client cancelled or aborted it so no need to notify it.
-      return;
-    default:
-      NOTREACHED();
-      return;
+  // The client cancelled or aborted the download so no need to notify it.
+  if (result->failure_reason ==
+      content::BackgroundFetchResult::FailureReason::CANCELLED) {
+    return;
   }
 
-  // TODO(delphick): consider calling OnItemUpdated here as well if for instance
-  // the download actually happened but 404ed.
-
   if (client()) {
-    client()->OnDownloadComplete(
-        job_unique_id, download_guid,
-        std::make_unique<content::BackgroundFetchResult>(base::Time::Now(),
-                                                         failure_reason));
+    client()->OnDownloadComplete(job_unique_id, download_guid,
+                                 std::move(result));
   }
 
-  job_details.current_download_guids.erase(
-      job_details.current_download_guids.find(download_guid));
+  job_details.current_download_guids.erase(download_guid);
   download_job_unique_id_map_.erase(download_guid);
 }
 
 void BackgroundFetchDelegateImpl::OnDownloadSucceeded(
     const std::string& download_guid,
-    const base::FilePath& path,
-    uint64_t size) {
+    std::unique_ptr<content::BackgroundFetchResult> result) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
 
   auto download_job_unique_id_iter =
@@ -429,14 +432,15 @@ void BackgroundFetchDelegateImpl::OnDownloadSucceeded(
   const std::string& job_unique_id = download_job_unique_id_iter->second;
   JobDetails& job_details = job_details_map_.find(job_unique_id)->second;
   ++job_details.fetch_description->completed_parts;
-  job_details.fetch_description->completed_parts_size = size;
+
+  job_details.fetch_description->completed_parts_size =
+      profile_->IsOffTheRecord() ? result->blob_handle->size()
+                                 : result->file_size;
   UpdateOfflineItemAndUpdateObservers(&job_details);
 
   if (client()) {
-    client()->OnDownloadComplete(
-        job_unique_id, download_guid,
-        std::make_unique<content::BackgroundFetchResult>(
-            base::Time::Now(), path, base::nullopt /* blob_handle */, size));
+    client()->OnDownloadComplete(job_unique_id, download_guid,
+                                 std::move(result));
   }
 
   job_details.current_download_guids.erase(
@@ -454,6 +458,9 @@ void BackgroundFetchDelegateImpl::OnDownloadReceived(
     case StartResult::ACCEPTED:
       // Nothing to do.
       break;
+    case StartResult::UNEXPECTED_GUID:
+      // The download started in a previous session. Nothing to do.
+      break;
     case StartResult::BACKOFF:
       // TODO(delphick): try again later?
       NOTREACHED();
@@ -463,10 +470,6 @@ void BackgroundFetchDelegateImpl::OnDownloadReceived(
       // DownloadClient.
       NOTREACHED();
       break;
-    case StartResult::UNEXPECTED_GUID:
-      // TODO(delphick): try again with a different GUID.
-      NOTREACHED();
-      break;
     case StartResult::CLIENT_CANCELLED:
       // TODO(delphick): do we need to do anything here, since we will have
       // cancelled it?
@@ -510,19 +513,22 @@ void BackgroundFetchDelegateImpl::FailFetch(const std::string& job_unique_id) {
   const std::string unique_id = job_unique_id;
   Abort(job_unique_id);
   if (client()) {
-    client()->OnJobCancelled(
-        unique_id,
-        content::BackgroundFetchReasonToAbort::TOTAL_DOWNLOAD_SIZE_EXCEEDED);
+    client()->OnJobCancelled(unique_id,
+                             blink::mojom::BackgroundFetchFailureReason::
+                                 TOTAL_DOWNLOAD_SIZE_EXCEEDED);
   }
 }
 
 void BackgroundFetchDelegateImpl::CancelDownload(
     const offline_items_collection::ContentId& id) {
-  Abort(id.id);
+  // Save a copy before Abort() deletes the reference.
+  const std::string unique_id = id.id;
+  Abort(unique_id);
 
   if (client()) {
     client()->OnJobCancelled(
-        id.id, content::BackgroundFetchReasonToAbort::CANCELLED_FROM_UI);
+        unique_id,
+        blink::mojom::BackgroundFetchFailureReason::CANCELLED_FROM_UI);
   }
 }
 
@@ -533,12 +539,9 @@ void BackgroundFetchDelegateImpl::PauseDownload(
     return;
 
   JobDetails& job_details = job_details_iter->second;
+  job_details.paused = true;
   for (auto& download_guid : job_details.current_download_guids)
-    download_service_->PauseDownload(download_guid);
-
-  // TODO(delphick): Mark overall download job as paused so that future
-  // downloads are not started until resume. (Initially not a worry because only
-  // one download will be scheduled at a time).
+    GetDownloadService()->PauseDownload(download_guid);
 }
 
 void BackgroundFetchDelegateImpl::ResumeDownload(
@@ -549,20 +552,12 @@ void BackgroundFetchDelegateImpl::ResumeDownload(
     return;
 
   JobDetails& job_details = job_details_iter->second;
+  job_details.paused = false;
   for (auto& download_guid : job_details.current_download_guids)
     GetDownloadService()->ResumeDownload(download_guid);
 
-  // TODO(delphick): Start new downloads that weren't started because of pause.
-}
-
-void BackgroundFetchDelegateImpl::ResumeActiveJobs() {
-  DCHECK_EQ(GetDownloadService()->GetStatus(),
-            download::DownloadService::ServiceStatus::READY);
-
-  for (const auto& job_details : job_details_map_) {
-    for (const auto& download_guid : job_details.second.current_download_guids)
-      GetDownloadService()->ResumeDownload(download_guid);
-  }
+  if (job_details.on_resume)
+    std::move(job_details.on_resume).Run();
 }
 
 void BackgroundFetchDelegateImpl::GetItemById(
@@ -620,3 +615,53 @@ void BackgroundFetchDelegateImpl::AddObserver(Observer* observer) {
 void BackgroundFetchDelegateImpl::RemoveObserver(Observer* observer) {
   observers_.erase(observer);
 }
+
+bool BackgroundFetchDelegateImpl::IsGuidOutstanding(
+    const std::string& guid) const {
+  auto unique_id_it = download_job_unique_id_map_.find(guid);
+  if (unique_id_it == download_job_unique_id_map_.end())
+    return false;
+
+  auto job_details_it = job_details_map_.find(unique_id_it->second);
+  if (job_details_it == job_details_map_.end())
+    return false;
+
+  std::vector<std::string>& outstanding_guids =
+      job_details_it->second.fetch_description->outstanding_guids;
+  return std::find(outstanding_guids.begin(), outstanding_guids.end(), guid) !=
+         outstanding_guids.end();
+}
+
+void BackgroundFetchDelegateImpl::RestartPausedDownload(
+    const std::string& download_guid) {
+  auto job_it = download_job_unique_id_map_.find(download_guid);
+
+  if (job_it == download_job_unique_id_map_.end())
+    return;
+
+  const std::string& unique_id = job_it->second;
+
+  DCHECK(job_details_map_.find(unique_id) != job_details_map_.end());
+  JobDetails& job_details = job_details_map_.find(unique_id)->second;
+  job_details.paused = true;
+
+  UpdateOfflineItemAndUpdateObservers(&job_details);
+}
+
+std::set<std::string> BackgroundFetchDelegateImpl::TakeOutstandingGuids() {
+  std::set<std::string> outstanding_guids;
+  for (auto& job_id_details : job_details_map_) {
+    auto& job_details = job_id_details.second;
+
+    // If the job is loaded at this point, then it already started
+    // in a previous session.
+    job_details.started = true;
+
+    std::vector<std::string>& job_outstanding_guids =
+        job_details.fetch_description->outstanding_guids;
+    for (std::string& outstanding_guid : job_outstanding_guids)
+      outstanding_guids.insert(std::move(outstanding_guid));
+    job_outstanding_guids.clear();
+  }
+  return outstanding_guids;
+}
