@@ -7,32 +7,28 @@
 
 #include <memory>
 
+#include "base/callback_forward.h"
 #include "base/macros.h"
 #include "chrome/browser/bitmap_fetcher/bitmap_fetcher_delegate.h"
 #include "chrome/browser/image_decoder.h"
-#include "net/url_request/url_fetcher_delegate.h"
+#include "net/traffic_annotation/network_traffic_annotation.h"
 #include "net/url_request/url_request.h"
+#include "services/network/public/cpp/simple_url_loader.h"
+#include "services/network/public/mojom/url_loader_factory.mojom.h"
 #include "url/gurl.h"
 
 class SkBitmap;
 
-namespace net {
-class URLFetcher;
-class URLRequestContextGetter;
-}  // namespace net
-
-namespace chrome {
-
 // Asynchrounously fetches an image from the given URL and returns the
 // decoded Bitmap to the provided BitmapFetcherDelegate.
-class BitmapFetcher : public net::URLFetcherDelegate,
-                      public ImageDecoder::ImageRequest {
+class BitmapFetcher : public ImageDecoder::ImageRequest {
  public:
-  BitmapFetcher(const GURL& url, BitmapFetcherDelegate* delegate);
+  BitmapFetcher(const GURL& url,
+                BitmapFetcherDelegate* delegate,
+                const net::NetworkTrafficAnnotationTag& traffic_annotation);
   ~BitmapFetcher() override;
 
   const GURL& url() const { return url_; }
-  net::URLFetcher* url_fetcher() { return url_fetcher_.get(); }
 
   // Initializes internal fetcher.  After this function returns url_fetcher()
   // can be accessed to configure it further (eg. add user data to request).
@@ -40,8 +36,7 @@ class BitmapFetcher : public net::URLFetcherDelegate,
   // Values for |load_flags| are defined in net/base/load_flags.h.  In general,
   // |net::LOAD_NORMAL| is appropriate.  Init may be called more than once in
   // some cases.  If so, subsequent starts will be ignored.
-  void Init(net::URLRequestContextGetter* request_context,
-            const std::string& referrer,
+  void Init(const std::string& referrer,
             net::URLRequest::ReferrerPolicy referrer_policy,
             int load_flags);
 
@@ -49,13 +44,7 @@ class BitmapFetcher : public net::URLFetcherDelegate,
   // asynchronously when done.  Start may be called more than once in some
   // cases.  If so, subsequent starts will be ignored since the operation is
   // already in progress.
-  void Start();
-
-  // Methods inherited from URLFetcherDelegate
-
-  // This will be called when the URL has been fetched, successfully or not.
-  // Use accessor methods on |source| to get the results.
-  void OnURLFetchComplete(const net::URLFetcher* source) override;
+  void Start(network::mojom::URLLoaderFactory* loader_factory);
 
   // Methods inherited from ImageDecoder::ImageRequest
 
@@ -68,16 +57,18 @@ class BitmapFetcher : public net::URLFetcherDelegate,
   void OnDecodeImageFailed() override;
 
  private:
+  void OnSimpleLoaderComplete(std::unique_ptr<std::string> response_body);
+
   // Alerts the delegate that a failure occurred.
   void ReportFailure();
 
-  std::unique_ptr<net::URLFetcher> url_fetcher_;
+  std::unique_ptr<network::SimpleURLLoader> simple_loader_;
+
   const GURL url_;
   BitmapFetcherDelegate* const delegate_;
+  const net::NetworkTrafficAnnotationTag traffic_annotation_;
 
   DISALLOW_COPY_AND_ASSIGN(BitmapFetcher);
 };
 
-}  // namespace chrome
-
 #endif  // CHROME_BROWSER_BITMAP_FETCHER_BITMAP_FETCHER_H_
