@@ -55,6 +55,7 @@
 #include "chrome/browser/loader/chrome_resource_dispatcher_host_delegate.h"
 #include "chrome/browser/media/webrtc/webrtc_event_log_manager.h"
 #include "chrome/browser/media/webrtc/webrtc_log_uploader.h"
+#include "chrome/browser/metrics/chrome_feature_list_creator.h"
 #include "chrome/browser/metrics/chrome_metrics_service_accessor.h"
 #include "chrome/browser/metrics/chrome_metrics_services_manager_client.h"
 #include "chrome/browser/metrics/thread_watcher.h"
@@ -95,6 +96,7 @@
 #include "components/metrics/metrics_pref_names.h"
 #include "components/metrics/metrics_service.h"
 #include "components/metrics_services_manager/metrics_services_manager.h"
+#include "components/metrics_services_manager/metrics_services_manager_client.h"
 #include "components/net_log/chrome_net_log.h"
 #include "components/network_time/network_time_tracker.h"
 #include "components/optimization_guide/optimization_guide_service.h"
@@ -107,16 +109,18 @@
 #include "components/rappor/rappor_service_impl.h"
 #include "components/sessions/core/session_id_generator.h"
 #include "components/signin/core/browser/profile_management_switches.h"
-#include "components/subresource_filter/content/browser/content_ruleset_service.h"
-#include "components/subresource_filter/core/browser/ruleset_service.h"
+#include "components/subresource_filter/content/browser/ruleset_service.h"
 #include "components/subresource_filter/core/browser/subresource_filter_constants.h"
 #include "components/subresource_filter/core/browser/subresource_filter_features.h"
 #include "components/translate/core/browser/translate_download_manager.h"
 #include "components/ukm/ukm_service.h"
 #include "components/update_client/update_query_params.h"
+#include "components/variations/service/variations_service.h"
 #include "components/web_resource/web_resource_pref_names.h"
+#include "content/public/browser/browser_task_traits.h"
 #include "content/public/browser/browser_thread.h"
 #include "content/public/browser/child_process_security_policy.h"
+#include "content/public/browser/network_quality_observer_factory.h"
 #include "content/public/browser/network_service_instance.h"
 #include "content/public/browser/notification_details.h"
 #include "content/public/browser/plugin_service.h"
@@ -134,7 +138,7 @@
 #include "net/url_request/url_request_context_getter.h"
 #include "ppapi/buildflags/buildflags.h"
 #include "printing/buildflags/buildflags.h"
-#include "services/network/public/cpp/network_quality_tracker.h"
+#include "services/network/public/cpp/features.h"
 #include "services/network/public/cpp/network_switches.h"
 #include "services/preferences/public/cpp/in_process_service_factory.h"
 #include "ui/base/idle/idle.h"
@@ -166,6 +170,7 @@
 #endif
 
 #if BUILDFLAG(ENABLE_EXTENSIONS)
+#include "chrome/browser/apps/platform_apps/chrome_apps_browser_api_provider.h"
 #include "chrome/browser/extensions/chrome_extensions_browser_client.h"
 #include "chrome/browser/extensions/event_router_forwarder.h"
 #include "chrome/browser/media_galleries/media_file_system_registry.h"
@@ -216,11 +221,17 @@ rappor::RapporService* GetBrowserRapporService() {
 }
 
 BrowserProcessImpl::BrowserProcessImpl(
-    scoped_refptr<PersistentPrefStore> user_pref_store)
-    : user_pref_store_(std::move(user_pref_store)),
-      pref_service_factory_(
-          std::make_unique<prefs::InProcessPrefServiceFactory>()) {
+    ChromeFeatureListCreator* chrome_feature_list_creator)
+    : chrome_feature_list_creator_(chrome_feature_list_creator) {
   g_browser_process = this;
+
+  DCHECK(chrome_feature_list_creator_);
+  browser_policy_connector_ =
+      chrome_feature_list_creator_->TakeChromeBrowserPolicyConnector();
+  created_browser_policy_connector_ = true;
+  pref_service_factory_ =
+      chrome_feature_list_creator_->TakePrefServiceFactory();
+
   platform_part_ = std::make_unique<BrowserProcessPlatformPart>();
   // Most work should be done in Init().
 }
@@ -265,6 +276,8 @@ void BrowserProcessImpl::Init() {
 
   extensions_browser_client_ =
       std::make_unique<extensions::ChromeExtensionsBrowserClient>();
+  extensions_browser_client_->AddAPIProvider(
+      std::make_unique<chrome_apps::ChromeAppsBrowserAPIProvider>());
   extensions::ExtensionsBrowserClient::Set(extensions_browser_client_.get());
 #endif
 
@@ -311,17 +324,15 @@ void BrowserProcessImpl::Init() {
 #if !defined(OS_ANDROID)
 void BrowserProcessImpl::SetQuitClosure(base::OnceClosure quit_closure) {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+  DCHECK(quit_closure);
   DCHECK(!quit_closure_);
   quit_closure_ = std::move(quit_closure);
 }
 #endif
 
 #if defined(OS_MACOSX)
-base::OnceClosure BrowserProcessImpl::SwapQuitClosure(
-    base::OnceClosure quit_closure) {
-  DCHECK(quit_closure);
-  std::swap(quit_closure, quit_closure_);
-  return quit_closure;
+void BrowserProcessImpl::ClearQuitClosure() {
+  quit_closure_.Reset();
 }
 #endif
 
@@ -438,7 +449,7 @@ void BrowserProcessImpl::StartTearDown() {
     local_state_->CommitPendingWrite();
 
   // This expects to be destroyed before the task scheduler is torn down.
-  system_network_context_manager_.reset();
+  SystemNetworkContextManager::DeleteInstance();
 }
 
 void BrowserProcessImpl::PostDestroyThreads() {
@@ -459,6 +470,15 @@ void BrowserProcessImpl::PostDestroyThreads() {
 }
 #endif  // !defined(OS_ANDROID)
 
+void BrowserProcessImpl::SetMetricsServices(
+    std::unique_ptr<metrics_services_manager::MetricsServicesManager> manager,
+    metrics_services_manager::MetricsServicesManagerClient* client) {
+  metrics_services_manager_ = std::move(manager);
+  metrics_services_manager_client_ =
+      static_cast<ChromeMetricsServicesManagerClient*>(client);
+  metrics_services_manager_->GetVariationsService()->OverrideCachedUIStrings();
+}
+
 namespace {
 
 // Used at the end of session to block the UI thread for completion of sentinel
@@ -534,8 +554,8 @@ void RequestProxyResolvingSocketFactoryOnUIThread(
 
 void RequestProxyResolvingSocketFactory(
     network::mojom::ProxyResolvingSocketFactoryRequest request) {
-  BrowserThread::PostTask(
-      BrowserThread::UI, FROM_HERE,
+  base::PostTaskWithTraits(
+      FROM_HERE, {BrowserThread::UI},
       base::BindOnce(&RequestProxyResolvingSocketFactoryOnUIThread,
                      std::move(request)));
 }
@@ -641,8 +661,8 @@ IOThread* BrowserProcessImpl::io_thread() {
 SystemNetworkContextManager*
 BrowserProcessImpl::system_network_context_manager() {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
-  DCHECK(system_network_context_manager_.get());
-  return system_network_context_manager_.get();
+  DCHECK(SystemNetworkContextManager::GetInstance());
+  return SystemNetworkContextManager::GetInstance();
 }
 
 scoped_refptr<network::SharedURLLoaderFactory>
@@ -828,16 +848,14 @@ const std::string& BrowserProcessImpl::GetApplicationLocale() {
   return locale_;
 }
 
-void BrowserProcessImpl::SetApplicationLocale(const std::string& locale) {
+void BrowserProcessImpl::SetApplicationLocale(
+    const std::string& actual_locale) {
   // NOTE: this is called before any threads have been created in non-test
   // environments.
-  locale_ = locale;
-#if BUILDFLAG(ENABLE_EXTENSIONS)
-  extension_l10n_util::SetProcessLocale(locale);
-#endif
-  ChromeContentBrowserClient::SetApplicationLocale(locale);
+  locale_ = actual_locale;
+  ChromeContentBrowserClient::SetApplicationLocale(actual_locale);
   translate::TranslateDownloadManager::GetInstance()->set_application_locale(
-      locale);
+      actual_locale);
 }
 
 DownloadStatusUpdater* BrowserProcessImpl::download_status_updater() {
@@ -1075,6 +1093,12 @@ void BrowserProcessImpl::ResourceDispatcherHostCreated() {
   ApplyAllowCrossOriginAuthPromptPolicy();
 }
 
+std::string BrowserProcessImpl::actual_locale() {
+  return chrome_feature_list_creator_
+             ? chrome_feature_list_creator_->actual_locale()
+             : std::string();
+}
+
 void BrowserProcessImpl::OnKeepAliveStateChanged(bool is_keeping_alive) {
   if (is_keeping_alive)
     Pin();
@@ -1082,6 +1106,13 @@ void BrowserProcessImpl::OnKeepAliveStateChanged(bool is_keeping_alive) {
     Unpin();
 }
 
+void BrowserProcessImpl::CreateNetworkQualityObserver() {
+  DCHECK(!network_quality_observer_);
+  network_quality_observer_ =
+      content::CreateNetworkQualityObserver(network_quality_tracker());
+  DCHECK(network_quality_observer_);
+}
+
 void BrowserProcessImpl::OnKeepAliveRestartStateChanged(bool can_restart) {}
 
 void BrowserProcessImpl::CreateWatchdogThread() {
@@ -1108,21 +1139,8 @@ void BrowserProcessImpl::CreateProfileManager() {
 void BrowserProcessImpl::CreateLocalState() {
   DCHECK(!local_state_);
 
-  base::FilePath local_state_path;
-  CHECK(base::PathService::Get(chrome::FILE_LOCAL_STATE, &local_state_path));
-  auto pref_registry = base::MakeRefCounted<PrefRegistrySimple>();
-
-  // Register local state preferences.
-  RegisterLocalState(pref_registry.get());
-
-  auto delegate = pref_service_factory_->CreateDelegate();
-  delegate->InitPrefRegistry(pref_registry.get());
-  local_state_ = chrome_prefs::CreateLocalState(
-      local_state_path, policy_service(), std::move(pref_registry), false,
-      std::move(delegate), std::move(user_pref_store_));
+  local_state_ = chrome_feature_list_creator_->TakePrefService();
   DCHECK(local_state_);
-
-  sessions::SessionIdGenerator::GetInstance()->Init(local_state_.get());
 }
 
 void BrowserProcessImpl::PreCreateThreads(
@@ -1134,7 +1152,8 @@ void BrowserProcessImpl::PreCreateThreads(
       extensions::kExtensionScheme, true);
 #endif
 
-  if (command_line.HasSwitch(network::switches::kLogNetLog)) {
+  if (command_line.HasSwitch(network::switches::kLogNetLog) &&
+      !base::FeatureList::IsEnabled(network::features::kNetworkService)) {
     base::FilePath log_file =
         command_line.GetSwitchValuePath(network::switches::kLogNetLog);
     if (log_file.empty()) {
@@ -1152,12 +1171,12 @@ void BrowserProcessImpl::PreCreateThreads(
   // Must be created before the IOThread.
   // TODO(mmenke): Once IOThread class is no longer needed (not the thread
   // itself), this can be created on first use.
-  system_network_context_manager_ =
-      std::make_unique<SystemNetworkContextManager>();
+  if (!SystemNetworkContextManager::GetInstance())
+    SystemNetworkContextManager::CreateInstance(local_state_.get());
   io_thread_ = std::make_unique<IOThread>(
       local_state(), policy_service(), net_log_.get(),
       extension_event_router_forwarder(),
-      system_network_context_manager_.get());
+      SystemNetworkContextManager::GetInstance());
 }
 
 void BrowserProcessImpl::PreMainMessageLoopRun() {
@@ -1214,6 +1233,8 @@ void BrowserProcessImpl::PreMainMessageLoopRun() {
         base::WrapUnique(new base::DefaultTickClock()), local_state(),
         system_network_context_manager()->GetSharedURLLoaderFactory());
   }
+
+  CreateNetworkQualityObserver();
 }
 
 void BrowserProcessImpl::CreateIconManager() {
@@ -1334,8 +1355,8 @@ void BrowserProcessImpl::CreateOptimizationGuideService() {
 
   optimization_guide_service_ =
       std::make_unique<optimization_guide::OptimizationGuideService>(
-          content::BrowserThread::GetTaskRunnerForThread(
-              content::BrowserThread::IO));
+          base::CreateSingleThreadTaskRunnerWithTraits(
+              {content::BrowserThread::IO}));
 }
 
 void BrowserProcessImpl::CreateGCMDriver() {
@@ -1359,11 +1380,12 @@ void BrowserProcessImpl::CreateGCMDriver() {
       base::WrapUnique(new gcm::GCMClientFactory), local_state(), store_path,
       base::BindRepeating(&RequestProxyResolvingSocketFactory),
       system_network_context_manager()->GetSharedURLLoaderFactory(),
-      chrome::GetChannel(), gcm::GetProductCategoryForSubtypes(local_state()),
-      content::BrowserThread::GetTaskRunnerForThread(
-          content::BrowserThread::UI),
-      content::BrowserThread::GetTaskRunnerForThread(
-          content::BrowserThread::IO),
+      content::GetNetworkConnectionTracker(), chrome::GetChannel(),
+      gcm::GetProductCategoryForSubtypes(local_state()),
+      base::CreateSingleThreadTaskRunnerWithTraits(
+          {content::BrowserThread::UI}),
+      base::CreateSingleThreadTaskRunnerWithTraits(
+          {content::BrowserThread::IO}),
       blocking_task_runner);
 #endif  // defined(OS_ANDROID)
 }
@@ -1425,6 +1447,15 @@ void BrowserProcessImpl::Pin() {
 
 void BrowserProcessImpl::Unpin() {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+
+#if !defined(OS_ANDROID)
+  // The quit closure is set by ChromeBrowserMainParts to transfer ownership of
+  // the browser's lifetime to the BrowserProcess. Any KeepAlives registered and
+  // unregistered prior to setting the quit closure are ignored. Only once the
+  // quit closure is set should unpinning start process shutdown.
+  if (!quit_closure_)
+    return;
+#endif
   release_last_reference_callstack_ = base::debug::StackTrace();
 
   DCHECK(!shutting_down_);
