@@ -12,10 +12,10 @@
 #include "chrome/browser/browser_process_platform_part_android.h"
 #elif defined(OS_CHROMEOS)
 #include "chrome/browser/browser_process_platform_part_chromeos.h"
-#elif defined(OS_MACOSX) && !defined(OS_IOS)
+#elif defined(OS_MACOSX)
 #include "chrome/browser/browser_process_platform_part_mac.h"
 #elif defined(OS_WIN)
-#include "chrome/browser/browser_process_platform_part_aurawin.h"
+#include "chrome/browser/browser_process_platform_part_win.h"
 #else
 #include "chrome/browser/browser_process_platform_part_base.h"
 typedef BrowserProcessPlatformPartBase BrowserProcessPlatformPart;
