@@ -6,10 +6,9 @@
 
 #include "base/android/memory_pressure_listener_android.h"
 #include "chrome/browser/lifetime/application_lifetime_android.h"
-#include "chrome/browser/memory_purger.h"
 
 BrowserProcessPlatformPart::BrowserProcessPlatformPart() {
-  base::android::MemoryPressureListenerAndroid::RegisterSystemCallback(
+  base::android::MemoryPressureListenerAndroid::Initialize(
       base::android::AttachCurrentThread());
 }
 
