@@ -5,7 +5,6 @@
 #include "chrome/browser/browser_process_platform_part_mac.h"
 
 #include "chrome/browser/chrome_browser_application_mac.h"
-#include "chrome/browser/ui/app_list/app_list_service.h"
 
 BrowserProcessPlatformPart::BrowserProcessPlatformPart() {
 }
@@ -27,12 +26,8 @@ void BrowserProcessPlatformPart::AttemptExit() {
 void BrowserProcessPlatformPart::PreMainMessageLoopRun() {
   // AppShimHostManager can not simply be reset, otherwise destroying the old
   // domain socket will cause the just-created socket to be unlinked.
-  DCHECK(!app_shim_host_manager_);
+  DCHECK(!app_shim_host_manager_.get());
   app_shim_host_manager_ = new AppShimHostManager;
-  // Init needs to be called after assigning to a scoped_refptr (i.e. after
-  // incrementing the refcount).
-  app_shim_host_manager_->Init();
-  AppListService::InitAll(NULL);
 }
 
 AppShimHostManager* BrowserProcessPlatformPart::app_shim_host_manager() {
