@@ -8,10 +8,11 @@
 #include "base/run_loop.h"
 #include "base/time/time.h"
 #include "chrome/test/base/testing_profile.h"
+#include "content/public/browser/storage_partition.h"
 #include "content/public/test/test_browser_thread_bundle.h"
 #include "net/cookies/canonical_cookie.h"
 #include "net/cookies/cookie_options.h"
-#include "net/url_request/url_request_context_getter.h"
+#include "services/network/public/mojom/cookie_manager.mojom.h"
 #include "testing/gtest/include/gtest/gtest.h"
 
 namespace {
@@ -93,8 +94,8 @@ class BrowsingDataCookieHelperTest : public testing::Test {
     // For each cookie, look for a matching expectation.
     for (const auto& cookie : cookie_list_) {
       CookieMatcher matcher(cookie);
-      std::vector<CookieExpectation>::iterator match = std::find_if(
-          cookie_expectations_.begin(), cookie_expectations_.end(), matcher);
+      auto match = std::find_if(cookie_expectations_.begin(),
+                                cookie_expectations_.end(), matcher);
       if (match != cookie_expectations_.end())
         match->matched_ = true;
     }
@@ -109,23 +110,39 @@ class BrowsingDataCookieHelperTest : public testing::Test {
   }
 
   void CreateCookiesForTest() {
-    net::CookieStore* cookie_store = testing_profile_->GetCookieStore();
-    cookie_store->SetCookieWithOptionsAsync(
-        GURL("http://www.google.com"), "A=1", net::CookieOptions(),
-        net::CookieMonster::SetCookiesCallback());
-    cookie_store->SetCookieWithOptionsAsync(
-        GURL("http://www.gmail.google.com"), "B=1", net::CookieOptions(),
-        net::CookieMonster::SetCookiesCallback());
+    auto cookie1 =
+        net::CanonicalCookie::Create(GURL("http://www.google.com"), "A=1",
+                                     base::Time::Now(), net::CookieOptions());
+    auto cookie2 =
+        net::CanonicalCookie::Create(GURL("http://www.gmail.google.com"), "B=1",
+                                     base::Time::Now(), net::CookieOptions());
+
+    network::mojom::CookieManager* cookie_manager =
+        storage_partition()->GetCookieManagerForBrowserProcess();
+    cookie_manager->SetCanonicalCookie(*cookie1, true /* secure_source */,
+                                       false /* modify_http_only */,
+                                       base::DoNothing());
+    cookie_manager->SetCanonicalCookie(*cookie2, true /* secure_source */,
+                                       false /* modify_http_only */,
+                                       base::DoNothing());
   }
 
   void CreateCookiesForDomainCookieTest() {
-    net::CookieStore* cookie_store = testing_profile_->GetCookieStore();
-    cookie_store->SetCookieWithOptionsAsync(
-        GURL("http://www.google.com"), "A=1", net::CookieOptions(),
-        net::CookieMonster::SetCookiesCallback());
-    cookie_store->SetCookieWithOptionsAsync(
+    auto cookie1 =
+        net::CanonicalCookie::Create(GURL("http://www.google.com"), "A=1",
+                                     base::Time::Now(), net::CookieOptions());
+    auto cookie2 = net::CanonicalCookie::Create(
         GURL("http://www.google.com"), "A=2; Domain=.www.google.com ",
-        net::CookieOptions(), net::CookieMonster::SetCookiesCallback());
+        base::Time::Now(), net::CookieOptions());
+
+    network::mojom::CookieManager* cookie_manager =
+        storage_partition()->GetCookieManagerForBrowserProcess();
+    cookie_manager->SetCanonicalCookie(*cookie1, true /* secure_source */,
+                                       false /* modify_http_only */,
+                                       base::DoNothing());
+    cookie_manager->SetCanonicalCookie(*cookie2, true /* secure_source */,
+                                       false /* modify_http_only */,
+                                       base::DoNothing());
   }
 
   void FetchCallback(const net::CookieList& cookies) {
