@@ -19,18 +19,20 @@
 #include "chrome/browser/browsing_data/browsing_data_quota_helper.h"
 #include "third_party/blink/public/mojom/quota/quota_types.mojom.h"
 
-class GURL;
-
 namespace storage {
 class QuotaManager;
 }
 
+namespace url {
+class Origin;
+}
+
 // Implementation of BrowsingDataQuotaHelper.  Since a client of
 // BrowsingDataQuotaHelper should live in UI thread and QuotaManager lives in
 // IO thread, we have to communicate over thread using PostTask.
 class BrowsingDataQuotaHelperImpl : public BrowsingDataQuotaHelper {
  public:
-  void StartFetching(const FetchResultCallback& callback) override;
+  void StartFetching(FetchResultCallback callback) override;
   void RevokeHostQuota(const std::string& host) override;
 
  private:
@@ -42,27 +44,27 @@ class BrowsingDataQuotaHelperImpl : public BrowsingDataQuotaHelper {
   ~BrowsingDataQuotaHelperImpl() override;
 
   // Calls QuotaManager::GetOriginModifiedSince for each storage type.
-  void FetchQuotaInfoOnIOThread(const FetchResultCallback& callback);
+  void FetchQuotaInfoOnIOThread(FetchResultCallback callback);
 
   // Callback function for QuotaManager::GetOriginModifiedSince.
   void GotOrigins(PendingHosts* pending_hosts,
-                  const base::Closure& completion,
-                  const std::set<GURL>& origins,
+                  base::OnceClosure completion,
+                  const std::set<url::Origin>& origins,
                   blink::mojom::StorageType type);
 
   // Calls QuotaManager::GetHostUsage for each (origin, type) pair.
-  void OnGetOriginsComplete(const FetchResultCallback& callback,
+  void OnGetOriginsComplete(FetchResultCallback callback,
                             PendingHosts* pending_hosts);
 
   // Callback function for QuotaManager::GetHostUsage.
   void GotHostUsage(QuotaInfoMap* quota_info,
-                    const base::Closure& completion,
+                    base::OnceClosure completion,
                     const std::string& host,
                     blink::mojom::StorageType type,
                     int64_t usage);
 
   // Called when all QuotaManager::GetHostUsage requests are complete.
-  void OnGetHostsUsageComplete(const FetchResultCallback& callback,
+  void OnGetHostsUsageComplete(FetchResultCallback callback,
                                QuotaInfoMap* quota_info);
 
   void RevokeHostQuotaOnIOThread(const std::string& host);
