@@ -11,6 +11,10 @@
 
 class Profile;
 
+// Whether the exception about not being signed out of your Google profile
+// should be shown.
+bool ShouldShowCookieException(Profile* profile);
+
 // Constructs the text to be displayed by a counter from the given |result|.
 base::string16 GetChromeCounterTextFromResult(
     const browsing_data::BrowsingDataCounter::Result* result,
