@@ -12,11 +12,12 @@
 #include "chrome/browser/browsing_data/browsing_data_cookie_helper.h"
 #include "net/cookies/canonical_cookie.h"
 
+class Profile;
+
 // Mock for BrowsingDataCookieHelper.
 class MockBrowsingDataCookieHelper : public BrowsingDataCookieHelper {
  public:
-  explicit MockBrowsingDataCookieHelper(
-      net::URLRequestContextGetter* request_context_getter);
+  explicit MockBrowsingDataCookieHelper(Profile* profile);
 
   // BrowsingDataCookieHelper methods.
   void StartFetching(const FetchCallback& callback) override;
