@@ -27,29 +27,30 @@ void MockBrowsingDataFileSystemHelper::DeleteFileSystemOrigin(
     const GURL& origin) {
   ASSERT_FALSE(callback_.is_null());
   std::string key = origin.spec();
-  ASSERT_TRUE(ContainsKey(file_systems_, key));
+  ASSERT_TRUE(base::ContainsKey(file_systems_, key));
   last_deleted_origin_ = origin;
   file_systems_[key] = false;
 }
 
 void MockBrowsingDataFileSystemHelper::AddFileSystem(
     const GURL& origin, bool has_persistent, bool has_temporary,
-    bool has_syncable) {
+    bool has_syncable, int64_t size_persistent, int64_t size_temporary,
+    int64_t size_syncable) {
   BrowsingDataFileSystemHelper::FileSystemInfo info(origin);
   if (has_persistent)
-    info.usage_map[storage::kFileSystemTypePersistent] = 0;
+    info.usage_map[storage::kFileSystemTypePersistent] = size_persistent;
   if (has_temporary)
-    info.usage_map[storage::kFileSystemTypeTemporary] = 0;
+    info.usage_map[storage::kFileSystemTypeTemporary] = size_temporary;
   if (has_syncable)
-    info.usage_map[storage::kFileSystemTypeSyncable] = 0;
+    info.usage_map[storage::kFileSystemTypeSyncable] = size_syncable;
   response_.push_back(info);
   file_systems_[origin.spec()] = true;
 }
 
 void MockBrowsingDataFileSystemHelper::AddFileSystemSamples() {
-  AddFileSystem(GURL("http://fshost1:1/"), false, true, false);
-  AddFileSystem(GURL("http://fshost2:2/"), true, false, true);
-  AddFileSystem(GURL("http://fshost3:3/"), true, true, true);
+  AddFileSystem(GURL("http://fshost1:1/"), false, true, false, 0, 1, 0);
+  AddFileSystem(GURL("http://fshost2:2/"), true, false, true, 2, 0, 2);
+  AddFileSystem(GURL("http://fshost3:3/"), true, true, true, 3, 3, 3);
 }
 
 void MockBrowsingDataFileSystemHelper::Notify() {
