@@ -14,20 +14,19 @@
 #include "chrome/browser/first_run/first_run.h"
 #include "chrome/browser/process_singleton.h"
 #include "chrome/browser/ui/startup/startup_browser_creator.h"
-#include "chrome/common/thread_profiler.h"
 #include "content/public/browser/browser_main_parts.h"
 #include "content/public/common/main_function_params.h"
-#include "ui/base/resource/data_pack.h"
 
 class BrowserProcessImpl;
 class ChromeBrowserMainExtraParts;
 class ChromeFeatureListCreator;
-class FieldTrialSynchronizer;
+class HeapProfilerController;
 class PrefService;
 class Profile;
 class StartupBrowserCreator;
 class StartupTimeBomb;
 class ShutdownWatcherHelper;
+class ThreadProfiler;
 class WebUsbDetector;
 
 namespace chrome_browser {
@@ -57,11 +56,9 @@ class ChromeBrowserMainParts : public content::BrowserMainParts {
 
  protected:
   ChromeBrowserMainParts(const content::MainFunctionParams& parameters,
-                         std::unique_ptr<ui::DataPack> data_pack,
                          ChromeFeatureListCreator* chrome_feature_list_creator);
 
   // content::BrowserMainParts overrides.
-  bool ShouldContentCreateFeatureList() override;
   // These are called in-order by content::BrowserMainLoop.
   // Each stage calls the same stages in any ChromeBrowserMainExtraParts added
   // with AddParts() from ChromeContentBrowserClient::CreateBrowserMainParts.
@@ -105,10 +102,6 @@ class ChromeBrowserMainParts : public content::BrowserMainParts {
  private:
   friend class ChromeBrowserMainPartsTestApi;
 
-  // Sets up the field trials and related initialization. Call only after
-  // about:flags have been converted to switches.
-  void SetupFieldTrials();
-
   // Constructs the metrics service and initializes metrics recording.
   void SetupMetrics();
 
@@ -123,12 +116,12 @@ class ChromeBrowserMainParts : public content::BrowserMainParts {
   // for child processes.
   void SetupOriginTrialsCommandLine(PrefService* local_state);
 
-  // Calling during PreEarlyInitialization() to load local state. Return value
-  // is an exit status, RESULT_CODE_NORMAL_EXIT indicates success.
-  // If the return value is RESULT_CODE_MISSING_DATA, then
-  // |failed_to_load_resource_bundle| indicates if the ResourceBundle couldn't
-  // be loaded.
-  int LoadLocalState(bool* failed_to_load_resource_bundle);
+  // Calling during PreEarlyInitialization() to complete the remaining tasks
+  // after the local state is loaded. Return value is an exit status,
+  // RESULT_CODE_NORMAL_EXIT indicates success. If the return value is
+  // RESULT_CODE_MISSING_DATA, then |failed_to_load_resource_bundle| indicates
+  // if the ResourceBundle couldn't be loaded.
+  int OnLocalStateLoaded(bool* failed_to_load_resource_bundle);
 
   // Applies any preferences (to local state) needed for first run. This is
   // always called and early outs if not first-run. Return value is an exit
@@ -169,6 +162,10 @@ class ChromeBrowserMainParts : public content::BrowserMainParts {
   // A profiler that periodically samples stack traces on the UI thread.
   std::unique_ptr<ThreadProfiler> ui_thread_profiler_;
 
+  // The controller schedules UMA heap profiles collections and forwarding down
+  // the reporting pipeline.
+  std::unique_ptr<HeapProfilerController> heap_profiler_controller_;
+
   // Whether PerformPreMainMessageLoopStartup() is called on VariationsService.
   // Initialized to true if |MainFunctionParams::ui_task| is null (meaning not
   // running browser_tests), but may be forced to true for tests.
@@ -186,28 +183,24 @@ class ChromeBrowserMainParts : public content::BrowserMainParts {
   // ProcessSingleton.
   std::unique_ptr<ChromeProcessSingleton> process_singleton_;
 
-  // Android's first run is done in Java instead of native.
-  std::unique_ptr<first_run::MasterPrefs> master_prefs_;
-
   ProcessSingleton::NotifyResult notify_result_ =
       ProcessSingleton::PROCESS_NONE;
 
   // Members needed across shutdown methods.
   bool restart_last_session_ = false;
+#endif  // !defined(OS_ANDROID)
+
+#if !defined(OS_ANDROID) && !defined(OS_CHROMEOS)
+  // Android's first run is done in Java instead of native. Chrome OS does not
+  // use master preferences.
+  std::unique_ptr<first_run::MasterPrefs> master_prefs_;
 #endif
 
   Profile* profile_;
   bool run_message_loop_;
 
-  // Initialized in |SetupFieldTrials()|.
-  scoped_refptr<FieldTrialSynchronizer> field_trial_synchronizer_;
-
   base::FilePath user_data_dir_;
 
-  // This is used to store the ui data pack. The data pack is moved when
-  // resource bundle gets created.
-  std::unique_ptr<ui::DataPack> service_manifest_data_pack_;
-
   ChromeFeatureListCreator* chrome_feature_list_creator_;
 
   DISALLOW_COPY_AND_ASSIGN(ChromeBrowserMainParts);
