@@ -18,8 +18,9 @@
 #include "chrome/grit/chromium_strings.h"
 #include "components/crash/content/app/breakpad_linux.h"
 #include "components/metrics/metrics_service.h"
+#include "content/public/browser/browser_task_traits.h"
 #include "device/bluetooth/dbus/bluez_dbus_manager.h"
-#include "device/bluetooth/dbus/dbus_thread_manager_linux.h"
+#include "device/bluetooth/dbus/bluez_dbus_thread_manager.h"
 #include "media/audio/audio_manager.h"
 #include "ui/base/l10n/l10n_util.h"
 
@@ -35,10 +36,8 @@
 
 ChromeBrowserMainPartsLinux::ChromeBrowserMainPartsLinux(
     const content::MainFunctionParams& parameters,
-    std::unique_ptr<ui::DataPack> data_pack,
     ChromeFeatureListCreator* chrome_feature_list_creator)
     : ChromeBrowserMainPartsPosix(parameters,
-                                  std::move(data_pack),
                                   chrome_feature_list_creator) {}
 
 ChromeBrowserMainPartsLinux::~ChromeBrowserMainPartsLinux() {
@@ -76,8 +75,8 @@ void ChromeBrowserMainPartsLinux::PreProfileInit() {
   // Forward the product name
   config->product_name = l10n_util::GetStringUTF8(IDS_PRODUCT_NAME);
   // OSCrypt may target keyring, which requires calls from the main thread.
-  config->main_thread_runner = content::BrowserThread::GetTaskRunnerForThread(
-      content::BrowserThread::UI);
+  config->main_thread_runner = base::CreateSingleThreadTaskRunnerWithTraits(
+      {content::BrowserThread::UI});
   // OSCrypt can be disabled in a special settings file.
   config->should_use_preference =
       parsed_command_line().HasSwitch(switches::kEnableEncryptionSelection);
@@ -97,9 +96,8 @@ void ChromeBrowserMainPartsLinux::PostProfileInit() {
 
 void ChromeBrowserMainPartsLinux::PostMainMessageLoopStart() {
 #if !defined(OS_CHROMEOS)
-  bluez::DBusThreadManagerLinux::Initialize();
-  bluez::BluezDBusManager::Initialize(
-      bluez::DBusThreadManagerLinux::Get()->GetSystemBus(), false);
+  bluez::BluezDBusThreadManager::Initialize();
+  bluez::BluezDBusManager::Initialize();
 #endif
 
   ChromeBrowserMainPartsPosix::PostMainMessageLoopStart();
@@ -108,7 +106,7 @@ void ChromeBrowserMainPartsLinux::PostMainMessageLoopStart() {
 void ChromeBrowserMainPartsLinux::PostDestroyThreads() {
 #if !defined(OS_CHROMEOS)
   bluez::BluezDBusManager::Shutdown();
-  bluez::DBusThreadManagerLinux::Shutdown();
+  bluez::BluezDBusThreadManager::Shutdown();
 #endif
 
   ChromeBrowserMainPartsPosix::PostDestroyThreads();
