@@ -6,7 +6,7 @@
 #define CHROME_BROWSER_CHROME_NOTIFICATION_TYPES_H_
 
 #include "build/build_config.h"
-#include "extensions/features/features.h"
+#include "extensions/buildflags/buildflags.h"
 
 #if BUILDFLAG(ENABLE_EXTENSIONS)
 #include "extensions/browser/notification_types.h"
@@ -20,11 +20,19 @@
 #define PREVIOUS_END content::NOTIFICATION_CONTENT_END
 #endif
 
+// **
+// ** NOTICE
+// **
+// ** The notification system is deprecated, obsolete, and is slowly being
+// ** removed. See https://crbug.com/268984.
+// **
+// ** Please don't add any new notification types, and please help migrate
+// ** existing uses of the notification types below to use the Observer and
+// ** Callback patterns.
+// **
+
 namespace chrome {
 
-// NotificationService &c. are deprecated (https://crbug.com/268984).
-// Don't add any new notification types, and migrate existing uses of the
-// notification types below to observers.
 enum NotificationType {
   NOTIFICATION_CHROME_START = PREVIOUS_END,
 
@@ -33,21 +41,12 @@ enum NotificationType {
   // This message is sent after a window has been opened.  The source is a
   // Source<Browser> containing the affected Browser.  No details are
   // expected.
+  // DEPRECATED: Use BrowserListObserver::OnBrowserAdded()
   NOTIFICATION_BROWSER_OPENED = NOTIFICATION_CHROME_START,
 
-  // This message is sent soon after BROWSER_OPENED, and indicates that
-  // the Browser's |window_| is now non-NULL. The source is a Source<Browser>
-  // containing the affected Browser.  No details are expected.
-  NOTIFICATION_BROWSER_WINDOW_READY,
-
-  // This message is sent when a browser is closing. The source is a
-  // Source<Browser> containing the affected Browser. No details are expected.
-  // This is sent prior to BROWSER_CLOSED, and may be sent more than once for a
-  // particular browser.
-  NOTIFICATION_BROWSER_CLOSING,
-
   // This message is sent after a window has been closed.  The source is a
-  // Source<Browser> containing the affected Browser.  No details are exptected.
+  // Source<Browser> containing the affected Browser.  No details are expected.
+  // DEPRECATED: Use BrowserListObserver::OnBrowserRemoved()
   NOTIFICATION_BROWSER_CLOSED,
 
   // This message is sent when closing a browser has been cancelled, either by
@@ -73,22 +72,10 @@ enum NotificationType {
   // Source<ThemeService>. There are no details.
   NOTIFICATION_BROWSER_THEME_CHANGED,
 
-#if defined(USE_AURA)
-  // The user has changed the fling curve configuration.
-  // Source<GesturePrefsObserver>. There are no details.
-  NOTIFICATION_BROWSER_FLING_CURVE_PARAMETERS_CHANGED,
-#endif  // defined(USE_AURA)
-
   // Sent when the renderer returns focus to the browser, as part of focus
   // traversal. The source is the browser, there are no details.
   NOTIFICATION_FOCUS_RETURNED_TO_BROWSER,
 
-  // A new tab is created from an existing tab to serve as a target of a
-  // navigation that is about to happen. The source will be a Source<Profile>
-  // corresponding to the profile in which the new tab will live.  Details in
-  // the form of a RetargetingDetails object are provided.
-  NOTIFICATION_RETARGETING,
-
   // Application-wide ----------------------------------------------------------
 
   // This message is sent when the application is terminating (the last
@@ -116,25 +103,6 @@ enum NotificationType {
   // handler.  Use APP_TERMINATING for such needs.
   NOTIFICATION_CLOSE_ALL_BROWSERS_REQUEST,
 
-  // This message is sent when a new InfoBar has been added to an
-  // InfoBarService.  The source is a Source<InfoBarService> with a pointer to
-  // the InfoBarService the InfoBar was added to.  The details is a
-  // Details<InfoBar::AddedDetails>.
-  NOTIFICATION_TAB_CONTENTS_INFOBAR_ADDED,
-
-  // This message is sent when an InfoBar is about to be removed from an
-  // InfoBarService.  The source is a Source<InfoBarService> with a pointer to
-  // the InfoBarService the InfoBar was removed from.  The details is a
-  // Details<InfoBar::RemovedDetails>.
-  NOTIFICATION_TAB_CONTENTS_INFOBAR_REMOVED,
-
-#if BUILDFLAG(ENABLE_EXTENSIONS)
-  // This notification is sent when extensions::TabHelper::SetExtensionApp is
-  // invoked. The source is the extensions::TabHelper SetExtensionApp was
-  // invoked on.
-  NOTIFICATION_TAB_CONTENTS_APPLICATION_EXTENSION_CHANGED,
-#endif
-
   // Tabs --------------------------------------------------------------------
 
   // Sent when a tab is added to a WebContentsDelegate. The source is the
@@ -252,11 +220,6 @@ enum NotificationType {
 
   // Non-history storage services --------------------------------------------
 
-  // A safe browsing database update completed.  Source is the
-  // SafeBrowsingService and the details are a bool indicating whether the
-  // update was successful.
-  NOTIFICATION_SAFE_BROWSING_UPDATE_COMPLETE,
-
   // Autocomplete ------------------------------------------------------------
 
   // Sent by the autocomplete controller when done.  The source is the
@@ -277,24 +240,6 @@ enum NotificationType {
   // Source is the WebContents that holds the print job.
   NOTIFICATION_PRINT_JOB_RELEASED,
 
-  // Upgrade notifications ---------------------------------------------------
-
-  // Sent when Chrome believes an update has been installed and available for
-  // long enough with the user shutting down to let it take effect. See
-  // upgrade_detector.cc for details on how long it waits. No details are
-  // expected.
-  NOTIFICATION_UPGRADE_RECOMMENDED,
-
-  // Sent when a critical update has been installed. No details are expected.
-  NOTIFICATION_CRITICAL_UPGRADE_INSTALLED,
-
-  // Sent when the current install is outdated. No details are expected.
-  NOTIFICATION_OUTDATED_INSTALL,
-
-  // Sent when the current install is outdated and auto-update (AU) is disabled.
-  // No details are expected.
-  NOTIFICATION_OUTDATED_INSTALL_NO_AU,
-
   // Content Settings --------------------------------------------------------
 
   // Sent when the collect cookies dialog is shown. The source is a
@@ -305,13 +250,6 @@ enum NotificationType {
   // content::WebContents object, the details are None.
   NOTIFICATION_WEB_CONTENT_SETTINGS_CHANGED,
 
-  // Sync --------------------------------------------------------------------
-
-  // The session service has been saved.  This notification type is only sent
-  // if there were new SessionService commands to save, and not for no-op save
-  // operations.
-  NOTIFICATION_SESSION_SERVICE_SAVED,
-
   // Cookies -----------------------------------------------------------------
 
 #if BUILDFLAG(ENABLE_EXTENSIONS)
@@ -320,14 +258,6 @@ enum NotificationType {
   NOTIFICATION_COOKIE_CHANGED_FOR_EXTENSIONS,
 #endif
 
-  // Download Notifications --------------------------------------------------
-
-  // Sent when a download is initiated. It is possible that the download will
-  // not actually begin due to the DownloadRequestLimiter cancelling it
-  // prematurely.
-  // The source is the corresponding WebContents. There are no details.
-  NOTIFICATION_DOWNLOAD_INITIATED,
-
   // Misc --------------------------------------------------------------------
 
 #if defined(OS_CHROMEOS)
@@ -367,13 +297,8 @@ enum NotificationType {
   //    NOTIFICATION_LOGIN_OR_LOCK_WEBUI_VISIBLE
   // 4. Boot into retail mode
   //    NOTIFICATION_LOGIN_OR_LOCK_WEBUI_VISIBLE
-  // 5. Boot into kiosk mode
-  //    NOTIFICATION_KIOSK_APP_LAUNCHED
   NOTIFICATION_LOGIN_OR_LOCK_WEBUI_VISIBLE,
 
-  // Sent when proxy dialog is closed.
-  NOTIFICATION_LOGIN_PROXY_CHANGED,
-
   // Send when kiosk auto-launch warning screen is visible.
   NOTIFICATION_KIOSK_AUTOLAUNCH_WARNING_VISIBLE,
 
@@ -392,9 +317,6 @@ enum NotificationType {
   // Sent when kiosk app list is loaded in UI.
   NOTIFICATION_KIOSK_APPS_LOADED,
 
-  // Sent when a kiosk app is launched.
-  NOTIFICATION_KIOSK_APP_LAUNCHED,
-
   // Sent when the user list has changed.
   NOTIFICATION_USER_LIST_CHANGED,
 
@@ -404,12 +326,6 @@ enum NotificationType {
   // is being deleted, so the receiver shouldn't use the screen locker
   // object.
   NOTIFICATION_SCREEN_LOCK_STATE_CHANGED,
-
-  // Sent by DeviceSettingsService to indicate that the ownership status
-  // changed. If you can, please use DeviceSettingsService::Observer instead.
-  // Other singleton-based services can't use that because Observer
-  // unregistration is impossible due to unpredictable deletion order.
-  NOTIFICATION_OWNERSHIP_STATUS_CHANGED,
 #endif
 
 #if defined(TOOLKIT_VIEWS)
@@ -422,10 +338,6 @@ enum NotificationType {
   NOTIFICATION_TAB_DRAG_LOOP_DONE,
 #endif
 
-  // Send when a context menu is shown. Used to notify tests that the context
-  // menu has been created and shown.
-  NOTIFICATION_RENDER_VIEW_CONTEXT_MENU_SHOWN,
-
   // Sent when the CaptivePortalService checks if we're behind a captive portal.
   // The Source is the Profile the CaptivePortalService belongs to, and the
   // Details are a Details<CaptivePortalService::CheckResults>.
@@ -441,7 +353,7 @@ enum NotificationType {
   // which was installed.
   NOTIFICATION_APP_INSTALLED_TO_NTP,
 
-#if defined(USE_ASH)
+#if defined(OS_CHROMEOS)
   // Sent when wallpaper show animation has finished.
   NOTIFICATION_WALLPAPER_ANIMATION_FINISHED,
 #endif
@@ -467,11 +379,6 @@ enum NotificationType {
   // all error UIs should update.
   NOTIFICATION_GLOBAL_ERRORS_CHANGED,
 
-  // The user accepted or dismissed a SSL client authentication request.
-  // The source is a Source<net::HttpNetworkSession>.  Details is a
-  // (std::pair<net::SSLCertRequestInfo*, net::X509Certificate*>).
-  NOTIFICATION_SSL_CLIENT_AUTH_CERT_SELECTED,
-
   // Note:-
   // Currently only Content and Chrome define and use notifications.
   // Custom notifications not belonging to Content and Chrome should start
@@ -481,4 +388,15 @@ enum NotificationType {
 
 }  // namespace chrome
 
+// **
+// ** NOTICE
+// **
+// ** The notification system is deprecated, obsolete, and is slowly being
+// ** removed. See https://crbug.com/268984.
+// **
+// ** Please don't add any new notification types, and please help migrate
+// ** existing uses of the notification types below to use the Observer and
+// ** Callback patterns.
+// **
+
 #endif  // CHROME_BROWSER_CHROME_NOTIFICATION_TYPES_H_
