@@ -353,9 +353,9 @@ IN_PROC_BROWSER_TEST_F(ChromeSecurityExploitBrowserTest,
 
   EXPECT_TRUE(content::ExecuteScriptAndExtractString(rfh, script, &body));
   EXPECT_EQ(
-      "Your file was not found\n"
+      "\nYour file was not found "
       "It may have been moved or deleted.\n"
-      "ERR_FILE_NOT_FOUND",
+      "ERR_FILE_NOT_FOUND\n",
       body);
 }
 
@@ -473,9 +473,9 @@ IN_PROC_BROWSER_TEST_F(ChromeSecurityExploitBrowserTest,
 
   EXPECT_TRUE(content::ExecuteScriptAndExtractString(rfh, script, &body));
   EXPECT_EQ(
-      "Your file was not found\n"
+      "\nYour file was not found "
       "It may have been moved or deleted.\n"
-      "ERR_FILE_NOT_FOUND",
+      "ERR_FILE_NOT_FOUND\n",
       body);
 }
 
