@@ -15,6 +15,8 @@
 #include "chrome/browser/prefs/pref_service_syncable_util.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/profiles/profile_manager.h"
+#include "chrome/browser/supervised_user/supervised_user_constants.h"
+#include "chrome/browser/ui/ash/ksv/keyboard_shortcut_viewer_util.h"
 #include "chrome/common/chrome_switches.h"
 #include "chrome/common/extensions/extension_constants.h"
 #include "chrome/test/base/in_process_browser_test.h"
@@ -513,6 +515,35 @@ IN_PROC_BROWSER_TEST_F(AccessibilityManagerTest, AccessibilityMenuVisibility) {
   EXPECT_FALSE(ShouldShowAccessibilityMenu());
 }
 
+// Tests text caret highlighting for remote mojo applications (e.g. shortcut
+// viewer). This test integration of AccessibilityManager with the IME driver.
+IN_PROC_BROWSER_TEST_F(AccessibilityManagerTest, CaretHighlightInRemoteApp) {
+  AccessibilityManager::Get()->SetCaretHighlightEnabled(true);
+
+  // App launch is asynchronous so we will wait for a non-empty caret bounds
+  // update.
+  auto wait_for_bounds = [](base::RunLoop* run_loop, const gfx::Rect& bounds) {
+    // Under mash the first bounds update we see might be from the ash process
+    // clearing its caret highlight. Wait for the app's highlight to show up.
+    if (!bounds.IsEmpty())
+      run_loop->Quit();
+  };
+  base::RunLoop run_loop;
+  AccessibilityManager::Get()->SetCaretBoundsObserverForTest(
+      base::BindRepeating(wait_for_bounds, &run_loop));
+
+  // Focus will move to the search field and show a text caret highlight.
+  keyboard_shortcut_viewer_util::ToggleKeyboardShortcutViewer();
+
+  // Wait for the app to launch, the IME session to start and the caret bounds
+  // to be set.
+  run_loop.Run();
+
+  // Browser tests spin the message loop during shutdown which can lead to
+  // additional bounds updates.
+  AccessibilityManager::Get()->SetCaretBoundsObserverForTest(base::DoNothing());
+}
+
 // For signin screen to user session accessibility manager tests.
 class AccessibilityManagerLoginTest : public OobeBaseTest {
  protected:
@@ -651,7 +682,15 @@ class AccessibilityManagerUserTypeTest : public AccessibilityManagerTest,
           user_manager::GuestAccountId().GetUserEmail());
     } else if (GetParam() ==
                AccountId::FromUserEmail(kTestSupervisedUserName)) {
-      command_line->AppendSwitchASCII(::switches::kSupervisedUserId, "asdf");
+      command_line->AppendSwitchASCII(::switches::kSupervisedUserId,
+                                      supervised_users::kChildAccountSUID);
+#if defined(OS_CHROMEOS)
+      command_line->AppendSwitchASCII(
+          chromeos::switches::kLoginUser,
+          "supervised_user@locally-managed.localhost");
+      command_line->AppendSwitchASCII(chromeos::switches::kLoginProfile,
+                                      "hash");
+#endif
     }
     AccessibilityManager::SetBrailleControllerForTest(&braille_controller_);
   }
