@@ -5,23 +5,21 @@
 #ifndef CHROME_BROWSER_CHROMEOS_ACCESSIBILITY_AX_HOST_SERVICE_H_
 #define CHROME_BROWSER_CHROMEOS_ACCESSIBILITY_AX_HOST_SERVICE_H_
 
+#include <map>
 #include <memory>
 
 #include "mojo/public/cpp/bindings/binding_set.h"
-#include "mojo/public/cpp/bindings/interface_ptr_set.h"
 #include "services/service_manager/public/cpp/binder_registry.h"
 #include "services/service_manager/public/cpp/service.h"
-#include "ui/accessibility/ax_host_delegate.h"
 #include "ui/accessibility/mojom/ax_host.mojom.h"
 
-// Forwards accessibility events from clients in other processes that use aura
-// and views (e.g. the Chrome OS keyboard shortcut_viewer) to accessibility
-// extensions. Renderers, PDF, etc. use a different path. Created when the first
-// client connects over mojo. Implements AXHostDelegate by routing actions over
-// mojo to the remote process.
+class AXRemoteHostDelegate;
+
+// Manages a set of remote processes that use aura and views. Renderers such as
+// web content, PDF, etc. use a different path. Created when the first client
+// connects over mojo.
 class AXHostService : public service_manager::Service,
-                      public ax::mojom::AXHost,
-                      public ui::AXHostDelegate {
+                      public ax::mojom::AXHost {
  public:
   AXHostService();
   ~AXHostService() override;
@@ -38,28 +36,32 @@ class AXHostService : public service_manager::Service,
                        mojo::ScopedMessagePipeHandle interface_pipe) override;
 
   // ax::mojom::AXHost:
-  void SetRemoteHost(ax::mojom::AXRemoteHostPtr remote) override;
-  void HandleAccessibilityEvent(int32_t tree_id,
+  void RegisterRemoteHost(ax::mojom::AXRemoteHostPtr remote_host_ptr,
+                          RegisterRemoteHostCallback cb) override;
+  void HandleAccessibilityEvent(const ui::AXTreeID& tree_id,
                                 const std::vector<ui::AXTreeUpdate>& updates,
                                 const ui::AXEvent& event) override;
 
-  // ui::AXHostDelegate:
-  void PerformAction(const ui::AXActionData& data) override;
+  // Cleans up after a remote host disconnects.
+  void OnRemoteHostDisconnected(const ui::AXTreeID& tree_id);
 
   void FlushForTesting();
 
  private:
   void AddBinding(ax::mojom::AXHostRequest request);
+
+  // Notifies all remote trees of automation enabled state.
   void NotifyAutomationEnabled();
-  void OnRemoteHostDisconnected();
 
   static AXHostService* instance_;
   static bool automation_enabled_;
 
   service_manager::BinderRegistry registry_;
   mojo::BindingSet<ax::mojom::AXHost> bindings_;
-  // TODO(jamescook): Support multiple remote hosts.
-  mojo::InterfacePtr<ax::mojom::AXRemoteHost> remote_host_;
+
+  // Map from a child tree id to the remote host responsible for that tree.
+  std::map<ui::AXTreeID, std::unique_ptr<AXRemoteHostDelegate>>
+      remote_host_delegate_map_;
 
   DISALLOW_COPY_AND_ASSIGN(AXHostService);
 };
