@@ -33,7 +33,6 @@
 #include "extensions/browser/notification_types.h"
 #include "extensions/browser/process_manager.h"
 #include "services/service_manager/public/cpp/connector.h"
-#include "ui/base/material_design/material_design_controller.h"
 #include "ui/events/test/event_generator.h"
 #include "url/url_constants.h"
 
@@ -84,8 +83,7 @@ class SelectToSpeakTest : public InProcessBrowserTest {
   gfx::Rect GetWebContentsBounds() const {
     // TODO(katie): Find a way to get the exact bounds programmatically.
     gfx::Rect bounds = browser()->window()->GetBounds();
-    const int top_inset = ui::MaterialDesignController::IsRefreshUi() ? 75 : 50;
-    bounds.Inset(8, 8, top_inset, 8);
+    bounds.Inset(8, 8, 75, 8);
     return bounds;
   }
 
