@@ -32,9 +32,6 @@ void SwitchAccessEventHandler::SetKeysToCapture(
 void SwitchAccessEventHandler::OnKeyEvent(ui::KeyEvent* event) {
   DCHECK(event);
 
-  if (!event->HasNativeEvent())
-    return;
-
   ui::KeyboardCode key_code = event->key_code();
   if (captured_keys_.find(key_code) != captured_keys_.end()) {
     CancelEvent(event);
@@ -54,6 +51,9 @@ void SwitchAccessEventHandler::DispatchKeyEventToSwitchAccess(
     const ui::KeyEvent& event) {
   extensions::ExtensionHost* host =
       GetAccessibilityExtensionHost(extension_misc::kSwitchAccessExtensionId);
+  if (!host)
+    return;
+
   ForwardKeyToExtension(event, host);
 }
 
