@@ -5,14 +5,15 @@
 #ifndef CHROME_BROWSER_CHROMEOS_APP_MODE_KIOSK_PROFILE_LOADER_H_
 #define CHROME_BROWSER_CHROMEOS_APP_MODE_KIOSK_PROFILE_LOADER_H_
 
+#include <memory>
 #include <string>
 
 #include "base/callback.h"
 #include "base/macros.h"
-#include "base/memory/scoped_ptr.h"
 #include "chrome/browser/chromeos/app_mode/kiosk_app_launch_error.h"
 #include "chrome/browser/chromeos/login/session/user_session_manager.h"
 #include "chromeos/login/auth/login_performer.h"
+#include "components/account_id/account_id.h"
 
 class Profile;
 
@@ -33,7 +34,7 @@ class KioskProfileLoader : public LoginPerformer::Delegate,
     virtual ~Delegate() {}
   };
 
-  KioskProfileLoader(const std::string& app_user_id,
+  KioskProfileLoader(const AccountId& app_account_id,
                      bool use_guest_mount,
                      Delegate* delegate);
 
@@ -53,15 +54,16 @@ class KioskProfileLoader : public LoginPerformer::Delegate,
   void OnAuthFailure(const AuthFailure& error) override;
   void WhiteListCheckFailed(const std::string& email) override;
   void PolicyLoadFailed() override;
+  void SetAuthFlowOffline(bool offline) override;
 
   // UserSessionManagerDelegate implementation:
   void OnProfilePrepared(Profile* profile, bool browser_launched) override;
 
-  std::string user_id_;
+  const AccountId account_id_;
   bool use_guest_mount_;
   Delegate* delegate_;
-  scoped_ptr<CryptohomedChecker> cryptohomed_checker_;
-  scoped_ptr<LoginPerformer> login_performer_;
+  std::unique_ptr<CryptohomedChecker> cryptohomed_checker_;
+  std::unique_ptr<LoginPerformer> login_performer_;
 
   DISALLOW_COPY_AND_ASSIGN(KioskProfileLoader);
 };
