@@ -60,13 +60,11 @@ ArcEnabledState ComputeEnabledState(bool enabled, const Profile* profile) {
 }  // namespace
 
 void UpdateOptInActionUMA(OptInActionType type) {
-  UMA_HISTOGRAM_ENUMERATION("Arc.OptInAction", static_cast<int>(type),
-                            static_cast<int>(OptInActionType::SIZE));
+  UMA_HISTOGRAM_ENUMERATION("Arc.OptInAction", type);
 }
 
 void UpdateOptInCancelUMA(OptInCancelReason reason) {
-  UMA_HISTOGRAM_ENUMERATION("Arc.OptInCancel", static_cast<int>(reason),
-                            static_cast<int>(OptInCancelReason::SIZE));
+  UMA_HISTOGRAM_ENUMERATION("Arc.OptInCancel", reason);
 }
 
 void UpdateEnabledStateUMA(bool enabled) {
@@ -77,20 +75,18 @@ void UpdateEnabledStateUMA(bool enabled) {
 void UpdateEnabledStateByUserTypeUMA(bool enabled, const Profile* profile) {
   base::UmaHistogramEnumeration(
       GetHistogramName("Arc.StateByUserType.", profile),
-      ComputeEnabledState(enabled, profile), ArcEnabledState::SIZE);
+      ComputeEnabledState(enabled, profile));
 }
 
 void UpdateOptInFlowResultUMA(OptInFlowResult result) {
-  UMA_HISTOGRAM_ENUMERATION("Arc.OptInResult", static_cast<int>(result),
-                            static_cast<int>(OptInFlowResult::SIZE));
+  UMA_HISTOGRAM_ENUMERATION("Arc.OptInResult", result);
 }
 
 void UpdateProvisioningResultUMA(ProvisioningResult result,
                                  const Profile* profile) {
   DCHECK_NE(result, ProvisioningResult::CHROME_SERVER_COMMUNICATION_ERROR);
   base::UmaHistogramEnumeration(
-      GetHistogramName("Arc.Provisioning.Result.", profile), result,
-      ProvisioningResult::SIZE);
+      GetHistogramName("Arc.Provisioning.Result.", profile), result);
 }
 
 void UpdateProvisioningTiming(const base::TimeDelta& elapsed_time,
@@ -109,8 +105,7 @@ void UpdateProvisioningTiming(const base::TimeDelta& elapsed_time,
 void UpdateReauthorizationResultUMA(ProvisioningResult result,
                                     const Profile* profile) {
   base::UmaHistogramEnumeration(
-      GetHistogramName("Arc.Reauthorization.Result.", profile), result,
-      ProvisioningResult::SIZE);
+      GetHistogramName("Arc.Reauthorization.Result.", profile), result);
 }
 
 void UpdatePlayStoreShowTime(const base::TimeDelta& elapsed_time,
@@ -181,7 +176,7 @@ std::ostream& operator<<(std::ostream& os, const ProvisioningResult& result) {
     MAP_PROVISIONING_RESULT(NO_NETWORK_CONNECTION);
     MAP_PROVISIONING_RESULT(ARC_DISABLED);
     MAP_PROVISIONING_RESULT(SUCCESS_ALREADY_PROVISIONED);
-    MAP_PROVISIONING_RESULT(SIZE);
+    MAP_PROVISIONING_RESULT(UNSUPPORTED_ACCOUNT_TYPE);
   }
 
 #undef MAP_PROVISIONING_RESULT
