@@ -365,13 +365,6 @@ class ArcSessionManager : public ArcSessionRunner::Observer,
   std::unique_ptr<ArcAppLauncher> playstore_launcher_;
   bool reenable_arc_ = false;
   bool provisioning_reported_ = false;
-  // In case ARC is started from OOBE |oobe_start_|, set to true. This flag is
-  // used to remember |IsArcOobeOptInActive| or
-  // |IsArcOptInWizardForAssistantActive| state when ARC start request was made.
-  // |IsArcOobeOptInActive| or |IsArcOptInWizardForAssistantActive| will be
-  // changed by the time when |oobe_or_opa_start_| is checked to prevent the
-  // Play Store auto-launch.
-  bool oobe_or_assistant_wizard_start_ = false;
   bool directly_started_ = false;
   base::OneShotTimer arc_sign_in_timer_;
 
