@@ -20,7 +20,7 @@
 #include "base/strings/string_util.h"
 #include "base/sys_info.h"
 #include "base/task/post_task.h"
-#include "base/threading/thread_restrictions.h"
+#include "base/threading/scoped_blocking_call.h"
 #include "chrome/browser/chromeos/arc/arc_session_manager.h"
 #include "chrome/browser/chromeos/arc/policy/arc_policy_util.h"
 #include "chrome/browser/chromeos/login/demo_mode/demo_session.h"
@@ -86,7 +86,7 @@ base::LazyInstance<std::set<AccountId>>::DestructorAtExit
 // Returns whether ARC can run on the filesystem mounted at |path|.
 // This function should run only on threads where IO operations are allowed.
 bool IsArcCompatibleFilesystem(const base::FilePath& path) {
-  base::AssertBlockingAllowed();
+  base::ScopedBlockingCall scoped_blocking_call(base::BlockingType::MAY_BLOCK);
 
   // If it can be verified it is not on ecryptfs, then it is ok.
   struct statfs statfs_buf;
@@ -277,6 +277,11 @@ bool IsArcAllowedForProfile(const Profile* profile) {
   return it->second;
 }
 
+bool IsArcProvisioned(const Profile* profile) {
+  return profile && profile->GetPrefs()->HasPrefPath(prefs::kArcSignedIn) &&
+         profile->GetPrefs()->GetBoolean(prefs::kArcSignedIn);
+}
+
 void ResetArcAllowedCheckForTesting(const Profile* profile) {
   g_profile_status_check.Get().erase(profile);
 }
@@ -630,6 +635,9 @@ ash::mojom::AssistantAllowedState IsAssistantAllowedForProfile(
   if (chromeos::DemoSession::IsDeviceInDemoMode())
     return ash::mojom::AssistantAllowedState::DISALLOWED_BY_DEMO_MODE;
 
+  if (user_manager::UserManager::Get()->IsLoggedInAsPublicAccount())
+    return ash::mojom::AssistantAllowedState::DISALLOWED_BY_PUBLIC_SESSION;
+
   if (chromeos::switches::IsAssistantEnabled()) {
     const std::string kAllowedLocales[] = {ULOC_US, ULOC_UK, ULOC_CANADA,
                                            ULOC_CANADA_FRENCH};
@@ -683,4 +691,16 @@ ArcSupervisionTransition GetSupervisionTransition(const Profile* profile) {
   return supervision_transition;
 }
 
+bool IsPlayStoreAvailable() {
+  if (ShouldArcAlwaysStartWithNoPlayStore())
+    return false;
+
+  if (!IsRobotOrOfflineDemoAccountMode())
+    return true;
+
+  // Demo Mode is the only public session scenario that can launch Play.
+  return chromeos::DemoSession::IsDeviceInDemoMode() &&
+         chromeos::switches::ShouldShowPlayStoreInDemoMode();
+}
+
 }  // namespace arc
