@@ -98,6 +98,7 @@ ProvisioningResult ConvertArcSignInStatusToProvisioningResult(
     MAP_PROVISIONING_RESULT(ARC_DISABLED);
     MAP_PROVISIONING_RESULT(SUCCESS);
     MAP_PROVISIONING_RESULT(SUCCESS_ALREADY_PROVISIONED);
+    MAP_PROVISIONING_RESULT(UNSUPPORTED_ACCOUNT_TYPE);
   }
 #undef MAP_PROVISIONING_RESULT
 
@@ -183,9 +184,9 @@ ArcAuthService::ArcAuthService(content::BrowserContext* browser_context,
 }
 
 ArcAuthService::~ArcAuthService() {
-  if (chromeos::switches::IsAccountManagerEnabled()) {
+  if (chromeos::switches::IsAccountManagerEnabled())
     account_manager_->RemoveObserver(this);
-  }
+
   arc_bridge_service_->auth()->RemoveObserver(this);
   arc_bridge_service_->auth()->SetHost(nullptr);
 }
@@ -274,34 +275,50 @@ void ArcAuthService::ReportSupervisionChangeStatus(
   }
 }
 
-void ArcAuthService::OnAccountInfoReady(mojom::AccountInfoPtr account_info,
-                                        mojom::ArcSignInStatus status) {
+void ArcAuthService::OnAccountInfoReadyDeprecated(
+    mojom::ArcSignInStatus status,
+    mojom::AccountInfoPtr account_info) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
   auto* instance = ARC_GET_INSTANCE_FOR_METHOD(arc_bridge_service_->auth(),
-                                               OnAccountInfoReady);
-  if (!instance) {
-    LOG(ERROR) << "Auth instance is not available.";
+                                               OnAccountInfoReadyDeprecated);
+  if (!instance)
     return;
-  }
-  instance->OnAccountInfoReady(std::move(account_info), status);
+
+  instance->OnAccountInfoReadyDeprecated(std::move(account_info), status);
 }
 
-void ArcAuthService::RequestAccountInfo(bool initial_signin) {
+void ArcAuthService::RequestAccountInfoDeprecated(bool initial_signin) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
 
-  FetchDeviceAccountInfo(initial_signin);
+  FetchPrimaryAccountInfo(
+      initial_signin,
+      base::BindOnce(&ArcAuthService::OnAccountInfoReadyDeprecated,
+                     weak_ptr_factory_.GetWeakPtr()));
 }
 
-void ArcAuthService::FetchDeviceAccountInfo(bool initial_signin) {
+void ArcAuthService::RequestPrimaryAccountInfo(
+    RequestPrimaryAccountInfoCallback callback) {
+  FetchPrimaryAccountInfo(true /* initial_signin */, std::move(callback));
+}
+
+void ArcAuthService::RequestAccountInfo(const std::string& account_name,
+                                        RequestAccountInfoCallback callback) {
+  // TODO(sinhak): Check for Secondary Accounts.
+  FetchPrimaryAccountInfo(false /* initial_signin */, std::move(callback));
+}
+
+void ArcAuthService::FetchPrimaryAccountInfo(
+    bool initial_signin,
+    RequestPrimaryAccountInfoCallback callback) {
   const mojom::ChromeAccountType account_type = GetAccountType(profile_);
 
   if (IsArcOptInVerificationDisabled()) {
-    OnAccountInfoReady(
+    std::move(callback).Run(
+        mojom::ArcSignInStatus::SUCCESS,
         CreateAccountInfo(false /* is_enforced */,
                           std::string() /* auth_info */,
                           std::string() /* auth_name */, account_type,
-                          policy_util::IsAccountManaged(profile_)),
-        mojom::ArcSignInStatus::SUCCESS);
+                          policy_util::IsAccountManaged(profile_)));
     return;
   }
 
@@ -311,20 +328,26 @@ void ArcAuthService::FetchDeviceAccountInfo(bool initial_signin) {
     auto enrollment_token_fetcher =
         std::make_unique<ArcActiveDirectoryEnrollmentTokenFetcher>(
             ArcSessionManager::Get()->support_host());
-    enrollment_token_fetcher->Fetch(base::BindOnce(
-        &ArcAuthService::OnActiveDirectoryEnrollmentTokenFetched,
-        weak_ptr_factory_.GetWeakPtr(), enrollment_token_fetcher.get()));
+
+    // Add the request to |pending_token_requests_| first, before starting a
+    // token fetch. In case the callback is called immediately, we do not want
+    // to add an already completed request to |pending_token_requests_|.
+    auto* enrollment_token_fetcher_ptr = enrollment_token_fetcher.get();
     pending_token_requests_.emplace_back(std::move(enrollment_token_fetcher));
+    enrollment_token_fetcher_ptr->Fetch(
+        base::BindOnce(&ArcAuthService::OnActiveDirectoryEnrollmentTokenFetched,
+                       weak_ptr_factory_.GetWeakPtr(),
+                       enrollment_token_fetcher_ptr, std::move(callback)));
     return;
   }
 
   if (account_type == mojom::ChromeAccountType::OFFLINE_DEMO_ACCOUNT) {
     // Skip account auth code fetch for offline enrolled demo mode.
-    OnAccountInfoReady(
+    std::move(callback).Run(
+        mojom::ArcSignInStatus::SUCCESS,
         CreateAccountInfo(true /* is_enforced */, std::string() /* auth_info */,
                           std::string() /* auth_name */, account_type,
-                          true /* is_managed */),
-        mojom::ArcSignInStatus::SUCCESS);
+                          true /* is_managed */));
     return;
   }
 
@@ -341,10 +364,16 @@ void ArcAuthService::FetchDeviceAccountInfo(bool initial_signin) {
     auth_code_fetcher = CreateArcBackgroundAuthCodeFetcher(
         signin_manager->GetAuthenticatedAccountId(), initial_signin);
   }
-  auth_code_fetcher->Fetch(
-      base::Bind(&ArcAuthService::OnDeviceAccountAuthCodeFetched,
-                 weak_ptr_factory_.GetWeakPtr(), auth_code_fetcher.get()));
+
+  // Add the request to |pending_token_requests_| first, before starting a token
+  // fetch. In case the callback is called immediately, we do not want to add an
+  // already completed request to |pending_token_requests_|.
+  auto* auth_code_fetcher_ptr = auth_code_fetcher.get();
   pending_token_requests_.emplace_back(std::move(auth_code_fetcher));
+  auth_code_fetcher_ptr->Fetch(
+      base::BindOnce(&ArcAuthService::OnPrimaryAccountAuthCodeFetched,
+                     weak_ptr_factory_.GetWeakPtr(), auth_code_fetcher_ptr,
+                     std::move(callback)));
 }
 
 void ArcAuthService::OnTokenUpserted(
@@ -365,6 +394,7 @@ void ArcAuthService::OnAccountRemoved(
 
 void ArcAuthService::OnActiveDirectoryEnrollmentTokenFetched(
     ArcActiveDirectoryEnrollmentTokenFetcher* fetcher,
+    RequestPrimaryAccountInfoCallback callback,
     ArcActiveDirectoryEnrollmentTokenFetcher::Status status,
     const std::string& enrollment_token,
     const std::string& user_id) {
@@ -379,30 +409,31 @@ void ArcAuthService::OnActiveDirectoryEnrollmentTokenFetched(
                                       user_id);
 
       // Send enrollment token to ARC.
-      OnAccountInfoReady(
+      std::move(callback).Run(
+          mojom::ArcSignInStatus::SUCCESS,
           CreateAccountInfo(true /* is_enforced */, enrollment_token,
                             std::string() /* account_name */,
                             mojom::ChromeAccountType::ACTIVE_DIRECTORY_ACCOUNT,
-                            true /* is_managed */),
-          mojom::ArcSignInStatus::SUCCESS);
+                            true /* is_managed */));
       break;
     }
     case ArcActiveDirectoryEnrollmentTokenFetcher::Status::FAILURE: {
       // Send error to ARC.
-      OnAccountInfoReady(
-          nullptr, mojom::ArcSignInStatus::CHROME_SERVER_COMMUNICATION_ERROR);
+      std::move(callback).Run(
+          mojom::ArcSignInStatus::CHROME_SERVER_COMMUNICATION_ERROR, nullptr);
       break;
     }
     case ArcActiveDirectoryEnrollmentTokenFetcher::Status::ARC_DISABLED: {
       // Send error to ARC.
-      OnAccountInfoReady(nullptr, mojom::ArcSignInStatus::ARC_DISABLED);
+      std::move(callback).Run(mojom::ArcSignInStatus::ARC_DISABLED, nullptr);
       break;
     }
   }
 }
 
-void ArcAuthService::OnDeviceAccountAuthCodeFetched(
+void ArcAuthService::OnPrimaryAccountAuthCodeFetched(
     ArcAuthCodeFetcher* fetcher,
+    RequestPrimaryAccountInfoCallback callback,
     bool success,
     const std::string& auth_code) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
@@ -414,62 +445,25 @@ void ArcAuthService::OnDeviceAccountAuthCodeFetched(
         SigninManagerFactory::GetForProfile(profile_);
     const std::string& full_account_id = base::UTF16ToUTF8(
         signin_ui_util::GetAuthenticatedUsername(signin_manager));
-    OnAccountInfoReady(
+    std::move(callback).Run(
+        mojom::ArcSignInStatus::SUCCESS,
         CreateAccountInfo(!IsArcOptInVerificationDisabled(), auth_code,
                           full_account_id, GetAccountType(profile_),
-                          policy_util::IsAccountManaged(profile_)),
-        mojom::ArcSignInStatus::SUCCESS);
+                          policy_util::IsAccountManaged(profile_)));
   } else if (chromeos::DemoSession::Get() &&
              chromeos::DemoSession::Get()->started()) {
     // For demo sessions, if auth code fetch failed (e.g. because the device is
     // offline), fall back to accountless offline demo mode provisioning.
-    OnAccountInfoReady(
+    std::move(callback).Run(
+        mojom::ArcSignInStatus::SUCCESS,
         CreateAccountInfo(true /* is_enforced */, std::string() /* auth_info */,
                           std::string() /* auth_name */,
                           mojom::ChromeAccountType::OFFLINE_DEMO_ACCOUNT,
-                          true /* is_managed */),
-        mojom::ArcSignInStatus::SUCCESS);
+                          true /* is_managed */));
   } else {
     // Send error to ARC.
-    OnAccountInfoReady(
-        nullptr, mojom::ArcSignInStatus::CHROME_SERVER_COMMUNICATION_ERROR);
-  }
-}
-
-void ArcAuthService::FetchSecondaryAccountInfo(
-    const std::string& account_name) {
-  DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
-
-  const std::string& account_id =
-      account_tracker_service_->FindAccountInfoByEmail(account_name).account_id;
-  DCHECK(!account_id.empty());
-
-  std::unique_ptr<ArcBackgroundAuthCodeFetcher> fetcher =
-      CreateArcBackgroundAuthCodeFetcher(account_id,
-                                         false /* initial_signin */);
-  fetcher->Fetch(base::BindRepeating(
-      &ArcAuthService::OnSecondaryAccountAuthCodeFetched,
-      weak_ptr_factory_.GetWeakPtr(), account_name, fetcher.get()));
-  pending_token_requests_.emplace_back(std::move(fetcher));
-}
-
-void ArcAuthService::OnSecondaryAccountAuthCodeFetched(
-    const std::string& account_name,
-    ArcBackgroundAuthCodeFetcher* fetcher,
-    bool success,
-    const std::string& auth_code) {
-  DeletePendingTokenRequest(fetcher);
-  fetcher = nullptr;
-
-  if (success) {
-    OnAccountInfoReady(
-        CreateAccountInfo(true /* is_enforced */, auth_code, account_name,
-                          mojom::ChromeAccountType::USER_ACCOUNT,
-                          false /* is_managed */),
-        mojom::ArcSignInStatus::SUCCESS);
-  } else {
-    OnAccountInfoReady(
-        nullptr, mojom::ArcSignInStatus::CHROME_SERVER_COMMUNICATION_ERROR);
+    std::move(callback).Run(
+        mojom::ArcSignInStatus::CHROME_SERVER_COMMUNICATION_ERROR, nullptr);
   }
 }
 
@@ -505,20 +499,10 @@ void ArcAuthService::OnDataRemovalAccepted(bool accepted) {
   ArcSessionManager::Get()->StopAndEnableArc();
 }
 
-void ArcAuthService::GetAccountsCallback(
+void ArcAuthService::OnGetAccounts(
     std::vector<chromeos::AccountManager::AccountKey> accounts) {
-  for (const auto& account_key : accounts) {
+  for (const auto& account_key : accounts)
     OnTokenUpserted(account_key);
-  }
-}
-
-bool ArcAuthService::IsDeviceAccount(
-    const chromeos::AccountManager::AccountKey& account_key) const {
-  const AccountId& device_account_id = chromeos::ProfileHelper::Get()
-                                           ->GetUserByProfile(profile_)
-                                           ->GetAccountId();
-
-  return account_mapper_util_.IsEqual(account_key, device_account_id);
 }
 
 std::unique_ptr<ArcBackgroundAuthCodeFetcher>
