@@ -5,12 +5,15 @@
 #include "chrome/browser/chromeos/arc/auth/arc_robot_auth_code_fetcher.h"
 
 #include <string>
+#include <utility>
 
 #include "base/bind.h"
+#include "base/callback_helpers.h"
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/chromeos/policy/browser_policy_connector_chromeos.h"
 #include "chrome/browser/net/system_network_context_manager.h"
 #include "components/policy/core/common/cloud/device_management_service.h"
+#include "components/policy/core/common/cloud/dm_auth.h"
 #include "google_apis/gaia/gaia_constants.h"
 #include "google_apis/gaia/gaia_urls.h"
 #include "services/network/public/cpp/shared_url_loader_factory.h"
@@ -43,13 +46,13 @@ ArcRobotAuthCodeFetcher::ArcRobotAuthCodeFetcher() : weak_ptr_factory_(this) {}
 
 ArcRobotAuthCodeFetcher::~ArcRobotAuthCodeFetcher() = default;
 
-void ArcRobotAuthCodeFetcher::Fetch(const FetchCallback& callback) {
+void ArcRobotAuthCodeFetcher::Fetch(FetchCallback callback) {
   DCHECK(!fetch_request_job_);
   const policy::CloudPolicyClient* client = GetCloudPolicyClient();
   if (!client) {
     LOG(WARNING) << "Synchronously failing auth request because "
                     "CloudPolicyClient is not initialized.";
-    callback.Run(false, std::string());
+    std::move(callback).Run(false, std::string());
     return;
   }
 
@@ -59,7 +62,8 @@ void ArcRobotAuthCodeFetcher::Fetch(const FetchCallback& callback) {
       g_browser_process->system_network_context_manager()
           ->GetSharedURLLoaderFactory()));
 
-  fetch_request_job_->SetDMToken(client->dm_token());
+  fetch_request_job_->SetAuthData(
+      policy::DMAuth::FromDMToken(client->dm_token()));
   fetch_request_job_->SetClientID(client->client_id());
 
   enterprise_management::DeviceServiceApiAccessRequest* request =
@@ -69,9 +73,12 @@ void ArcRobotAuthCodeFetcher::Fetch(const FetchCallback& callback) {
   request->set_device_type(
       enterprise_management::DeviceServiceApiAccessRequest::ANDROID_OS);
 
+  // TODO(sinhak): Migrate |DeviceManagementService| to use
+  // |base::OnceCallback|.
   fetch_request_job_->Start(
       base::Bind(&ArcRobotAuthCodeFetcher::OnFetchRobotAuthCodeCompleted,
-                 weak_ptr_factory_.GetWeakPtr(), callback));
+                 weak_ptr_factory_.GetWeakPtr(),
+                 base::AdaptCallbackForRepeating(std::move(callback))));
 }
 
 void ArcRobotAuthCodeFetcher::OnFetchRobotAuthCodeCompleted(
@@ -89,12 +96,12 @@ void ArcRobotAuthCodeFetcher::OnFetchRobotAuthCodeCompleted(
 
   if (status != policy::DM_STATUS_SUCCESS) {
     LOG(ERROR) << "Fetching of robot auth code failed. DM Status: " << status;
-    callback.Run(false /* success */, std::string());
+    std::move(callback).Run(false /* success */, std::string());
     return;
   }
 
-  callback.Run(true /* success */,
-               response.service_api_access_response().auth_code());
+  std::move(callback).Run(true /* success */,
+                          response.service_api_access_response().auth_code());
 }
 
 }  // namespace arc
