@@ -8,6 +8,7 @@
 #include <utility>
 
 #include "base/bind.h"
+#include "base/metrics/histogram_macros.h"
 #include "base/metrics/user_metrics.h"
 #include "base/strings/string_util.h"
 #include "base/strings/utf_string_conversions.h"
@@ -18,6 +19,7 @@
 #include "components/arc/arc_service_manager.h"
 #include "components/arc/common/intent_helper.mojom.h"
 #include "components/arc/intent_helper/arc_intent_helper_bridge.h"
+#include "components/arc/metrics/arc_metrics_constants.h"
 #include "components/renderer_context_menu/render_view_context_menu_proxy.h"
 #include "content/public/common/context_menu_params.h"
 #include "ui/gfx/image/image_skia.h"
@@ -99,6 +101,11 @@ void StartSmartSelectionActionMenu::ExecuteCommand(int command_id) {
 
   instance->HandleIntent(std::move(actions_[index]->action_intent),
                          std::move(actions_[index]->activity));
+
+  UMA_HISTOGRAM_ENUMERATION(
+      "Arc.UserInteraction",
+      arc::UserInteractionType::
+          APP_STARTED_FROM_SMART_TEXT_SELECTION_CONTEXT_MENU);
 }
 
 void StartSmartSelectionActionMenu::HandleTextSelectionActions(
