@@ -86,7 +86,8 @@ void ConsumerStatusReportingService::CreateStatusUploaderIfNeeded(
           policy::DeviceStatusCollector::CPUStatisticsFetcher(),
           policy::DeviceStatusCollector::CPUTempFetcher(),
           policy::DeviceStatusCollector::AndroidStatusFetcher(),
-          day_reset_time_, false /* is_enterprise_reporting */),
+          policy::DeviceStatusCollector::TpmStatusFetcher(), day_reset_time_,
+          false /* is_enterprise_reporting */),
       base::ThreadTaskRunnerHandle::Get(), kStatusUploadFrequency);
 }
 
