@@ -64,6 +64,7 @@ ScreenTimeController::ScreenTimeController(content::BrowserContext* context)
       pref_service_(Profile::FromBrowserContext(context)->GetPrefs()) {
   session_manager::SessionManager::Get()->AddObserver(this);
   system::TimezoneSettings::GetInstance()->AddObserver(this);
+  chromeos::DBusThreadManager::Get()->GetSystemClockClient()->AddObserver(this);
   pref_change_registrar_.Init(pref_service_);
   pref_change_registrar_.Add(
       prefs::kUsageTimeLimit,
@@ -74,6 +75,8 @@ ScreenTimeController::ScreenTimeController(content::BrowserContext* context)
 ScreenTimeController::~ScreenTimeController() {
   session_manager::SessionManager::Get()->RemoveObserver(this);
   system::TimezoneSettings::GetInstance()->RemoveObserver(this);
+  chromeos::DBusThreadManager::Get()->GetSystemClockClient()->RemoveObserver(
+      this);
 }
 
 base::TimeDelta ScreenTimeController::GetScreenTimeDuration() {
@@ -368,4 +371,8 @@ void ScreenTimeController::TimezoneChanged(const icu::TimeZone& timezone) {
   CheckTimeLimit("TimezoneChanged");
 }
 
+void ScreenTimeController::SystemClockUpdated() {
+  CheckTimeLimit("SystemClockUpdated");
+}
+
 }  // namespace chromeos
