@@ -8,7 +8,6 @@
 #include <map>
 #include <set>
 #include <string>
-#include <tuple>
 #include <utility>
 #include <vector>
 
@@ -23,6 +22,7 @@
 #include "chromeos/dbus/cicerone_client.h"
 #include "chromeos/dbus/concierge/service.pb.h"
 #include "chromeos/dbus/concierge_client.h"
+#include "components/keyed_service/core/keyed_service.h"
 
 class Profile;
 
@@ -40,6 +40,9 @@ enum class ConciergeClientResult {
   LIST_VM_DISKS_FAILED,
   CLIENT_ERROR,
   DISK_TYPE_ERROR,
+  CONTAINER_DOWNLOAD_TIMED_OUT,
+  CONTAINER_CREATE_CANCELLED,
+  CONTAINER_CREATE_FAILED,
   CONTAINER_START_FAILED,
   LAUNCH_CONTAINER_APPLICATION_FAILED,
   INSTALL_LINUX_PACKAGE_FAILED,
@@ -57,6 +60,12 @@ enum class InstallLinuxPackageProgressStatus {
   INSTALLING,
 };
 
+enum class VmState {
+  STARTING,
+  STARTED,
+  STOPPING,
+};
+
 // Return type when getting app icons from within a container.
 struct Icon {
   std::string desktop_file_id;
@@ -86,7 +95,8 @@ class InstallLinuxPackageProgressObserver {
 // communication with the Cicerone service and both should remain as thin as
 // possible. The existence of Cicerone is abstracted behind this class and
 // only the Concierge name is exposed outside of here.
-class CrostiniManager : public chromeos::ConciergeClient::Observer,
+class CrostiniManager : public KeyedService,
+                        public chromeos::ConciergeClient::Observer,
                         public chromeos::CiceroneClient::Observer {
  public:
   using ConciergeClientCallback =
@@ -99,25 +109,25 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
   // The type of the callback for CrostiniManager::StopConcierge.
   using StopConciergeCallback = BoolCallback;
   // The type of the callback for CrostiniManager::StartTerminaVm.
-  using StartTerminaVmCallback = ConciergeClientCallback;
+  using StartTerminaVmCallback = CrostiniResultCallback;
   // The type of the callback for CrostiniManager::CreateDiskImage.
   using CreateDiskImageCallback =
       base::OnceCallback<void(ConciergeClientResult result,
                               const base::FilePath& disk_path)>;
   // The type of the callback for CrostiniManager::DestroyDiskImage.
-  using DestroyDiskImageCallback = ConciergeClientCallback;
+  using DestroyDiskImageCallback = CrostiniResultCallback;
   // The type of the callback for CrostiniManager::ListVmDisks.
   using ListVmDisksCallback =
       base::OnceCallback<void(ConciergeClientResult result,
                               int64_t total_size)>;
   // The type of the callback for CrostiniManager::StopVm.
-  using StopVmCallback = ConciergeClientCallback;
+  using StopVmCallback = CrostiniResultCallback;
   // The type of the callback for CrostiniManager::StartContainer.
-  using StartContainerCallback = ConciergeClientCallback;
+  using StartContainerCallback = CrostiniResultCallback;
   // The type of the callback for CrostiniManager::ShutdownContainer.
   using ShutdownContainerCallback = base::OnceClosure;
   // The type of the callback for CrostiniManager::LaunchContainerApplication.
-  using LaunchContainerApplicationCallback = ConciergeClientCallback;
+  using LaunchContainerApplicationCallback = CrostiniResultCallback;
   // The type of the callback for CrostiniManager::GetContainerAppIcons.
   using GetContainerAppIconsCallback =
       base::OnceCallback<void(ConciergeClientResult result,
@@ -135,9 +145,9 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
                               const std::string& host_private_key,
                               const std::string& hostname)>;
   // The type of the callback for CrostiniManager::RestartCrostini.
-  using RestartCrostiniCallback = ConciergeClientCallback;
+  using RestartCrostiniCallback = CrostiniResultCallback;
   // The type of the callback for CrostiniManager::RemoveCrostini.
-  using RemoveCrostiniCallback = ConciergeClientCallback;
+  using RemoveCrostiniCallback = CrostiniResultCallback;
 
   // Observer class for the Crostini restart flow.
   class RestartObserver {
@@ -147,12 +157,22 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
     virtual void OnConciergeStarted(ConciergeClientResult result) = 0;
     virtual void OnDiskImageCreated(ConciergeClientResult result) = 0;
     virtual void OnVmStarted(ConciergeClientResult result) = 0;
+    virtual void OnContainerDownloading(int32_t download_percent) = 0;
+    virtual void OnContainerCreated(ConciergeClientResult result) = 0;
     virtual void OnContainerStarted(ConciergeClientResult result) = 0;
     virtual void OnSshKeysFetched(ConciergeClientResult result) = 0;
   };
 
-  // Checks if the cros-termina component is installed.
-  bool IsCrosTerminaInstalled() const;
+  static CrostiniManager* GetForProfile(Profile* profile);
+
+  explicit CrostiniManager(Profile* profile);
+  ~CrostiniManager() override;
+
+  // Returns true if the cros-termina component is installed.
+  static bool IsCrosTerminaInstalled();
+
+  // Returns true if the /dev/kvm directory is present.
+  static bool IsDevKvmPresent();
 
   // Generate the URL for Crostini terminal application.
   static GURL GenerateVshInCroshUrl(
@@ -165,12 +185,15 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
   static AppLaunchParams GenerateTerminalAppLaunchParams(Profile* profile);
 
   // Upgrades cros-termina component if the current version is not compatible.
-  void MaybeUpgradeCrostini(Profile* profile);
+  void MaybeUpgradeCrostini();
 
   // Installs the current version of cros-termina component. Attempts to apply
   // pending upgrades if a MaybeUpgradeCrostini failed.
   void InstallTerminaComponent(CrostiniResultCallback callback);
 
+  // Unloads and removes the cros-termina component. Returns success/failure.
+  bool UninstallTerminaComponent();
+
   // Starts the Concierge service. |callback| is called after the method call
   // finishes.
   void StartConcierge(StartConciergeCallback callback);
@@ -184,8 +207,6 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
   // |callback| is called if the arguments are bad, or after the method call
   // finishes.
   void CreateDiskImage(
-      // The cryptohome id for the user's encrypted storage.
-      const std::string& cryptohome_id,
       // The path to the disk image, including the name of
       // the image itself. The image name should match the
       // name of the VM that it will be used for.
@@ -199,8 +220,6 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
   // |callback| is called if the arguments are bad, or after the method call
   // finishes.
   void DestroyDiskImage(
-      // The cryptohome id for the user's encrypted storage.
-      const std::string& cryptohome_id,
       // The path to the disk image, including the name of
       // the image itself.
       const base::FilePath& disk_path,
@@ -208,49 +227,58 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
       vm_tools::concierge::StorageLocation storage_location,
       DestroyDiskImageCallback callback);
 
-  void ListVmDisks(
-      // The cryptohome id for the user's encrypted storage.
-      const std::string& cryptohome_id,
-      ListVmDisksCallback callback);
+  void ListVmDisks(ListVmDisksCallback callback);
 
   // Checks the arguments for starting a Termina VM. Starts a Termina VM via
   // ConciergeClient::StartTerminaVm. |callback| is called if the arguments
   // are bad, or after the method call finishes.
-  void StartTerminaVm(std::string owner_id,
-                      // The human-readable name to be assigned to this VM.
-                      std::string name,
-                      // Path to the disk image on the host.
-                      const base::FilePath& disk_path,
-                      StartTerminaVmCallback callback);
+  void StartTerminaVm(
+      // The human-readable name to be assigned to this VM.
+      std::string name,
+      // Path to the disk image on the host.
+      const base::FilePath& disk_path,
+      StartTerminaVmCallback callback);
 
   // Checks the arguments for stopping a Termina VM. Stops the Termina VM via
   // ConciergeClient::StopVm. |callback| is called if the arguments are bad,
   // or after the method call finishes.
-  void StopVm(Profile* profile, std::string name, StopVmCallback callback);
+  void StopVm(std::string name, StopVmCallback callback);
 
-  // Checks the arguments for starting a Container inside an existing Termina
-  // VM. Starts the container via ConciergeClient::StartContainer. |callback|
-  // is called if the arguments are bad, or after the method call finishes.
-  void StartContainer(std::string vm_name,
-                      std::string container_name,
-                      std::string container_username,
-                      std::string cryptohome_id,
-                      StartContainerCallback callback);
+  // Checks the arguments for creating an Lxd container via
+  // CiceroneClient::CreateLxdContainer. |callback| is called immediately if the
+  // arguments are bad, or once the container has been created.
+  void CreateLxdContainer(std::string vm_name,
+                          std::string container_name,
+                          CrostiniResultCallback callback);
+
+  // Checks the arguments for starting an Lxd container via
+  // CiceroneClient::StartLxdContainer. |callback| is called immediately if the
+  // arguments are bad, or once the container has been created.
+  void StartLxdContainer(std::string vm_name,
+                         std::string container_name,
+                         CrostiniResultCallback callback);
+
+  // Checks the arguments for setting up an Lxd container user via
+  // CiceroneClient::SetUpLxdContainerUser. |callback| is called immediately if
+  // the arguments are bad, or once garcon has been started.
+  void SetUpLxdContainerUser(std::string vm_name,
+                             std::string container_name,
+                             std::string container_username,
+                             CrostiniResultCallback callback);
 
   // Asynchronously launches an app as specified by its desktop file id.
   // |callback| is called with SUCCESS when the relevant process is started
   // or LAUNCH_CONTAINER_APPLICATION_FAILED if there was an error somewhere.
-  void LaunchContainerApplication(Profile* profile,
-                                  std::string vm_name,
+  void LaunchContainerApplication(std::string vm_name,
                                   std::string container_name,
                                   std::string desktop_file_id,
                                   const std::vector<std::string>& files,
+                                  bool display_scaled,
                                   LaunchContainerApplicationCallback callback);
 
   // Asynchronously gets app icons as specified by their desktop file ids.
   // |callback| is called after the method call finishes.
-  void GetContainerAppIcons(Profile* profile,
-                            std::string vm_name,
+  void GetContainerAppIcons(std::string vm_name,
                             std::string container_name,
                             std::vector<std::string> desktop_file_ids,
                             int icon_size,
@@ -260,8 +288,7 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
   // Begin installation of a Linux Package inside the container. If the
   // installation is successfully started, further updates will be sent to
   // added InstallLinuxPackageProgressObservers.
-  void InstallLinuxPackage(Profile* profile,
-                           std::string vm_name,
+  void InstallLinuxPackage(std::string vm_name,
                            std::string container_name,
                            std::string package_path,
                            InstallLinuxPackageCallback callback);
@@ -271,24 +298,22 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
   // |callback| is called after the method call finishes.
   void GetContainerSshKeys(std::string vm_name,
                            std::string container_name,
-                           std::string cryptohome_id,
                            GetContainerSshKeysCallback callback);
 
   // Create the crosh-in-a-window that displays a shell in an container on a VM.
-  Browser* CreateContainerTerminal(const AppLaunchParams& launch_params,
-                                   const GURL& vsh_in_crosh_url);
+  static Browser* CreateContainerTerminal(const AppLaunchParams& launch_params,
+                                          const GURL& vsh_in_crosh_url);
 
   // Shows the already created crosh-in-a-window that displays a shell in an
   // already running container on a VM.
-  void ShowContainerTerminal(const AppLaunchParams& launch_params,
-                             const GURL& vsh_in_crosh_url,
-                             Browser* browser);
+  static void ShowContainerTerminal(const AppLaunchParams& launch_params,
+                                    const GURL& vsh_in_crosh_url,
+                                    Browser* browser);
 
   // Launches the crosh-in-a-window that displays a shell in an already running
   // container on a VM and passes |terminal_args| as parameters to that shell
   // which will cause them to be executed as program inside that shell.
-  void LaunchContainerTerminal(Profile* profile,
-                               const std::string& vm_name,
+  void LaunchContainerTerminal(const std::string& vm_name,
                                const std::string& container_name,
                                const std::vector<std::string>& terminal_args);
 
@@ -296,33 +321,32 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
   static const RestartId kUninitializedRestartId = -1;
   // Runs all the steps required to restart the given crostini vm and container.
   // The optional |observer| tracks progress.
-  RestartId RestartCrostini(Profile* profile,
-                            std::string vm_name,
+  RestartId RestartCrostini(std::string vm_name,
                             std::string container_name,
                             RestartCrostiniCallback callback,
                             RestartObserver* observer = nullptr);
 
   // Aborts a restart. A "next" restarter with the same <vm_name,
   // container_name> will run, if there is one.
-  void AbortRestartCrostini(Profile* profile, RestartId restart_id);
+  void AbortRestartCrostini(RestartId restart_id);
 
   // Returns true if the Restart corresponding to |restart_id| is not yet
   // complete.
-  bool IsRestartPending(Profile* profile, RestartId restart_id);
+  bool IsRestartPending(RestartId restart_id);
 
   // Adds a callback to receive notification of container shutdown.
   void AddShutdownContainerCallback(
-      Profile* profile,
       std::string vm_name,
       std::string container_name,
       ShutdownContainerCallback shutdown_callback);
 
+  // Adds a callback to receive uninstall notification.
+  void AddRemoveCrostiniCallback(RemoveCrostiniCallback remove_callback);
+
   // Add/remove observers for package install progress.
   void AddInstallLinuxPackageProgressObserver(
-      Profile* profile,
       InstallLinuxPackageProgressObserver* observer);
   void RemoveInstallLinuxPackageProgressObserver(
-      Profile* profile,
       InstallLinuxPackageProgressObserver* observer);
 
   // ConciergeClient::Observer:
@@ -344,22 +368,22 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
   void OnTremplinStarted(
       const vm_tools::cicerone::TremplinStartedSignal& signal) override;
 
-  void RemoveCrostini(Profile* profile,
-                      std::string vm_name,
+  void RemoveCrostini(std::string vm_name,
                       std::string container_name,
                       RemoveCrostiniCallback callback);
 
-  // Returns the singleton instance of CrostiniManager.
-  static CrostiniManager* GetInstance();
+  void SetVmState(std::string vm_name, VmState vm_state);
+  bool IsVmRunning(std::string vm_name);
 
-  bool IsVmRunning(Profile* profile, std::string vm_name);
   // Returns null if VM is not running.
   base::Optional<vm_tools::concierge::VmInfo> GetVmInfo(std::string vm_name);
   void AddRunningVmForTesting(std::string vm_name,
                               vm_tools::concierge::VmInfo vm_info);
-  bool IsContainerRunning(Profile* profile,
-                          std::string vm_name,
-                          std::string container_name);
+  bool IsContainerRunning(std::string vm_name, std::string container_name);
+
+  // If the Crostini reporting policy is set, save the last app launch
+  // time window and the Termina version in prefs for asynchronous reporting.
+  void UpdateLaunchMetricsForEnterpriseReporting();
 
   // Clear the lists of running VMs and containers.
   // Can be called for testing to skip restart.
@@ -370,15 +394,8 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
     component_manager_load_error_for_testing_ = error;
   }
 
-  // If the Crostini reporting policy is set, save the last app launch
-  // time window and the Termina version in prefs for asynchronous reporting.
-  void UpdateLaunchMetricsForEnterpriseReporting(Profile* profile);
-
  private:
-  friend struct base::DefaultSingletonTraits<CrostiniManager>;
-
-  CrostiniManager();
-  ~CrostiniManager() override;
+  class CrostiniRestarter;
 
   // Callback for ConciergeClient::CreateDiskImage. Called after the Concierge
   // service method finishes.
@@ -399,17 +416,24 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
       base::Optional<vm_tools::concierge::ListVmDisksResponse> reply);
 
   // Callback for ConciergeClient::StartTerminaVm. Called after the Concierge
-  // service method finishes.
+  // service method finishes.  Updates running containers list then calls the
+  // |callback| if the container has already been started, otherwise passes the
+  // callback to OnStartTremplin.
   void OnStartTerminaVm(
-      std::string owner_id,
       std::string vm_name,
       StartTerminaVmCallback callback,
       base::Optional<vm_tools::concierge::StartVmResponse> reply);
 
+  // Callback for ConciergeClient::TremplinStartedSignal. Called after the
+  // Tremplin service starts. Updates running containers list and then calls the
+  // |callback|.
+  void OnStartTremplin(std::string vm_name,
+                       StartTerminaVmCallback callback,
+                       ConciergeClientResult result);
+
   // Callback for ConciergeClient::StopVm. Called after the Concierge
   // service method finishes.
-  void OnStopVm(std::string owner_id,
-                std::string vm_name,
+  void OnStopVm(std::string vm_name,
                 StopVmCallback callback,
                 base::Optional<vm_tools::concierge::StopVmResponse> reply);
 
@@ -429,14 +453,28 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
   // DebugDaemon service method finishes.
   void OnStopConcierge(StopConciergeCallback callback, bool success);
 
-  // Callback for CrostiniManager::StartContainer. Called after the Concierge
-  // service finishes.
-  void OnStartContainer(
-      std::string owner_id,
+  // Callback for CiceroneClient::CreateLxdContainer. May indicate the container
+  // is still being created, in which case we will wait for an
+  // OnLxdContainerCreated event.
+  void OnCreateLxdContainer(
       std::string vm_name,
       std::string container_name,
-      StartContainerCallback callback,
-      base::Optional<vm_tools::concierge::StartContainerResponse> reply);
+      CrostiniResultCallback callback,
+      base::Optional<vm_tools::cicerone::CreateLxdContainerResponse> reply);
+
+  // Callback for CiceroneClient::StartLxdContainer.
+  void OnStartLxdContainer(
+      std::string vm_name,
+      std::string container_name,
+      CrostiniResultCallback callback,
+      base::Optional<vm_tools::cicerone::StartLxdContainerResponse> reply);
+
+  // Callback for CiceroneClient::SetUpLxdContainerUser.
+  void OnSetUpLxdContainerUser(
+      std::string vm_name,
+      std::string container_name,
+      CrostiniResultCallback callback,
+      base::Optional<vm_tools::cicerone::SetUpLxdContainerUserResponse> reply);
 
   // Callback for CrostiniManager::LaunchContainerApplication.
   void OnLaunchContainerApplication(
@@ -461,9 +499,13 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
       GetContainerSshKeysCallback callback,
       base::Optional<vm_tools::concierge::ContainerSshKeysResponse> reply);
 
+  // Helper for CrostiniManager::MaybeUpgradeCrostini. Makes blocking calls to
+  // check for file paths and registered components.
+  static void CheckPathsAndComponents();
+
   // Helper for CrostiniManager::MaybeUpgradeCrostini. Separated because the
-  // checking registration code may block.
-  void MaybeUpgradeCrostiniAfterTerminaCheck(bool is_registered);
+  // checking component registration code may block.
+  void MaybeUpgradeCrostiniAfterChecks();
 
   // Helper for CrostiniManager::CreateDiskImage. Separated so it can be run
   // off the main thread.
@@ -472,37 +514,65 @@ class CrostiniManager : public chromeos::ConciergeClient::Observer,
       CreateDiskImageCallback callback,
       int64_t free_disk_size);
 
+  void FinishRestart(CrostiniRestarter* restarter,
+                     ConciergeClientResult result);
+
+  // Callback for CrostiniManager::RemoveCrostini.
+  void OnRemoveCrostini(ConciergeClientResult result);
+
+  Profile* profile_;
+  std::string owner_id_;
+
   bool skip_restart_for_testing_ = false;
   component_updater::CrOSComponentManager::Error
       component_manager_load_error_for_testing_ =
           component_updater::CrOSComponentManager::Error::NONE;
 
-  bool is_cros_termina_registered_ = false;
+  static bool is_cros_termina_registered_;
   bool termina_update_check_needed_ = false;
+  static bool is_dev_kvm_present_;
 
-  // Pending StartContainer callbacks are keyed by <owner_id, vm_name,
-  // container_name> string tuples.
-  std::multimap<std::tuple<std::string, std::string, std::string>,
-                StartContainerCallback>
+  // Pending container started callbacks are keyed by <vm_name, container_name>
+  // string pairs.
+  std::multimap<std::pair<std::string, std::string>, StartContainerCallback>
       start_container_callbacks_;
 
-  // Pending ShutdownContainer callbacks are keyed by <owner_id, vm_name,
-  // container_name> string tuples.
-  std::multimap<std::tuple<std::string, std::string, std::string>,
-                ShutdownContainerCallback>
+  // Pending ShutdownContainer callbacks are keyed by <vm_name, container_name>
+  // string pairs.
+  std::multimap<std::pair<std::string, std::string>, ShutdownContainerCallback>
       shutdown_container_callbacks_;
 
-  // Running vms as <owner_id, vm_name> pairs.
-  std::set<std::pair<std::string, std::string>> running_vms_;
+  // Pending CreateLxdContainer callbacks are keyed by <vm_name, container_name>
+  // string pairs. These are used if CreateLxdContainer indicates we need to
+  // wait for an LxdContainerCreate signal.
+  std::multimap<std::pair<std::string, std::string>, CrostiniResultCallback>
+      create_lxd_container_callbacks_;
 
-  // Running containers as keyed by <owner_id, vm_name> string pairs.
-  std::multimap<std::pair<std::string, std::string>, std::string>
-      running_containers_;
+  // Callbacks to run after Tremplin is started, keyed by vm_name. These are
+  // used if StartTerminaVm completes but we need to wait from Tremplin to
+  // start.
+  std::multimap<std::string, base::OnceClosure> tremplin_started_callbacks_;
 
-  // Keyed by owner_id.
-  std::multimap<std::string, InstallLinuxPackageProgressObserver*>
+  std::map<std::string, std::pair<VmState, vm_tools::concierge::VmInfo>>
+      running_vms_;
+
+  // Running containers as keyed by vm name.
+  std::multimap<std::string, std::string> running_containers_;
+
+  std::vector<RemoveCrostiniCallback> remove_crostini_callbacks_;
+
+  base::ObserverList<InstallLinuxPackageProgressObserver>::Unchecked
       install_linux_package_progress_observers_;
 
+  // Restarts by <vm_name, container_name>. Only one restarter flow is actually
+  // running for a given container, other restarters will just have their
+  // callback called when the running restarter completes.
+  std::multimap<std::pair<std::string, std::string>, CrostiniManager::RestartId>
+      restarters_by_container_;
+
+  std::map<CrostiniManager::RestartId, scoped_refptr<CrostiniRestarter>>
+      restarters_by_id_;
+
   // Note: This should remain the last member so it'll be destroyed and
   // invalidate its weak pointers before any other members are destroyed.
   base::WeakPtrFactory<CrostiniManager> weak_ptr_factory_;
