@@ -3,6 +3,7 @@
 // found in the LICENSE file.
 
 #include "chrome/browser/chromeos/crostini/crostini_manager.h"
+#include <memory>
 #include "base/base64.h"
 #include "base/bind.h"
 #include "base/memory/ptr_util.h"
@@ -21,11 +22,8 @@
 namespace crostini {
 
 namespace {
-const char kOwnerId[] = "owner_id";
 const char kVmName[] = "vm_name";
 const char kContainerName[] = "container_name";
-const char kContainerUserName[] = "container_username";
-const char kCryptohomeId[] = "cryptohome_id";
 }  // namespace
 
 class CrostiniManagerTest : public testing::Test {
@@ -67,13 +65,6 @@ class CrostiniManagerTest : public testing::Test {
     std::move(closure).Run();
   }
 
-  void StartContainerClientErrorCallback(base::OnceClosure closure,
-                                         ConciergeClientResult result) {
-    EXPECT_FALSE(fake_concierge_client_->start_container_called());
-    EXPECT_EQ(result, ConciergeClientResult::CLIENT_ERROR);
-    std::move(closure).Run();
-  }
-
   void CreateDiskImageSuccessCallback(base::OnceClosure closure,
                                       ConciergeClientResult result,
                                       const base::FilePath& file_path) {
@@ -100,15 +91,23 @@ class CrostiniManagerTest : public testing::Test {
     std::move(closure).Run();
   }
 
+  void OnStartTremplinRecordsRunningVmCallback(base::OnceClosure closure,
+                                               ConciergeClientResult result) {
+    // Check that running_vms_ contains the running vm.
+    EXPECT_TRUE(crostini_manager()->IsVmRunning(kVmName));
+    std::move(closure).Run();
+  }
+
   void StopVmSuccessCallback(base::OnceClosure closure,
                              ConciergeClientResult result) {
     EXPECT_TRUE(fake_concierge_client_->stop_vm_called());
     std::move(closure).Run();
   }
 
-  void StartContainerSuccessCallback(base::OnceClosure closure,
-                                     ConciergeClientResult result) {
-    EXPECT_TRUE(fake_concierge_client_->start_container_called());
+  void CreateContainerFailsCallback(base::OnceClosure closure,
+                                    ConciergeClientResult result) {
+    create_container_fails_callback_called_ = true;
+    EXPECT_EQ(result, ConciergeClientResult::UNKNOWN_ERROR);
     std::move(closure).Run();
   }
 
@@ -123,17 +122,15 @@ class CrostiniManagerTest : public testing::Test {
   }
 
   CrostiniManagerTest()
-      : fake_cicerone_client_(new chromeos::FakeCiceroneClient()),
-        fake_concierge_client_(new chromeos::FakeConciergeClient()),
-        scoped_task_environment_(
+      : scoped_task_environment_(
             base::test::ScopedTaskEnvironment::MainThreadType::UI),
         test_browser_thread_bundle_(
             content::TestBrowserThreadBundle::REAL_IO_THREAD) {
-    chromeos::DBusThreadManager::GetSetterForTesting()->SetCiceroneClient(
-        base::WrapUnique(fake_cicerone_client_));
-    chromeos::DBusThreadManager::GetSetterForTesting()->SetConciergeClient(
-        base::WrapUnique(fake_concierge_client_));
     chromeos::DBusThreadManager::Initialize();
+    fake_cicerone_client_ = static_cast<chromeos::FakeCiceroneClient*>(
+        chromeos::DBusThreadManager::Get()->GetCiceroneClient());
+    fake_concierge_client_ = static_cast<chromeos::FakeConciergeClient*>(
+        chromeos::DBusThreadManager::Get()->GetConciergeClient());
   }
 
   ~CrostiniManagerTest() override { chromeos::DBusThreadManager::Shutdown(); }
@@ -141,16 +138,19 @@ class CrostiniManagerTest : public testing::Test {
   void SetUp() override {
     run_loop_ = std::make_unique<base::RunLoop>();
     profile_ = std::make_unique<TestingProfile>();
+    crostini_manager_ = std::make_unique<CrostiniManager>(profile_.get());
   }
 
   void TearDown() override {
-    run_loop_.reset();
+    crostini_manager_.reset();
     profile_.reset();
+    run_loop_.reset();
   }
 
  protected:
   base::RunLoop* run_loop() { return run_loop_.get(); }
   Profile* profile() { return profile_.get(); }
+  CrostiniManager* crostini_manager() { return crostini_manager_.get(); }
 
   // Owned by chromeos::DBusThreadManager
   chromeos::FakeCiceroneClient* fake_cicerone_client_;
@@ -159,6 +159,8 @@ class CrostiniManagerTest : public testing::Test {
   std::unique_ptr<base::RunLoop>
       run_loop_;  // run_loop_ must be created on the UI thread.
   std::unique_ptr<TestingProfile> profile_;
+  std::unique_ptr<CrostiniManager> crostini_manager_;
+  bool create_container_fails_callback_called_ = false;
 
  private:
   base::test::ScopedTaskEnvironment scoped_task_environment_;
@@ -169,19 +171,8 @@ class CrostiniManagerTest : public testing::Test {
 TEST_F(CrostiniManagerTest, CreateDiskImageNameError) {
   const base::FilePath& disk_path = base::FilePath("");
 
-  CrostiniManager::GetInstance()->CreateDiskImage(
-      "a_cryptohome_id", disk_path,
-      vm_tools::concierge::STORAGE_CRYPTOHOME_ROOT,
-      base::BindOnce(&CrostiniManagerTest::CreateDiskImageClientErrorCallback,
-                     base::Unretained(this), run_loop()->QuitClosure()));
-  run_loop()->Run();
-}
-
-TEST_F(CrostiniManagerTest, CreateDiskImageCryptohomeError) {
-  const base::FilePath& disk_path = base::FilePath(kVmName);
-
-  CrostiniManager::GetInstance()->CreateDiskImage(
-      "", disk_path, vm_tools::concierge::STORAGE_CRYPTOHOME_ROOT,
+  crostini_manager()->CreateDiskImage(
+      disk_path, vm_tools::concierge::STORAGE_CRYPTOHOME_ROOT,
       base::BindOnce(&CrostiniManagerTest::CreateDiskImageClientErrorCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
   run_loop()->Run();
@@ -190,8 +181,8 @@ TEST_F(CrostiniManagerTest, CreateDiskImageCryptohomeError) {
 TEST_F(CrostiniManagerTest, CreateDiskImageStorageLocationError) {
   const base::FilePath& disk_path = base::FilePath(kVmName);
 
-  CrostiniManager::GetInstance()->CreateDiskImage(
-      "a_cryptohome_id", disk_path,
+  crostini_manager()->CreateDiskImage(
+      disk_path,
       vm_tools::concierge::StorageLocation_INT_MIN_SENTINEL_DO_NOT_USE_,
       base::BindOnce(&CrostiniManagerTest::CreateDiskImageClientErrorCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
@@ -201,9 +192,8 @@ TEST_F(CrostiniManagerTest, CreateDiskImageStorageLocationError) {
 TEST_F(CrostiniManagerTest, CreateDiskImageSuccess) {
   const base::FilePath& disk_path = base::FilePath(kVmName);
 
-  CrostiniManager::GetInstance()->CreateDiskImage(
-      "a_cryptohome_id", disk_path,
-      vm_tools::concierge::STORAGE_CRYPTOHOME_DOWNLOADS,
+  crostini_manager()->CreateDiskImage(
+      disk_path, vm_tools::concierge::STORAGE_CRYPTOHOME_DOWNLOADS,
       base::BindOnce(&CrostiniManagerTest::CreateDiskImageSuccessCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
   run_loop()->Run();
@@ -212,19 +202,8 @@ TEST_F(CrostiniManagerTest, CreateDiskImageSuccess) {
 TEST_F(CrostiniManagerTest, DestroyDiskImageNameError) {
   const base::FilePath& disk_path = base::FilePath("");
 
-  CrostiniManager::GetInstance()->DestroyDiskImage(
-      "a_cryptohome_id", disk_path,
-      vm_tools::concierge::STORAGE_CRYPTOHOME_ROOT,
-      base::BindOnce(&CrostiniManagerTest::DestroyDiskImageClientErrorCallback,
-                     base::Unretained(this), run_loop()->QuitClosure()));
-  run_loop()->Run();
-}
-
-TEST_F(CrostiniManagerTest, DestroyDiskImageCryptohomeError) {
-  const base::FilePath& disk_path = base::FilePath(kVmName);
-
-  CrostiniManager::GetInstance()->DestroyDiskImage(
-      "", disk_path, vm_tools::concierge::STORAGE_CRYPTOHOME_ROOT,
+  crostini_manager()->DestroyDiskImage(
+      disk_path, vm_tools::concierge::STORAGE_CRYPTOHOME_ROOT,
       base::BindOnce(&CrostiniManagerTest::DestroyDiskImageClientErrorCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
   run_loop()->Run();
@@ -233,8 +212,8 @@ TEST_F(CrostiniManagerTest, DestroyDiskImageCryptohomeError) {
 TEST_F(CrostiniManagerTest, DestroyDiskImageStorageLocationError) {
   const base::FilePath& disk_path = base::FilePath(kVmName);
 
-  CrostiniManager::GetInstance()->DestroyDiskImage(
-      "a_cryptohome_id", disk_path,
+  crostini_manager()->DestroyDiskImage(
+      disk_path,
       vm_tools::concierge::StorageLocation_INT_MIN_SENTINEL_DO_NOT_USE_,
       base::BindOnce(&CrostiniManagerTest::DestroyDiskImageClientErrorCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
@@ -244,44 +223,25 @@ TEST_F(CrostiniManagerTest, DestroyDiskImageStorageLocationError) {
 TEST_F(CrostiniManagerTest, DestroyDiskImageSuccess) {
   const base::FilePath& disk_path = base::FilePath(kVmName);
 
-  CrostiniManager::GetInstance()->DestroyDiskImage(
-      "a_cryptohome_id", disk_path,
-      vm_tools::concierge::STORAGE_CRYPTOHOME_DOWNLOADS,
+  crostini_manager()->DestroyDiskImage(
+      disk_path, vm_tools::concierge::STORAGE_CRYPTOHOME_DOWNLOADS,
       base::BindOnce(&CrostiniManagerTest::DestroyDiskImageSuccessCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
   run_loop()->Run();
 }
 
-TEST_F(CrostiniManagerTest, ListVmDisksCryptohomeError) {
-  CrostiniManager::GetInstance()->ListVmDisks(
-      "", base::BindOnce(&CrostiniManagerTest::ListVmDisksClientErrorCallback,
-                         base::Unretained(this), run_loop()->QuitClosure()));
-  run_loop()->Run();
-}
-
 TEST_F(CrostiniManagerTest, ListVmDisksSuccess) {
-  CrostiniManager::GetInstance()->ListVmDisks(
-      "a_cryptohome_id",
+  crostini_manager()->ListVmDisks(
       base::BindOnce(&CrostiniManagerTest::ListVmDisksSuccessCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
   run_loop()->Run();
 }
 
-TEST_F(CrostiniManagerTest, StartTerminaVmOwnerIdError) {
-  const base::FilePath& disk_path = base::FilePath(kVmName);
-
-  CrostiniManager::GetInstance()->StartTerminaVm(
-      "", kVmName, disk_path,
-      base::BindOnce(&CrostiniManagerTest::StartTerminaVmClientErrorCallback,
-                     base::Unretained(this), run_loop()->QuitClosure()));
-  run_loop()->Run();
-}
-
 TEST_F(CrostiniManagerTest, StartTerminaVmNameError) {
   const base::FilePath& disk_path = base::FilePath(kVmName);
 
-  CrostiniManager::GetInstance()->StartTerminaVm(
-      kOwnerId, "", disk_path,
+  crostini_manager()->StartTerminaVm(
+      "", disk_path,
       base::BindOnce(&CrostiniManagerTest::StartTerminaVmClientErrorCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
   run_loop()->Run();
@@ -290,8 +250,8 @@ TEST_F(CrostiniManagerTest, StartTerminaVmNameError) {
 TEST_F(CrostiniManagerTest, StartTerminaVmDiskPathError) {
   const base::FilePath& disk_path = base::FilePath();
 
-  CrostiniManager::GetInstance()->StartTerminaVm(
-      kOwnerId, kVmName, disk_path,
+  crostini_manager()->StartTerminaVm(
+      kVmName, disk_path,
       base::BindOnce(&CrostiniManagerTest::StartTerminaVmClientErrorCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
   run_loop()->Run();
@@ -300,92 +260,50 @@ TEST_F(CrostiniManagerTest, StartTerminaVmDiskPathError) {
 TEST_F(CrostiniManagerTest, StartTerminaVmSuccess) {
   const base::FilePath& disk_path = base::FilePath(kVmName);
 
-  CrostiniManager::GetInstance()->StartTerminaVm(
-      kOwnerId, kVmName, disk_path,
+  crostini_manager()->StartTerminaVm(
+      kVmName, disk_path,
       base::BindOnce(&CrostiniManagerTest::StartTerminaVmSuccessCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
   run_loop()->Run();
 }
 
+TEST_F(CrostiniManagerTest, OnStartTremplinRecordsRunningVm) {
+  const base::FilePath& disk_path = base::FilePath(kVmName);
+  const std::string owner_id = CryptohomeIdForProfile(profile());
+
+  // Start the Vm.
+  crostini_manager()->StartTerminaVm(
+      kVmName, disk_path,
+      base::BindOnce(
+          &CrostiniManagerTest::OnStartTremplinRecordsRunningVmCallback,
+          base::Unretained(this), run_loop()->QuitClosure()));
+
+  // Check that the Vm start is not recorded (without tremplin start).
+  EXPECT_FALSE(crostini_manager()->IsVmRunning(kVmName));
+
+  run_loop()->Run();
+}
+
 TEST_F(CrostiniManagerTest, StopVmNameError) {
-  CrostiniManager::GetInstance()->StopVm(
-      profile(), "",
-      base::BindOnce(&CrostiniManagerTest::StopVmClientErrorCallback,
-                     base::Unretained(this), run_loop()->QuitClosure()));
+  crostini_manager()->StopVm(
+      "", base::BindOnce(&CrostiniManagerTest::StopVmClientErrorCallback,
+                         base::Unretained(this), run_loop()->QuitClosure()));
   run_loop()->Run();
 }
 
 TEST_F(CrostiniManagerTest, StopVmSuccess) {
-  CrostiniManager::GetInstance()->StopVm(
-      profile(), kVmName,
+  crostini_manager()->StopVm(
+      kVmName,
       base::BindOnce(&CrostiniManagerTest::StopVmSuccessCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
   run_loop()->Run();
 }
 
-TEST_F(CrostiniManagerTest, StartContainerVmNameError) {
-  CrostiniManager::GetInstance()->StartContainer(
-      "", kContainerName, kContainerUserName, kCryptohomeId,
-      base::BindOnce(&CrostiniManagerTest::StartContainerClientErrorCallback,
-                     base::Unretained(this), run_loop()->QuitClosure()));
-  run_loop()->Run();
-}
-
-TEST_F(CrostiniManagerTest, StartContainerContainerNameError) {
-  CrostiniManager::GetInstance()->StartContainer(
-      kVmName, "", kContainerUserName, kCryptohomeId,
-      base::BindOnce(&CrostiniManagerTest::StartContainerClientErrorCallback,
-                     base::Unretained(this), run_loop()->QuitClosure()));
-  run_loop()->Run();
-}
-
-TEST_F(CrostiniManagerTest, StartContainerContainerUserNameError) {
-  CrostiniManager::GetInstance()->StartContainer(
-      kVmName, kContainerName, "", kCryptohomeId,
-      base::BindOnce(&CrostiniManagerTest::StartContainerClientErrorCallback,
-                     base::Unretained(this), run_loop()->QuitClosure()));
-  run_loop()->Run();
-}
-
-TEST_F(CrostiniManagerTest, StartContainerContainerCryptohomeIdError) {
-  CrostiniManager::GetInstance()->StartContainer(
-      kVmName, kContainerName, kContainerUserName, "",
-      base::BindOnce(&CrostiniManagerTest::StartContainerClientErrorCallback,
-                     base::Unretained(this), run_loop()->QuitClosure()));
-  run_loop()->Run();
-}
-
-TEST_F(CrostiniManagerTest, StartContainerSignalNotConnectedError) {
-  fake_cicerone_client_->set_container_started_signal_connected(false);
-  CrostiniManager::GetInstance()->StartContainer(
-      kVmName, kContainerName, kContainerUserName, kCryptohomeId,
-      base::BindOnce(&CrostiniManagerTest::StartContainerClientErrorCallback,
-                     base::Unretained(this), run_loop()->QuitClosure()));
-  run_loop()->Run();
-}
-
-TEST_F(CrostiniManagerTest, ShutdownContainerSignalNotConnectedError) {
-  fake_cicerone_client_->set_container_shutdown_signal_connected(false);
-  CrostiniManager::GetInstance()->StartContainer(
-      kVmName, kContainerName, kContainerUserName, kCryptohomeId,
-      base::BindOnce(&CrostiniManagerTest::StartContainerClientErrorCallback,
-                     base::Unretained(this), run_loop()->QuitClosure()));
-  run_loop()->Run();
-}
-
-TEST_F(CrostiniManagerTest, StartContainerSuccess) {
-  CrostiniManager::GetInstance()->StartContainer(
-      kVmName, kContainerName, kContainerUserName, kCryptohomeId,
-      base::BindOnce(&CrostiniManagerTest::StartContainerSuccessCallback,
-                     base::Unretained(this), run_loop()->QuitClosure()));
-  run_loop()->Run();
-}
-
 TEST_F(CrostiniManagerTest, InstallLinuxPackageSignalNotConnectedError) {
   fake_cicerone_client_->set_install_linux_package_progress_signal_connected(
       false);
-  CrostiniManager::GetInstance()->InstallLinuxPackage(
-      profile(), kVmName, kContainerName, "/tmp/package.deb",
+  crostini_manager()->InstallLinuxPackage(
+      kVmName, kContainerName, "/tmp/package.deb",
       base::BindOnce(&CrostiniManagerTest::InstallLinuxPackageCallback,
                      base::Unretained(this), run_loop()->QuitClosure(),
                      ConciergeClientResult::INSTALL_LINUX_PACKAGE_FAILED,
@@ -397,8 +315,8 @@ TEST_F(CrostiniManagerTest, InstallLinuxPackageSignalSuccess) {
   vm_tools::cicerone::InstallLinuxPackageResponse response;
   response.set_status(vm_tools::cicerone::InstallLinuxPackageResponse::STARTED);
   fake_cicerone_client_->set_install_linux_package_response(response);
-  CrostiniManager::GetInstance()->InstallLinuxPackage(
-      profile(), kVmName, kContainerName, "/tmp/package.deb",
+  crostini_manager()->InstallLinuxPackage(
+      kVmName, kContainerName, "/tmp/package.deb",
       base::BindOnce(&CrostiniManagerTest::InstallLinuxPackageCallback,
                      base::Unretained(this), run_loop()->QuitClosure(),
                      ConciergeClientResult::SUCCESS, std::string()));
@@ -411,8 +329,8 @@ TEST_F(CrostiniManagerTest, InstallLinuxPackageSignalFailure) {
   response.set_status(vm_tools::cicerone::InstallLinuxPackageResponse::FAILED);
   response.set_failure_reason(failure_reason);
   fake_cicerone_client_->set_install_linux_package_response(response);
-  CrostiniManager::GetInstance()->InstallLinuxPackage(
-      profile(), kVmName, kContainerName, "/tmp/package.deb",
+  crostini_manager()->InstallLinuxPackage(
+      kVmName, kContainerName, "/tmp/package.deb",
       base::BindOnce(&CrostiniManagerTest::InstallLinuxPackageCallback,
                      base::Unretained(this), run_loop()->QuitClosure(),
                      ConciergeClientResult::INSTALL_LINUX_PACKAGE_FAILED,
@@ -423,6 +341,8 @@ TEST_F(CrostiniManagerTest, InstallLinuxPackageSignalFailure) {
 class CrostiniManagerRestartTest : public CrostiniManagerTest,
                                    public CrostiniManager::RestartObserver {
  public:
+  void SetUp() override { CrostiniManagerTest::SetUp(); }
+
   void RestartCrostiniCallback(base::OnceClosure closure,
                                ConciergeClientResult result) {
     restart_crostini_callback_count_++;
@@ -454,6 +374,14 @@ class CrostiniManagerRestartTest : public CrostiniManagerTest,
     }
   }
 
+  void OnContainerDownloading(int32_t download_percent) override {}
+
+  void OnContainerCreated(ConciergeClientResult result) override {
+    if (abort_on_container_created_) {
+      Abort();
+    }
+  }
+
   void OnContainerStarted(ConciergeClientResult result) override {
     if (abort_on_container_started_) {
       Abort();
@@ -468,8 +396,7 @@ class CrostiniManagerRestartTest : public CrostiniManagerTest,
 
  protected:
   void Abort() {
-    CrostiniManager::GetInstance()->AbortRestartCrostini(profile(),
-                                                         restart_id_);
+    crostini_manager()->AbortRestartCrostini(restart_id_);
     run_loop()->Quit();
   }
 
@@ -494,6 +421,7 @@ class CrostiniManagerRestartTest : public CrostiniManagerTest,
   bool abort_on_concierge_started_ = false;
   bool abort_on_disk_image_created_ = false;
   bool abort_on_vm_started_ = false;
+  bool abort_on_container_created_ = false;
   bool abort_on_container_started_ = false;
   bool abort_on_ssh_keys_fetched_ = false;
   int restart_crostini_callback_count_ = 0;
@@ -501,15 +429,14 @@ class CrostiniManagerRestartTest : public CrostiniManagerTest,
 };
 
 TEST_F(CrostiniManagerRestartTest, RestartSuccess) {
-  restart_id_ = CrostiniManager::GetInstance()->RestartCrostini(
-      profile(), kVmName, kContainerName,
+  restart_id_ = crostini_manager()->RestartCrostini(
+      kVmName, kContainerName,
       base::BindOnce(&CrostiniManagerRestartTest::RestartCrostiniCallback,
                      base::Unretained(this), run_loop()->QuitClosure()),
       this);
   run_loop()->Run();
   EXPECT_TRUE(fake_concierge_client_->create_disk_image_called());
   EXPECT_TRUE(fake_concierge_client_->start_termina_vm_called());
-  EXPECT_TRUE(fake_concierge_client_->start_container_called());
   // Mount only performed for termina/penguin.
   EXPECT_FALSE(fake_concierge_client_->get_container_ssh_keys_called());
   EXPECT_EQ(1, restart_crostini_callback_count_);
@@ -517,60 +444,90 @@ TEST_F(CrostiniManagerRestartTest, RestartSuccess) {
 
 TEST_F(CrostiniManagerRestartTest, AbortOnComponentLoaded) {
   abort_on_component_loaded_ = true;
-  restart_id_ = CrostiniManager::GetInstance()->RestartCrostini(
-      profile(), kVmName, kContainerName,
+  restart_id_ = crostini_manager()->RestartCrostini(
+      kVmName, kContainerName,
       base::BindOnce(&CrostiniManagerRestartTest::RestartCrostiniCallback,
                      base::Unretained(this), run_loop()->QuitClosure()),
       this);
   run_loop()->Run();
   EXPECT_FALSE(fake_concierge_client_->create_disk_image_called());
   EXPECT_FALSE(fake_concierge_client_->start_termina_vm_called());
-  EXPECT_FALSE(fake_concierge_client_->start_container_called());
   EXPECT_FALSE(fake_concierge_client_->get_container_ssh_keys_called());
   EXPECT_EQ(0, restart_crostini_callback_count_);
 }
 
 TEST_F(CrostiniManagerRestartTest, AbortOnConciergeStarted) {
   abort_on_concierge_started_ = true;
-  restart_id_ = CrostiniManager::GetInstance()->RestartCrostini(
-      profile(), kVmName, kContainerName,
+  restart_id_ = crostini_manager()->RestartCrostini(
+      kVmName, kContainerName,
       base::BindOnce(&CrostiniManagerRestartTest::RestartCrostiniCallback,
                      base::Unretained(this), run_loop()->QuitClosure()),
       this);
   run_loop()->Run();
   EXPECT_FALSE(fake_concierge_client_->create_disk_image_called());
   EXPECT_FALSE(fake_concierge_client_->start_termina_vm_called());
-  EXPECT_FALSE(fake_concierge_client_->start_container_called());
   EXPECT_FALSE(fake_concierge_client_->get_container_ssh_keys_called());
   EXPECT_EQ(0, restart_crostini_callback_count_);
 }
 
 TEST_F(CrostiniManagerRestartTest, AbortOnDiskImageCreated) {
   abort_on_disk_image_created_ = true;
-  restart_id_ = CrostiniManager::GetInstance()->RestartCrostini(
-      profile(), kVmName, kContainerName,
+  restart_id_ = crostini_manager()->RestartCrostini(
+      kVmName, kContainerName,
       base::BindOnce(&CrostiniManagerRestartTest::RestartCrostiniCallback,
                      base::Unretained(this), run_loop()->QuitClosure()),
       this);
   run_loop()->Run();
   EXPECT_TRUE(fake_concierge_client_->create_disk_image_called());
   EXPECT_FALSE(fake_concierge_client_->start_termina_vm_called());
-  EXPECT_FALSE(fake_concierge_client_->start_container_called());
   EXPECT_FALSE(fake_concierge_client_->get_container_ssh_keys_called());
   EXPECT_EQ(0, restart_crostini_callback_count_);
 }
 
 TEST_F(CrostiniManagerRestartTest, AbortOnVmStarted) {
   abort_on_vm_started_ = true;
-  restart_id_ = CrostiniManager::GetInstance()->RestartCrostini(
-      profile(), kVmName, kContainerName,
+  restart_id_ = crostini_manager()->RestartCrostini(
+      kVmName, kContainerName,
       base::BindOnce(&CrostiniManagerRestartTest::RestartCrostiniCallback,
                      base::Unretained(this), run_loop()->QuitClosure()),
       this);
   run_loop()->Run();
   EXPECT_TRUE(fake_concierge_client_->create_disk_image_called());
   EXPECT_TRUE(fake_concierge_client_->start_termina_vm_called());
-  EXPECT_FALSE(fake_concierge_client_->start_container_called());
+  EXPECT_FALSE(fake_concierge_client_->get_container_ssh_keys_called());
+  EXPECT_EQ(0, restart_crostini_callback_count_);
+}
+
+TEST_F(CrostiniManagerRestartTest, AbortOnContainerCreated) {
+  abort_on_container_created_ = true;
+  // Use termina/penguin names to allow fetch ssh keys.
+  restart_id_ = crostini_manager()->RestartCrostini(
+      kCrostiniDefaultVmName, kCrostiniDefaultContainerName,
+      base::BindOnce(&CrostiniManagerRestartTest::RestartCrostiniCallback,
+                     base::Unretained(this), run_loop()->QuitClosure()),
+      this);
+  run_loop()->Run();
+  EXPECT_TRUE(fake_concierge_client_->create_disk_image_called());
+  EXPECT_TRUE(fake_concierge_client_->start_termina_vm_called());
+  EXPECT_FALSE(fake_concierge_client_->get_container_ssh_keys_called());
+  EXPECT_EQ(0, restart_crostini_callback_count_);
+}
+
+TEST_F(CrostiniManagerRestartTest, AbortOnContainerCreatedError) {
+  abort_on_container_started_ = true;
+  fake_cicerone_client_->set_lxd_container_created_signal_status(
+      vm_tools::cicerone::LxdContainerCreatedSignal::UNKNOWN);
+  // Use termina/penguin names to allow fetch ssh keys.
+  restart_id_ = crostini_manager()->RestartCrostini(
+      kCrostiniDefaultVmName, kCrostiniDefaultContainerName,
+      base::BindOnce(&CrostiniManagerTest::CreateContainerFailsCallback,
+                     base::Unretained(this), run_loop()->QuitClosure()),
+      this);
+  run_loop()->Run();
+
+  EXPECT_TRUE(create_container_fails_callback_called_);
+  EXPECT_TRUE(fake_concierge_client_->create_disk_image_called());
+  EXPECT_TRUE(fake_concierge_client_->start_termina_vm_called());
   EXPECT_FALSE(fake_concierge_client_->get_container_ssh_keys_called());
   EXPECT_EQ(0, restart_crostini_callback_count_);
 }
@@ -578,65 +535,59 @@ TEST_F(CrostiniManagerRestartTest, AbortOnVmStarted) {
 TEST_F(CrostiniManagerRestartTest, AbortOnContainerStarted) {
   abort_on_container_started_ = true;
   // Use termina/penguin names to allow fetch ssh keys.
-  restart_id_ = CrostiniManager::GetInstance()->RestartCrostini(
-      profile(), kCrostiniDefaultVmName, kCrostiniDefaultContainerName,
+  restart_id_ = crostini_manager()->RestartCrostini(
+      kCrostiniDefaultVmName, kCrostiniDefaultContainerName,
       base::BindOnce(&CrostiniManagerRestartTest::RestartCrostiniCallback,
                      base::Unretained(this), run_loop()->QuitClosure()),
       this);
   run_loop()->Run();
   EXPECT_TRUE(fake_concierge_client_->create_disk_image_called());
   EXPECT_TRUE(fake_concierge_client_->start_termina_vm_called());
-  EXPECT_TRUE(fake_concierge_client_->start_container_called());
   EXPECT_FALSE(fake_concierge_client_->get_container_ssh_keys_called());
   EXPECT_EQ(0, restart_crostini_callback_count_);
 }
 
 TEST_F(CrostiniManagerRestartTest, OnlyMountTerminaPenguin) {
   // Use names other than termina/penguin.  Will not mount sshfs.
-  restart_id_ = CrostiniManager::GetInstance()->RestartCrostini(
-      profile(), kVmName, kContainerName,
+  restart_id_ = crostini_manager()->RestartCrostini(
+      kVmName, kContainerName,
       base::BindOnce(&CrostiniManagerRestartTest::RestartCrostiniCallback,
                      base::Unretained(this), run_loop()->QuitClosure()),
       this);
   run_loop()->Run();
   EXPECT_TRUE(fake_concierge_client_->create_disk_image_called());
   EXPECT_TRUE(fake_concierge_client_->start_termina_vm_called());
-  EXPECT_TRUE(fake_concierge_client_->start_container_called());
   EXPECT_FALSE(fake_concierge_client_->get_container_ssh_keys_called());
   EXPECT_EQ(1, restart_crostini_callback_count_);
 }
 
 TEST_F(CrostiniManagerRestartTest, MultiRestartAllowed) {
   CrostiniManager::RestartId id1, id2, id3;
-  id1 = CrostiniManager::GetInstance()->RestartCrostini(
-      profile(), kVmName, kContainerName,
+  id1 = crostini_manager()->RestartCrostini(
+      kVmName, kContainerName,
       base::BindOnce(&CrostiniManagerRestartTest::RestartCrostiniCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
-  id2 = CrostiniManager::GetInstance()->RestartCrostini(
-      profile(), kVmName, kContainerName,
+  id2 = crostini_manager()->RestartCrostini(
+      kVmName, kContainerName,
       base::BindOnce(&CrostiniManagerRestartTest::RestartCrostiniCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
-  id3 = CrostiniManager::GetInstance()->RestartCrostini(
-      profile(), kVmName, kContainerName,
+  id3 = crostini_manager()->RestartCrostini(
+      kVmName, kContainerName,
       base::BindOnce(&CrostiniManagerRestartTest::RestartCrostiniCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
 
-  EXPECT_TRUE(CrostiniManager::GetInstance()->IsRestartPending(profile(), id1));
-  EXPECT_TRUE(CrostiniManager::GetInstance()->IsRestartPending(profile(), id2));
-  EXPECT_TRUE(CrostiniManager::GetInstance()->IsRestartPending(profile(), id3));
+  EXPECT_TRUE(crostini_manager()->IsRestartPending(id1));
+  EXPECT_TRUE(crostini_manager()->IsRestartPending(id2));
+  EXPECT_TRUE(crostini_manager()->IsRestartPending(id3));
 
   run_loop()->Run();
   EXPECT_TRUE(fake_concierge_client_->create_disk_image_called());
   EXPECT_TRUE(fake_concierge_client_->start_termina_vm_called());
-  EXPECT_TRUE(fake_concierge_client_->start_container_called());
   EXPECT_EQ(3, restart_crostini_callback_count_);
 
-  EXPECT_FALSE(
-      CrostiniManager::GetInstance()->IsRestartPending(profile(), id1));
-  EXPECT_FALSE(
-      CrostiniManager::GetInstance()->IsRestartPending(profile(), id2));
-  EXPECT_FALSE(
-      CrostiniManager::GetInstance()->IsRestartPending(profile(), id3));
+  EXPECT_FALSE(crostini_manager()->IsRestartPending(id1));
+  EXPECT_FALSE(crostini_manager()->IsRestartPending(id2));
+  EXPECT_FALSE(crostini_manager()->IsRestartPending(id3));
 }
 
 TEST_F(CrostiniManagerRestartTest, MountForTerminaPenguin) {
@@ -663,15 +614,13 @@ TEST_F(CrostiniManagerRestartTest, MountForTerminaPenguin) {
           &CrostiniManagerRestartTest_MountForTerminaPenguin_Test::SshfsMount));
 
   // Use termina/penguin to perform mount.
-  restart_id_ = CrostiniManager::GetInstance()->RestartCrostini(
-      profile(), kCrostiniDefaultVmName, kCrostiniDefaultContainerName,
+  restart_id_ = crostini_manager()->RestartCrostini(
+      kCrostiniDefaultVmName, kCrostiniDefaultContainerName,
       base::BindOnce(&CrostiniManagerRestartTest::RestartCrostiniCallback,
                      base::Unretained(this), run_loop()->QuitClosure()));
-
   run_loop()->Run();
   EXPECT_TRUE(fake_concierge_client_->create_disk_image_called());
   EXPECT_TRUE(fake_concierge_client_->start_termina_vm_called());
-  EXPECT_TRUE(fake_concierge_client_->start_container_called());
   EXPECT_TRUE(fake_concierge_client_->get_container_ssh_keys_called());
   EXPECT_EQ(1, restart_crostini_callback_count_);
   base::FilePath path;
