@@ -192,7 +192,7 @@ IN_PROC_BROWSER_TEST_F(CustomizationLocaleTest, CheckAvailableLocales) {
     waiter.Wait();
     {
       std::string resolved_locale;
-      base::ThreadRestrictions::ScopedAllowIO allow_io;
+      base::ScopedAllowBlockingForTesting allow_blocking;
       l10n_util::CheckAndResolveLocale(languages_available[i],
                                        &resolved_locale);
       EXPECT_EQ(GetExpectedLanguage(languages_available[i]), resolved_locale)
@@ -214,7 +214,7 @@ class CustomizationVPDTest : public InProcessBrowserTest,
   }
 
  private:
-  scoped_ptr<system::FakeStatisticsProvider> statistics_provider_;
+  std::unique_ptr<system::FakeStatisticsProvider> statistics_provider_;
 };
 
 IN_PROC_BROWSER_TEST_P(CustomizationVPDTest, GetUILanguageList) {
@@ -229,7 +229,8 @@ IN_PROC_BROWSER_TEST_P(CustomizationVPDTest, GetUILanguageList) {
       << "Test failed for initial_locale='" << GetParam()
       << "', locales=" << Print(locales);
 
-  scoped_ptr<base::ListValue> ui_language_list = GetUILanguageList(NULL, "");
+  std::unique_ptr<base::ListValue> ui_language_list =
+      GetUILanguageList(NULL, "");
   EXPECT_GE(ui_language_list->GetSize(), locales.size())
       << "Test failed for initial_locale='" << GetParam() << "'";
 
