@@ -5,10 +5,12 @@
 #include "base/files/file_util.h"
 #include "base/memory/ptr_util.h"
 #include "base/run_loop.h"
+#include "base/test/bind_test_util.h"
 #include "chrome/test/base/in_process_browser_test.h"
 #include "components/quirks/quirks_manager.h"
 #include "content/public/test/test_utils.h"
-#include "net/url_request/test_url_fetcher_factory.h"
+#include "services/network/public/cpp/weak_wrapper_shared_url_loader_factory.h"
+#include "services/network/test/test_url_loader_factory.h"
 
 namespace quirks {
 
@@ -18,26 +20,6 @@ const char kFakeIccJson[] = "{\n  \"icc\": \"AAAIkCAgICACEAAA\"\n}";
 const char kFakeIccData[] = {0x00, 0x00, 0x08, 0x90, 0x20, 0x20,
                              0x20, 0x20, 0x02, 0x10, 0x00, 0x00};
 
-// Create FakeURLFetcher which returns fake icc file json.
-std::unique_ptr<net::URLFetcher> CreateFakeURLFetcherSuccess(
-    const GURL& url,
-    net::URLFetcherDelegate* delegate) {
-  net::URLFetcher* fetcher =
-      new net::FakeURLFetcher(url, delegate, kFakeIccJson, net::HTTP_OK,
-                              net::URLRequestStatus::SUCCESS);
-  return base::WrapUnique(fetcher);
-}
-
-// Create FakeURLFetcher which replies with HTTP_NOT_FOUND.
-std::unique_ptr<net::URLFetcher> CreateFakeURLFetcherFailure(
-    const GURL& url,
-    net::URLFetcherDelegate* delegate) {
-  net::URLFetcher* fetcher = new net::FakeURLFetcher(
-      url, delegate, "File not found", net::HTTP_NOT_FOUND,
-      net::URLRequestStatus::FAILED);
-  return base::WrapUnique(fetcher);
-}
-
 // Full path to fake icc file in <tmp test directory>/display_profiles/.
 base::FilePath GetPathForIccFile(int64_t product_id) {
   return QuirksManager::Get()->delegate()->GetDisplayProfileDirectory().Append(
@@ -48,7 +30,18 @@ base::FilePath GetPathForIccFile(int64_t product_id) {
 
 class QuirksBrowserTest : public InProcessBrowserTest {
  public:
-  QuirksBrowserTest() : file_existed_(false) {}
+  QuirksBrowserTest() {
+    test_url_loader_factory_.SetInterceptor(base::BindLambdaForTesting(
+        [this](const network::ResourceRequest& request) {
+          if (find_fake_file_) {
+            test_url_loader_factory_.AddResponse(request.url.spec(),
+                                                 kFakeIccJson);
+          } else {
+            test_url_loader_factory_.AddResponse(request.url.spec(), "",
+                                                 net::HTTP_NOT_FOUND);
+          }
+        }));
+  }
 
  protected:
   ~QuirksBrowserTest() override = default;
@@ -56,10 +49,7 @@ class QuirksBrowserTest : public InProcessBrowserTest {
   // Query QuirksManager for icc file, then run msg loop to wait for callback.
   // |find_fake_file| indicates that URLFetcher should respond with success.
   void TestQuirksClient(int64_t product_id, bool find_fake_file) {
-    // Set up fake url getter.
-    QuirksManager::Get()->SetFakeQuirksFetcherCreatorForTests(
-        base::Bind(find_fake_file ? &CreateFakeURLFetcherSuccess
-                                  : &CreateFakeURLFetcherFailure));
+    find_fake_file_ = find_fake_file;
 
     base::RunLoop run_loop;
     end_message_loop_ = run_loop.QuitClosure();
@@ -70,6 +60,8 @@ class QuirksBrowserTest : public InProcessBrowserTest {
                    base::Unretained(this)));
 
     run_loop.Run();
+
+    test_url_loader_factory_.ClearResponses();
   }
 
   // Callback from RequestIccProfilePath().
@@ -93,11 +85,20 @@ class QuirksBrowserTest : public InProcessBrowserTest {
 
     // Quirks clients can't run until after login.
     quirks::QuirksManager::Get()->OnLoginCompleted();
+
+    // Set up interception for URL requests.
+    QuirksManager::Get()->SetURLLoaderFactoryForTests(
+        base::MakeRefCounted<network::WeakWrapperSharedURLLoaderFactory>(
+            &test_url_loader_factory_));
   }
 
   base::Closure end_message_loop_;  // Callback to terminate message loop.
   base::FilePath icc_path_;         // Path to icc file if found or downloaded.
-  bool file_existed_;               // File was previously downloaded.
+  bool file_existed_ = false;       // File was previously downloaded.
+  bool find_fake_file_ = false;     // Return success from Quirks server
+                                    // request.
+
+  network::TestURLLoaderFactory test_url_loader_factory_;
 
  private:
   DISALLOW_COPY_AND_ASSIGN(QuirksBrowserTest);
