@@ -4,11 +4,11 @@
 
 #include "chrome/browser/chromeos/drive/drive_integration_service.h"
 
-#include "base/prefs/pref_service.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/ui/browser.h"
 #include "chrome/test/base/in_process_browser_test.h"
 #include "components/drive/drive_pref_names.h"
+#include "components/prefs/pref_service.h"
 
 namespace drive {
 
