@@ -48,10 +48,6 @@ using content::BrowserThread;
 namespace drive {
 namespace util {
 
-namespace {
-
-// Returns DriveIntegrationService instance, if Drive is enabled.
-// Otherwise, NULL.
 DriveIntegrationService* GetIntegrationServiceByProfile(Profile* profile) {
   DriveIntegrationService* service =
       DriveIntegrationServiceFactory::FindForProfile(profile);
@@ -60,8 +56,6 @@ DriveIntegrationService* GetIntegrationServiceByProfile(Profile* profile) {
   return service;
 }
 
-}  // namespace
-
 base::FilePath GetDriveMountPointPath(Profile* profile) {
   std::string id = chromeos::ProfileHelper::GetUserIdHashFromProfile(profile);
   if (id.empty() || id == chrome::kLegacyProfileDir) {
@@ -134,15 +128,6 @@ FileSystemInterface* GetFileSystemByProfileId(void* profile_id) {
   return GetFileSystemByProfile(profile);
 }
 
-DriveAppRegistry* GetDriveAppRegistryByProfile(Profile* profile) {
-  DCHECK_CURRENTLY_ON(BrowserThread::UI);
-
-  DriveIntegrationService* integration_service =
-      GetIntegrationServiceByProfile(profile);
-  return integration_service ? integration_service->drive_app_registry()
-                             : nullptr;
-}
-
 DriveServiceInterface* GetDriveServiceByProfile(Profile* profile) {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
 
