@@ -12,14 +12,14 @@
 
 namespace extensions {
 
-// This class adds a logging feature to AsyncExtensionFunction. Logging is
+// This class adds a logging feature to ChromeAsyncExtensionFunction. Logging is
 // done when sending the response to JavaScript, using drive::util::Log().
 // Async API functions of fileManagerPrivate should inherit this class.
 //
 // By default, logging is turned off, hence sub classes should call
 // set_log_on_completion(true) to enable it, if they want. However, even if
 // the logging is turned off, a warning is emitted when a function call is
-// very slow. See the implementation of SendResponse() for details.
+// very slow. See the implementation of OnResponded() for details.
 class LoggedAsyncExtensionFunction : public ChromeAsyncExtensionFunction {
  public:
   LoggedAsyncExtensionFunction();
@@ -27,8 +27,8 @@ class LoggedAsyncExtensionFunction : public ChromeAsyncExtensionFunction {
  protected:
   ~LoggedAsyncExtensionFunction() override;
 
-  // AsyncExtensionFunction overrides.
-  void SendResponse(bool success) override;
+  // ChromeAsyncExtensionFunction overrides.
+  void OnResponded() override;
 
   // Sets the logging on completion flag. By default, logging is turned off.
   void set_log_on_completion(bool log_on_completion) {
