@@ -11,8 +11,13 @@
 
 #include "base/base64.h"
 #include "base/command_line.h"
+#include "base/i18n/string_search.h"
 #include "base/memory/ptr_util.h"
+#include "base/metrics/histogram_functions.h"
 #include "base/strings/strcat.h"
+#include "base/strings/string_piece.h"
+#include "base/strings/string_split.h"
+#include "base/strings/utf_string_conversions.h"
 #include "base/task/post_task.h"
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/chromeos/drive/drive_integration_service.h"
@@ -35,7 +40,7 @@
 #include "chromeos/chromeos_switches.h"
 #include "chromeos/network/network_handler.h"
 #include "chromeos/network/network_state_handler.h"
-#include "components/drive/drive_app_registry.h"
+#include "components/drive/chromeos/search_metadata.h"
 #include "components/drive/event_logger.h"
 #include "components/signin/core/browser/profile_oauth2_token_service.h"
 #include "components/signin/core/browser/signin_manager.h"
@@ -43,8 +48,8 @@
 #include "content/public/browser/storage_partition.h"
 #include "google_apis/drive/auth_service.h"
 #include "google_apis/drive/drive_api_url_generator.h"
-#include "google_apis/drive/drive_switches.h"
 #include "mojo/public/cpp/bindings/callback_helpers.h"
+#include "net/base/network_change_notifier.h"
 #include "services/network/public/cpp/shared_url_loader_factory.h"
 #include "storage/common/fileapi/file_system_info.h"
 #include "storage/common/fileapi/file_system_util.h"
@@ -132,8 +137,7 @@ void FillEntryPropertiesValueForDrive(const drive::ResourceEntry& entry_proto,
       DriveApiUrlGenerator url_generator(
           (GURL(google_apis::DriveApiUrlGenerator::kBaseUrlForProduction)),
           (GURL(google_apis::DriveApiUrlGenerator::
-                    kBaseThumbnailUrlForProduction)),
-          google_apis::GetTeamDrivesIntegrationSwitch());
+                    kBaseThumbnailUrlForProduction)));
       properties->thumbnail_url = std::make_unique<std::string>(
           url_generator
               .GetThumbnailUrl(entry_proto.resource_id(), 500 /* width */,
@@ -230,7 +234,7 @@ void ConvertSearchResultInfoListToEntryDefinitionList(
     Profile* profile,
     const std::string& extension_id,
     const std::vector<T>& search_result_info_list,
-    const EntryDefinitionListCallback& callback) {
+    EntryDefinitionListCallback callback) {
   FileDefinitionList file_definition_list;
 
   for (size_t i = 0; i < search_result_info_list.size(); ++i) {
@@ -243,10 +247,9 @@ void ConvertSearchResultInfoListToEntryDefinitionList(
   }
 
   file_manager::util::ConvertFileDefinitionListToEntryDefinitionList(
-      profile,
-      extension_id,
+      profile, extension_id,
       file_definition_list,  // Safe, since copied internally.
-      callback);
+      std::move(callback));
 }
 
 class SingleEntryPropertiesGetterForDrive {
@@ -392,10 +395,8 @@ class SingleEntryPropertiesGetterForDrive {
 
     drive::FileSystemInterface* const file_system =
         drive::util::GetFileSystemByProfile(file_owner_profile_);
-    drive::DriveAppRegistry* const app_registry =
-        drive::util::GetDriveAppRegistryByProfile(file_owner_profile_);
-    if (!file_system || !app_registry) {
-      // |file_system| or |app_registry| is NULL if Drive is disabled.
+    if (!file_system) {
+      // |file_system| is NULL if Drive is disabled.
       CompleteGetEntryProperties(drive::FILE_ERROR_FAILED);
       return;
     }
@@ -407,37 +408,6 @@ class SingleEntryPropertiesGetterForDrive {
       return;
     }
 
-    const drive::FileSpecificInfo& file_specific_info =
-        owner_resource_entry_->file_specific_info();
-
-    // Get drive WebApps that can accept this file. We just need to extract the
-    // doc icon for the drive app, which is set as default.
-    std::vector<drive::DriveAppInfo> drive_apps;
-    app_registry->GetAppsForFile(file_path_.Extension(),
-                                 file_specific_info.content_mime_type(),
-                                 &drive_apps);
-    if (!drive_apps.empty()) {
-      std::string default_task_id =
-          file_manager::file_tasks::GetDefaultTaskIdFromPrefs(
-              *file_owner_profile_->GetPrefs(),
-              file_specific_info.content_mime_type(),
-              file_path_.Extension());
-      file_manager::file_tasks::TaskDescriptor default_task;
-      file_manager::file_tasks::ParseTaskID(default_task_id, &default_task);
-      DCHECK(default_task_id.empty() || !default_task.app_id.empty());
-      for (size_t i = 0; i < drive_apps.size(); ++i) {
-        const drive::DriveAppInfo& app_info = drive_apps[i];
-        if (default_task.app_id == app_info.app_id) {
-          // The drive app is set as default. The Files app should use the doc
-          // icon.
-          const GURL doc_icon = drive::util::FindPreferredIcon(
-              app_info.document_icons, drive::util::kPreferredIconSize);
-          properties_->custom_icon_url =
-              std::make_unique<std::string>(doc_icon.spec());
-        }
-      }
-    }
-
     CompleteGetEntryProperties(drive::FILE_ERROR_OK);
   }
 
@@ -605,15 +575,13 @@ class SingleEntryPropertiesGetterForDriveFs {
                               base::File::Error error)>;
 
   // Creates an instance and starts the process.
-  static void Start(base::FilePath local_path,
-                    bool want_thumbnail,
+  static void Start(const storage::FileSystemURL& file_system_url,
                     Profile* const profile,
                     ResultCallback callback) {
     DCHECK_CURRENTLY_ON(BrowserThread::UI);
 
     SingleEntryPropertiesGetterForDriveFs* instance =
-        new SingleEntryPropertiesGetterForDriveFs(std::move(local_path),
-                                                  want_thumbnail, profile,
+        new SingleEntryPropertiesGetterForDriveFs(file_system_url, profile,
                                                   std::move(callback));
     instance->StartProcess();
 
@@ -621,13 +589,12 @@ class SingleEntryPropertiesGetterForDriveFs {
   }
 
  private:
-  SingleEntryPropertiesGetterForDriveFs(base::FilePath local_path,
-                                        bool want_thumbnail,
-                                        Profile* const profile,
-                                        ResultCallback callback)
+  SingleEntryPropertiesGetterForDriveFs(
+      const storage::FileSystemURL& file_system_url,
+      Profile* const profile,
+      ResultCallback callback)
       : callback_(std::move(callback)),
-        local_path_(std::move(local_path)),
-        want_thumbnail_(want_thumbnail),
+        file_system_url_(file_system_url),
         running_profile_(profile),
         properties_(std::make_unique<EntryProperties>()),
         weak_ptr_factory_(this) {
@@ -645,7 +612,8 @@ class SingleEntryPropertiesGetterForDriveFs {
       return;
     }
     base::FilePath path;
-    if (!integration_service->GetRelativeDrivePath(local_path_, &path)) {
+    if (!integration_service->GetRelativeDrivePath(file_system_url_.path(),
+                                                   &path)) {
       CompleteGetEntryProperties(drive::FILE_ERROR_INVALID_OPERATION);
       return;
     }
@@ -657,12 +625,11 @@ class SingleEntryPropertiesGetterForDriveFs {
     }
 
     drivefs_interface->GetMetadata(
-        path, want_thumbnail_,
-        mojo::WrapCallbackWithDefaultInvokeIfNotRun(
-            base::BindOnce(
-                &SingleEntryPropertiesGetterForDriveFs::OnGetFileInfo,
-                weak_ptr_factory_.GetWeakPtr()),
-            drive::FILE_ERROR_SERVICE_UNAVAILABLE, nullptr));
+        path, mojo::WrapCallbackWithDefaultInvokeIfNotRun(
+                  base::BindOnce(
+                      &SingleEntryPropertiesGetterForDriveFs::OnGetFileInfo,
+                      weak_ptr_factory_.GetWeakPtr()),
+                  drive::FILE_ERROR_SERVICE_UNAVAILABLE, nullptr));
   }
 
   void OnGetFileInfo(drive::FileError error,
@@ -675,14 +642,12 @@ class SingleEntryPropertiesGetterForDriveFs {
     }
 
     properties_->size = std::make_unique<double>(metadata->size);
-    properties_->available_offline =
-        std::make_unique<bool>(metadata->available_offline);
     properties_->present = std::make_unique<bool>(metadata->available_offline);
     properties_->dirty = std::make_unique<bool>(metadata->dirty);
     properties_->hosted = std::make_unique<bool>(
         metadata->type == drivefs::mojom::FileMetadata::Type::kHosted);
-    properties_->present = std::make_unique<bool>(metadata->available_offline ||
-                                                  *properties_->hosted);
+    properties_->available_offline = std::make_unique<bool>(
+        metadata->available_offline || *properties_->hosted);
     properties_->available_when_metered = std::make_unique<bool>(
         metadata->available_offline || *properties_->hosted);
     properties_->pinned = std::make_unique<bool>(metadata->pinned);
@@ -693,9 +658,9 @@ class SingleEntryPropertiesGetterForDriveFs {
       properties_->modification_time =
           std::make_unique<double>(metadata->modification_time.ToJsTime());
     }
-    if (metadata->modification_by_me_time != base::Time()) {
-      properties_->modification_by_me_time = std::make_unique<double>(
-          metadata->modification_by_me_time.ToJsTime());
+    if (metadata->last_viewed_by_me_time != base::Time()) {
+      properties_->modification_by_me_time =
+          std::make_unique<double>(metadata->last_viewed_by_me_time.ToJsTime());
     }
     if (!metadata->content_mime_type.empty()) {
       properties_->content_mime_type =
@@ -740,38 +705,16 @@ class SingleEntryPropertiesGetterForDriveFs {
     properties_->can_share =
         std::make_unique<bool>(metadata->capabilities->can_share);
 
-    if (metadata->thumbnail) {
-      base::PostTaskAndReplyWithResult(
-          FROM_HERE,
-          base::BindOnce(&SingleEntryPropertiesGetterForDriveFs::
-                             MakeThumbnailDataUrlOnSequence,
-                         std::move(*metadata->thumbnail)),
-          base::BindOnce(
-              &SingleEntryPropertiesGetterForDriveFs::SetThumbnailAndComplete,
-              weak_ptr_factory_.GetWeakPtr()));
-      return;
+    if (metadata->type != drivefs::mojom::FileMetadata::Type::kDirectory) {
+      properties_->thumbnail_url = std::make_unique<std::string>(
+          base::StrCat({"drivefs:", file_system_url_.ToGURL().spec()}));
+      properties_->cropped_thumbnail_url =
+          std::make_unique<std::string>(*properties_->thumbnail_url);
     }
 
     CompleteGetEntryProperties(drive::FILE_ERROR_OK);
   }
 
-  static std::string MakeThumbnailDataUrlOnSequence(
-      const std::vector<uint8_t>& png_data) {
-    std::string encoded;
-    base::Base64Encode(
-        base::StringPiece(reinterpret_cast<const char*>(png_data.data()),
-                          png_data.size()),
-        &encoded);
-    return base::StrCat({"data:image/png;base64,", encoded});
-  }
-
-  void SetThumbnailAndComplete(std::string thumbnail_data_url) {
-    properties_->thumbnail_url =
-        std::make_unique<std::string>(std::move(thumbnail_data_url));
-
-    CompleteGetEntryProperties(drive::FILE_ERROR_OK);
-  }
-
   void CompleteGetEntryProperties(drive::FileError error) {
     DCHECK_CURRENTLY_ON(BrowserThread::UI);
     DCHECK(callback_);
@@ -783,8 +726,7 @@ class SingleEntryPropertiesGetterForDriveFs {
 
   // Given parameters.
   ResultCallback callback_;
-  const base::FilePath local_path_;
-  const bool want_thumbnail_;
+  const storage::FileSystemURL file_system_url_;
   Profile* const running_profile_;
 
   // Values used in the process.
@@ -795,6 +737,140 @@ class SingleEntryPropertiesGetterForDriveFs {
   DISALLOW_COPY_AND_ASSIGN(SingleEntryPropertiesGetterForDriveFs);
 };
 
+std::string MakeThumbnailDataUrlOnSequence(
+    const std::vector<uint8_t>& png_data) {
+  std::string encoded;
+  base::Base64Encode(
+      base::StringPiece(reinterpret_cast<const char*>(png_data.data()),
+                        png_data.size()),
+      &encoded);
+  return base::StrCat({"data:image/png;base64,", encoded});
+}
+
+drivefs::mojom::QueryParameters::QuerySource SearchDriveFs(
+    scoped_refptr<ChromeAsyncExtensionFunction> function,
+    drivefs::mojom::QueryParametersPtr query,
+    bool filter_dirs,
+    base::OnceCallback<void(std::unique_ptr<base::ListValue>)> callback);
+
+void OnSearchDriveFs(
+    scoped_refptr<ChromeAsyncExtensionFunction> function,
+    drivefs::mojom::SearchQueryPtr search,
+    drivefs::mojom::QueryParametersPtr query,
+    bool filter_dirs,
+    base::OnceCallback<void(std::unique_ptr<base::ListValue>)> callback,
+    drive::FileError error,
+    base::Optional<std::vector<drivefs::mojom::QueryItemPtr>> items) {
+  drive::DriveIntegrationService* integration_service =
+      drive::util::GetIntegrationServiceByProfile(function->GetProfile());
+  if (!integration_service) {
+    std::move(callback).Run(nullptr);
+    return;
+  }
+
+  if (error == drive::FILE_ERROR_NO_CONNECTION &&
+      query->query_source !=
+          drivefs::mojom::QueryParameters::QuerySource::kLocalOnly) {
+    // Retry with offline query.
+    query->query_source =
+        drivefs::mojom::QueryParameters::QuerySource::kLocalOnly;
+    if (query->text_content) {
+      // Full-text searches not supported offline.
+      std::swap(query->text_content, query->title);
+      query->text_content.reset();
+    }
+    SearchDriveFs(std::move(function), std::move(query), filter_dirs,
+                  std::move(callback));
+    return;
+  }
+
+  if (error != drive::FILE_ERROR_OK || !items.has_value()) {
+    std::move(callback).Run(nullptr);
+    return;
+  }
+
+  GURL url;
+  file_manager::util::ConvertAbsoluteFilePathToFileSystemUrl(
+      function->GetProfile(), integration_service->GetMountPointPath(),
+      function->extension_id(), &url);
+  const auto fs_root = base::StrCat({url.spec(), "/"});
+  const auto fs_name =
+      integration_service->GetMountPointPath().BaseName().value();
+  const base::FilePath root("/");
+
+  auto result = std::make_unique<base::ListValue>();
+  result->GetList().reserve(items->size());
+  for (const auto& item : *items) {
+    base::FilePath path;
+    if (!root.AppendRelativePath(item->path, &path))
+      path = item->path;
+    base::DictionaryValue entry;
+    entry.SetKey("fileSystemName", base::Value(fs_name));
+    entry.SetKey("fileSystemRoot", base::Value(fs_root));
+    entry.SetKey("fileFullPath", base::Value(item->path.AsUTF8Unsafe()));
+    bool is_dir =
+        item->metadata->type == drivefs::mojom::FileMetadata::Type::kDirectory;
+    entry.SetKey("fileIsDirectory", base::Value(is_dir));
+    if (!filter_dirs || !is_dir) {
+      result->GetList().emplace_back(std::move(entry));
+    }
+  }
+
+  std::move(callback).Run(std::move(result));
+}
+
+drivefs::mojom::QueryParameters::QuerySource SearchDriveFs(
+    scoped_refptr<ChromeAsyncExtensionFunction> function,
+    drivefs::mojom::QueryParametersPtr query,
+    bool filter_dirs,
+    base::OnceCallback<void(std::unique_ptr<base::ListValue>)> callback) {
+  drive::DriveIntegrationService* const integration_service =
+      drive::util::GetIntegrationServiceByProfile(function->GetProfile());
+  drivefs::mojom::SearchQueryPtr search;
+  integration_service->GetDriveFsInterface()->StartSearchQuery(
+      mojo::MakeRequest(&search), query.Clone());
+  drivefs::mojom::QueryParameters::QuerySource source = query->query_source;
+  if (net::NetworkChangeNotifier::IsOffline() &&
+      source != drivefs::mojom::QueryParameters::QuerySource::kLocalOnly) {
+    // No point trying cloud query if we know we are offline.
+    source = drivefs::mojom::QueryParameters::QuerySource::kLocalOnly;
+    OnSearchDriveFs(std::move(function), std::move(search), std::move(query),
+                    filter_dirs, std::move(callback),
+                    drive::FILE_ERROR_NO_CONNECTION, {});
+  } else {
+    auto* raw_search = search.get();
+    raw_search->GetNextPage(
+        base::BindOnce(&OnSearchDriveFs, std::move(function), std::move(search),
+                       std::move(query), filter_dirs, std::move(callback)));
+  }
+  return source;
+}
+
+void UmaEmitSearchOutcome(
+    bool success,
+    bool remote,
+    FileManagerPrivateSearchDriveMetadataFunction::SearchType type,
+    const base::TimeTicks& time_started) {
+  const char* infix = nullptr;
+  switch (type) {
+    case FileManagerPrivateSearchDriveMetadataFunction::SearchType::kText:
+      infix = "TextSearchTime";
+      break;
+    case FileManagerPrivateSearchDriveMetadataFunction::SearchType::
+        kSharedWithMe:
+      infix = "SharedSearchTime";
+      break;
+    case FileManagerPrivateSearchDriveMetadataFunction::SearchType::kOffline:
+      infix = "OfflineSearchTime";
+      break;
+  }
+  base::UmaHistogramTimes(
+      base::StrCat(
+          {remote ? "DriveCommon.RemoteSearch." : "DriveCommon.LocalSearch.",
+           infix, success ? ".SuccessTime" : ".FailTime"}),
+      base::TimeTicks::Now() - time_started);
+}
+
 }  // namespace
 
 FileManagerPrivateInternalGetEntryPropertiesFunction::
@@ -840,10 +916,7 @@ bool FileManagerPrivateInternalGetEntryPropertiesFunction::RunAsync() {
         break;
       case storage::kFileSystemTypeDriveFs:
         SingleEntryPropertiesGetterForDriveFs::Start(
-            file_system_url.path(),
-            names_as_set.count(
-                api::file_manager_private::ENTRY_PROPERTY_NAME_THUMBNAILURL),
-            GetProfile(),
+            file_system_url, GetProfile(),
             base::BindOnce(
                 &FileManagerPrivateInternalGetEntryPropertiesFunction::
                     CompleteGetEntryProperties,
@@ -1067,24 +1140,68 @@ bool FileManagerPrivateSearchDriveFunction::RunAsync() {
   const std::unique_ptr<Params> params(Params::Create(*args_));
   EXTENSION_FUNCTION_VALIDATE(params);
 
-  drive::FileSystemInterface* const file_system =
-      drive::util::GetFileSystemByProfile(GetProfile());
-  if (!file_system) {
-    // |file_system| is NULL if Drive is disabled.
+  if (!drive::util::GetIntegrationServiceByProfile(GetProfile())) {
+    // |integration_service| is NULL if Drive is disabled or not mounted.
     return false;
   }
 
-  file_system->Search(
-      params->search_params.query, GURL(params->search_params.next_feed),
-      base::Bind(&FileManagerPrivateSearchDriveFunction::OnSearch, this));
+  operation_start_ = base::TimeTicks::Now();
+  is_offline_ = net::NetworkChangeNotifier::IsOffline();
+
+  drive::FileSystemInterface* const file_system =
+      drive::util::GetFileSystemByProfile(GetProfile());
+  if (file_system) {
+    file_system->Search(
+        params->search_params.query, GURL(params->search_params.next_feed),
+        base::BindOnce(&FileManagerPrivateSearchDriveFunction::OnSearch, this));
+  } else {
+    // |file_system| is NULL if the backend is DriveFs.
+    auto query = drivefs::mojom::QueryParameters::New();
+    query->text_content = params->search_params.query;
+    is_offline_ =
+        SearchDriveFs(
+            this, std::move(query), false,
+            base::BindOnce(
+                &FileManagerPrivateSearchDriveFunction::OnSearchDriveFs,
+                this)) ==
+        drivefs::mojom::QueryParameters::QuerySource::kLocalOnly;
+  }
+
   return true;
 }
 
+void FileManagerPrivateSearchDriveFunction::OnSearchDriveFs(
+    std::unique_ptr<base::ListValue> results) {
+  if (!results) {
+    UmaEmitSearchOutcome(
+        false, !is_offline_,
+        FileManagerPrivateSearchDriveMetadataFunction::SearchType::kText,
+        operation_start_);
+    SendResponse(false);
+    return;
+  }
+  auto result = std::make_unique<base::DictionaryValue>();
+  result->SetKey("entries", std::move(*results));
+  // Search queries are capped at 100 of items anyway and pagination is
+  // never actually used, so no need to fill this.
+  result->SetKey("nextFeed", base::Value(""));
+  SetResult(std::move(result));
+  UmaEmitSearchOutcome(
+      true, !is_offline_,
+      FileManagerPrivateSearchDriveMetadataFunction::SearchType::kText,
+      operation_start_);
+  SendResponse(true);
+}
+
 void FileManagerPrivateSearchDriveFunction::OnSearch(
     drive::FileError error,
     const GURL& next_link,
     std::unique_ptr<SearchResultInfoList> results) {
   if (error != drive::FILE_ERROR_OK) {
+    UmaEmitSearchOutcome(
+        false, !is_offline_,
+        FileManagerPrivateSearchDriveMetadataFunction::SearchType::kText,
+        operation_start_);
     SendResponse(false);
     return;
   }
@@ -1095,13 +1212,10 @@ void FileManagerPrivateSearchDriveFunction::OnSearch(
   const SearchResultInfoList& results_ref = *results.get();
 
   ConvertSearchResultInfoListToEntryDefinitionList(
-      GetProfile(),
-      extension_->id(),
-      results_ref,
-      base::Bind(&FileManagerPrivateSearchDriveFunction::OnEntryDefinitionList,
-                 this,
-                 next_link,
-                 base::Passed(&results)));
+      GetProfile(), extension_->id(), results_ref,
+      base::BindOnce(
+          &FileManagerPrivateSearchDriveFunction::OnEntryDefinitionList, this,
+          next_link, std::move(results)));
 }
 
 void FileManagerPrivateSearchDriveFunction::OnEntryDefinitionList(
@@ -1109,25 +1223,18 @@ void FileManagerPrivateSearchDriveFunction::OnEntryDefinitionList(
     std::unique_ptr<SearchResultInfoList> search_result_info_list,
     std::unique_ptr<EntryDefinitionList> entry_definition_list) {
   DCHECK_EQ(search_result_info_list->size(), entry_definition_list->size());
-  auto entries = std::make_unique<base::ListValue>();
-
-  // Convert Drive files to something File API stack can understand.
-  for (EntryDefinitionList::const_iterator it = entry_definition_list->begin();
-       it != entry_definition_list->end();
-       ++it) {
-    auto entry = std::make_unique<base::DictionaryValue>();
-    entry->SetString("fileSystemName", it->file_system_name);
-    entry->SetString("fileSystemRoot", it->file_system_root_url);
-    entry->SetString("fileFullPath", "/" + it->full_path.AsUTF8Unsafe());
-    entry->SetBoolean("fileIsDirectory", it->is_directory);
-    entries->Append(std::move(entry));
-  }
+  auto entries = file_manager::util::ConvertEntryDefinitionListToListValue(
+      *entry_definition_list);
 
   std::unique_ptr<base::DictionaryValue> result(new base::DictionaryValue());
   result->Set("entries", std::move(entries));
   result->SetString("nextFeed", next_link.spec());
 
   SetResult(std::move(result));
+  UmaEmitSearchOutcome(
+      true, !is_offline_,
+      FileManagerPrivateSearchDriveMetadataFunction::SearchType::kText,
+      operation_start_);
   SendResponse(true);
 }
 
@@ -1146,45 +1253,146 @@ bool FileManagerPrivateSearchDriveMetadataFunction::RunAsync() {
   }
   set_log_on_completion(true);
 
-  drive::FileSystemInterface* const file_system =
-      drive::util::GetFileSystemByProfile(GetProfile());
-  if (!file_system) {
-    // |file_system| is NULL if Drive is disabled.
+  drive::DriveIntegrationService* const integration_service =
+      drive::util::GetIntegrationServiceByProfile(GetProfile());
+  if (!integration_service) {
+    // |integration_service| is NULL if Drive is disabled or not mounted.
     return false;
   }
 
-  int options = -1;
-  switch (params->search_params.types) {
-    case api::file_manager_private::SEARCH_TYPE_EXCLUDE_DIRECTORIES:
-      options = drive::SEARCH_METADATA_EXCLUDE_DIRECTORIES;
-      break;
-    case api::file_manager_private::SEARCH_TYPE_SHARED_WITH_ME:
-      options = drive::SEARCH_METADATA_SHARED_WITH_ME;
-      break;
-    case api::file_manager_private::SEARCH_TYPE_OFFLINE:
-      options = drive::SEARCH_METADATA_OFFLINE;
-      break;
-    case api::file_manager_private::SEARCH_TYPE_ALL:
-      options = drive::SEARCH_METADATA_ALL;
-      break;
-    case api::file_manager_private::SEARCH_TYPE_NONE:
-      break;
+  operation_start_ = base::TimeTicks::Now();
+  is_offline_ = true;  // Legacy search is assumed offline always.
+
+  drive::FileSystemInterface* const file_system =
+      drive::util::GetFileSystemByProfile(GetProfile());
+  // |file_system| is NULL if the backend is DriveFs, otherwise it's legacy
+  // sync client.
+  if (file_system) {
+    int options = -1;
+    switch (params->search_params.types) {
+      case api::file_manager_private::SEARCH_TYPE_EXCLUDE_DIRECTORIES:
+        options = drive::SEARCH_METADATA_EXCLUDE_DIRECTORIES;
+        search_type_ = SearchType::kText;
+        break;
+      case api::file_manager_private::SEARCH_TYPE_SHARED_WITH_ME:
+        options = drive::SEARCH_METADATA_SHARED_WITH_ME;
+        search_type_ = SearchType::kSharedWithMe;
+        break;
+      case api::file_manager_private::SEARCH_TYPE_OFFLINE:
+        options = drive::SEARCH_METADATA_OFFLINE;
+        search_type_ = SearchType::kOffline;
+        break;
+      case api::file_manager_private::SEARCH_TYPE_ALL:
+        options = drive::SEARCH_METADATA_ALL;
+        search_type_ = SearchType::kText;
+        break;
+      default:
+        return false;
+    }
+    file_system->SearchMetadata(
+        params->search_params.query, options, params->search_params.max_results,
+        drive::MetadataSearchOrder::LAST_ACCESSED,
+        base::BindOnce(
+            &FileManagerPrivateSearchDriveMetadataFunction::OnSearchMetadata,
+            this));
+  } else {
+    auto query = drivefs::mojom::QueryParameters::New();
+    query->sort_field =
+        drivefs::mojom::QueryParameters::SortField::kLastModified;
+    query->sort_direction =
+        drivefs::mojom::QueryParameters::SortDirection::kDescending;
+    if (!params->search_params.query.empty()) {
+      query->title = params->search_params.query;
+      query->query_source =
+          drivefs::mojom::QueryParameters::QuerySource::kLocalOnly;
+    }
+    query->page_size = params->search_params.max_results;
+    bool filter_dirs = false;
+    switch (params->search_params.types) {
+      case api::file_manager_private::SEARCH_TYPE_EXCLUDE_DIRECTORIES:
+        filter_dirs = true;
+        search_type_ = SearchType::kText;
+        break;
+      case api::file_manager_private::SEARCH_TYPE_SHARED_WITH_ME:
+        query->shared_with_me = true;
+        search_type_ = SearchType::kSharedWithMe;
+        break;
+      case api::file_manager_private::SEARCH_TYPE_OFFLINE:
+        query->available_offline = true;
+        query->query_source =
+            drivefs::mojom::QueryParameters::QuerySource::kLocalOnly;
+        search_type_ = SearchType::kOffline;
+        break;
+      case api::file_manager_private::SEARCH_TYPE_ALL:
+        search_type_ = SearchType::kText;
+        break;
+      default:
+        return false;
+    }
+    is_offline_ =
+        SearchDriveFs(
+            this, std::move(query), filter_dirs,
+            base::BindOnce(
+                &FileManagerPrivateSearchDriveMetadataFunction::OnSearchDriveFs,
+                this, params->search_params.query)) ==
+        drivefs::mojom::QueryParameters::QuerySource::kLocalOnly;
   }
-  DCHECK_NE(options, -1);
 
-  file_system->SearchMetadata(
-      params->search_params.query, options, params->search_params.max_results,
-      drive::MetadataSearchOrder::LAST_ACCESSED,
-      base::Bind(
-          &FileManagerPrivateSearchDriveMetadataFunction::OnSearchMetadata,
-          this));
   return true;
 }
 
+void FileManagerPrivateSearchDriveMetadataFunction::OnSearchDriveFs(
+    const std::string& query_text,
+    std::unique_ptr<base::ListValue> results) {
+  if (!results) {
+    UmaEmitSearchOutcome(false, !is_offline_, search_type_, operation_start_);
+    SendResponse(false);
+    return;
+  }
+
+  std::vector<base::string16> keywords =
+      base::SplitString(base::UTF8ToUTF16(query_text),
+                        base::StringPiece16(base::kWhitespaceUTF16),
+                        base::TRIM_WHITESPACE, base::SPLIT_WANT_NONEMPTY);
+  std::vector<std::unique_ptr<
+      base::i18n::FixedPatternStringSearchIgnoringCaseAndAccents>>
+      queries;
+  queries.reserve(keywords.size());
+  for (const auto& keyword : keywords) {
+    queries.push_back(
+        std::make_unique<
+            base::i18n::FixedPatternStringSearchIgnoringCaseAndAccents>(
+            keyword));
+  }
+
+  auto results_list = std::make_unique<base::ListValue>();
+  results_list->GetList().reserve(results->GetList().size());
+  for (auto& entry : *results) {
+    base::DictionaryValue dict;
+    std::string highlight;
+    base::Value* value = entry.FindKey("fileFullPath");
+    if (value && value->GetAsString(&highlight)) {
+      base::FilePath path(highlight);
+      if (!drive::internal::FindAndHighlight(path.BaseName().value(), queries,
+                                             &highlight)) {
+        highlight = path.BaseName().value();
+      }
+    }
+    dict.SetKey("entry", std::move(entry));
+    dict.SetKey("highlightedBaseName", base::Value(highlight));
+    results_list->GetList().emplace_back(std::move(dict));
+  }
+
+  SetResult(std::move(results_list));
+  UmaEmitSearchOutcome(true, !is_offline_, search_type_, operation_start_);
+  SendResponse(true);
+}
+
 void FileManagerPrivateSearchDriveMetadataFunction::OnSearchMetadata(
     drive::FileError error,
     std::unique_ptr<drive::MetadataSearchResultVector> results) {
   if (error != drive::FILE_ERROR_OK) {
+    UmaEmitSearchOutcome(false, !is_offline_, search_type_, operation_start_);
     SendResponse(false);
     return;
   }
@@ -1195,13 +1403,10 @@ void FileManagerPrivateSearchDriveMetadataFunction::OnSearchMetadata(
   const drive::MetadataSearchResultVector& results_ref = *results.get();
 
   ConvertSearchResultInfoListToEntryDefinitionList(
-      GetProfile(),
-      extension_->id(),
-      results_ref,
-      base::Bind(
+      GetProfile(), extension_->id(), results_ref,
+      base::BindOnce(
           &FileManagerPrivateSearchDriveMetadataFunction::OnEntryDefinitionList,
-          this,
-          base::Passed(&results)));
+          this, std::move(results)));
 }
 
 void FileManagerPrivateSearchDriveMetadataFunction::OnEntryDefinitionList(
@@ -1218,16 +1423,8 @@ void FileManagerPrivateSearchDriveMetadataFunction::OnEntryDefinitionList(
     auto result_dict = std::make_unique<base::DictionaryValue>();
 
     // FileEntry fields.
-    auto entry = std::make_unique<base::DictionaryValue>();
-    entry->SetString(
-        "fileSystemName", entry_definition_list->at(i).file_system_name);
-    entry->SetString(
-        "fileSystemRoot", entry_definition_list->at(i).file_system_root_url);
-    entry->SetString(
-        "fileFullPath",
-        "/" + entry_definition_list->at(i).full_path.AsUTF8Unsafe());
-    entry->SetBoolean("fileIsDirectory",
-                      entry_definition_list->at(i).is_directory);
+    auto entry = file_manager::util::ConvertEntryDefinitionToValue(
+        entry_definition_list->at(i));
 
     result_dict->Set("entry", std::move(entry));
     result_dict->SetString(
@@ -1237,6 +1434,7 @@ void FileManagerPrivateSearchDriveMetadataFunction::OnEntryDefinitionList(
   }
 
   SetResult(std::move(results_list));
+  UmaEmitSearchOutcome(true, !is_offline_, search_type_, operation_start_);
   SendResponse(true);
 }
 
@@ -1317,45 +1515,6 @@ void FileManagerPrivateRequestAccessTokenFunction::OnAccessTokenFetched(
   SendResponse(true);
 }
 
-bool FileManagerPrivateInternalGetShareUrlFunction::RunAsync() {
-  using extensions::api::file_manager_private_internal::GetShareUrl::Params;
-  const std::unique_ptr<Params> params(Params::Create(*args_));
-  EXTENSION_FUNCTION_VALIDATE(params);
-
-  const base::FilePath path = file_manager::util::GetLocalPathFromURL(
-      render_frame_host(), GetProfile(), GURL(params->url));
-  DCHECK(drive::util::IsUnderDriveMountPoint(path));
-
-  const base::FilePath drive_path = drive::util::ExtractDrivePath(path);
-
-  drive::FileSystemInterface* const file_system =
-      drive::util::GetFileSystemByProfile(GetProfile());
-  if (!file_system) {
-    // |file_system| is NULL if Drive is disabled.
-    return false;
-  }
-
-  file_system->GetShareUrl(
-      drive_path,
-      GURL("chrome-extension://" + extension_id()),  // embed origin
-      base::Bind(&FileManagerPrivateInternalGetShareUrlFunction::OnGetShareUrl,
-                 this));
-  return true;
-}
-
-void FileManagerPrivateInternalGetShareUrlFunction::OnGetShareUrl(
-    drive::FileError error,
-    const GURL& share_url) {
-  if (error != drive::FILE_ERROR_OK) {
-    SetError("Share Url for this item is not available.");
-    SendResponse(false);
-    return;
-  }
-
-  SetResult(std::make_unique<base::Value>(share_url.spec()));
-  SendResponse(true);
-}
-
 bool FileManagerPrivateInternalRequestDriveShareFunction::RunAsync() {
   using extensions::api::file_manager_private_internal::RequestDriveShare::
       Params;
@@ -1419,7 +1578,7 @@ FileManagerPrivateInternalGetDownloadUrlFunction::
     ~FileManagerPrivateInternalGetDownloadUrlFunction() = default;
 
 bool FileManagerPrivateInternalGetDownloadUrlFunction::RunAsync() {
-  using extensions::api::file_manager_private_internal::GetShareUrl::Params;
+  using extensions::api::file_manager_private_internal::GetDownloadUrl::Params;
   const std::unique_ptr<Params> params(Params::Create(*args_));
   EXTENSION_FUNCTION_VALIDATE(params);
 
@@ -1483,8 +1642,8 @@ void FileManagerPrivateInternalGetDownloadUrlFunction::OnGetResourceEntry(
 
   DriveApiUrlGenerator url_generator(
       (GURL(google_apis::DriveApiUrlGenerator::kBaseUrlForProduction)),
-      (GURL(google_apis::DriveApiUrlGenerator::kBaseThumbnailUrlForProduction)),
-      google_apis::GetTeamDrivesIntegrationSwitch());
+      (GURL(
+          google_apis::DriveApiUrlGenerator::kBaseThumbnailUrlForProduction)));
   OnGotDownloadUrl(url_generator.GenerateDownloadFileUrl(entry->resource_id()));
 }
 
@@ -1547,7 +1706,7 @@ bool FileManagerPrivateInternalGetDownloadUrlFunction::RunAsyncForDriveFs(
     return false;
 
   drivefs_interface->GetMetadata(
-      path, false,
+      path,
       mojo::WrapCallbackWithDefaultInvokeIfNotRun(
           base::BindOnce(
               &FileManagerPrivateInternalGetDownloadUrlFunction::OnGotMetadata,
@@ -1562,4 +1721,67 @@ void FileManagerPrivateInternalGetDownloadUrlFunction::OnGotMetadata(
   OnGotDownloadUrl(metadata ? GURL(metadata->download_url) : GURL());
 }
 
+FileManagerPrivateInternalGetThumbnailFunction::
+    FileManagerPrivateInternalGetThumbnailFunction() = default;
+
+FileManagerPrivateInternalGetThumbnailFunction::
+    ~FileManagerPrivateInternalGetThumbnailFunction() = default;
+
+// ChromeAsyncExtensionFunction overrides.
+bool FileManagerPrivateInternalGetThumbnailFunction::RunAsync() {
+  using extensions::api::file_manager_private_internal::GetThumbnail::Params;
+  const std::unique_ptr<Params> params(Params::Create(*args_));
+  EXTENSION_FUNCTION_VALIDATE(params);
+
+  scoped_refptr<storage::FileSystemContext> file_system_context =
+      file_manager::util::GetFileSystemContextForRenderFrameHost(
+          GetProfile(), render_frame_host());
+  const GURL url = GURL(params->url);
+  const storage::FileSystemURL file_system_url =
+      file_system_context->CrackURL(url);
+
+  if (file_system_url.type() != storage::kFileSystemTypeDriveFs) {
+    return false;
+  }
+  drive::DriveIntegrationService* integration_service =
+      drive::DriveIntegrationServiceFactory::FindForProfile(GetProfile());
+  base::FilePath path;
+  if (!integration_service || !integration_service->GetRelativeDrivePath(
+                                  file_system_url.path(), &path)) {
+    return false;
+  }
+  auto* drivefs_interface = integration_service->GetDriveFsInterface();
+  if (!drivefs_interface) {
+    return false;
+  }
+  drivefs_interface->GetThumbnail(
+      path, params->crop_to_square,
+      mojo::WrapCallbackWithDefaultInvokeIfNotRun(
+          base::BindOnce(
+              &FileManagerPrivateInternalGetThumbnailFunction::GotThumbnail,
+              this),
+          base::Optional<std::vector<uint8_t>>()));
+  return true;
+}
+
+void FileManagerPrivateInternalGetThumbnailFunction::GotThumbnail(
+    const base::Optional<std::vector<uint8_t>>& data) {
+  if (!data) {
+    SetResult(std::make_unique<base::Value>(""));
+    SendResponse(true);
+    return;
+  }
+  base::PostTaskAndReplyWithResult(
+      FROM_HERE, base::BindOnce(&MakeThumbnailDataUrlOnSequence, *data),
+      base::BindOnce(
+          &FileManagerPrivateInternalGetThumbnailFunction::SendEncodedThumbnail,
+          this));
+}
+
+void FileManagerPrivateInternalGetThumbnailFunction::SendEncodedThumbnail(
+    std::string thumbnail_data_url) {
+  SetResult(std::make_unique<base::Value>(std::move(thumbnail_data_url)));
+  SendResponse(true);
+}
+
 }  // namespace extensions
