@@ -5,10 +5,12 @@
 #include "chrome/browser/chromeos/extensions/file_manager/private_api_file_system.h"
 
 #include <sys/statvfs.h>
+#include <sys/xattr.h>
 
 #include <algorithm>
 #include <utility>
 
+#include "base/files/file_enumerator.h"
 #include "base/files/file_util.h"
 #include "base/posix/eintr_wrapper.h"
 #include "base/strings/string_number_conversions.h"
@@ -36,8 +38,10 @@
 #include "components/drive/chromeos/file_system_interface.h"
 #include "components/drive/drive.pb.h"
 #include "components/drive/event_logger.h"
+#include "components/drive/file_system_core_util.h"
 #include "components/storage_monitor/storage_info.h"
 #include "components/storage_monitor/storage_monitor.h"
+#include "content/public/browser/browser_task_traits.h"
 #include "content/public/browser/browser_thread.h"
 #include "content/public/browser/child_process_security_policy.h"
 #include "content/public/browser/render_frame_host.h"
@@ -94,6 +98,22 @@ size_t GetFileNameMaxLengthAsync(const std::string& path) {
   return stat.f_namemax;
 }
 
+bool GetFileExtendedAttribute(const base::FilePath& path,
+                              const char* name,
+                              std::vector<char>* value) {
+  ssize_t len = getxattr(path.value().c_str(), name, nullptr, 0);
+  if (len < 0) {
+    PLOG_IF(ERROR, errno != ENODATA) << "getxattr: " << path;
+    return false;
+  }
+  value->resize(len);
+  if (getxattr(path.value().c_str(), name, value->data(), len) != len) {
+    PLOG(ERROR) << "getxattr: " << path;
+    return false;
+  }
+  return true;
+}
+
 // Returns EventRouter for the |profile_id| if available.
 file_manager::EventRouter* GetEventRouterByProfileId(void* profile_id) {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
@@ -136,8 +156,8 @@ void OnCopyProgress(
     int64_t size) {
   DCHECK_CURRENTLY_ON(BrowserThread::IO);
 
-  BrowserThread::PostTask(
-      BrowserThread::UI, FROM_HERE,
+  base::PostTaskWithTraits(
+      FROM_HERE, {BrowserThread::UI},
       base::BindOnce(&NotifyCopyProgress, profile_id, *operation_id, type,
                      source_url, destination_url, size));
 }
@@ -169,8 +189,8 @@ void OnCopyCompleted(
     base::File::Error error) {
   DCHECK_CURRENTLY_ON(BrowserThread::IO);
 
-  BrowserThread::PostTask(
-      BrowserThread::UI, FROM_HERE,
+  base::PostTaskWithTraits(
+      FROM_HERE, {BrowserThread::UI},
       base::BindOnce(&NotifyCopyCompletion, profile_id, *operation_id,
                      source_url, destination_url, error));
 }
@@ -234,18 +254,19 @@ void ComputeChecksumRespondOnUIThread(
     const base::Callback<void(const std::string&)>& callback,
     const std::string& hash) {
   DCHECK_CURRENTLY_ON(BrowserThread::IO);
-  BrowserThread::PostTask(BrowserThread::UI, FROM_HERE,
-                          base::BindOnce(callback, hash));
+  base::PostTaskWithTraits(FROM_HERE, {BrowserThread::UI},
+                           base::BindOnce(callback, hash));
 }
 
 // Calls a response callback on the UI thread.
 void GetFileMetadataRespondOnUIThread(
-    const storage::FileSystemOperation::GetMetadataCallback& callback,
+    storage::FileSystemOperation::GetMetadataCallback callback,
     base::File::Error result,
     const base::File::Info& file_info) {
   DCHECK_CURRENTLY_ON(BrowserThread::IO);
-  BrowserThread::PostTask(BrowserThread::UI, FROM_HERE,
-                          base::BindOnce(callback, result, file_info));
+  base::PostTaskWithTraits(
+      FROM_HERE, {BrowserThread::UI},
+      base::BindOnce(std::move(callback), result, file_info));
 }
 
 }  // namespace
@@ -308,16 +329,16 @@ void PostResponseCallbackTaskToUIThread(
     const FileWatchFunctionBase::ResponseCallback& callback,
     bool success) {
   DCHECK_CURRENTLY_ON(BrowserThread::IO);
-  BrowserThread::PostTask(BrowserThread::UI, FROM_HERE,
-                          base::BindOnce(callback, success));
+  base::PostTaskWithTraits(FROM_HERE, {BrowserThread::UI},
+                           base::BindOnce(callback, success));
 }
 
 void PostNotificationCallbackTaskToUIThread(
     const storage::WatcherManager::NotificationCallback& callback,
     storage::WatcherManager::ChangeType type) {
   DCHECK_CURRENTLY_ON(BrowserThread::IO);
-  BrowserThread::PostTask(BrowserThread::UI, FROM_HERE,
-                          base::BindOnce(callback, type));
+  base::PostTaskWithTraits(FROM_HERE, {BrowserThread::UI},
+                           base::BindOnce(callback, type));
 }
 
 }  // namespace
@@ -354,8 +375,8 @@ bool FileWatchFunctionBase::RunAsync() {
   file_manager::EventRouter* const event_router =
       file_manager::EventRouterFactory::GetForProfile(GetProfile());
 
-  BrowserThread::PostTask(
-      BrowserThread::IO, FROM_HERE,
+  base::PostTaskWithTraits(
+      FROM_HERE, {BrowserThread::IO},
       base::BindOnce(&FileWatchFunctionBase::RunAsyncOnIOThread, this,
                      file_system_context, file_system_url,
                      event_router->GetWeakPtr()));
@@ -372,8 +393,8 @@ void FileWatchFunctionBase::RunAsyncOnIOThread(
       file_system_context->GetWatcherManager(file_system_url.type());
 
   if (!watcher_manager) {
-    BrowserThread::PostTask(
-        BrowserThread::UI, FROM_HERE,
+    base::PostTaskWithTraits(
+        FROM_HERE, {BrowserThread::UI},
         base::BindOnce(
             &FileWatchFunctionBase::PerformFallbackFileWatchOperationOnUIThread,
             this, file_system_url, event_router));
@@ -472,7 +493,7 @@ bool FileManagerPrivateGetSizeStatsFunction::RunAsync() {
       return true;
     }
 
-    file_system->GetAvailableSpace(base::Bind(
+    file_system->GetAvailableSpace(base::BindOnce(
         &FileManagerPrivateGetSizeStatsFunction::OnGetDriveAvailableSpace,
         this));
   } else if (volume->type() == file_manager::VOLUME_TYPE_MTP) {
@@ -636,10 +657,11 @@ void GetFileMetadataOnIOThread(
     scoped_refptr<storage::FileSystemContext> file_system_context,
     const FileSystemURL& url,
     int fields,
-    const storage::FileSystemOperation::GetMetadataCallback& callback) {
+    storage::FileSystemOperation::GetMetadataCallback callback) {
   DCHECK_CURRENTLY_ON(BrowserThread::IO);
   file_system_context->operation_runner()->GetMetadata(
-      url, fields, base::Bind(&GetFileMetadataRespondOnUIThread, callback));
+      url, fields,
+      base::BindOnce(&GetFileMetadataRespondOnUIThread, std::move(callback)));
 }
 
 // Checks if the available space of the |path| is enough for required |bytes|.
@@ -686,18 +708,18 @@ bool FileManagerPrivateInternalStartCopyFunction::RunAsync() {
   // spece by freeing drive caches.
   if (destination_url_.filesystem_id() ==
       file_manager::util::GetDownloadsMountPointName(GetProfile())) {
-    return BrowserThread::PostTask(
-        BrowserThread::IO, FROM_HERE,
-        base::BindOnce(&GetFileMetadataOnIOThread, file_system_context,
-                       source_url_,
-                       storage::FileSystemOperation::GET_METADATA_FIELD_SIZE,
-                       base::Bind(&FileManagerPrivateInternalStartCopyFunction::
-                                      RunAfterGetFileMetadata,
-                                  this)));
+    return base::PostTaskWithTraits(
+        FROM_HERE, {BrowserThread::IO},
+        base::BindOnce(
+            &GetFileMetadataOnIOThread, file_system_context, source_url_,
+            storage::FileSystemOperation::GET_METADATA_FIELD_SIZE,
+            base::BindOnce(&FileManagerPrivateInternalStartCopyFunction::
+                               RunAfterGetFileMetadata,
+                           this)));
   }
 
-  return BrowserThread::PostTask(
-      BrowserThread::UI, FROM_HERE,
+  return base::PostTaskWithTraits(
+      FROM_HERE, {BrowserThread::UI},
       base::BindOnce(
           &FileManagerPrivateInternalStartCopyFunction::RunAfterFreeDiskSpace,
           this, true));
@@ -748,8 +770,8 @@ void FileManagerPrivateInternalStartCopyFunction::RunAfterFreeDiskSpace(
   scoped_refptr<storage::FileSystemContext> file_system_context =
       file_manager::util::GetFileSystemContextForRenderFrameHost(
           GetProfile(), render_frame_host());
-  const bool result = BrowserThread::PostTaskAndReplyWithResult(
-      BrowserThread::IO, FROM_HERE,
+  const bool result = base::PostTaskWithTraitsAndReplyWithResult(
+      FROM_HERE, {BrowserThread::IO},
       base::Bind(&StartCopyOnIOThread, GetProfile(), file_system_context,
                  source_url_, destination_url_),
       base::Bind(
@@ -779,9 +801,10 @@ bool FileManagerPrivateCancelCopyFunction::RunAsync() {
           GetProfile(), render_frame_host());
 
   // We don't much take care about the result of cancellation.
-  BrowserThread::PostTask(BrowserThread::IO, FROM_HERE,
-                          base::BindOnce(&CancelCopyOnIOThread,
-                                         file_system_context, params->copy_id));
+  base::PostTaskWithTraits(
+      FROM_HERE, {BrowserThread::IO},
+      base::BindOnce(&CancelCopyOnIOThread, file_system_context,
+                     params->copy_id));
   SendResponse(true);
   return true;
 }
@@ -822,10 +845,9 @@ bool FileManagerPrivateInternalResolveIsolatedEntriesFunction::RunAsync() {
   }
 
   file_manager::util::ConvertFileDefinitionListToEntryDefinitionList(
-      GetProfile(),
-      extension_->id(),
+      GetProfile(), extension_->id(),
       file_definition_list,  // Safe, since copied internally.
-      base::Bind(
+      base::BindOnce(
           &FileManagerPrivateInternalResolveIsolatedEntriesFunction::
               RunAsyncAfterConvertFileDefinitionListToEntryDefinitionList,
           this));
@@ -893,8 +915,8 @@ bool FileManagerPrivateInternalComputeChecksumFunction::RunAsync() {
       &ComputeChecksumRespondOnUIThread,
       base::Bind(&FileManagerPrivateInternalComputeChecksumFunction::Respond,
                  this));
-  BrowserThread::PostTask(
-      BrowserThread::IO, FROM_HERE,
+  base::PostTaskWithTraits(
+      FROM_HERE, {BrowserThread::IO},
       base::BindOnce(&FileStreamMd5Digester::GetMd5Digest,
                      base::Unretained(digester_.get()), base::Passed(&reader),
                      result_callback));
@@ -927,23 +949,82 @@ bool FileManagerPrivateSearchFilesByHashesFunction::RunAsync() {
   }
   set_log_on_completion(true);
 
-  drive::FileSystemInterface* const file_system =
-      drive::util::GetFileSystemByProfile(GetProfile());
-  if (!file_system) {
-    // |file_system| is NULL if Drive is disabled.
+  drive::DriveIntegrationService* integration_service =
+      drive::util::GetIntegrationServiceByProfile(GetProfile());
+  if (!integration_service) {
+    // |integration_service| is NULL if Drive is disabled or not mounted.
     return false;
   }
 
   std::set<std::string> hashes(params->hash_list.begin(),
                                params->hash_list.end());
-  file_system->SearchByHashes(
-      hashes,
-      base::Bind(
-          &FileManagerPrivateSearchFilesByHashesFunction::OnSearchByHashes,
-          this, hashes));
+
+  drive::FileSystemInterface* const file_system =
+      drive::util::GetFileSystemByProfile(GetProfile());
+  if (file_system) {
+    file_system->SearchByHashes(
+        hashes,
+        base::BindOnce(
+            &FileManagerPrivateSearchFilesByHashesFunction::OnSearchByHashes,
+            this, hashes));
+  } else {
+    // |file_system| is NULL if the backend is DriveFs. It doesn't provide
+    // dedicated backup solution yet, so for now just walk the files and check
+    // MD5 extended attribute.
+    base::PostTaskWithTraitsAndReplyWithResult(
+        FROM_HERE, {base::MayBlock(), base::TaskPriority::BEST_EFFORT},
+        base::BindOnce(
+            &FileManagerPrivateSearchFilesByHashesFunction::SearchByAttribute,
+            this, hashes,
+            integration_service->GetMountPointPath().Append(
+                drive::util::kDriveMyDriveRootDirName),
+            drive::util::GetDriveMountPointPath(GetProfile())),
+        base::BindOnce(
+            &FileManagerPrivateSearchFilesByHashesFunction::OnSearchByAttribute,
+            this, hashes));
+  }
+
   return true;
 }
 
+std::vector<drive::HashAndFilePath>
+FileManagerPrivateSearchFilesByHashesFunction::SearchByAttribute(
+    const std::set<std::string>& hashes,
+    const base::FilePath& dir,
+    const base::FilePath& prefix) {
+  std::vector<drive::HashAndFilePath> results;
+
+  if (hashes.empty())
+    return results;
+
+  std::set<std::string> remaining = hashes;
+  std::vector<char> attribute;
+  base::FileEnumerator enumerator(dir, true, base::FileEnumerator::FILES);
+  for (base::FilePath path = enumerator.Next(); !path.empty();
+       path = enumerator.Next()) {
+    if (GetFileExtendedAttribute(path, "user.drive.md5", &attribute)) {
+      std::string md5(attribute.begin(), attribute.end());
+
+      if (remaining.erase(md5)) {
+        base::FilePath drive_path = prefix;
+        bool success = dir.AppendRelativePath(path, &drive_path);
+        DCHECK(success);
+        results.push_back({md5, drive_path});
+        if (remaining.empty())
+          break;
+      }
+    }
+  }
+
+  return results;
+}
+
+void FileManagerPrivateSearchFilesByHashesFunction::OnSearchByAttribute(
+    const std::set<std::string>& hashes,
+    const std::vector<drive::HashAndFilePath>& results) {
+  OnSearchByHashes(hashes, drive::FileError::FILE_ERROR_OK, results);
+}
+
 void FileManagerPrivateSearchFilesByHashesFunction::OnSearchByHashes(
     const std::set<std::string>& hashes,
     drive::FileError error,
@@ -986,9 +1067,17 @@ FileManagerPrivateInternalSetEntryTagFunction::Run() {
   const std::unique_ptr<Params> params(Params::Create(*args_));
   EXTENSION_FUNCTION_VALIDATE(params);
 
-  const base::FilePath local_path = file_manager::util::GetLocalPathFromURL(
-      render_frame_host(), chrome_details_.GetProfile(), GURL(params->url));
-  const base::FilePath drive_path = drive::util::ExtractDrivePath(local_path);
+  scoped_refptr<storage::FileSystemContext> file_system_context =
+      file_manager::util::GetFileSystemContextForRenderFrameHost(
+          Profile::FromBrowserContext(browser_context()), render_frame_host());
+  const storage::FileSystemURL file_system_url(
+      file_system_context->CrackURL(GURL(params->url)));
+  if (file_system_url.type() == storage::kFileSystemTypeDriveFs) {
+    return RespondNow(NoArguments());
+  }
+
+  const base::FilePath drive_path =
+      drive::util::ExtractDrivePath(file_system_url.path());
   if (drive_path.empty())
     return RespondNow(Error("Only Drive files and directories are supported."));
 
