@@ -722,6 +722,8 @@ ExtensionFunction::ResponseAction FileManagerPrivateGetStringsFunction::Run() {
   SET_STRING("SHARE_BUTTON_LABEL", IDS_FILE_BROWSER_SHARE_BUTTON_LABEL);
   SET_STRING("MANAGE_IN_DRIVE_BUTTON_LABEL",
              IDS_FILE_BROWSER_MANAGE_IN_DRIVE_BUTTON_LABEL);
+  SET_STRING("SHARE_WITH_LINUX_BUTTON_LABEL",
+             IDS_FILE_BROWSER_SHARE_WITH_LINUX_BUTTON_LABEL);
   SET_STRING("CHANGE_TO_LISTVIEW_BUTTON_LABEL",
              IDS_FILE_BROWSER_CHANGE_TO_LISTVIEW_BUTTON_LABEL);
   SET_STRING("CHANGE_TO_THUMBNAILVIEW_BUTTON_LABEL",
@@ -756,6 +758,12 @@ ExtensionFunction::ResponseAction FileManagerPrivateGetStringsFunction::Run() {
   SET_STRING("MEDIA_TITLE_COLUMN_LABEL",
              IDS_FILE_BROWSER_MEDIA_TITLE_COLUMN_LABEL);
   SET_STRING("RECENT_ROOT_LABEL", IDS_FILE_BROWSER_RECENT_ROOT_LABEL);
+  SET_STRING("SHARE_BEFORE_OPEN_CROSTINI_MULTIPLE",
+             IDS_FILE_BROWSER_SHARE_BEFORE_OPEN_CROSTINI_MULTIPLE);
+  SET_STRING("SHARE_BEFORE_OPEN_CROSTINI_SINGLE",
+             IDS_FILE_BROWSER_SHARE_BEFORE_OPEN_CROSTINI_SINGLE);
+  SET_STRING("SHARE_BEFORE_OPEN_CROSTINI_TITLE",
+             IDS_FILE_BROWSER_SHARE_BEFORE_OPEN_CROSTINI_TITLE);
   SET_STRING("SUGGEST_DIALOG_INSTALLATION_FAILED",
              IDS_FILE_BROWSER_SUGGEST_DIALOG_INSTALLATION_FAILED);
   SET_STRING("SUGGEST_DIALOG_LINK_TO_WEBSTORE",
