@@ -7,6 +7,7 @@
 #include <stddef.h>
 
 #include <map>
+#include <utility>
 
 #include "apps/launcher.h"
 #include "base/bind.h"
@@ -16,7 +17,6 @@
 #include "base/strings/stringprintf.h"
 #include "chrome/browser/chromeos/crostini/crostini_util.h"
 #include "chrome/browser/chromeos/drive/file_system_util.h"
-#include "chrome/browser/chromeos/drive/file_task_executor.h"
 #include "chrome/browser/chromeos/file_manager/app_id.h"
 #include "chrome/browser/chromeos/file_manager/arc_file_tasks.h"
 #include "chrome/browser/chromeos/file_manager/crostini_file_tasks.h"
@@ -33,7 +33,6 @@
 #include "chrome/common/pref_names.h"
 #include "chromeos/chromeos_switches.h"
 #include "components/drive/drive_api_util.h"
-#include "components/drive/drive_app_registry.h"
 #include "components/prefs/pref_service.h"
 #include "components/prefs/scoped_user_pref_update.h"
 #include "extensions/browser/api/file_handlers/mime_util.h"
@@ -61,13 +60,9 @@ namespace {
 // these are used in default task IDs stored in preferences.
 const char kFileBrowserHandlerTaskType[] = "file";
 const char kFileHandlerTaskType[] = "app";
-const char kDriveAppTaskType[] = "drive";
 const char kArcAppTaskType[] = "arc";
 const char kCrostiniAppTaskType[] = "crostini";
 
-// Drive apps always use the action ID.
-const char kDriveAppActionID[] = "open-with";
-
 // Converts a TaskType to a string.
 std::string TaskTypeToString(TaskType task_type) {
   switch (task_type) {
@@ -75,13 +70,12 @@ std::string TaskTypeToString(TaskType task_type) {
       return kFileBrowserHandlerTaskType;
     case TASK_TYPE_FILE_HANDLER:
       return kFileHandlerTaskType;
-    case TASK_TYPE_DRIVE_APP:
-      return kDriveAppTaskType;
     case TASK_TYPE_ARC_APP:
       return kArcAppTaskType;
     case TASK_TYPE_CROSTINI_APP:
       return kCrostiniAppTaskType;
     case TASK_TYPE_UNKNOWN:
+    case DEPRECATED_TASK_TYPE_DRIVE_APP:
     case NUM_TASK_TYPE:
       break;
   }
@@ -95,8 +89,6 @@ TaskType StringToTaskType(const std::string& str) {
     return TASK_TYPE_FILE_BROWSER_HANDLER;
   if (str == kFileHandlerTaskType)
     return TASK_TYPE_FILE_HANDLER;
-  if (str == kDriveAppTaskType)
-    return TASK_TYPE_DRIVE_APP;
   if (str == kArcAppTaskType)
     return TASK_TYPE_ARC_APP;
   if (str == kCrostiniAppTaskType)
@@ -104,11 +96,6 @@ TaskType StringToTaskType(const std::string& str) {
   return TASK_TYPE_UNKNOWN;
 }
 
-// Legacy Drive task extension prefix, used by CrackTaskID.
-const char kDriveTaskExtensionPrefix[] = "drive-app:";
-const size_t kDriveTaskExtensionPrefixLength =
-    arraysize(kDriveTaskExtensionPrefix) - 1;
-
 // Returns true if path_mime_set contains a Google document.
 bool ContainsGoogleDocument(const std::vector<extensions::EntryInfo>& entries) {
   for (const auto& it : entries) {
@@ -174,22 +161,22 @@ void ExecuteByArcAfterMimeTypesCollected(
     Profile* profile,
     const TaskDescriptor& task,
     const std::vector<FileSystemURL>& file_urls,
-    const FileTaskFinishedCallback& done,
+    FileTaskFinishedCallback done,
     extensions::app_file_handler_util::MimeTypeCollector* mime_collector,
     std::unique_ptr<std::vector<std::string>> mime_types) {
-  ExecuteArcTask(profile, task, file_urls, *mime_types, done);
+  ExecuteArcTask(profile, task, file_urls, *mime_types, std::move(done));
 }
 
 void PostProcessFoundTasks(
     Profile* profile,
     const std::vector<extensions::EntryInfo>& entries,
-    const FindTasksCallback& callback,
+    FindTasksCallback callback,
     std::unique_ptr<std::vector<FullTaskDescriptor>> result_list) {
   // Google documents can only be handled by internal handlers.
   if (ContainsGoogleDocument(entries))
     KeepOnlyFileManagerInternalTasks(result_list.get());
   ChooseAndSetDefaultTask(*profile->GetPrefs(), entries, result_list.get());
-  callback.Run(std::move(result_list));
+  std::move(callback).Run(std::move(result_list));
 }
 
 }  // namespace
@@ -292,19 +279,11 @@ bool ParseTaskID(const std::string& task_id, TaskDescriptor* task) {
   std::vector<std::string> result = base::SplitString(
       task_id, "|", base::KEEP_WHITESPACE, base::SPLIT_WANT_NONEMPTY);
 
-  // Parse a legacy task ID that only contain two parts. Drive tasks are
-  // identified by a prefix "drive-app:" on the extension ID. The legacy task
-  // IDs can be stored in preferences.
+  // Parse a legacy task ID that only contain two parts. The legacy task IDs
+  // can be stored in preferences.
   if (result.size() == 2) {
-    if (base::StartsWith(result[0], kDriveTaskExtensionPrefix,
-                         base::CompareCase::SENSITIVE)) {
-      task->task_type = TASK_TYPE_DRIVE_APP;
-      task->app_id = result[0].substr(kDriveTaskExtensionPrefixLength);
-    } else {
-      task->task_type = TASK_TYPE_FILE_BROWSER_HANDLER;
-      task->app_id = result[0];
-    }
-
+    task->task_type = TASK_TYPE_FILE_BROWSER_HANDLER;
+    task->app_id = result[0];
     task->action_id = result[1];
 
     return true;
@@ -328,7 +307,7 @@ bool ExecuteFileTask(Profile* profile,
                      const GURL& source_url,
                      const TaskDescriptor& task,
                      const std::vector<FileSystemURL>& file_urls,
-                     const FileTaskFinishedCallback& done) {
+                     FileTaskFinishedCallback done) {
   UMA_HISTOGRAM_ENUMERATION("FileBrowser.ViewingTaskType", task.task_type,
                             NUM_TASK_TYPE);
 
@@ -337,24 +316,15 @@ bool ExecuteFileTask(Profile* profile,
     extensions::app_file_handler_util::MimeTypeCollector* mime_collector =
         new extensions::app_file_handler_util::MimeTypeCollector(profile);
     mime_collector->CollectForURLs(
-        file_urls,
-        base::Bind(&ExecuteByArcAfterMimeTypesCollected, profile, task,
-                   file_urls, done, base::Owned(mime_collector)));
+        file_urls, base::Bind(&ExecuteByArcAfterMimeTypesCollected, profile,
+                              task, file_urls, base::Passed(std::move(done)),
+                              base::Owned(mime_collector)));
     return true;
   }
 
   if (task.task_type == TASK_TYPE_CROSTINI_APP) {
     DCHECK_EQ(kCrostiniAppActionID, task.action_id);
-    ExecuteCrostiniTask(profile, task, file_urls, done);
-    return true;
-  }
-
-  // drive::FileTaskExecutor is responsible to handle drive tasks.
-  if (task.task_type == TASK_TYPE_DRIVE_APP) {
-    DCHECK_EQ(kDriveAppActionID, task.action_id);
-    drive::FileTaskExecutor* executor =
-        new drive::FileTaskExecutor(profile, task.app_id);
-    executor->Execute(file_urls, done);
+    ExecuteCrostiniTask(profile, task, file_urls, std::move(done));
     return true;
   }
 
@@ -370,7 +340,8 @@ bool ExecuteFileTask(Profile* profile,
   // Execute the task.
   if (task.task_type == TASK_TYPE_FILE_BROWSER_HANDLER) {
     return file_browser_handlers::ExecuteFileBrowserHandler(
-        extension_task_profile, extension, task.action_id, file_urls, done);
+        extension_task_profile, extension, task.action_id, file_urls,
+        std::move(done));
   } else if (task.task_type == TASK_TYPE_FILE_HANDLER) {
     std::vector<base::FilePath> paths;
     for (size_t i = 0; i != file_urls.size(); ++i)
@@ -378,75 +349,14 @@ bool ExecuteFileTask(Profile* profile,
     apps::LaunchPlatformAppWithFileHandler(extension_task_profile, extension,
                                            task.action_id, paths);
     if (!done.is_null())
-      done.Run(extensions::api::file_manager_private::TASK_RESULT_MESSAGE_SENT);
+      std::move(done).Run(
+          extensions::api::file_manager_private::TASK_RESULT_MESSAGE_SENT);
     return true;
   }
   NOTREACHED();
   return false;
 }
 
-void FindDriveAppTasks(const drive::DriveAppRegistry& drive_app_registry,
-                       const std::vector<extensions::EntryInfo>& entries,
-                       std::vector<FullTaskDescriptor>* result_list) {
-  DCHECK(result_list);
-
-  bool is_first = true;
-  typedef std::map<std::string, drive::DriveAppInfo> DriveAppInfoMap;
-  DriveAppInfoMap drive_app_map;
-
-  for (std::vector<extensions::EntryInfo>::const_iterator it = entries.begin();
-       it != entries.end(); ++it) {
-    const base::FilePath& file_path = it->path;
-    const std::string& mime_type = it->mime_type;
-    // Return immediately if a file not on Drive is found, as Drive app tasks
-    // work only if all files are on Drive.
-    if (!drive::util::IsUnderDriveMountPoint(file_path))
-      return;
-
-    std::vector<drive::DriveAppInfo> app_info_list;
-    drive_app_registry.GetAppsForFile(file_path.Extension(),
-                                      mime_type,
-                                      &app_info_list);
-
-    if (is_first) {
-      // For the first file, we store all the info.
-      for (size_t j = 0; j < app_info_list.size(); ++j)
-        drive_app_map[app_info_list[j].app_id] = app_info_list[j];
-    } else {
-      // For remaining files, take the intersection with the current
-      // result, based on the app id.
-      std::set<std::string> app_id_set;
-      for (size_t j = 0; j < app_info_list.size(); ++j)
-        app_id_set.insert(app_info_list[j].app_id);
-      for (DriveAppInfoMap::iterator iter = drive_app_map.begin();
-           iter != drive_app_map.end();) {
-        if (app_id_set.count(iter->first) == 0) {
-          drive_app_map.erase(iter++);
-        } else {
-          ++iter;
-        }
-      }
-    }
-
-    is_first = false;
-  }
-
-  for (DriveAppInfoMap::const_iterator iter = drive_app_map.begin();
-       iter != drive_app_map.end(); ++iter) {
-    const drive::DriveAppInfo& app_info = iter->second;
-    TaskDescriptor descriptor(app_info.app_id,
-                              TASK_TYPE_DRIVE_APP,
-                              kDriveAppActionID);
-    GURL icon_url = drive::util::FindPreferredIcon(
-        app_info.app_icons,
-        drive::util::kPreferredIconSize);
-
-    result_list->push_back(FullTaskDescriptor(
-        descriptor, app_info.app_name, Verb::VERB_OPEN_WITH, icon_url,
-        false /* is_default */, false /* is_generic_file_handler */));
-  }
-}
-
 bool IsGoodMatchFileHandler(
     const extensions::FileHandlerInfo& file_handler_info,
     const std::vector<extensions::EntryInfo>& entries) {
@@ -502,14 +412,6 @@ void FindFileHandlerTasks(Profile* profile,
     if (file_handlers.empty())
       continue;
 
-    // If the new ZIP unpacker is disabled, then hide its handlers, so we don't
-    // show both the legacy one and the new one in Files app for ZIP files.
-    if (extension->id() == extension_misc::kZIPUnpackerExtensionId &&
-        base::CommandLine::ForCurrentProcess()->HasSwitch(
-            chromeos::switches::kDisableNewZIPUnpacker)) {
-      continue;
-    }
-
     // A map which has as key a handler verb, and as value a pair of the
     // handler with which to open the given entries and a boolean marking
     // if the handler is a good match.
@@ -535,7 +437,7 @@ void FindFileHandlerTasks(Profile* profile,
           extension->id(), file_tasks::TASK_TYPE_FILE_HANDLER, handler->id);
 
       GURL best_icon = extensions::ExtensionIconSource::GetIconURL(
-          extension, drive::util::kPreferredIconSize,
+          extension, extension_misc::EXTENSION_ICON_SMALL,
           ExtensionIconSet::MATCH_BIGGER,
           false);  // grayscale
 
@@ -608,42 +510,38 @@ void FindExtensionAndAppTasks(
     Profile* profile,
     const std::vector<extensions::EntryInfo>& entries,
     const std::vector<GURL>& file_urls,
-    const FindTasksCallback& callback,
+    FindTasksCallback callback,
     std::unique_ptr<std::vector<FullTaskDescriptor>> result_list) {
   std::vector<FullTaskDescriptor>* result_list_ptr = result_list.get();
 
-  // 3. Continues from FindAllTypesOfTasks. Find and append file handler tasks.
+  // 2. Continues from FindAllTypesOfTasks. Find and append file handler tasks.
   FindFileHandlerTasks(profile, entries, result_list_ptr);
 
-  // 4. Find and append file browser handler tasks. We know there aren't
+  // 3. Find and append file browser handler tasks. We know there aren't
   // duplicates because "file_browser_handlers" and "file_handlers" shouldn't
   // be used in the same manifest.json.
   FindFileBrowserHandlerTasks(profile, file_urls, result_list_ptr);
 
-  // 5. Find and append Crostini tasks.
-  FindCrostiniTasks(profile, entries, result_list_ptr,
-                    // Done. Apply post-filtering and callback.
-                    base::BindOnce(PostProcessFoundTasks, profile, entries,
-                                   callback, std::move(result_list)));
+  // 4. Find and append Crostini tasks.
+  FindCrostiniTasks(
+      profile, entries, result_list_ptr,
+      // Done. Apply post-filtering and callback.
+      base::BindOnce(PostProcessFoundTasks, profile, entries,
+                     std::move(callback), std::move(result_list)));
 }
 
 void FindAllTypesOfTasks(Profile* profile,
-                         const drive::DriveAppRegistry* drive_app_registry,
                          const std::vector<extensions::EntryInfo>& entries,
                          const std::vector<GURL>& file_urls,
-                         const FindTasksCallback& callback) {
+                         FindTasksCallback callback) {
   DCHECK(profile);
   std::unique_ptr<std::vector<FullTaskDescriptor>> result_list(
       new std::vector<FullTaskDescriptor>);
 
-  // 1. Find Drive app tasks, if the drive app registry is present.
-  if (drive_app_registry)
-    FindDriveAppTasks(*drive_app_registry, entries, result_list.get());
-
-  // 2. Find and append ARC handler tasks.
+  // Find and append ARC handler tasks.
   FindArcTasks(profile, entries, file_urls, std::move(result_list),
-               base::Bind(&FindExtensionAndAppTasks, profile, entries,
-                          file_urls, callback));
+               base::BindOnce(&FindExtensionAndAppTasks, profile, entries,
+                              file_urls, std::move(callback)));
 }
 
 void ChooseAndSetDefaultTask(const PrefService& pref_service,
