@@ -106,7 +106,8 @@ class Volume : public base::SupportsWeakPtr<Volume> {
       const std::string& root_document_id);
   static std::unique_ptr<Volume> CreateForSshfsCrostini(
       const base::FilePath& crostini_path);
-  static std::unique_ptr<Volume> CreateForAndroidFiles();
+  static std::unique_ptr<Volume> CreateForAndroidFiles(
+      const base::FilePath& mount_path);
   static std::unique_ptr<Volume> CreateForTesting(
       const base::FilePath& path,
       VolumeType volume_type,
@@ -263,7 +264,7 @@ class VolumeManager : public KeyedService,
       chromeos::PowerManagerClient* power_manager_client,
       chromeos::disks::DiskMountManager* disk_mount_manager,
       chromeos::file_system_provider::Service* file_system_provider_service,
-      const GetMtpStorageInfoCallback& get_mtp_storage_info_callback);
+      GetMtpStorageInfoCallback get_mtp_storage_info_callback);
   ~VolumeManager() override;
 
   // Returns the instance corresponding to the |context|.
@@ -296,6 +297,9 @@ class VolumeManager : public KeyedService,
   // Removes specified sshfs crostini mount.
   void RemoveSshfsCrostiniVolume(const base::FilePath& sshfs_mount_path);
 
+  // Removes Downloads volume used for testing.
+  void RemoveDownloadsDirectoryForTesting();
+
   // For testing purpose, registers a native local file system pointing to
   // |path| with DOWNLOADS type, and adds its volume info.
   bool RegisterDownloadsDirectoryForTesting(const base::FilePath& path);
@@ -304,6 +308,14 @@ class VolumeManager : public KeyedService,
   // |path| with CROSTINI type, and adds its volume info.
   bool RegisterCrostiniDirectoryForTesting(const base::FilePath& path);
 
+  // For testing purpose, registers a native local file system pointing to
+  // |path| with ANDROID_FILES type, and adds its volume info.
+  bool RegisterAndroidFilesDirectoryForTesting(const base::FilePath& path);
+
+  // For testing purpose, removes a registered native local file system
+  // pointing to |path| with ANDROID_FILES type, and removes its volume info.
+  bool RemoveAndroidFilesDirectoryForTesting(const base::FilePath& path);
+
   // For testing purpose, adds a volume info pointing to |path|, with TESTING
   // type. Assumes that the mount point is already registered.
   void AddVolumeForTesting(const base::FilePath& path,
