@@ -6,14 +6,16 @@
 #define CHROME_BROWSER_CHROMEOS_FILE_SYSTEM_PROVIDER_NOTIFICATION_MANAGER_H_
 
 #include <map>
+#include <memory>
 #include <string>
 
 #include "base/callback.h"
 #include "base/macros.h"
-#include "base/memory/scoped_ptr.h"
+#include "base/memory/weak_ptr.h"
 #include "chrome/browser/chromeos/file_system_provider/notification_manager_interface.h"
 #include "chrome/browser/chromeos/file_system_provider/provided_file_system_info.h"
-#include "chrome/browser/extensions/app_icon_loader.h"
+#include "chrome/browser/ui/app_icon_loader.h"
+#include "ui/message_center/public/cpp/notification_delegate.h"
 
 class Profile;
 
@@ -22,10 +24,6 @@ class Image;
 class ImageSkia;
 }  // message gfx
 
-namespace message_center {
-class Notification;
-}  // namespace message_center
-
 namespace chromeos {
 namespace file_system_provider {
 
@@ -33,7 +31,8 @@ namespace file_system_provider {
 // up to one notification. If more than one request is unresponsive, then
 // all of them will be aborted when clicking on the notification button.
 class NotificationManager : public NotificationManagerInterface,
-                            public extensions::AppIconLoader::Delegate {
+                            public AppIconLoaderDelegate,
+                            public message_center::NotificationObserver {
  public:
   NotificationManager(Profile* profile,
                       const ProvidedFileSystemInfo& file_system_info);
@@ -45,20 +44,24 @@ class NotificationManager : public NotificationManagerInterface,
       const NotificationCallback& callback) override;
   void HideUnresponsiveNotification(int id) override;
 
-  // Invoked when a button on the notification is clicked.
-  void OnButtonClick(int button_index);
+  // AppIconLoaderDelegate overrides:
+  void OnAppImageUpdated(const std::string& id,
+                         const gfx::ImageSkia& image) override;
 
-  // Invoked when the notification got closed either by user or by system.
-  void OnClose();
-
-  // extensions::AppIconLoader::Delegate overrides:
-  void SetAppImage(const std::string& id, const gfx::ImageSkia& image) override;
+  // message_center::NotificationObserver overrides:
+  void Click(const base::Optional<int>& button_index,
+             const base::Optional<base::string16>& reply) override;
+  void Close(bool by_user) override;
 
  private:
   typedef std::map<int, NotificationCallback> CallbackMap;
 
-  // Creates a notification object for the actual state of the manager.
-  scoped_ptr<message_center::Notification> CreateNotification();
+  std::string GetNotificationId();
+
+  // Creates and displays a notification object for the actual state of the
+  // manager. This will either add a new one or update the existing
+  // notification.
+  void ShowNotification();
 
   // Handles a notification result by calling all registered callbacks and
   // clearing the list.
@@ -67,8 +70,9 @@ class NotificationManager : public NotificationManagerInterface,
   Profile* profile_;
   ProvidedFileSystemInfo file_system_info_;
   CallbackMap callbacks_;
-  scoped_ptr<extensions::AppIconLoader> icon_loader_;
-  scoped_ptr<gfx::Image> extension_icon_;
+  std::unique_ptr<AppIconLoader> icon_loader_;
+  std::unique_ptr<gfx::Image> extension_icon_;
+  base::WeakPtrFactory<NotificationManager> weak_factory_;
 
   DISALLOW_COPY_AND_ASSIGN(NotificationManager);
 };
