@@ -38,7 +38,7 @@ class WriteFile : public Operation {
             scoped_refptr<net::IOBuffer> buffer,
             int64_t offset,
             int length,
-            const storage::AsyncFileUtil::StatusCallback& callback);
+            storage::AsyncFileUtil::StatusCallback callback);
   ~WriteFile() override;
 
   // Operation overrides.
@@ -55,7 +55,7 @@ class WriteFile : public Operation {
   scoped_refptr<net::IOBuffer> buffer_;
   int64_t offset_;
   int length_;
-  const storage::AsyncFileUtil::StatusCallback callback_;
+  storage::AsyncFileUtil::StatusCallback callback_;
 
   DISALLOW_COPY_AND_ASSIGN(WriteFile);
 };
