@@ -5,19 +5,25 @@
 #ifndef CHROME_BROWSER_CHROMEOS_FIRST_RUN_STEPS_APP_LIST_STEP_H_
 #define CHROME_BROWSER_CHROMEOS_FIRST_RUN_STEPS_APP_LIST_STEP_H_
 
-#include "base/compiler_specific.h"
+#include "base/macros.h"
 #include "chrome/browser/chromeos/first_run/step.h"
 
+namespace gfx {
+class Rect;
+}
+
 namespace chromeos {
 namespace first_run {
 
 class AppListStep : public Step {
  public:
-  AppListStep(ash::FirstRunHelper* shell_helper, FirstRunActor* actor);
+  AppListStep(FirstRunController* controller, FirstRunActor* actor);
 
  private:
-  // Overriden from Step.
-  virtual void DoShow() OVERRIDE;
+  // Step:
+  void DoShow() override;
+
+  void ShowWithButtonBounds(const gfx::Rect& screen_bounds);
 
   DISALLOW_COPY_AND_ASSIGN(AppListStep);
 };
