@@ -47,33 +47,32 @@ constexpr char kAdOfflineAuthId[] = "offline-ad-auth";
 
 constexpr char kTestActiveDirectoryUser[] = "test-user";
 constexpr char kTestUserRealm[] = "user.realm";
-constexpr char kAdMachineInput[] = "machineNameInput";
-constexpr char kAdMoreOptionsButton[] = "moreOptionsBtn";
-constexpr char kAdUserInput[] = "userInput";
-constexpr char kAdPasswordInput[] = "passwordInput";
-constexpr char kAdCredsButton[] = "adCreds /deep/ #button";
-constexpr char kAdPasswordChangeButton[] = "button";
-constexpr char kAdWelcomMessage[] = "welcomeMsg";
-constexpr char kAdAutocompleteRealm[] = "userInput /deep/ #domainLabel";
+constexpr char kAdMachineInput[] = "$.machineNameInput";
+constexpr char kAdMoreOptionsButton[] = "$.moreOptionsBtn";
+constexpr char kAdUserInput[] = "$.userInput";
+constexpr char kAdPasswordInput[] = "$.passwordInput";
+constexpr char kAdCredsButton[] = "$$('#nextButton')";
+constexpr char kAdPasswordChangeButton[] = "$.inputForm.$.button";
+constexpr char kAdAutocompleteRealm[] = "$.userInput.querySelector('span')";
 
-constexpr char kAdPasswordChangeId[] = "ad-password-change";
-constexpr char kAdAnimatedPages[] = "animatedPages";
-constexpr char kAdOldPasswordInput[] = "oldPassword";
-constexpr char kAdNewPassword1Input[] = "newPassword1";
-constexpr char kAdNewPassword2Input[] = "newPassword2";
+constexpr char kAdPasswordChangeId[] = "active-directory-password-change";
+constexpr char kAdAnimatedPages[] = "$.animatedPages";
+constexpr char kAdOldPasswordInput[] = "$.oldPassword";
+constexpr char kAdNewPassword1Input[] = "$.newPassword1";
+constexpr char kAdNewPassword2Input[] = "$.newPassword2";
 constexpr char kNewPassword[] = "new_password";
 constexpr char kDifferentNewPassword[] = "different_new_password";
 
-constexpr char kCloseButtonId[] = "closeButton";
+constexpr char kCloseButtonId[] = "$.navigation.$.closeButton";
 
 class ActiveDirectoryLoginTest : public LoginManagerTest {
  public:
   ActiveDirectoryLoginTest()
-      : LoginManagerTest(true),
+      : LoginManagerTest(true, true),
         // Using the same realm as supervised user domain. Should be treated as
         // normal realm.
         test_realm_(user_manager::kSupervisedUserDomain),
-        autocomplete_realm_(test_realm_) {}
+        test_user_(kTestActiveDirectoryUser + ("@" + test_realm_)) {}
 
   ~ActiveDirectoryLoginTest() override = default;
 
@@ -110,8 +109,7 @@ class ActiveDirectoryLoginTest : public LoginManagerTest {
 
   void MarkAsActiveDirectoryEnterprise() {
     StartupUtils::MarkOobeCompleted();
-    active_directory_test_helper::PrepareLogin(kTestActiveDirectoryUser +
-                                               ("@" + test_realm_));
+    active_directory_test_helper::PrepareLogin(test_user_);
   }
 
   void TriggerPasswordChangeScreen() {
@@ -120,14 +118,14 @@ class ActiveDirectoryLoginTest : public LoginManagerTest {
 
     fake_auth_policy_client()->set_auth_error(
         authpolicy::ERROR_PASSWORD_EXPIRED);
-    SubmitActiveDirectoryCredentials(kTestActiveDirectoryUser, kPassword);
+    SubmitActiveDirectoryCredentials(test_user_, kPassword);
     screen_waiter.Wait();
     TestAdPasswordChangeError(std::string());
   }
 
   void ClosePasswordChangeScreen() {
     js_checker().Evaluate(JSElement(kAdPasswordChangeId, kCloseButtonId) +
-                          ".fire('tap')");
+                          ".click()");
   }
 
   // Checks if Active Directory login is visible.
@@ -144,18 +142,13 @@ class ActiveDirectoryLoginTest : public LoginManagerTest {
     JSExpect("!" + JSElement(kAdOfflineAuthId, kAdUserInput) + ".hidden");
     JSExpect("!" + JSElement(kAdOfflineAuthId, kAdPasswordInput) + ".hidden");
 
-    const std::string innerText(".innerText");
-    // Checks if Active Directory welcome message contains realm.
-    EXPECT_EQ(l10n_util::GetStringFUTF8(IDS_AD_DOMAIN_AUTH_WELCOME_MESSAGE,
-                                        base::UTF8ToUTF16(test_realm_)),
-              js_checker().GetString(
-                  JSElement(kAdOfflineAuthId, kAdWelcomMessage) + innerText));
-
-    // Checks if realm is set to autocomplete username.
-    EXPECT_EQ(
-        "@" + autocomplete_realm_,
+    std::string autocomplete_domain_ui;
+    base::TrimString(
         js_checker().GetString(
-            JSElement(kAdOfflineAuthId, kAdAutocompleteRealm) + innerText));
+            JSElement(kAdOfflineAuthId, kAdAutocompleteRealm) + ".innerText"),
+        base::kWhitespaceASCII, &autocomplete_domain_ui);
+    // Checks if realm is set to autocomplete username.
+    EXPECT_EQ(autocomplete_realm_, autocomplete_domain_ui);
 
     // Checks if bottom bar is visible.
     JSExpect("!Oobe.getInstance().headerHidden");
@@ -175,22 +168,31 @@ class ActiveDirectoryLoginTest : public LoginManagerTest {
   // Checks if user input is marked as invalid.
   void TestUserError() {
     TestLoginVisible();
-    JSExpect(JSElement(kAdOfflineAuthId, kAdUserInput) + ".isInvalid");
+    JSExpect(JSElement(kAdOfflineAuthId, kAdUserInput) + ".invalid");
+  }
+
+  void SetUserInput(const std::string& value) {
+    js_checker().ExecuteAsync(JSElement(kAdOfflineAuthId, kAdUserInput) +
+                              ".value='" + value + "'");
+  }
+
+  void TestUserInput(const std::string& value) {
+    js_checker().ExpectEQ(JSElement(kAdOfflineAuthId, kAdUserInput) + ".value",
+                          value);
   }
 
   // Checks if password input is marked as invalid.
   void TestPasswordError() {
     TestLoginVisible();
-    JSExpect(JSElement(kAdOfflineAuthId, kAdPasswordInput) + ".isInvalid");
+    JSExpect(JSElement(kAdOfflineAuthId, kAdPasswordInput) + ".invalid");
   }
 
   // Checks that machine, password and user inputs are valid.
   void TestNoError() {
     TestLoginVisible();
-    JSExpect("!" + JSElement(kAdOfflineAuthId, kAdMachineInput) + ".isInvalid");
-    JSExpect("!" + JSElement(kAdOfflineAuthId, kAdUserInput) + ".isInvalid");
-    JSExpect("!" + JSElement(kAdOfflineAuthId, kAdPasswordInput) +
-             ".isInvalid");
+    JSExpect("!" + JSElement(kAdOfflineAuthId, kAdMachineInput) + ".invalid");
+    JSExpect("!" + JSElement(kAdOfflineAuthId, kAdUserInput) + ".invalid");
+    JSExpect("!" + JSElement(kAdOfflineAuthId, kAdPasswordInput) + ".invalid");
   }
 
   // Checks if autocomplete domain is visible for the user input.
@@ -226,7 +228,7 @@ class ActiveDirectoryLoginTest : public LoginManagerTest {
     js_checker().ExecuteAsync(JSElement(kAdOfflineAuthId, kAdPasswordInput) +
                               ".value='" + password + "'");
     js_checker().Evaluate(JSElement(kAdOfflineAuthId, kAdCredsButton) +
-                          ".fire('tap')");
+                          ".click()");
   }
 
   // Sets username and password for the Active Directory login and submits it.
@@ -244,8 +246,7 @@ class ActiveDirectoryLoginTest : public LoginManagerTest {
         JSElement(kAdPasswordChangeId, kAdNewPassword2Input) + ".value='" +
         new_password2 + "'");
     js_checker().Evaluate(
-        JSElement(kAdPasswordChangeId, kAdPasswordChangeButton) +
-        ".fire('tap')");
+        JSElement(kAdPasswordChangeId, kAdPasswordChangeButton) + ".click()");
   }
 
   void SetupActiveDirectoryJSNotifications() {
@@ -269,15 +270,15 @@ class ActiveDirectoryLoginTest : public LoginManagerTest {
   // Returns string representing element with id=|element_id| inside Active
   // Directory login element.
   std::string JSElement(const std::string& parent_id,
-                        const std::string& element_id) {
-    return "document.querySelector('#" + parent_id + " /deep/ #" + element_id +
-           "')";
+                        const std::string& selector) {
+    return "document.querySelector('#" + parent_id + "')." + selector;
   }
   FakeAuthPolicyClient* fake_auth_policy_client() {
     return fake_auth_policy_client_;
   }
 
   const std::string test_realm_;
+  const std::string test_user_;
   std::string autocomplete_realm_;
 
  private:
@@ -296,7 +297,7 @@ class ActiveDirectoryLoginAutocompleteTest : public ActiveDirectoryLoginTest {
     device_settings.mutable_login_screen_domain_auto_complete()
         ->set_login_screen_domain_auto_complete(kTestUserRealm);
     fake_auth_policy_client()->set_device_policy(device_settings);
-    autocomplete_realm_ = kTestUserRealm;
+    autocomplete_realm_ = "@" + std::string(kTestUserRealm);
   }
 
  private:
@@ -316,12 +317,12 @@ class ActiveDirectoryLoginAutocompleteTest : public ActiveDirectoryLoginTest {
 // Test successful Active Directory login.
 IN_PROC_BROWSER_TEST_F_WITH_PRE(ActiveDirectoryLoginTest, LoginSuccess) {
   TestNoError();
-  TestDomainVisible();
+  TestDomainHidden();
 
   content::WindowedNotificationObserver session_start_waiter(
       chrome::NOTIFICATION_SESSION_STARTED,
       content::NotificationService::AllSources());
-  SubmitActiveDirectoryCredentials(kTestActiveDirectoryUser, kPassword);
+  SubmitActiveDirectoryCredentials(test_user_, kPassword);
   session_start_waiter.Wait();
 }
 
@@ -329,49 +330,49 @@ IN_PROC_BROWSER_TEST_F_WITH_PRE(ActiveDirectoryLoginTest, LoginSuccess) {
 IN_PROC_BROWSER_TEST_F_WITH_PRE(ActiveDirectoryLoginTest, LoginErrors) {
   SetupActiveDirectoryJSNotifications();
   TestNoError();
-  TestDomainVisible();
+  TestDomainHidden();
 
   content::DOMMessageQueue message_queue;
 
   SubmitActiveDirectoryCredentials("", "");
   TestUserError();
-  TestDomainVisible();
+  TestDomainHidden();
 
-  SubmitActiveDirectoryCredentials(kTestActiveDirectoryUser, "");
+  SubmitActiveDirectoryCredentials(test_user_, "");
   TestPasswordError();
-  TestDomainVisible();
+  TestDomainHidden();
 
   SubmitActiveDirectoryCredentials(std::string(kTestActiveDirectoryUser) + "@",
                                    kPassword);
+  WaitForMessage(&message_queue, "\"ShowAuthError\"");
   TestUserError();
   TestDomainHidden();
 
   fake_auth_policy_client()->set_auth_error(authpolicy::ERROR_BAD_USER_NAME);
-  SubmitActiveDirectoryCredentials(
-      std::string(kTestActiveDirectoryUser) + "@" + test_realm_, kPassword);
+  SubmitActiveDirectoryCredentials(test_user_, kPassword);
   WaitForMessage(&message_queue, "\"ShowAuthError\"");
   TestUserError();
-  TestDomainVisible();
+  TestDomainHidden();
 
   fake_auth_policy_client()->set_auth_error(authpolicy::ERROR_BAD_PASSWORD);
-  SubmitActiveDirectoryCredentials(kTestActiveDirectoryUser, kPassword);
+  SubmitActiveDirectoryCredentials(test_user_, kPassword);
   WaitForMessage(&message_queue, "\"ShowAuthError\"");
   TestPasswordError();
-  TestDomainVisible();
+  TestDomainHidden();
 
   fake_auth_policy_client()->set_auth_error(authpolicy::ERROR_UNKNOWN);
-  SubmitActiveDirectoryCredentials(kTestActiveDirectoryUser, kPassword);
+  SubmitActiveDirectoryCredentials(test_user_, kPassword);
   WaitForMessage(&message_queue, "\"ShowAuthError\"");
   // Inputs are not invalidated for the unknown error.
   TestNoError();
-  TestDomainVisible();
+  TestDomainHidden();
 }
 
 // Test successful Active Directory login from the password change screen.
 IN_PROC_BROWSER_TEST_F_WITH_PRE(ActiveDirectoryLoginTest,
                                 PasswordChange_LoginSuccess) {
   TestLoginVisible();
-  TestDomainVisible();
+  TestDomainHidden();
 
   TriggerPasswordChangeScreen();
 
@@ -389,7 +390,7 @@ IN_PROC_BROWSER_TEST_F_WITH_PRE(ActiveDirectoryLoginTest,
 IN_PROC_BROWSER_TEST_F_WITH_PRE(ActiveDirectoryLoginTest,
                                 PasswordChange_UIErrors) {
   TestLoginVisible();
-  TestDomainVisible();
+  TestDomainHidden();
 
   TriggerPasswordChangeScreen();
   // Password rejected by UX.
@@ -421,7 +422,7 @@ IN_PROC_BROWSER_TEST_F_WITH_PRE(ActiveDirectoryLoginTest,
 IN_PROC_BROWSER_TEST_F_WITH_PRE(ActiveDirectoryLoginTest,
                                 PasswordChange_ReopenClearErrors) {
   TestLoginVisible();
-  TestDomainVisible();
+  TestDomainHidden();
 
   TriggerPasswordChangeScreen();
 
@@ -434,12 +435,50 @@ IN_PROC_BROWSER_TEST_F_WITH_PRE(ActiveDirectoryLoginTest,
   TriggerPasswordChangeScreen();
 }
 
-// Tests that DeviceLoginScreenDomainAutoComplete policy overrides device realm
-// for user autocomplete.
+// Tests that autocomplete works. Submits username without domain.
+IN_PROC_BROWSER_TEST_F_WITH_PRE(ActiveDirectoryLoginAutocompleteTest,
+                                LoginSuccess) {
+  TestNoError();
+  TestDomainVisible();
+
+  content::WindowedNotificationObserver session_start_waiter(
+      chrome::NOTIFICATION_SESSION_STARTED,
+      content::NotificationService::AllSources());
+  SubmitActiveDirectoryCredentials(kTestActiveDirectoryUser, kPassword);
+  session_start_waiter.Wait();
+}
+
+// Tests that user could override autocomplete domain.
 IN_PROC_BROWSER_TEST_F_WITH_PRE(ActiveDirectoryLoginAutocompleteTest,
                                 TestAutocomplete) {
+  SetupActiveDirectoryJSNotifications();
+
   TestLoginVisible();
   TestDomainVisible();
+  fake_auth_policy_client()->set_auth_error(authpolicy::ERROR_BAD_PASSWORD);
+  content::DOMMessageQueue message_queue;
+
+  // Submit with a different domain.
+  SetUserInput(test_user_);
+  TestDomainHidden();
+  TestUserInput(test_user_);
+  SubmitActiveDirectoryCredentials(test_user_, "password");
+  WaitForMessage(&message_queue, "\"ShowAuthError\"");
+  TestLoginVisible();
+  TestDomainHidden();
+  TestUserInput(test_user_);
+
+  // Set userinput with the autocomplete domain. JS will remove the autocomplete
+  // domain.
+  SetUserInput(kTestActiveDirectoryUser + autocomplete_realm_);
+  TestDomainVisible();
+  TestUserInput(kTestActiveDirectoryUser);
+  SubmitActiveDirectoryCredentials(
+      kTestActiveDirectoryUser + autocomplete_realm_, "password");
+  WaitForMessage(&message_queue, "\"ShowAuthError\"");
+  TestLoginVisible();
+  TestDomainVisible();
+  TestUserInput(kTestActiveDirectoryUser);
 }
 
 #undef IN_PROC_BROWSER_TEST_F_WITH_PRE
