@@ -14,12 +14,17 @@
 #include "base/files/file_path.h"
 #include "base/macros.h"
 #include "base/optional.h"
+#include "chrome/browser/browser_process.h"
+#include "chrome/browser/browser_process_platform_part.h"
+#include "chrome/browser/component_updater/fake_cros_component_manager.h"
+#include "chrome/test/base/browser_process_platform_part_test_api_chromeos.h"
 #include "chromeos/dbus/dbus_thread_manager.h"
-#include "chromeos/dbus/fake_image_loader_client.h"
 #include "components/session_manager/core/session_manager.h"
 #include "content/public/test/test_browser_thread_bundle.h"
 #include "testing/gtest/include/gtest/gtest.h"
 
+using component_updater::FakeCrOSComponentManager;
+
 namespace chromeos {
 
 namespace {
@@ -36,110 +41,65 @@ void SetBoolean(bool* value) {
   *value = true;
 }
 
-class TestImageLoaderClient : public FakeImageLoaderClient {
- public:
-  TestImageLoaderClient() = default;
-  ~TestImageLoaderClient() override = default;
-
-  const std::list<std::string>& pending_loads() const { return pending_loads_; }
-
-  // FakeImageLoaderClient:
-  void LoadComponentAtPath(
-      const std::string& name,
-      const base::FilePath& path,
-      DBusMethodCallback<base::FilePath> callback) override {
-    ASSERT_FALSE(path.empty());
-
-    components_[name].source = path;
-    components_[name].load_callbacks.emplace_back(std::move(callback));
-    pending_loads_.push_back(name);
-  }
-
-  bool FinishComponentLoad(const std::string& component_name,
-                           const base::FilePath& mount_point) {
-    if (pending_loads_.empty() || pending_loads_.front() != component_name)
-      return false;
-    pending_loads_.pop_front();
-
-    components_[component_name].loaded = true;
-    RunPendingLoadCallback(component_name, mount_point);
-    return true;
-  }
-
-  bool FailComponentLoad(const std::string& component_name) {
-    if (pending_loads_.empty() || pending_loads_.front() != component_name)
-      return false;
-    pending_loads_.pop_front();
-    RunPendingLoadCallback(component_name, base::nullopt);
-    return true;
-  }
-
-  bool ComponentLoadedFromPath(const std::string& name,
-                               const base::FilePath& file_path) const {
-    const auto& component = components_.find(name);
-    if (component == components_.end())
-      return false;
-    return component->second.loaded && component->second.source == file_path;
-  }
-
- private:
-  struct ComponentInfo {
-    ComponentInfo() = default;
-    ~ComponentInfo() = default;
-
-    base::FilePath source;
-    bool loaded = false;
-    std::list<DBusMethodCallback<base::FilePath>> load_callbacks;
-  };
-
-  void RunPendingLoadCallback(const std::string& component_name,
-                              base::Optional<base::FilePath> mount_point) {
-    DBusMethodCallback<base::FilePath> callback =
-        std::move(components_[component_name].load_callbacks.front());
-    components_[component_name].load_callbacks.pop_front();
-
-    std::move(callback).Run(std::move(mount_point));
-  }
-
-  // Map containing known components.
-  std::map<std::string, ComponentInfo> components_;
-
-  // List of components whose load has been requested.
-  std::list<std::string> pending_loads_;
-
-  DISALLOW_COPY_AND_ASSIGN(TestImageLoaderClient);
-};
-
 }  // namespace
 
 class DemoSessionTest : public testing::Test {
  public:
-  DemoSessionTest() = default;
+  DemoSessionTest()
+      : browser_process_platform_part_test_api_(
+            g_browser_process->platform_part()) {}
   ~DemoSessionTest() override = default;
 
   void SetUp() override {
+    chromeos::DBusThreadManager::Initialize();
     DemoSession::SetDemoConfigForTesting(DemoSession::DemoModeConfig::kOnline);
-    auto image_loader_client = std::make_unique<TestImageLoaderClient>();
-    image_loader_client_ = image_loader_client.get();
-    chromeos::DBusThreadManager::GetSetterForTesting()->SetImageLoaderClient(
-        std::move(image_loader_client));
+    InitializeCrosComponentManager();
     session_manager_ = std::make_unique<session_manager::SessionManager>();
   }
 
   void TearDown() override {
     DemoSession::ShutDownIfInitialized();
     DemoSession::ResetDemoConfigForTesting();
-    image_loader_client_ = nullptr;
+
     chromeos::DBusThreadManager::Shutdown();
+
+    cros_component_manager_ = nullptr;
+    browser_process_platform_part_test_api_.ShutdownCrosComponentManager();
   }
 
  protected:
-  // Points to the image loader client passed to the test DBusTestManager.
-  TestImageLoaderClient* image_loader_client_ = nullptr;
+  bool FinishResourcesComponentLoad(const base::FilePath& mount_path) {
+    EXPECT_TRUE(
+        cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
+    EXPECT_FALSE(
+        cros_component_manager_->UpdateRequested(kOfflineResourcesComponent));
+
+    return cros_component_manager_->FinishLoadRequest(
+        kOfflineResourcesComponent,
+        FakeCrOSComponentManager::ComponentInfo(
+            component_updater::CrOSComponentManager::Error::NONE,
+            base::FilePath("/dev/null"), mount_path));
+  }
+
+  void InitializeCrosComponentManager() {
+    auto fake_cros_component_manager =
+        std::make_unique<FakeCrOSComponentManager>();
+    fake_cros_component_manager->set_queue_load_requests(true);
+    fake_cros_component_manager->set_supported_components(
+        {kOfflineResourcesComponent});
+    cros_component_manager_ = fake_cros_component_manager.get();
+
+    browser_process_platform_part_test_api_.InitializeCrosComponentManager(
+        std::move(fake_cros_component_manager));
+  }
+
+  FakeCrOSComponentManager* cros_component_manager_ = nullptr;
   content::TestBrowserThreadBundle thread_bundle_;
   std::unique_ptr<session_manager::SessionManager> session_manager_;
 
  private:
+  BrowserProcessPlatformPartTestApi browser_process_platform_part_test_api_;
+
   DISALLOW_COPY_AND_ASSIGN(DemoSessionTest);
 };
 
@@ -157,13 +117,10 @@ TEST_F(DemoSessionTest, StartInitiatesOfflineResourcesLoad) {
   ASSERT_TRUE(demo_session);
 
   EXPECT_FALSE(demo_session->offline_resources_loaded());
-  EXPECT_EQ(std::list<std::string>({kOfflineResourcesComponent}),
-            image_loader_client_->pending_loads());
 
   const base::FilePath component_mount_point =
       base::FilePath(kTestDemoModeResourcesMountPoint);
-  ASSERT_TRUE(image_loader_client_->FinishComponentLoad(
-      kOfflineResourcesComponent, component_mount_point));
+  ASSERT_TRUE(FinishResourcesComponentLoad(component_mount_point));
 
   EXPECT_TRUE(demo_session->offline_resources_loaded());
   EXPECT_EQ(component_mount_point.AppendASCII(kDemoAppsImageFile),
@@ -193,7 +150,8 @@ TEST_F(DemoSessionTest, StartForDemoDeviceNotInDemoMode) {
   EXPECT_FALSE(DemoSession::StartIfInDemoMode());
   EXPECT_FALSE(DemoSession::Get());
 
-  EXPECT_EQ(std::list<std::string>(), image_loader_client_->pending_loads());
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 }
 
 TEST_F(DemoSessionTest, StartIfInOfflineEnrolledDemoMode) {
@@ -207,8 +165,8 @@ TEST_F(DemoSessionTest, StartIfInOfflineEnrolledDemoMode) {
   EXPECT_EQ(demo_session, DemoSession::Get());
 
   EXPECT_FALSE(demo_session->offline_resources_loaded());
-  EXPECT_EQ(std::list<std::string>({kOfflineResourcesComponent}),
-            image_loader_client_->pending_loads());
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 }
 
 TEST_F(DemoSessionTest, PreloadOfflineResourcesIfInDemoMode) {
@@ -220,13 +178,12 @@ TEST_F(DemoSessionTest, PreloadOfflineResourcesIfInDemoMode) {
   EXPECT_FALSE(demo_session->offline_enrolled());
 
   EXPECT_FALSE(demo_session->offline_resources_loaded());
-  EXPECT_EQ(std::list<std::string>({kOfflineResourcesComponent}),
-            image_loader_client_->pending_loads());
 
   const base::FilePath component_mount_point =
       base::FilePath(kTestDemoModeResourcesMountPoint);
-  ASSERT_TRUE(image_loader_client_->FinishComponentLoad(
-      kOfflineResourcesComponent, component_mount_point));
+  ASSERT_TRUE(FinishResourcesComponentLoad(component_mount_point));
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 
   EXPECT_FALSE(demo_session->started());
   EXPECT_TRUE(demo_session->offline_resources_loaded());
@@ -240,7 +197,8 @@ TEST_F(DemoSessionTest, PreloadOfflineResourcesIfNotInDemoMode) {
   DemoSession::SetDemoConfigForTesting(DemoSession::DemoModeConfig::kNone);
   DemoSession::PreloadOfflineResourcesIfInDemoMode();
   EXPECT_FALSE(DemoSession::Get());
-  EXPECT_EQ(std::list<std::string>(), image_loader_client_->pending_loads());
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 }
 
 TEST_F(DemoSessionTest, PreloadOfflineResourcesIfInOfflineDemoMode) {
@@ -253,8 +211,8 @@ TEST_F(DemoSessionTest, PreloadOfflineResourcesIfInOfflineDemoMode) {
   EXPECT_TRUE(demo_session->offline_enrolled());
 
   EXPECT_FALSE(demo_session->offline_resources_loaded());
-  EXPECT_EQ(std::list<std::string>({kOfflineResourcesComponent}),
-            image_loader_client_->pending_loads());
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 }
 
 TEST_F(DemoSessionTest, ShutdownResetsInstance) {
@@ -279,13 +237,12 @@ TEST_F(DemoSessionTest, StartDemoSessionWhilePreloadingResources) {
   EXPECT_TRUE(demo_session->started());
 
   EXPECT_FALSE(demo_session->offline_resources_loaded());
-  EXPECT_EQ(std::list<std::string>({kOfflineResourcesComponent}),
-            image_loader_client_->pending_loads());
 
   const base::FilePath component_mount_point =
       base::FilePath(kTestDemoModeResourcesMountPoint);
-  ASSERT_TRUE(image_loader_client_->FinishComponentLoad(
-      kOfflineResourcesComponent, component_mount_point));
+  ASSERT_TRUE(FinishResourcesComponentLoad(component_mount_point));
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 
   EXPECT_TRUE(demo_session->started());
   EXPECT_TRUE(demo_session->offline_resources_loaded());
@@ -298,13 +255,11 @@ TEST_F(DemoSessionTest, StartDemoSessionWhilePreloadingResources) {
 TEST_F(DemoSessionTest, StartDemoSessionAfterPreloadingResources) {
   DemoSession::PreloadOfflineResourcesIfInDemoMode();
 
-  EXPECT_EQ(std::list<std::string>({kOfflineResourcesComponent}),
-            image_loader_client_->pending_loads());
-
   const base::FilePath component_mount_point =
       base::FilePath(kTestDemoModeResourcesMountPoint);
-  ASSERT_TRUE(image_loader_client_->FinishComponentLoad(
-      kOfflineResourcesComponent, component_mount_point));
+  ASSERT_TRUE(FinishResourcesComponentLoad(component_mount_point));
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 
   DemoSession* demo_session = DemoSession::StartIfInDemoMode();
   EXPECT_TRUE(demo_session->started());
@@ -314,7 +269,8 @@ TEST_F(DemoSessionTest, StartDemoSessionAfterPreloadingResources) {
   EXPECT_EQ(component_mount_point.AppendASCII(kExternalExtensionsPrefsFile),
             demo_session->GetExternalExtensionsPrefsPath());
 
-  EXPECT_EQ(std::list<std::string>(), image_loader_client_->pending_loads());
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 }
 
 TEST_F(DemoSessionTest, EnsureOfflineResourcesLoadedAfterStart) {
@@ -328,13 +284,11 @@ TEST_F(DemoSessionTest, EnsureOfflineResourcesLoadedAfterStart) {
   EXPECT_FALSE(callback_called);
   EXPECT_FALSE(demo_session->offline_resources_loaded());
 
-  EXPECT_EQ(std::list<std::string>({kOfflineResourcesComponent}),
-            image_loader_client_->pending_loads());
-
   const base::FilePath component_mount_point =
       base::FilePath(kTestDemoModeResourcesMountPoint);
-  ASSERT_TRUE(image_loader_client_->FinishComponentLoad(
-      kOfflineResourcesComponent, component_mount_point));
+  ASSERT_TRUE(FinishResourcesComponentLoad(component_mount_point));
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 
   EXPECT_TRUE(callback_called);
   EXPECT_TRUE(demo_session->offline_resources_loaded());
@@ -347,18 +301,18 @@ TEST_F(DemoSessionTest, EnsureOfflineResourcesLoadedAfterStart) {
 TEST_F(DemoSessionTest, EnsureOfflineResourcesLoadedAfterOfflineResourceLoad) {
   DemoSession* demo_session = DemoSession::StartIfInDemoMode();
   ASSERT_TRUE(demo_session);
-  EXPECT_EQ(std::list<std::string>({kOfflineResourcesComponent}),
-            image_loader_client_->pending_loads());
 
   const base::FilePath component_mount_point =
       base::FilePath(kTestDemoModeResourcesMountPoint);
-  ASSERT_TRUE(image_loader_client_->FinishComponentLoad(
-      kOfflineResourcesComponent, component_mount_point));
+  ASSERT_TRUE(FinishResourcesComponentLoad(component_mount_point));
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 
   bool callback_called = false;
   demo_session->EnsureOfflineResourcesLoaded(
       base::BindOnce(&SetBoolean, &callback_called));
-  EXPECT_EQ(std::list<std::string>(), image_loader_client_->pending_loads());
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 
   EXPECT_TRUE(callback_called);
   EXPECT_TRUE(demo_session->offline_resources_loaded());
@@ -381,13 +335,11 @@ TEST_F(DemoSessionTest, EnsureOfflineResourcesLoadedAfterPreload) {
   EXPECT_FALSE(callback_called);
   EXPECT_FALSE(demo_session->offline_resources_loaded());
 
-  EXPECT_EQ(std::list<std::string>({kOfflineResourcesComponent}),
-            image_loader_client_->pending_loads());
-
   const base::FilePath component_mount_point =
       base::FilePath(kTestDemoModeResourcesMountPoint);
-  ASSERT_TRUE(image_loader_client_->FinishComponentLoad(
-      kOfflineResourcesComponent, component_mount_point));
+  ASSERT_TRUE(FinishResourcesComponentLoad(component_mount_point));
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 
   EXPECT_TRUE(callback_called);
   EXPECT_TRUE(demo_session->offline_resources_loaded());
@@ -418,13 +370,11 @@ TEST_F(DemoSessionTest, MultipleEnsureOfflineResourcesLoaded) {
   EXPECT_FALSE(third_callback_called);
   EXPECT_FALSE(demo_session->offline_resources_loaded());
 
-  EXPECT_EQ(std::list<std::string>({kOfflineResourcesComponent}),
-            image_loader_client_->pending_loads());
-
   const base::FilePath component_mount_point =
       base::FilePath(kTestDemoModeResourcesMountPoint);
-  ASSERT_TRUE(image_loader_client_->FinishComponentLoad(
-      kOfflineResourcesComponent, component_mount_point));
+  ASSERT_TRUE(FinishResourcesComponentLoad(component_mount_point));
+  EXPECT_FALSE(
+      cros_component_manager_->HasPendingInstall(kOfflineResourcesComponent));
 
   EXPECT_TRUE(first_callback_called);
   EXPECT_TRUE(second_callback_called);
