@@ -24,6 +24,7 @@
 #include "chromeos/chromeos_switches.h"
 #include "chromeos/dbus/dbus_thread_manager.h"
 #include "components/policy/core/common/cloud/cloud_policy_constants.h"
+#include "components/policy/core/common/cloud/dm_auth.h"
 #include "google_apis/gaia/gaia_auth_consumer.h"
 #include "google_apis/gaia/gaia_auth_fetcher.h"
 #include "google_apis/gaia/gaia_constants.h"
@@ -113,18 +114,20 @@ void EnterpriseEnrollmentHelperImpl::EnrollUsingToken(
   DCHECK(oauth_status_ != OAUTH_STARTED_WITH_TOKEN);
   if (oauth_status_ == OAUTH_NOT_STARTED)
     oauth_status_ = OAUTH_STARTED_WITH_TOKEN;
-  DoEnroll(token);
+  DoEnroll(policy::DMAuth::FromOAuthToken(token));
 }
 
 void EnterpriseEnrollmentHelperImpl::EnrollUsingAttestation() {
   CHECK(enrollment_config_.is_mode_attestation());
-  DoEnroll("");  // The token is not used in attestation mode.
+  // The tokens are not used in attestation mode.
+  DoEnroll(policy::DMAuth::NoAuth());
 }
 
 void EnterpriseEnrollmentHelperImpl::EnrollForOfflineDemo() {
   CHECK_EQ(enrollment_config_.mode,
            policy::EnrollmentConfig::MODE_OFFLINE_DEMO);
-  DoEnroll("");  // The token is not used in offline demo mode.
+  // The tokens are not used in offline demo mode.
+  DoEnroll(policy::DMAuth::NoAuth());
 }
 
 void EnterpriseEnrollmentHelperImpl::ClearAuth(const base::Closure& callback) {
@@ -142,12 +145,12 @@ void EnterpriseEnrollmentHelperImpl::ClearAuth(const base::Closure& callback) {
         (new TokenRevoker())->Start(oauth_fetcher_->OAuth2RefreshToken());
 
       oauth_fetcher_.reset();
-    } else if (oauth_token_.length()) {
+    } else if (auth_data_ && auth_data_->has_oauth_token()) {
       // EnrollUsingToken was called.
-      (new TokenRevoker())->Start(oauth_token_);
+      (new TokenRevoker())->Start(auth_data_->oauth_token());
     }
   }
-
+  auth_data_.reset();
   chromeos::ProfileHelper::Get()->ClearSigninProfile(
       base::Bind(&EnterpriseEnrollmentHelperImpl::OnSigninProfileCleared,
                  weak_ptr_factory_.GetWeakPtr(), callback));
@@ -165,14 +168,16 @@ bool EnterpriseEnrollmentHelperImpl::ShouldCheckLicenseType() const {
       switches::kEnterpriseDisableLicenseTypeSelection);
 }
 
-void EnterpriseEnrollmentHelperImpl::DoEnroll(const std::string& token) {
-  DCHECK(token == oauth_token_ || oauth_token_.empty());
+void EnterpriseEnrollmentHelperImpl::DoEnroll(
+    std::unique_ptr<policy::DMAuth> auth_data) {
+  CHECK(auth_data);
+  DCHECK(!auth_data_ || auth_data_->Equals(*auth_data));
   DCHECK(enrollment_config_.is_mode_attestation() ||
          enrollment_config_.mode ==
              policy::EnrollmentConfig::MODE_OFFLINE_DEMO ||
          oauth_status_ == OAUTH_STARTED_WITH_AUTH_CODE ||
          oauth_status_ == OAUTH_STARTED_WITH_TOKEN);
-  oauth_token_ = token;
+  auth_data_ = std::move(auth_data);
   policy::BrowserPolicyConnectorChromeOS* connector =
       g_browser_process->platform_part()->browser_policy_connector_chromeos();
   // Re-enrollment is not implemented for Active Directory.
@@ -193,7 +198,7 @@ void EnterpriseEnrollmentHelperImpl::DoEnroll(const std::string& token) {
   CHECK(dcp_initializer);
   dcp_initializer->PrepareEnrollment(
       connector->device_management_service(), ad_join_delegate_,
-      enrollment_config_, token,
+      enrollment_config_, auth_data_->Clone(),
       base::Bind(&EnterpriseEnrollmentHelperImpl::OnEnrollmentFinished,
                  weak_ptr_factory_.GetWeakPtr()));
   if (ShouldCheckLicenseType()) {
@@ -217,6 +222,7 @@ void EnterpriseEnrollmentHelperImpl::UseLicenseType(policy::LicenseType type) {
 }
 
 void EnterpriseEnrollmentHelperImpl::GetDeviceAttributeUpdatePermission() {
+  DCHECK(auth_data_);
   policy::BrowserPolicyConnectorChromeOS* connector =
       g_browser_process->platform_part()->browser_policy_connector_chromeos();
   // Don't update device attributes for Active Directory management.
@@ -229,7 +235,7 @@ void EnterpriseEnrollmentHelperImpl::GetDeviceAttributeUpdatePermission() {
   policy::CloudPolicyClient* client = policy_manager->core()->client();
 
   client->GetDeviceAttributeUpdatePermission(
-      oauth_token_,
+      auth_data_->Clone(),
       base::Bind(
           &EnterpriseEnrollmentHelperImpl::OnDeviceAttributeUpdatePermission,
           weak_ptr_factory_.GetWeakPtr()));
@@ -238,6 +244,7 @@ void EnterpriseEnrollmentHelperImpl::GetDeviceAttributeUpdatePermission() {
 void EnterpriseEnrollmentHelperImpl::UpdateDeviceAttributes(
     const std::string& asset_id,
     const std::string& location) {
+  DCHECK(auth_data_);
   policy::BrowserPolicyConnectorChromeOS* connector =
       g_browser_process->platform_part()->browser_policy_connector_chromeos();
   policy::DeviceCloudPolicyManagerChromeOS* policy_manager =
@@ -245,7 +252,7 @@ void EnterpriseEnrollmentHelperImpl::UpdateDeviceAttributes(
   policy::CloudPolicyClient* client = policy_manager->core()->client();
 
   client->UpdateDeviceAttributes(
-      oauth_token_, asset_id, location,
+      auth_data_->Clone(), asset_id, location,
       base::Bind(
           &EnterpriseEnrollmentHelperImpl::OnDeviceAttributeUploadCompleted,
           weak_ptr_factory_.GetWeakPtr()));
