@@ -112,8 +112,6 @@ class WebUIScreenLocker : public WebUILoginView,
   void RenderProcessGone(base::TerminationStatus status) override;
 
   // display::DisplayObserver:
-  void OnDisplayAdded(const display::Display& new_display) override;
-  void OnDisplayRemoved(const display::Display& old_display) override;
   void OnDisplayMetricsChanged(const display::Display& display,
                                uint32_t changed_metrics) override;
 
