@@ -31,8 +31,9 @@ class OobeConfiguration {
   virtual ~OobeConfiguration();
 
   const base::Value& GetConfiguration() const;
+  bool CheckCompleted() const;
 
-  void AddObserver(Observer* observer);
+  void AddAndFireObserver(Observer* observer);
   void RemoveObserver(Observer* observer);
 
   void ResetConfiguration();
@@ -42,9 +43,14 @@ class OobeConfiguration {
   // initialized yet.
   static OobeConfiguration* Get();
 
+  static void set_skip_check_for_testing(bool value) {
+    skip_check_for_testing_ = value;
+  }
+
  private:
   void OnConfigurationCheck(bool has_configuration,
                             const std::string& configuration);
+  void NotifyObservers();
 
   // Pointer to the existing OobeConfiguration instance (if any).
   // Set in ctor, reset in dtor. Not owned since we need to control the lifetime
@@ -52,7 +58,16 @@ class OobeConfiguration {
   // Instance is owned by ChromeSessionManager
   static OobeConfiguration* instance;
 
-  // Non-null dictionary value with configuration
+  // Some tests might require setting some expectations before configuration is
+  // loaded. This field allows tests to skip actual configuration check in
+  // CheckConfiguration() call. Once all expectations are set, test should set
+  // this flag back to false and run CheckConfiguration() to proceed.
+  static bool skip_check_for_testing_;
+
+  // Tracks if configuration check is completed.
+  bool check_completed_;
+
+  // Non-null dictionary value with configuration.
   std::unique_ptr<base::Value> configuration_;
 
   // Observers
