@@ -5,7 +5,11 @@
 #include "chrome/browser/chromeos/login/screens/discover_screen.h"
 
 #include "base/logging.h"
+#include "chrome/browser/chromeos/login/quick_unlock/quick_unlock_utils.h"
 #include "chrome/browser/chromeos/login/screens/discover_screen_view.h"
+#include "chrome/browser/profiles/profile_manager.h"
+#include "chrome/browser/ui/ash/tablet_mode_client.h"
+#include "components/prefs/pref_service.h"
 
 namespace chromeos {
 
@@ -26,15 +30,25 @@ DiscoverScreen::~DiscoverScreen() {
 }
 
 void DiscoverScreen::Show() {
+  PrefService* prefs = ProfileManager::GetActiveUserProfile()->GetPrefs();
+  if (!TabletModeClient::Get()->tablet_mode_enabled() ||
+      !chromeos::quick_unlock::IsPinEnabled(prefs) ||
+      chromeos::quick_unlock::IsPinDisabledByPolicy(prefs)) {
+    Finish(ScreenExitCode::DISCOVER_FINISHED);
+    return;
+  }
   view_->Show();
+  is_shown_ = true;
 }
 
 void DiscoverScreen::Hide() {
   view_->Hide();
+  is_shown_ = false;
 }
 
 void DiscoverScreen::OnUserAction(const std::string& action_id) {
-  if (action_id == kFinished) {
+  // Only honor finish if discover is currently being shown.
+  if (action_id == kFinished && is_shown_) {
     Finish(ScreenExitCode::DISCOVER_FINISHED);
     return;
   }
