@@ -55,7 +55,12 @@ class OAuth2LoginManager : public KeyedService,
   enum SessionRestoreStrategy {
     // Generate OAuth2 refresh token from authentication profile's cookie jar.
     // Restore session from generated OAuth2 refresh token.
-    RESTORE_FROM_COOKIE_JAR,
+    //
+    // This value is no longer used as generating OAuth 2 refresh tokens from
+    // cookies is no longer supported.
+    // TODO(http://crbug.com/882838) Remove the entry
+    // DEPRECATED_RESTORE_FROM_COOKIE_JAR.
+    DEPRECATED_RESTORE_FROM_COOKIE_JAR,
     // Restore session from saved OAuth2 refresh token from TokenServices.
     RESTORE_FROM_SAVED_OAUTH2_REFRESH_TOKEN,
     // Restore session from OAuth2 refresh token passed via command line.
@@ -87,7 +92,7 @@ class OAuth2LoginManager : public KeyedService,
   // Restores and verifies OAuth tokens following specified |restore_strategy|.
   // For |restore_strategy| RESTORE_FROM_PASSED_OAUTH2_REFRESH_TOKEN, parameter
   // |oauth2_refresh_token| needs to have a non-empty value.
-  // For |restore_strategy| RESTORE_FROM_COOKIE_JAR.
+  // For |restore_strategy| DDEPRECATED_RESTORE_FROM_COOKIE_JAR.
   void RestoreSession(
       scoped_refptr<network::SharedURLLoaderFactory> auth_url_loader_factory,
       SessionRestoreStrategy restore_strategy,
@@ -185,10 +190,6 @@ class OAuth2LoginManager : public KeyedService,
   // Notify that the refresh tokens are loaded and ready to use.
   void FireRefreshTokensLoaded();
 
-  // Attempts to fetch OAuth2 tokens by using pre-authenticated cookie jar from
-  // provided |auth_profile|.
-  void FetchOAuth2Tokens();
-
   // Reports when all tokens are loaded.
   void ReportOAuth2TokensLoaded();
 
