@@ -5,13 +5,17 @@
 #ifndef CHROME_BROWSER_CHROMEOS_LOGIN_TEST_HTTPS_FORWARDER_H_
 #define CHROME_BROWSER_CHROMEOS_LOGIN_TEST_HTTPS_FORWARDER_H_
 
+#include <memory>
 #include <string>
 
 #include "base/compiler_specific.h"
 #include "base/macros.h"
-#include "base/memory/scoped_ptr.h"
 #include "url/gurl.h"
 
+namespace net {
+class ScopedTestRoot;
+}
+
 namespace chromeos {
 
 class ForwardingServer;
@@ -35,7 +39,8 @@ class HTTPSForwarder {
  private:
   std::string ssl_host_;
 
-  scoped_ptr<ForwardingServer> forwarding_server_;
+  std::unique_ptr<net::ScopedTestRoot> test_root_;
+  std::unique_ptr<ForwardingServer> forwarding_server_;
 
   DISALLOW_COPY_AND_ASSIGN(HTTPSForwarder);
 };
