@@ -9,8 +9,6 @@
 #include "chrome/browser/chromeos/login/ui/login_display.h"
 #include "testing/gmock/include/gmock/gmock.h"
 
-class AccountId;
-
 namespace chromeos {
 
 class MockLoginDisplay : public LoginDisplay {
@@ -28,8 +26,7 @@ class MockLoginDisplay : public LoginDisplay {
   MOCK_METHOD2(ShowPasswordChangedDialog, void(bool, const std::string&));
   MOCK_METHOD1(ShowSigninUI, void(const std::string&));
   MOCK_METHOD0(ShowWhitelistCheckFailedError, void(void));
-  MOCK_METHOD1(OnBeforeUserRemoved, void(const AccountId&));
-  MOCK_METHOD1(OnUserRemoved, void(const AccountId&));
+  MOCK_METHOD0(ShowUnrecoverableCrypthomeErrorDialog, void());
 
  private:
   DISALLOW_COPY_AND_ASSIGN(MockLoginDisplay);
