@@ -13,11 +13,11 @@
 #include "base/scoped_observer.h"
 #include "base/strings/string16.h"
 #include "chrome/browser/chromeos/login/screens/error_screen.h"
+#include "chrome/browser/ui/ash/chrome_keyboard_controller_client.h"
 #include "chrome/browser/ui/ash/tablet_mode_client_observer.h"
 #include "chrome/browser/ui/chrome_web_modal_dialog_manager_delegate.h"
 #include "components/web_modal/web_contents_modal_dialog_host.h"
 #include "ui/display/display_observer.h"
-#include "ui/keyboard/keyboard_controller_observer.h"
 #include "ui/web_dialogs/web_dialog_delegate.h"
 
 class TabletModeClient;
@@ -56,7 +56,7 @@ class CaptivePortalDialogDelegate;
 class OobeUIDialogDelegate : public display::DisplayObserver,
                              public TabletModeClientObserver,
                              public ui::WebDialogDelegate,
-                             public keyboard::KeyboardControllerObserver,
+                             public ChromeKeyboardControllerClient::Observer,
                              public CaptivePortalWindowProxy::Observer {
  public:
   explicit OobeUIDialogDelegate(base::WeakPtr<LoginDisplayHostMojo> controller);
@@ -114,8 +114,8 @@ class OobeUIDialogDelegate : public display::DisplayObserver,
   std::vector<ui::Accelerator> GetAccelerators() override;
   bool AcceleratorPressed(const ui::Accelerator& accelerator) override;
 
-  // keyboard::KeyboardControllerObserver:
-  void OnKeyboardVisibilityStateChanged(bool is_visible) override;
+  // ChromeKeyboardControllerClient::Observer:
+  void OnKeyboardVisibilityChanged(bool visible) override;
 
   // CaptivePortalWindowProxy::Observer:
   void OnBeforeCaptivePortalShown() override;
@@ -136,7 +136,8 @@ class OobeUIDialogDelegate : public display::DisplayObserver,
       this};
   ScopedObserver<TabletModeClient, TabletModeClientObserver>
       tablet_mode_observer_{this};
-  ScopedObserver<keyboard::KeyboardController, KeyboardControllerObserver>
+  ScopedObserver<ChromeKeyboardControllerClient,
+                 ChromeKeyboardControllerClient::Observer>
       keyboard_observer_{this};
   ScopedObserver<CaptivePortalWindowProxy, OobeUIDialogDelegate>
       captive_portal_observer_{this};
